package com.google.android.exoplayer2.extractor.mkv;

import android.util.Pair;
import android.util.SparseArray;
import androidx.annotation.CallSuper;
import androidx.annotation.Nullable;
import androidx.base.b2;
import androidx.base.bs;
import androidx.base.wk;
import androidx.exifinterface.media.ExifInterface;
import com.google.android.exoplayer2.C;
import com.google.android.exoplayer2.Format;
import com.google.android.exoplayer2.ParserException;
import com.google.android.exoplayer2.audio.AacUtil;
import com.google.android.exoplayer2.audio.Ac3Util;
import com.google.android.exoplayer2.drm.DrmInitData;
import com.google.android.exoplayer2.extractor.ChunkIndex;
import com.google.android.exoplayer2.extractor.Extractor;
import com.google.android.exoplayer2.extractor.ExtractorInput;
import com.google.android.exoplayer2.extractor.ExtractorOutput;
import com.google.android.exoplayer2.extractor.ExtractorsFactory;
import com.google.android.exoplayer2.extractor.PositionHolder;
import com.google.android.exoplayer2.extractor.SeekMap;
import com.google.android.exoplayer2.extractor.TrackOutput;
import com.google.android.exoplayer2.upstream.DataReader;
import com.google.android.exoplayer2.util.Assertions;
import com.google.android.exoplayer2.util.Log;
import com.google.android.exoplayer2.util.LongArray;
import com.google.android.exoplayer2.util.MimeTypes;
import com.google.android.exoplayer2.util.NalUnitUtil;
import com.google.android.exoplayer2.util.ParsableByteArray;
import com.google.android.exoplayer2.util.Util;
import com.google.android.exoplayer2.video.AvcConfig;
import com.google.android.exoplayer2.video.ColorInfo;
import com.google.android.exoplayer2.video.DolbyVisionConfig;
import com.google.android.exoplayer2.video.HevcConfig;
import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.UUID;
import org.checkerframework.checker.nullness.qual.EnsuresNonNull;
import org.checkerframework.checker.nullness.qual.RequiresNonNull;

public class MatroskaExtractor implements Extractor {
    private static final int BLOCK_ADDITIONAL_ID_VP9_ITU_T_35 = 4;
    private static final int BLOCK_ADD_ID_TYPE_DVCC = 1685480259;
    private static final int BLOCK_ADD_ID_TYPE_DVVC = 1685485123;
    private static final int BLOCK_STATE_DATA = 2;
    private static final int BLOCK_STATE_HEADER = 1;
    private static final int BLOCK_STATE_START = 0;
    private static final String CODEC_ID_AAC = "A_AAC";
    private static final String CODEC_ID_AC3 = "A_AC3";
    private static final String CODEC_ID_ACM = "A_MS/ACM";
    private static final String CODEC_ID_ASS = "S_TEXT/ASS";
    private static final String CODEC_ID_AV1 = "V_AV1";
    private static final String CODEC_ID_DTS = "A_DTS";
    private static final String CODEC_ID_DTS_EXPRESS = "A_DTS/EXPRESS";
    private static final String CODEC_ID_DTS_LOSSLESS = "A_DTS/LOSSLESS";
    private static final String CODEC_ID_DVBSUB = "S_DVBSUB";
    private static final String CODEC_ID_E_AC3 = "A_EAC3";
    private static final String CODEC_ID_FLAC = "A_FLAC";
    private static final String CODEC_ID_FOURCC = "V_MS/VFW/FOURCC";
    private static final String CODEC_ID_H264 = "V_MPEG4/ISO/AVC";
    private static final String CODEC_ID_H265 = "V_MPEGH/ISO/HEVC";
    private static final String CODEC_ID_MP2 = "A_MPEG/L2";
    private static final String CODEC_ID_MP3 = "A_MPEG/L3";
    private static final String CODEC_ID_MPEG2 = "V_MPEG2";
    private static final String CODEC_ID_MPEG4_AP = "V_MPEG4/ISO/AP";
    private static final String CODEC_ID_MPEG4_ASP = "V_MPEG4/ISO/ASP";
    private static final String CODEC_ID_MPEG4_SP = "V_MPEG4/ISO/SP";
    private static final String CODEC_ID_OPUS = "A_OPUS";
    private static final String CODEC_ID_PCM_FLOAT = "A_PCM/FLOAT/IEEE";
    private static final String CODEC_ID_PCM_INT_BIG = "A_PCM/INT/BIG";
    private static final String CODEC_ID_PCM_INT_LIT = "A_PCM/INT/LIT";
    private static final String CODEC_ID_PGS = "S_HDMV/PGS";
    private static final String CODEC_ID_SUBRIP = "S_TEXT/UTF8";
    private static final String CODEC_ID_THEORA = "V_THEORA";
    private static final String CODEC_ID_TRUEHD = "A_TRUEHD";
    private static final String CODEC_ID_VOBSUB = "S_VOBSUB";
    private static final String CODEC_ID_VORBIS = "A_VORBIS";
    private static final String CODEC_ID_VP8 = "V_VP8";
    private static final String CODEC_ID_VP9 = "V_VP9";
    private static final String DOC_TYPE_MATROSKA = "matroska";
    private static final String DOC_TYPE_WEBM = "webm";
    private static final int ENCRYPTION_IV_SIZE = 8;
    public static final ExtractorsFactory FACTORY = wk.a;
    public static final int FLAG_DISABLE_SEEK_FOR_CUES = 1;
    private static final int FOURCC_COMPRESSION_DIVX = 1482049860;
    private static final int FOURCC_COMPRESSION_H263 = 859189832;
    private static final int FOURCC_COMPRESSION_VC1 = 826496599;
    private static final int ID_AUDIO = 225;
    private static final int ID_AUDIO_BIT_DEPTH = 25188;
    private static final int ID_BLOCK = 161;
    private static final int ID_BLOCK_ADDITIONAL = 165;
    private static final int ID_BLOCK_ADDITIONS = 30113;
    private static final int ID_BLOCK_ADDITION_MAPPING = 16868;
    private static final int ID_BLOCK_ADD_ID = 238;
    private static final int ID_BLOCK_ADD_ID_EXTRA_DATA = 16877;
    private static final int ID_BLOCK_ADD_ID_TYPE = 16871;
    private static final int ID_BLOCK_DURATION = 155;
    private static final int ID_BLOCK_GROUP = 160;
    private static final int ID_BLOCK_MORE = 166;
    private static final int ID_CHANNELS = 159;
    private static final int ID_CLUSTER = 524531317;
    private static final int ID_CODEC_DELAY = 22186;
    private static final int ID_CODEC_ID = 134;
    private static final int ID_CODEC_PRIVATE = 25506;
    private static final int ID_COLOUR = 21936;
    private static final int ID_COLOUR_PRIMARIES = 21947;
    private static final int ID_COLOUR_RANGE = 21945;
    private static final int ID_COLOUR_TRANSFER = 21946;
    private static final int ID_CONTENT_COMPRESSION = 20532;
    private static final int ID_CONTENT_COMPRESSION_ALGORITHM = 16980;
    private static final int ID_CONTENT_COMPRESSION_SETTINGS = 16981;
    private static final int ID_CONTENT_ENCODING = 25152;
    private static final int ID_CONTENT_ENCODINGS = 28032;
    private static final int ID_CONTENT_ENCODING_ORDER = 20529;
    private static final int ID_CONTENT_ENCODING_SCOPE = 20530;
    private static final int ID_CONTENT_ENCRYPTION = 20533;
    private static final int ID_CONTENT_ENCRYPTION_AES_SETTINGS = 18407;
    private static final int ID_CONTENT_ENCRYPTION_AES_SETTINGS_CIPHER_MODE = 18408;
    private static final int ID_CONTENT_ENCRYPTION_ALGORITHM = 18401;
    private static final int ID_CONTENT_ENCRYPTION_KEY_ID = 18402;
    private static final int ID_CUES = 475249515;
    private static final int ID_CUE_CLUSTER_POSITION = 241;
    private static final int ID_CUE_POINT = 187;
    private static final int ID_CUE_TIME = 179;
    private static final int ID_CUE_TRACK_POSITIONS = 183;
    private static final int ID_DEFAULT_DURATION = 2352003;
    private static final int ID_DISPLAY_HEIGHT = 21690;
    private static final int ID_DISPLAY_UNIT = 21682;
    private static final int ID_DISPLAY_WIDTH = 21680;
    private static final int ID_DOC_TYPE = 17026;
    private static final int ID_DOC_TYPE_READ_VERSION = 17029;
    private static final int ID_DURATION = 17545;
    private static final int ID_EBML = 440786851;
    private static final int ID_EBML_READ_VERSION = 17143;
    private static final int ID_FLAG_DEFAULT = 136;
    private static final int ID_FLAG_FORCED = 21930;
    private static final int ID_INFO = 357149030;
    private static final int ID_LANGUAGE = 2274716;
    private static final int ID_LUMNINANCE_MAX = 21977;
    private static final int ID_LUMNINANCE_MIN = 21978;
    private static final int ID_MASTERING_METADATA = 21968;
    private static final int ID_MAX_BLOCK_ADDITION_ID = 21998;
    private static final int ID_MAX_CLL = 21948;
    private static final int ID_MAX_FALL = 21949;
    private static final int ID_NAME = 21358;
    private static final int ID_PIXEL_HEIGHT = 186;
    private static final int ID_PIXEL_WIDTH = 176;
    private static final int ID_PRIMARY_B_CHROMATICITY_X = 21973;
    private static final int ID_PRIMARY_B_CHROMATICITY_Y = 21974;
    private static final int ID_PRIMARY_G_CHROMATICITY_X = 21971;
    private static final int ID_PRIMARY_G_CHROMATICITY_Y = 21972;
    private static final int ID_PRIMARY_R_CHROMATICITY_X = 21969;
    private static final int ID_PRIMARY_R_CHROMATICITY_Y = 21970;
    private static final int ID_PROJECTION = 30320;
    private static final int ID_PROJECTION_POSE_PITCH = 30324;
    private static final int ID_PROJECTION_POSE_ROLL = 30325;
    private static final int ID_PROJECTION_POSE_YAW = 30323;
    private static final int ID_PROJECTION_PRIVATE = 30322;
    private static final int ID_PROJECTION_TYPE = 30321;
    private static final int ID_REFERENCE_BLOCK = 251;
    private static final int ID_SAMPLING_FREQUENCY = 181;
    private static final int ID_SEEK = 19899;
    private static final int ID_SEEK_HEAD = 290298740;
    private static final int ID_SEEK_ID = 21419;
    private static final int ID_SEEK_POSITION = 21420;
    private static final int ID_SEEK_PRE_ROLL = 22203;
    private static final int ID_SEGMENT = 408125543;
    private static final int ID_SEGMENT_INFO = 357149030;
    private static final int ID_SIMPLE_BLOCK = 163;
    private static final int ID_STEREO_MODE = 21432;
    private static final int ID_TIMECODE_SCALE = 2807729;
    private static final int ID_TIME_CODE = 231;
    private static final int ID_TRACKS = 374648427;
    private static final int ID_TRACK_ENTRY = 174;
    private static final int ID_TRACK_NUMBER = 215;
    private static final int ID_TRACK_TYPE = 131;
    private static final int ID_VIDEO = 224;
    private static final int ID_WHITE_POINT_CHROMATICITY_X = 21975;
    private static final int ID_WHITE_POINT_CHROMATICITY_Y = 21976;
    private static final int LACING_EBML = 3;
    private static final int LACING_FIXED_SIZE = 2;
    private static final int LACING_NONE = 0;
    private static final int LACING_XIPH = 1;
    private static final int OPUS_MAX_INPUT_SIZE = 5760;
    private static final byte[] SSA_DIALOGUE_FORMAT = Util.getUtf8Bytes("Format: Start, End, ReadOrder, Layer, Style, Name, MarginL, MarginR, MarginV, Effect, Text");
    private static final byte[] SSA_PREFIX = {68, 105, 97, 108, 111, 103, 117, 101, 58, 32, 48, 58, 48, 48, 58, 48, 48, 58, 48, 48, 44, 48, 58, 48, 48, 58, 48, 48, 58, 48, 48, 44};
    private static final int SSA_PREFIX_END_TIMECODE_OFFSET = 21;
    private static final String SSA_TIMECODE_FORMAT = "%01d:%02d:%02d:%02d";
    private static final long SSA_TIMECODE_LAST_VALUE_SCALING_FACTOR = 10000;
    private static final byte[] SUBRIP_PREFIX = {49, 10, 48, 48, 58, 48, 48, 58, 48, 48, 44, 48, 48, 48, 32, 45, 45, 62, 32, 48, 48, 58, 48, 48, 58, 48, 48, 44, 48, 48, 48, 10};
    private static final int SUBRIP_PREFIX_END_TIMECODE_OFFSET = 19;
    private static final String SUBRIP_TIMECODE_FORMAT = "%02d:%02d:%02d,%03d";
    private static final long SUBRIP_TIMECODE_LAST_VALUE_SCALING_FACTOR = 1000;
    private static final String TAG = "MatroskaExtractor";
    private static final Map<String, Integer> TRACK_NAME_TO_ROTATION_DEGREES;
    private static final int TRACK_TYPE_AUDIO = 2;
    private static final int UNSET_ENTRY_ID = -1;
    private static final int VORBIS_MAX_INPUT_SIZE = 8192;
    private static final int WAVE_FORMAT_EXTENSIBLE = 65534;
    private static final int WAVE_FORMAT_PCM = 1;
    private static final int WAVE_FORMAT_SIZE = 18;
    private static final UUID WAVE_SUBFORMAT_PCM = new UUID(72057594037932032L, -9223371306706625679L);
    private final ParsableByteArray blockAdditionalData;
    private int blockAdditionalId;
    private long blockDurationUs;
    private int blockFlags;
    private boolean blockHasReferenceBlock;
    private int blockSampleCount;
    private int blockSampleIndex;
    private int[] blockSampleSizes;
    private int blockState;
    private long blockTimeUs;
    private int blockTrackNumber;
    private int blockTrackNumberLength;
    private long clusterTimecodeUs;
    @Nullable
    private LongArray cueClusterPositions;
    @Nullable
    private LongArray cueTimesUs;
    private long cuesContentPosition;
    @Nullable
    private Track currentTrack;
    private long durationTimecode;
    private long durationUs;
    private final ParsableByteArray encryptionInitializationVector;
    private final ParsableByteArray encryptionSubsampleData;
    private ByteBuffer encryptionSubsampleDataBuffer;
    private ExtractorOutput extractorOutput;
    private boolean haveOutputSample;
    private final ParsableByteArray nalLength;
    private final ParsableByteArray nalStartCode;
    private final EbmlReader reader;
    private int sampleBytesRead;
    private int sampleBytesWritten;
    private int sampleCurrentNalBytesRemaining;
    private boolean sampleEncodingHandled;
    private boolean sampleInitializationVectorRead;
    private int samplePartitionCount;
    private boolean samplePartitionCountRead;
    private byte sampleSignalByte;
    private boolean sampleSignalByteRead;
    private final ParsableByteArray sampleStrippedBytes;
    private final ParsableByteArray scratch;
    private int seekEntryId;
    private final ParsableByteArray seekEntryIdBytes;
    private long seekEntryPosition;
    private boolean seekForCues;
    private final boolean seekForCuesEnabled;
    private long seekPositionAfterBuildingCues;
    private boolean seenClusterPositionForCurrentCuePoint;
    private long segmentContentPosition;
    private long segmentContentSize;
    private boolean sentSeekMap;
    private final ParsableByteArray subtitleSample;
    private long timecodeScale;
    private final SparseArray<Track> tracks;
    private final VarintReader varintReader;
    private final ParsableByteArray vorbisNumPageSamples;

    @Documented
    @Retention(RetentionPolicy.SOURCE)
    public @interface Flags {
    }

    public final class InnerEbmlProcessor implements EbmlProcessor {
        private InnerEbmlProcessor() {
        }

        @Override // com.google.android.exoplayer2.extractor.mkv.EbmlProcessor
        public void binaryElement(int i, int i2, ExtractorInput extractorInput) {
            MatroskaExtractor.this.binaryElement(i, i2, extractorInput);
        }

        @Override // com.google.android.exoplayer2.extractor.mkv.EbmlProcessor
        public void endMasterElement(int i) {
            MatroskaExtractor.this.endMasterElement(i);
        }

        @Override // com.google.android.exoplayer2.extractor.mkv.EbmlProcessor
        public void floatElement(int i, double d) {
            MatroskaExtractor.this.floatElement(i, d);
        }

        @Override // com.google.android.exoplayer2.extractor.mkv.EbmlProcessor
        public int getElementType(int i) {
            return MatroskaExtractor.this.getElementType(i);
        }

        @Override // com.google.android.exoplayer2.extractor.mkv.EbmlProcessor
        public void integerElement(int i, long j) {
            MatroskaExtractor.this.integerElement(i, j);
        }

        @Override // com.google.android.exoplayer2.extractor.mkv.EbmlProcessor
        public boolean isLevel1Element(int i) {
            return MatroskaExtractor.this.isLevel1Element(i);
        }

        @Override // com.google.android.exoplayer2.extractor.mkv.EbmlProcessor
        public void startMasterElement(int i, long j, long j2) {
            MatroskaExtractor.this.startMasterElement(i, j, j2);
        }

        @Override // com.google.android.exoplayer2.extractor.mkv.EbmlProcessor
        public void stringElement(int i, String str) {
            MatroskaExtractor.this.stringElement(i, str);
        }
    }

    public static final class Track {
        private static final int DEFAULT_MAX_CLL = 1000;
        private static final int DEFAULT_MAX_FALL = 200;
        private static final int DISPLAY_UNIT_PIXELS = 0;
        private static final int MAX_CHROMATICITY = 50000;
        public int audioBitDepth;
        private int blockAddIdType;
        public int channelCount;
        public long codecDelayNs;
        public String codecId;
        public byte[] codecPrivate;
        public int colorRange;
        public int colorSpace;
        public int colorTransfer;
        public TrackOutput.CryptoData cryptoData;
        public int defaultSampleDurationNs;
        public int displayHeight;
        public int displayUnit;
        public int displayWidth;
        public byte[] dolbyVisionConfigBytes;
        public DrmInitData drmInitData;
        public boolean flagDefault;
        public boolean flagForced;
        public boolean hasColorInfo;
        public boolean hasContentEncryption;
        public int height;
        private String language;
        public int maxBlockAdditionId;
        public int maxContentLuminance;
        public int maxFrameAverageLuminance;
        public float maxMasteringLuminance;
        public float minMasteringLuminance;
        public int nalUnitLengthFieldLength;
        public String name;
        public int number;
        public TrackOutput output;
        public float primaryBChromaticityX;
        public float primaryBChromaticityY;
        public float primaryGChromaticityX;
        public float primaryGChromaticityY;
        public float primaryRChromaticityX;
        public float primaryRChromaticityY;
        public byte[] projectionData;
        public float projectionPosePitch;
        public float projectionPoseRoll;
        public float projectionPoseYaw;
        public int projectionType;
        public int sampleRate;
        public byte[] sampleStrippedBytes;
        public long seekPreRollNs;
        public int stereoMode;
        public TrueHdSampleRechunker trueHdSampleRechunker;
        public int type;
        public float whitePointChromaticityX;
        public float whitePointChromaticityY;
        public int width;

        private Track() {
            this.width = -1;
            this.height = -1;
            this.displayWidth = -1;
            this.displayHeight = -1;
            this.displayUnit = 0;
            this.projectionType = -1;
            this.projectionPoseYaw = 0.0f;
            this.projectionPosePitch = 0.0f;
            this.projectionPoseRoll = 0.0f;
            this.projectionData = null;
            this.stereoMode = -1;
            this.hasColorInfo = false;
            this.colorSpace = -1;
            this.colorTransfer = -1;
            this.colorRange = -1;
            this.maxContentLuminance = 1000;
            this.maxFrameAverageLuminance = 200;
            this.primaryRChromaticityX = -1.0f;
            this.primaryRChromaticityY = -1.0f;
            this.primaryGChromaticityX = -1.0f;
            this.primaryGChromaticityY = -1.0f;
            this.primaryBChromaticityX = -1.0f;
            this.primaryBChromaticityY = -1.0f;
            this.whitePointChromaticityX = -1.0f;
            this.whitePointChromaticityY = -1.0f;
            this.maxMasteringLuminance = -1.0f;
            this.minMasteringLuminance = -1.0f;
            this.channelCount = 1;
            this.audioBitDepth = -1;
            this.sampleRate = 8000;
            this.codecDelayNs = 0;
            this.seekPreRollNs = 0;
            this.flagDefault = true;
            this.language = "eng";
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        @EnsuresNonNull({"output"})
        private void assertOutputInitialized() {
            Assertions.checkNotNull(this.output);
        }

        @EnsuresNonNull({"codecPrivate"})
        private byte[] getCodecPrivate(String str) {
            byte[] bArr = this.codecPrivate;
            if (bArr != null) {
                return bArr;
            }
            String valueOf = String.valueOf(str);
            throw new ParserException(valueOf.length() != 0 ? "Missing CodecPrivate for codec ".concat(valueOf) : new String("Missing CodecPrivate for codec "));
        }

        @Nullable
        private byte[] getHdrStaticInfo() {
            if (this.primaryRChromaticityX == -1.0f || this.primaryRChromaticityY == -1.0f || this.primaryGChromaticityX == -1.0f || this.primaryGChromaticityY == -1.0f || this.primaryBChromaticityX == -1.0f || this.primaryBChromaticityY == -1.0f || this.whitePointChromaticityX == -1.0f || this.whitePointChromaticityY == -1.0f || this.maxMasteringLuminance == -1.0f || this.minMasteringLuminance == -1.0f) {
                return null;
            }
            byte[] bArr = new byte[25];
            ByteBuffer order = ByteBuffer.wrap(bArr).order(ByteOrder.LITTLE_ENDIAN);
            order.put((byte) 0);
            order.putShort((short) ((int) ((this.primaryRChromaticityX * 50000.0f) + 0.5f)));
            order.putShort((short) ((int) ((this.primaryRChromaticityY * 50000.0f) + 0.5f)));
            order.putShort((short) ((int) ((this.primaryGChromaticityX * 50000.0f) + 0.5f)));
            order.putShort((short) ((int) ((this.primaryGChromaticityY * 50000.0f) + 0.5f)));
            order.putShort((short) ((int) ((this.primaryBChromaticityX * 50000.0f) + 0.5f)));
            order.putShort((short) ((int) ((this.primaryBChromaticityY * 50000.0f) + 0.5f)));
            order.putShort((short) ((int) ((this.whitePointChromaticityX * 50000.0f) + 0.5f)));
            order.putShort((short) ((int) ((this.whitePointChromaticityY * 50000.0f) + 0.5f)));
            order.putShort((short) ((int) (this.maxMasteringLuminance + 0.5f)));
            order.putShort((short) ((int) (this.minMasteringLuminance + 0.5f)));
            order.putShort((short) this.maxContentLuminance);
            order.putShort((short) this.maxFrameAverageLuminance);
            return bArr;
        }

        private static Pair<String, List<byte[]>> parseFourCcPrivate(ParsableByteArray parsableByteArray) {
            try {
                parsableByteArray.skipBytes(16);
                long readLittleEndianUnsignedInt = parsableByteArray.readLittleEndianUnsignedInt();
                if (readLittleEndianUnsignedInt == 1482049860) {
                    return new Pair<>(MimeTypes.VIDEO_DIVX, null);
                }
                if (readLittleEndianUnsignedInt == 859189832) {
                    return new Pair<>(MimeTypes.VIDEO_H263, null);
                }
                if (readLittleEndianUnsignedInt == 826496599) {
                    byte[] data = parsableByteArray.getData();
                    for (int position = parsableByteArray.getPosition() + 20; position < data.length - 4; position++) {
                        if (data[position] == 0 && data[position + 1] == 0 && data[position + 2] == 1 && data[position + 3] == 15) {
                            return new Pair<>(MimeTypes.VIDEO_VC1, Collections.singletonList(Arrays.copyOfRange(data, position, data.length)));
                        }
                    }
                    throw new ParserException("Failed to find FourCC VC1 initialization data");
                }
                Log.w(MatroskaExtractor.TAG, "Unknown FourCC. Setting mimeType to video/x-unknown");
                return new Pair<>(MimeTypes.VIDEO_UNKNOWN, null);
            } catch (ArrayIndexOutOfBoundsException unused) {
                throw new ParserException("Error parsing FourCC private data");
            }
        }

        private static boolean parseMsAcmCodecPrivate(ParsableByteArray parsableByteArray) {
            try {
                int readLittleEndianUnsignedShort = parsableByteArray.readLittleEndianUnsignedShort();
                if (readLittleEndianUnsignedShort == 1) {
                    return true;
                }
                if (readLittleEndianUnsignedShort != 65534) {
                    return false;
                }
                parsableByteArray.setPosition(24);
                if (parsableByteArray.readLong() == MatroskaExtractor.WAVE_SUBFORMAT_PCM.getMostSignificantBits() && parsableByteArray.readLong() == MatroskaExtractor.WAVE_SUBFORMAT_PCM.getLeastSignificantBits()) {
                    return true;
                }
                return false;
            } catch (ArrayIndexOutOfBoundsException unused) {
                throw new ParserException("Error parsing MS/ACM codec private");
            }
        }

        private static List<byte[]> parseVorbisCodecPrivate(byte[] bArr) {
            try {
                if (bArr[0] == 2) {
                    int i = 1;
                    int i2 = 0;
                    while ((bArr[i] & ExifInterface.MARKER) == 255) {
                        i2 += 255;
                        i++;
                    }
                    int i3 = i + 1;
                    int i4 = i2 + (bArr[i] & 255);
                    int i5 = 0;
                    while ((bArr[i3] & ExifInterface.MARKER) == 255) {
                        i5 += 255;
                        i3++;
                    }
                    int i6 = i3 + 1;
                    int i7 = i5 + (bArr[i3] & 255);
                    if (bArr[i6] == 1) {
                        byte[] bArr2 = new byte[i4];
                        System.arraycopy(bArr, i6, bArr2, 0, i4);
                        int i8 = i6 + i4;
                        if (bArr[i8] == 3) {
                            int i9 = i8 + i7;
                            if (bArr[i9] == 5) {
                                byte[] bArr3 = new byte[(bArr.length - i9)];
                                System.arraycopy(bArr, i9, bArr3, 0, bArr.length - i9);
                                ArrayList arrayList = new ArrayList(2);
                                arrayList.add(bArr2);
                                arrayList.add(bArr3);
                                return arrayList;
                            }
                            throw new ParserException("Error parsing vorbis codec private");
                        }
                        throw new ParserException("Error parsing vorbis codec private");
                    }
                    throw new ParserException("Error parsing vorbis codec private");
                }
                throw new ParserException("Error parsing vorbis codec private");
            } catch (ArrayIndexOutOfBoundsException unused) {
                throw new ParserException("Error parsing vorbis codec private");
            }
        }

        /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
        /* JADX WARNING: Removed duplicated region for block: B:170:0x047a  */
        /* JADX WARNING: Removed duplicated region for block: B:171:0x047c  */
        /* JADX WARNING: Removed duplicated region for block: B:174:0x0489  */
        /* JADX WARNING: Removed duplicated region for block: B:175:0x049b  */
        @EnsuresNonNull({"this.output"})
        @RequiresNonNull({"codecId"})
        public void initializeOutput(ExtractorOutput extractorOutput, int i) {
            char c;
            String str;
            int i2;
            String str2;
            List<byte[]> list;
            Format.Builder builder;
            int i3;
            int i4;
            DolbyVisionConfig parse;
            ArrayList arrayList;
            bs bsVar;
            List<byte[]> list2;
            String str3;
            List list3;
            List list4;
            String str4 = this.codecId;
            str4.hashCode();
            int i5 = 4;
            int i6 = 3;
            int i7 = 0;
            switch (str4.hashCode()) {
                case -2095576542:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_MPEG4_AP)) {
                        c = 0;
                        break;
                    }
                    c = 65535;
                    break;
                case -2095575984:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_MPEG4_SP)) {
                        c = 1;
                        break;
                    }
                    c = 65535;
                    break;
                case -1985379776:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_ACM)) {
                        c = 2;
                        break;
                    }
                    c = 65535;
                    break;
                case -1784763192:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_TRUEHD)) {
                        c = 3;
                        break;
                    }
                    c = 65535;
                    break;
                case -1730367663:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_VORBIS)) {
                        c = 4;
                        break;
                    }
                    c = 65535;
                    break;
                case -1482641358:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_MP2)) {
                        c = 5;
                        break;
                    }
                    c = 65535;
                    break;
                case -1482641357:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_MP3)) {
                        c = 6;
                        break;
                    }
                    c = 65535;
                    break;
                case -1373388978:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_FOURCC)) {
                        c = 7;
                        break;
                    }
                    c = 65535;
                    break;
                case -933872740:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_DVBSUB)) {
                        c = '\b';
                        break;
                    }
                    c = 65535;
                    break;
                case -538363189:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_MPEG4_ASP)) {
                        c = '\t';
                        break;
                    }
                    c = 65535;
                    break;
                case -538363109:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_H264)) {
                        c = '\n';
                        break;
                    }
                    c = 65535;
                    break;
                case -425012669:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_VOBSUB)) {
                        c = 11;
                        break;
                    }
                    c = 65535;
                    break;
                case -356037306:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_DTS_LOSSLESS)) {
                        c = '\f';
                        break;
                    }
                    c = 65535;
                    break;
                case 62923557:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_AAC)) {
                        c = '\r';
                        break;
                    }
                    c = 65535;
                    break;
                case 62923603:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_AC3)) {
                        c = 14;
                        break;
                    }
                    c = 65535;
                    break;
                case 62927045:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_DTS)) {
                        c = 15;
                        break;
                    }
                    c = 65535;
                    break;
                case 82318131:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_AV1)) {
                        c = 16;
                        break;
                    }
                    c = 65535;
                    break;
                case 82338133:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_VP8)) {
                        c = 17;
                        break;
                    }
                    c = 65535;
                    break;
                case 82338134:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_VP9)) {
                        c = 18;
                        break;
                    }
                    c = 65535;
                    break;
                case 99146302:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_PGS)) {
                        c = 19;
                        break;
                    }
                    c = 65535;
                    break;
                case 444813526:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_THEORA)) {
                        c = 20;
                        break;
                    }
                    c = 65535;
                    break;
                case 542569478:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_DTS_EXPRESS)) {
                        c = 21;
                        break;
                    }
                    c = 65535;
                    break;
                case 635596514:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_PCM_FLOAT)) {
                        c = 22;
                        break;
                    }
                    c = 65535;
                    break;
                case 725948237:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_PCM_INT_BIG)) {
                        c = 23;
                        break;
                    }
                    c = 65535;
                    break;
                case 725957860:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_PCM_INT_LIT)) {
                        c = 24;
                        break;
                    }
                    c = 65535;
                    break;
                case 738597099:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_ASS)) {
                        c = 25;
                        break;
                    }
                    c = 65535;
                    break;
                case 855502857:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_H265)) {
                        c = 26;
                        break;
                    }
                    c = 65535;
                    break;
                case 1422270023:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_SUBRIP)) {
                        c = 27;
                        break;
                    }
                    c = 65535;
                    break;
                case 1809237540:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_MPEG2)) {
                        c = 28;
                        break;
                    }
                    c = 65535;
                    break;
                case 1950749482:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_E_AC3)) {
                        c = 29;
                        break;
                    }
                    c = 65535;
                    break;
                case 1950789798:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_FLAC)) {
                        c = 30;
                        break;
                    }
                    c = 65535;
                    break;
                case 1951062397:
                    if (str4.equals(MatroskaExtractor.CODEC_ID_OPUS)) {
                        c = 31;
                        break;
                    }
                    c = 65535;
                    break;
                default:
                    c = 65535;
                    break;
            }
            String str5 = MimeTypes.AUDIO_RAW;
            switch (c) {
                case 0:
                case 1:
                case '\t':
                    str = MimeTypes.APPLICATION_PGS;
                    byte[] bArr = this.codecPrivate;
                    List singletonList = bArr == null ? null : Collections.singletonList(bArr);
                    str5 = MimeTypes.VIDEO_MP4V;
                    bsVar = singletonList;
                    str2 = null;
                    list4 = bsVar;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr2 = this.dolbyVisionConfigBytes;
                    if (!(bArr2 == null || (parse = DolbyVisionConfig.parse(new ParsableByteArray(bArr2))) == null)) {
                        str2 = parse.codecs;
                        str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    }
                    int i8 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                        builder.setChannelCount(this.channelCount).setSampleRate(this.sampleRate).setPcmEncoding(i5);
                        i6 = 1;
                    } else if (MimeTypes.isVideo(str5)) {
                        if (this.displayUnit == 0) {
                            int i9 = this.displayWidth;
                            i3 = -1;
                            if (i9 == -1) {
                                i9 = this.width;
                            }
                            this.displayWidth = i9;
                            int i10 = this.displayHeight;
                            if (i10 == -1) {
                                i10 = this.height;
                            }
                            this.displayHeight = i10;
                        } else {
                            i3 = -1;
                        }
                        float f = -1.0f;
                        int i11 = this.displayWidth;
                        if (!(i11 == i3 || (i4 = this.displayHeight) == i3)) {
                            f = ((float) (this.height * i11)) / ((float) (this.width * i4));
                        }
                        ColorInfo colorInfo = this.hasColorInfo ? new ColorInfo(this.colorSpace, this.colorRange, this.colorTransfer, getHdrStaticInfo()) : null;
                        if (this.name != null && MatroskaExtractor.TRACK_NAME_TO_ROTATION_DEGREES.containsKey(this.name)) {
                            i3 = ((Integer) MatroskaExtractor.TRACK_NAME_TO_ROTATION_DEGREES.get(this.name)).intValue();
                        }
                        if (this.projectionType == 0 && Float.compare(this.projectionPoseYaw, 0.0f) == 0 && Float.compare(this.projectionPosePitch, 0.0f) == 0) {
                            if (Float.compare(this.projectionPoseRoll, 0.0f) != 0) {
                                if (Float.compare(this.projectionPosePitch, 90.0f) == 0) {
                                    i7 = 90;
                                } else if (Float.compare(this.projectionPosePitch, -180.0f) == 0 || Float.compare(this.projectionPosePitch, 180.0f) == 0) {
                                    i7 = 180;
                                } else if (Float.compare(this.projectionPosePitch, -90.0f) == 0) {
                                    i7 = 270;
                                }
                            }
                            builder.setWidth(this.width).setHeight(this.height).setPixelWidthHeightRatio(f).setRotationDegrees(i7).setProjectionData(this.projectionData).setStereoMode(this.stereoMode).setColorInfo(colorInfo);
                            i6 = 2;
                        }
                        i7 = i3;
                        builder.setWidth(this.width).setHeight(this.height).setPixelWidthHeightRatio(f).setRotationDegrees(i7).setProjectionData(this.projectionData).setStereoMode(this.stereoMode).setColorInfo(colorInfo);
                        i6 = 2;
                    } else if (!MimeTypes.APPLICATION_SUBRIP.equals(str5) && !MimeTypes.TEXT_SSA.equals(str5) && !MimeTypes.APPLICATION_VOBSUB.equals(str5) && !str.equals(str5) && !MimeTypes.APPLICATION_DVBSUBS.equals(str5)) {
                        throw new ParserException("Unexpected MIME type.");
                    }
                    if (this.name != null && !MatroskaExtractor.TRACK_NAME_TO_ROTATION_DEGREES.containsKey(this.name)) {
                        builder.setLabel(this.name);
                    }
                    Format build = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i8).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track = extractorOutput.track(this.number, i6);
                    this.output = track;
                    track.format(build);
                    return;
                case 2:
                    str = MimeTypes.APPLICATION_PGS;
                    if (parseMsAcmCodecPrivate(new ParsableByteArray(getCodecPrivate(this.codecId)))) {
                        i5 = Util.getPcmEncoding(this.audioBitDepth);
                        if (i5 == 0) {
                            int i12 = this.audioBitDepth;
                            StringBuilder sb = new StringBuilder(MimeTypes.AUDIO_UNKNOWN.length() + 60);
                            sb.append("Unsupported PCM bit depth: ");
                            sb.append(i12);
                            sb.append(". Setting mimeType to ");
                            sb.append(MimeTypes.AUDIO_UNKNOWN);
                            Log.w(MatroskaExtractor.TAG, sb.toString());
                        }
                        list3 = null;
                        str2 = null;
                        i2 = -1;
                        list = list3;
                        byte[] bArr22 = this.dolbyVisionConfigBytes;
                        str2 = parse.codecs;
                        str5 = MimeTypes.VIDEO_DOLBY_VISION;
                        int i82 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                        builder = new Format.Builder();
                        if (!MimeTypes.isAudio(str5)) {
                        }
                        builder.setLabel(this.name);
                        Format build2 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i82).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                        TrackOutput track2 = extractorOutput.track(this.number, i6);
                        this.output = track2;
                        track2.format(build2);
                        return;
                    }
                    Log.w(MatroskaExtractor.TAG, MimeTypes.AUDIO_UNKNOWN.length() != 0 ? "Non-PCM MS/ACM is unsupported. Setting mimeType to ".concat(MimeTypes.AUDIO_UNKNOWN) : new String("Non-PCM MS/ACM is unsupported. Setting mimeType to "));
                    str5 = MimeTypes.AUDIO_UNKNOWN;
                    list4 = null;
                    str2 = null;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i822 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build22 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i822).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track22 = extractorOutput.track(this.number, i6);
                    this.output = track22;
                    track22.format(build22);
                    return;
                case 3:
                    str = MimeTypes.APPLICATION_PGS;
                    this.trueHdSampleRechunker = new TrueHdSampleRechunker();
                    str5 = MimeTypes.AUDIO_TRUEHD;
                    list4 = null;
                    str2 = null;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr2222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i8222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i8222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track222 = extractorOutput.track(this.number, i6);
                    this.output = track222;
                    track222.format(build222);
                    return;
                case 4:
                    str = MimeTypes.APPLICATION_PGS;
                    i2 = 8192;
                    List<byte[]> parseVorbisCodecPrivate = parseVorbisCodecPrivate(getCodecPrivate(this.codecId));
                    str5 = MimeTypes.AUDIO_VORBIS;
                    arrayList = parseVorbisCodecPrivate;
                    str2 = null;
                    i5 = -1;
                    list = arrayList;
                    byte[] bArr22222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i82222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build2222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i82222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track2222 = extractorOutput.track(this.number, i6);
                    this.output = track2222;
                    track2222.format(build2222);
                    return;
                case 5:
                    str = MimeTypes.APPLICATION_PGS;
                    str5 = MimeTypes.AUDIO_MPEG_L2;
                    list = null;
                    str2 = null;
                    i5 = -1;
                    i2 = 4096;
                    byte[] bArr222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i822222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build22222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i822222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track22222 = extractorOutput.track(this.number, i6);
                    this.output = track22222;
                    track22222.format(build22222);
                    return;
                case 6:
                    str = MimeTypes.APPLICATION_PGS;
                    str5 = MimeTypes.AUDIO_MPEG;
                    list = null;
                    str2 = null;
                    i5 = -1;
                    i2 = 4096;
                    byte[] bArr2222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i8222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i8222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track222222 = extractorOutput.track(this.number, i6);
                    this.output = track222222;
                    track222222.format(build222222);
                    return;
                case 7:
                    str = MimeTypes.APPLICATION_PGS;
                    Pair<String, List<byte[]>> parseFourCcPrivate = parseFourCcPrivate(new ParsableByteArray(getCodecPrivate(this.codecId)));
                    str5 = (String) parseFourCcPrivate.first;
                    bsVar = (List) parseFourCcPrivate.second;
                    str2 = null;
                    list4 = bsVar;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr22222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i82222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build2222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i82222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track2222222 = extractorOutput.track(this.number, i6);
                    this.output = track2222222;
                    track2222222.format(build2222222);
                    return;
                case '\b':
                    str = MimeTypes.APPLICATION_PGS;
                    byte[] bArr3 = new byte[4];
                    System.arraycopy(getCodecPrivate(this.codecId), 0, bArr3, 0, 4);
                    bs of = bs.of(bArr3);
                    str5 = MimeTypes.APPLICATION_DVBSUBS;
                    bsVar = of;
                    str2 = null;
                    list4 = bsVar;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i822222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build22222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i822222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track22222222 = extractorOutput.track(this.number, i6);
                    this.output = track22222222;
                    track22222222.format(build22222222);
                    return;
                case '\n':
                    str = MimeTypes.APPLICATION_PGS;
                    AvcConfig parse2 = AvcConfig.parse(new ParsableByteArray(getCodecPrivate(this.codecId)));
                    list2 = parse2.initializationData;
                    this.nalUnitLengthFieldLength = parse2.nalUnitLengthFieldLength;
                    str3 = parse2.codecs;
                    str5 = "video/avc";
                    i5 = -1;
                    i2 = -1;
                    str2 = str3;
                    list = list2;
                    byte[] bArr2222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i8222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i8222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track222222222 = extractorOutput.track(this.number, i6);
                    this.output = track222222222;
                    track222222222.format(build222222222);
                    return;
                case 11:
                    str = MimeTypes.APPLICATION_PGS;
                    bs of2 = bs.of(getCodecPrivate(this.codecId));
                    str5 = MimeTypes.APPLICATION_VOBSUB;
                    bsVar = of2;
                    str2 = null;
                    list4 = bsVar;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr22222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i82222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build2222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i82222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track2222222222 = extractorOutput.track(this.number, i6);
                    this.output = track2222222222;
                    track2222222222.format(build2222222222);
                    return;
                case '\f':
                    str = MimeTypes.APPLICATION_PGS;
                    str5 = MimeTypes.AUDIO_DTS_HD;
                    list4 = null;
                    str2 = null;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr222222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i822222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build22222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i822222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track22222222222 = extractorOutput.track(this.number, i6);
                    this.output = track22222222222;
                    track22222222222.format(build22222222222);
                    return;
                case '\r':
                    str = MimeTypes.APPLICATION_PGS;
                    List singletonList2 = Collections.singletonList(getCodecPrivate(this.codecId));
                    AacUtil.Config parseAudioSpecificConfig = AacUtil.parseAudioSpecificConfig(this.codecPrivate);
                    this.sampleRate = parseAudioSpecificConfig.sampleRateHz;
                    this.channelCount = parseAudioSpecificConfig.channelCount;
                    str2 = parseAudioSpecificConfig.codecs;
                    str5 = MimeTypes.AUDIO_AAC;
                    list4 = singletonList2;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr2222222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i8222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i8222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track222222222222 = extractorOutput.track(this.number, i6);
                    this.output = track222222222222;
                    track222222222222.format(build222222222222);
                    return;
                case 14:
                    str = MimeTypes.APPLICATION_PGS;
                    str5 = MimeTypes.AUDIO_AC3;
                    list4 = null;
                    str2 = null;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr22222222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i82222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build2222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i82222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track2222222222222 = extractorOutput.track(this.number, i6);
                    this.output = track2222222222222;
                    track2222222222222.format(build2222222222222);
                    return;
                case 15:
                case 21:
                    str = MimeTypes.APPLICATION_PGS;
                    str5 = MimeTypes.AUDIO_DTS;
                    list4 = null;
                    str2 = null;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr222222222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i822222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build22222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i822222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track22222222222222 = extractorOutput.track(this.number, i6);
                    this.output = track22222222222222;
                    track22222222222222.format(build22222222222222);
                    return;
                case 16:
                    str = MimeTypes.APPLICATION_PGS;
                    str5 = MimeTypes.VIDEO_AV1;
                    list4 = null;
                    str2 = null;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr2222222222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i8222222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build222222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i8222222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track222222222222222 = extractorOutput.track(this.number, i6);
                    this.output = track222222222222222;
                    track222222222222222.format(build222222222222222);
                    return;
                case 17:
                    str = MimeTypes.APPLICATION_PGS;
                    str5 = "video/x-vnd.on2.vp8";
                    list4 = null;
                    str2 = null;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr22222222222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i82222222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build2222222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i82222222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track2222222222222222 = extractorOutput.track(this.number, i6);
                    this.output = track2222222222222222;
                    track2222222222222222.format(build2222222222222222);
                    return;
                case 18:
                    str = MimeTypes.APPLICATION_PGS;
                    str5 = "video/x-vnd.on2.vp9";
                    list4 = null;
                    str2 = null;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr222222222222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i822222222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build22222222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i822222222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track22222222222222222 = extractorOutput.track(this.number, i6);
                    this.output = track22222222222222222;
                    track22222222222222222.format(build22222222222222222);
                    return;
                case 19:
                    str = MimeTypes.APPLICATION_PGS;
                    list4 = null;
                    str2 = null;
                    str5 = str;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr2222222222222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i8222222222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build222222222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i8222222222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track222222222222222222 = extractorOutput.track(this.number, i6);
                    this.output = track222222222222222222;
                    track222222222222222222.format(build222222222222222222);
                    return;
                case 20:
                    str = MimeTypes.APPLICATION_PGS;
                    str5 = MimeTypes.VIDEO_UNKNOWN;
                    list4 = null;
                    str2 = null;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr22222222222222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i82222222222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build2222222222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i82222222222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track2222222222222222222 = extractorOutput.track(this.number, i6);
                    this.output = track2222222222222222222;
                    track2222222222222222222.format(build2222222222222222222);
                    return;
                case 22:
                    str = MimeTypes.APPLICATION_PGS;
                    int i13 = this.audioBitDepth;
                    if (i13 != 32) {
                        StringBuilder sb2 = new StringBuilder(MimeTypes.AUDIO_UNKNOWN.length() + 75);
                        sb2.append("Unsupported floating point PCM bit depth: ");
                        sb2.append(i13);
                        sb2.append(". Setting mimeType to ");
                        sb2.append(MimeTypes.AUDIO_UNKNOWN);
                        Log.w(MatroskaExtractor.TAG, sb2.toString());
                        str5 = MimeTypes.AUDIO_UNKNOWN;
                        list4 = null;
                        str2 = null;
                        i5 = -1;
                        list3 = list4;
                        i2 = -1;
                        list = list3;
                        byte[] bArr222222222222222222222 = this.dolbyVisionConfigBytes;
                        str2 = parse.codecs;
                        str5 = MimeTypes.VIDEO_DOLBY_VISION;
                        int i822222222222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                        builder = new Format.Builder();
                        if (!MimeTypes.isAudio(str5)) {
                        }
                        builder.setLabel(this.name);
                        Format build22222222222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i822222222222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                        TrackOutput track22222222222222222222 = extractorOutput.track(this.number, i6);
                        this.output = track22222222222222222222;
                        track22222222222222222222.format(build22222222222222222222);
                        return;
                    }
                    list3 = null;
                    str2 = null;
                    i2 = -1;
                    list = list3;
                    byte[] bArr2222222222222222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i8222222222222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build222222222222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i8222222222222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track222222222222222222222 = extractorOutput.track(this.number, i6);
                    this.output = track222222222222222222222;
                    track222222222222222222222.format(build222222222222222222222);
                    return;
                case 23:
                    str = MimeTypes.APPLICATION_PGS;
                    int i14 = this.audioBitDepth;
                    if (i14 == 8) {
                        list3 = null;
                        str2 = null;
                        i5 = 3;
                        i2 = -1;
                        list = list3;
                        byte[] bArr22222222222222222222222 = this.dolbyVisionConfigBytes;
                        str2 = parse.codecs;
                        str5 = MimeTypes.VIDEO_DOLBY_VISION;
                        int i82222222222222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                        builder = new Format.Builder();
                        if (!MimeTypes.isAudio(str5)) {
                        }
                        builder.setLabel(this.name);
                        Format build2222222222222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i82222222222222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                        TrackOutput track2222222222222222222222 = extractorOutput.track(this.number, i6);
                        this.output = track2222222222222222222222;
                        track2222222222222222222222.format(build2222222222222222222222);
                        return;
                    } else if (i14 == 16) {
                        i5 = 268435456;
                        list3 = null;
                        str2 = null;
                        i2 = -1;
                        list = list3;
                        byte[] bArr222222222222222222222222 = this.dolbyVisionConfigBytes;
                        str2 = parse.codecs;
                        str5 = MimeTypes.VIDEO_DOLBY_VISION;
                        int i822222222222222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                        builder = new Format.Builder();
                        if (!MimeTypes.isAudio(str5)) {
                        }
                        builder.setLabel(this.name);
                        Format build22222222222222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i822222222222222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                        TrackOutput track22222222222222222222222 = extractorOutput.track(this.number, i6);
                        this.output = track22222222222222222222222;
                        track22222222222222222222222.format(build22222222222222222222222);
                        return;
                    } else {
                        StringBuilder sb3 = new StringBuilder(MimeTypes.AUDIO_UNKNOWN.length() + 71);
                        sb3.append("Unsupported big endian PCM bit depth: ");
                        sb3.append(i14);
                        sb3.append(". Setting mimeType to ");
                        sb3.append(MimeTypes.AUDIO_UNKNOWN);
                        Log.w(MatroskaExtractor.TAG, sb3.toString());
                        str5 = MimeTypes.AUDIO_UNKNOWN;
                        list4 = null;
                        str2 = null;
                        i5 = -1;
                        list3 = list4;
                        i2 = -1;
                        list = list3;
                        byte[] bArr2222222222222222222222222 = this.dolbyVisionConfigBytes;
                        str2 = parse.codecs;
                        str5 = MimeTypes.VIDEO_DOLBY_VISION;
                        int i8222222222222222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                        builder = new Format.Builder();
                        if (!MimeTypes.isAudio(str5)) {
                        }
                        builder.setLabel(this.name);
                        Format build222222222222222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i8222222222222222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                        TrackOutput track222222222222222222222222 = extractorOutput.track(this.number, i6);
                        this.output = track222222222222222222222222;
                        track222222222222222222222222.format(build222222222222222222222222);
                        return;
                    }
                case 24:
                    str = MimeTypes.APPLICATION_PGS;
                    i5 = Util.getPcmEncoding(this.audioBitDepth);
                    if (i5 == 0) {
                        int i15 = this.audioBitDepth;
                        StringBuilder sb4 = new StringBuilder(MimeTypes.AUDIO_UNKNOWN.length() + 74);
                        sb4.append("Unsupported little endian PCM bit depth: ");
                        sb4.append(i15);
                        sb4.append(". Setting mimeType to ");
                        sb4.append(MimeTypes.AUDIO_UNKNOWN);
                        Log.w(MatroskaExtractor.TAG, sb4.toString());
                        str5 = MimeTypes.AUDIO_UNKNOWN;
                        list4 = null;
                        str2 = null;
                        i5 = -1;
                        list3 = list4;
                        i2 = -1;
                        list = list3;
                        byte[] bArr22222222222222222222222222 = this.dolbyVisionConfigBytes;
                        str2 = parse.codecs;
                        str5 = MimeTypes.VIDEO_DOLBY_VISION;
                        int i82222222222222222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                        builder = new Format.Builder();
                        if (!MimeTypes.isAudio(str5)) {
                        }
                        builder.setLabel(this.name);
                        Format build2222222222222222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i82222222222222222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                        TrackOutput track2222222222222222222222222 = extractorOutput.track(this.number, i6);
                        this.output = track2222222222222222222222222;
                        track2222222222222222222222222.format(build2222222222222222222222222);
                        return;
                    }
                    list3 = null;
                    str2 = null;
                    i2 = -1;
                    list = list3;
                    byte[] bArr222222222222222222222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i822222222222222222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build22222222222222222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i822222222222222222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track22222222222222222222222222 = extractorOutput.track(this.number, i6);
                    this.output = track22222222222222222222222222;
                    track22222222222222222222222222.format(build22222222222222222222222222);
                    return;
                case 25:
                    str = MimeTypes.APPLICATION_PGS;
                    bs of3 = bs.of(MatroskaExtractor.SSA_DIALOGUE_FORMAT, getCodecPrivate(this.codecId));
                    str5 = MimeTypes.TEXT_SSA;
                    bsVar = of3;
                    str2 = null;
                    list4 = bsVar;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr2222222222222222222222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i8222222222222222222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build222222222222222222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i8222222222222222222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track222222222222222222222222222 = extractorOutput.track(this.number, i6);
                    this.output = track222222222222222222222222222;
                    track222222222222222222222222222.format(build222222222222222222222222222);
                    return;
                case 26:
                    str = MimeTypes.APPLICATION_PGS;
                    HevcConfig parse3 = HevcConfig.parse(new ParsableByteArray(getCodecPrivate(this.codecId)));
                    list2 = parse3.initializationData;
                    this.nalUnitLengthFieldLength = parse3.nalUnitLengthFieldLength;
                    str3 = parse3.codecs;
                    str5 = "video/hevc";
                    i5 = -1;
                    i2 = -1;
                    str2 = str3;
                    list = list2;
                    byte[] bArr22222222222222222222222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i82222222222222222222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build2222222222222222222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i82222222222222222222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track2222222222222222222222222222 = extractorOutput.track(this.number, i6);
                    this.output = track2222222222222222222222222222;
                    track2222222222222222222222222222.format(build2222222222222222222222222222);
                    return;
                case 27:
                    str = MimeTypes.APPLICATION_PGS;
                    str5 = MimeTypes.APPLICATION_SUBRIP;
                    list4 = null;
                    str2 = null;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr222222222222222222222222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i822222222222222222222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build22222222222222222222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i822222222222222222222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track22222222222222222222222222222 = extractorOutput.track(this.number, i6);
                    this.output = track22222222222222222222222222222;
                    track22222222222222222222222222222.format(build22222222222222222222222222222);
                    return;
                case 28:
                    str = MimeTypes.APPLICATION_PGS;
                    str5 = MimeTypes.VIDEO_MPEG2;
                    list4 = null;
                    str2 = null;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr2222222222222222222222222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i8222222222222222222222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build222222222222222222222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i8222222222222222222222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track222222222222222222222222222222 = extractorOutput.track(this.number, i6);
                    this.output = track222222222222222222222222222222;
                    track222222222222222222222222222222.format(build222222222222222222222222222222);
                    return;
                case 29:
                    str = MimeTypes.APPLICATION_PGS;
                    str5 = MimeTypes.AUDIO_E_AC3;
                    list4 = null;
                    str2 = null;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr22222222222222222222222222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i82222222222222222222222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build2222222222222222222222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i82222222222222222222222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track2222222222222222222222222222222 = extractorOutput.track(this.number, i6);
                    this.output = track2222222222222222222222222222222;
                    track2222222222222222222222222222222.format(build2222222222222222222222222222222);
                    return;
                case 30:
                    str = MimeTypes.APPLICATION_PGS;
                    List singletonList3 = Collections.singletonList(getCodecPrivate(this.codecId));
                    str5 = MimeTypes.AUDIO_FLAC;
                    bsVar = singletonList3;
                    str2 = null;
                    list4 = bsVar;
                    i5 = -1;
                    list3 = list4;
                    i2 = -1;
                    list = list3;
                    byte[] bArr222222222222222222222222222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i822222222222222222222222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build22222222222222222222222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i822222222222222222222222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track22222222222222222222222222222222 = extractorOutput.track(this.number, i6);
                    this.output = track22222222222222222222222222222222;
                    track22222222222222222222222222222222.format(build22222222222222222222222222222222);
                    return;
                case 31:
                    i2 = MatroskaExtractor.OPUS_MAX_INPUT_SIZE;
                    ArrayList arrayList2 = new ArrayList(3);
                    arrayList2.add(getCodecPrivate(this.codecId));
                    ByteBuffer allocate = ByteBuffer.allocate(8);
                    ByteOrder byteOrder = ByteOrder.LITTLE_ENDIAN;
                    ByteBuffer order = allocate.order(byteOrder);
                    str = MimeTypes.APPLICATION_PGS;
                    arrayList2.add(order.putLong(this.codecDelayNs).array());
                    arrayList2.add(ByteBuffer.allocate(8).order(byteOrder).putLong(this.seekPreRollNs).array());
                    str5 = MimeTypes.AUDIO_OPUS;
                    arrayList = arrayList2;
                    str2 = null;
                    i5 = -1;
                    list = arrayList;
                    byte[] bArr2222222222222222222222222222222222 = this.dolbyVisionConfigBytes;
                    str2 = parse.codecs;
                    str5 = MimeTypes.VIDEO_DOLBY_VISION;
                    int i8222222222222222222222222222222222 = (this.flagDefault ? 1 : 0) | 0 | (!this.flagForced ? 2 : 0);
                    builder = new Format.Builder();
                    if (!MimeTypes.isAudio(str5)) {
                    }
                    builder.setLabel(this.name);
                    Format build222222222222222222222222222222222 = builder.setId(i).setSampleMimeType(str5).setMaxInputSize(i2).setLanguage(this.language).setSelectionFlags(i8222222222222222222222222222222222).setInitializationData(list).setCodecs(str2).setDrmInitData(this.drmInitData).build();
                    TrackOutput track222222222222222222222222222222222 = extractorOutput.track(this.number, i6);
                    this.output = track222222222222222222222222222222222;
                    track222222222222222222222222222222222.format(build222222222222222222222222222222222);
                    return;
                default:
                    throw new ParserException("Unrecognized codec identifier.");
            }
        }

        @RequiresNonNull({"output"})
        public void outputPendingSampleMetadata() {
            TrueHdSampleRechunker trueHdSampleRechunker2 = this.trueHdSampleRechunker;
            if (trueHdSampleRechunker2 != null) {
                trueHdSampleRechunker2.outputPendingSampleMetadata(this);
            }
        }

        public void reset() {
            TrueHdSampleRechunker trueHdSampleRechunker2 = this.trueHdSampleRechunker;
            if (trueHdSampleRechunker2 != null) {
                trueHdSampleRechunker2.reset();
            }
        }
    }

    public static final class TrueHdSampleRechunker {
        private int chunkFlags;
        private int chunkOffset;
        private int chunkSampleCount;
        private int chunkSize;
        private long chunkTimeUs;
        private boolean foundSyncframe;
        private final byte[] syncframePrefix = new byte[10];

        @RequiresNonNull({"#1.output"})
        public void outputPendingSampleMetadata(Track track) {
            if (this.chunkSampleCount > 0) {
                track.output.sampleMetadata(this.chunkTimeUs, this.chunkFlags, this.chunkSize, this.chunkOffset, track.cryptoData);
                this.chunkSampleCount = 0;
            }
        }

        public void reset() {
            this.foundSyncframe = false;
            this.chunkSampleCount = 0;
        }

        @RequiresNonNull({"#1.output"})
        public void sampleMetadata(Track track, long j, int i, int i2, int i3) {
            if (this.foundSyncframe) {
                int i4 = this.chunkSampleCount;
                int i5 = i4 + 1;
                this.chunkSampleCount = i5;
                if (i4 == 0) {
                    this.chunkTimeUs = j;
                    this.chunkFlags = i;
                    this.chunkSize = 0;
                }
                this.chunkSize += i2;
                this.chunkOffset = i3;
                if (i5 >= 16) {
                    outputPendingSampleMetadata(track);
                }
            }
        }

        public void startSample(ExtractorInput extractorInput) {
            if (!this.foundSyncframe) {
                extractorInput.peekFully(this.syncframePrefix, 0, 10);
                extractorInput.resetPeekPosition();
                if (Ac3Util.parseTrueHdSyncframeAudioSampleCount(this.syncframePrefix) != 0) {
                    this.foundSyncframe = true;
                }
            }
        }
    }

    static {
        HashMap hashMap = new HashMap();
        hashMap.put("htc_video_rotA-000", 0);
        hashMap.put("htc_video_rotA-090", 90);
        hashMap.put("htc_video_rotA-180", 180);
        hashMap.put("htc_video_rotA-270", 270);
        TRACK_NAME_TO_ROTATION_DEGREES = Collections.unmodifiableMap(hashMap);
    }

    public MatroskaExtractor() {
        this(0);
    }

    @EnsuresNonNull({"cueTimesUs", "cueClusterPositions"})
    private void assertInCues(int i) {
        if (this.cueTimesUs == null || this.cueClusterPositions == null) {
            StringBuilder sb = new StringBuilder(37);
            sb.append("Element ");
            sb.append(i);
            sb.append(" must be in a Cues");
            throw new ParserException(sb.toString());
        }
    }

    @EnsuresNonNull({"currentTrack"})
    private void assertInTrackEntry(int i) {
        if (this.currentTrack == null) {
            StringBuilder sb = new StringBuilder(43);
            sb.append("Element ");
            sb.append(i);
            sb.append(" must be in a TrackEntry");
            throw new ParserException(sb.toString());
        }
    }

    @EnsuresNonNull({"extractorOutput"})
    private void assertInitialized() {
        Assertions.checkStateNotNull(this.extractorOutput);
    }

    private SeekMap buildSeekMap(@Nullable LongArray longArray, @Nullable LongArray longArray2) {
        int i;
        if (this.segmentContentPosition == -1 || this.durationUs == C.TIME_UNSET || longArray == null || longArray.size() == 0 || longArray2 == null || longArray2.size() != longArray.size()) {
            return new SeekMap.Unseekable(this.durationUs);
        }
        int size = longArray.size();
        int[] iArr = new int[size];
        long[] jArr = new long[size];
        long[] jArr2 = new long[size];
        long[] jArr3 = new long[size];
        int i2 = 0;
        for (int i3 = 0; i3 < size; i3++) {
            jArr3[i3] = longArray.get(i3);
            jArr[i3] = longArray2.get(i3) + this.segmentContentPosition;
        }
        while (true) {
            i = size - 1;
            if (i2 >= i) {
                break;
            }
            int i4 = i2 + 1;
            iArr[i2] = (int) (jArr[i4] - jArr[i2]);
            jArr2[i2] = jArr3[i4] - jArr3[i2];
            i2 = i4;
        }
        iArr[i] = (int) ((this.segmentContentPosition + this.segmentContentSize) - jArr[i]);
        jArr2[i] = this.durationUs - jArr3[i];
        long j = jArr2[i];
        if (j <= 0) {
            StringBuilder sb = new StringBuilder(72);
            sb.append("Discarding last cue point with unexpected duration: ");
            sb.append(j);
            Log.w(TAG, sb.toString());
            iArr = Arrays.copyOf(iArr, i);
            jArr = Arrays.copyOf(jArr, i);
            jArr2 = Arrays.copyOf(jArr2, i);
            jArr3 = Arrays.copyOf(jArr3, i);
        }
        return new ChunkIndex(iArr, jArr, jArr2, jArr3);
    }

    @RequiresNonNull({"#1.output"})
    private void commitSampleToOutput(Track track, long j, int i, int i2, int i3) {
        TrueHdSampleRechunker trueHdSampleRechunker = track.trueHdSampleRechunker;
        if (trueHdSampleRechunker != null) {
            trueHdSampleRechunker.sampleMetadata(track, j, i, i2, i3);
        } else {
            if (CODEC_ID_SUBRIP.equals(track.codecId) || CODEC_ID_ASS.equals(track.codecId)) {
                if (this.blockSampleCount > 1) {
                    Log.w(TAG, "Skipping subtitle sample in laced block.");
                } else {
                    long j2 = this.blockDurationUs;
                    if (j2 == C.TIME_UNSET) {
                        Log.w(TAG, "Skipping subtitle sample with no duration.");
                    } else {
                        setSubtitleEndTime(track.codecId, j2, this.subtitleSample.getData());
                        int position = this.subtitleSample.getPosition();
                        while (true) {
                            if (position >= this.subtitleSample.limit()) {
                                break;
                            } else if (this.subtitleSample.getData()[position] == 0) {
                                this.subtitleSample.setLimit(position);
                                break;
                            } else {
                                position++;
                            }
                        }
                        TrackOutput trackOutput = track.output;
                        ParsableByteArray parsableByteArray = this.subtitleSample;
                        trackOutput.sampleData(parsableByteArray, parsableByteArray.limit());
                        i2 += this.subtitleSample.limit();
                    }
                }
            }
            if ((268435456 & i) != 0) {
                if (this.blockSampleCount > 1) {
                    i &= -268435457;
                } else {
                    int limit = this.blockAdditionalData.limit();
                    track.output.sampleData(this.blockAdditionalData, limit, 2);
                    i2 += limit;
                }
            }
            track.output.sampleMetadata(j, i, i2, i3, track.cryptoData);
        }
        this.haveOutputSample = true;
    }

    private static int[] ensureArrayCapacity(@Nullable int[] iArr, int i) {
        if (iArr == null) {
            return new int[i];
        }
        if (iArr.length >= i) {
            return iArr;
        }
        return new int[Math.max(iArr.length * 2, i)];
    }

    private int finishWriteSampleData() {
        int i = this.sampleBytesWritten;
        resetWriteSampleData();
        return i;
    }

    private static byte[] formatSubtitleTimecode(long j, String str, long j2) {
        Assertions.checkArgument(j != C.TIME_UNSET);
        int i = (int) (j / 3600000000L);
        long j3 = j - (((long) (i * 3600)) * 1000000);
        int i2 = (int) (j3 / 60000000);
        long j4 = j3 - (((long) (i2 * 60)) * 1000000);
        int i3 = (int) (j4 / 1000000);
        return Util.getUtf8Bytes(String.format(Locale.US, str, Integer.valueOf(i), Integer.valueOf(i2), Integer.valueOf(i3), Integer.valueOf((int) ((j4 - (((long) i3) * 1000000)) / j2))));
    }

    private Track getCurrentTrack(int i) {
        assertInTrackEntry(i);
        return this.currentTrack;
    }

    private static boolean isCodecSupported(String str) {
        str.hashCode();
        char c = 65535;
        switch (str.hashCode()) {
            case -2095576542:
                if (str.equals(CODEC_ID_MPEG4_AP)) {
                    c = 0;
                    break;
                }
                break;
            case -2095575984:
                if (str.equals(CODEC_ID_MPEG4_SP)) {
                    c = 1;
                    break;
                }
                break;
            case -1985379776:
                if (str.equals(CODEC_ID_ACM)) {
                    c = 2;
                    break;
                }
                break;
            case -1784763192:
                if (str.equals(CODEC_ID_TRUEHD)) {
                    c = 3;
                    break;
                }
                break;
            case -1730367663:
                if (str.equals(CODEC_ID_VORBIS)) {
                    c = 4;
                    break;
                }
                break;
            case -1482641358:
                if (str.equals(CODEC_ID_MP2)) {
                    c = 5;
                    break;
                }
                break;
            case -1482641357:
                if (str.equals(CODEC_ID_MP3)) {
                    c = 6;
                    break;
                }
                break;
            case -1373388978:
                if (str.equals(CODEC_ID_FOURCC)) {
                    c = 7;
                    break;
                }
                break;
            case -933872740:
                if (str.equals(CODEC_ID_DVBSUB)) {
                    c = '\b';
                    break;
                }
                break;
            case -538363189:
                if (str.equals(CODEC_ID_MPEG4_ASP)) {
                    c = '\t';
                    break;
                }
                break;
            case -538363109:
                if (str.equals(CODEC_ID_H264)) {
                    c = '\n';
                    break;
                }
                break;
            case -425012669:
                if (str.equals(CODEC_ID_VOBSUB)) {
                    c = 11;
                    break;
                }
                break;
            case -356037306:
                if (str.equals(CODEC_ID_DTS_LOSSLESS)) {
                    c = '\f';
                    break;
                }
                break;
            case 62923557:
                if (str.equals(CODEC_ID_AAC)) {
                    c = '\r';
                    break;
                }
                break;
            case 62923603:
                if (str.equals(CODEC_ID_AC3)) {
                    c = 14;
                    break;
                }
                break;
            case 62927045:
                if (str.equals(CODEC_ID_DTS)) {
                    c = 15;
                    break;
                }
                break;
            case 82318131:
                if (str.equals(CODEC_ID_AV1)) {
                    c = 16;
                    break;
                }
                break;
            case 82338133:
                if (str.equals(CODEC_ID_VP8)) {
                    c = 17;
                    break;
                }
                break;
            case 82338134:
                if (str.equals(CODEC_ID_VP9)) {
                    c = 18;
                    break;
                }
                break;
            case 99146302:
                if (str.equals(CODEC_ID_PGS)) {
                    c = 19;
                    break;
                }
                break;
            case 444813526:
                if (str.equals(CODEC_ID_THEORA)) {
                    c = 20;
                    break;
                }
                break;
            case 542569478:
                if (str.equals(CODEC_ID_DTS_EXPRESS)) {
                    c = 21;
                    break;
                }
                break;
            case 635596514:
                if (str.equals(CODEC_ID_PCM_FLOAT)) {
                    c = 22;
                    break;
                }
                break;
            case 725948237:
                if (str.equals(CODEC_ID_PCM_INT_BIG)) {
                    c = 23;
                    break;
                }
                break;
            case 725957860:
                if (str.equals(CODEC_ID_PCM_INT_LIT)) {
                    c = 24;
                    break;
                }
                break;
            case 738597099:
                if (str.equals(CODEC_ID_ASS)) {
                    c = 25;
                    break;
                }
                break;
            case 855502857:
                if (str.equals(CODEC_ID_H265)) {
                    c = 26;
                    break;
                }
                break;
            case 1422270023:
                if (str.equals(CODEC_ID_SUBRIP)) {
                    c = 27;
                    break;
                }
                break;
            case 1809237540:
                if (str.equals(CODEC_ID_MPEG2)) {
                    c = 28;
                    break;
                }
                break;
            case 1950749482:
                if (str.equals(CODEC_ID_E_AC3)) {
                    c = 29;
                    break;
                }
                break;
            case 1950789798:
                if (str.equals(CODEC_ID_FLAC)) {
                    c = 30;
                    break;
                }
                break;
            case 1951062397:
                if (str.equals(CODEC_ID_OPUS)) {
                    c = 31;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case '\b':
            case '\t':
            case '\n':
            case 11:
            case '\f':
            case '\r':
            case 14:
            case 15:
            case 16:
            case 17:
            case 18:
            case 19:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 25:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
                return true;
            default:
                return false;
        }
    }

    private boolean maybeSeekForCues(PositionHolder positionHolder, long j) {
        if (this.seekForCues) {
            this.seekPositionAfterBuildingCues = j;
            positionHolder.position = this.cuesContentPosition;
            this.seekForCues = false;
            return true;
        }
        if (this.sentSeekMap) {
            long j2 = this.seekPositionAfterBuildingCues;
            if (j2 != -1) {
                positionHolder.position = j2;
                this.seekPositionAfterBuildingCues = -1;
                return true;
            }
        }
        return false;
    }

    private void readScratch(ExtractorInput extractorInput, int i) {
        if (this.scratch.limit() < i) {
            if (this.scratch.capacity() < i) {
                ParsableByteArray parsableByteArray = this.scratch;
                parsableByteArray.ensureCapacity(Math.max(parsableByteArray.capacity() * 2, i));
            }
            extractorInput.readFully(this.scratch.getData(), this.scratch.limit(), i - this.scratch.limit());
            this.scratch.setLimit(i);
        }
    }

    private void resetWriteSampleData() {
        this.sampleBytesRead = 0;
        this.sampleBytesWritten = 0;
        this.sampleCurrentNalBytesRemaining = 0;
        this.sampleEncodingHandled = false;
        this.sampleSignalByteRead = false;
        this.samplePartitionCountRead = false;
        this.samplePartitionCount = 0;
        this.sampleSignalByte = 0;
        this.sampleInitializationVectorRead = false;
        this.sampleStrippedBytes.reset(0);
    }

    private long scaleTimecodeToUs(long j) {
        long j2 = this.timecodeScale;
        if (j2 != C.TIME_UNSET) {
            return Util.scaleLargeTimestamp(j, j2, 1000);
        }
        throw new ParserException("Can't scale timecode prior to timecodeScale being set.");
    }

    private static void setSubtitleEndTime(String str, long j, byte[] bArr) {
        int i;
        byte[] bArr2;
        str.hashCode();
        if (str.equals(CODEC_ID_ASS)) {
            bArr2 = formatSubtitleTimecode(j, SSA_TIMECODE_FORMAT, SSA_TIMECODE_LAST_VALUE_SCALING_FACTOR);
            i = 21;
        } else if (!str.equals(CODEC_ID_SUBRIP)) {
            throw new IllegalArgumentException();
        } else {
            bArr2 = formatSubtitleTimecode(j, SUBRIP_TIMECODE_FORMAT, 1000);
            i = 19;
        }
        System.arraycopy(bArr2, 0, bArr, i, bArr2.length);
    }

    @RequiresNonNull({"#2.output"})
    private int writeSampleData(ExtractorInput extractorInput, Track track, int i) {
        int i2;
        if (CODEC_ID_SUBRIP.equals(track.codecId)) {
            writeSubtitleSampleData(extractorInput, SUBRIP_PREFIX, i);
            return finishWriteSampleData();
        } else if (CODEC_ID_ASS.equals(track.codecId)) {
            writeSubtitleSampleData(extractorInput, SSA_PREFIX, i);
            return finishWriteSampleData();
        } else {
            TrackOutput trackOutput = track.output;
            boolean z = true;
            if (!this.sampleEncodingHandled) {
                if (track.hasContentEncryption) {
                    this.blockFlags &= -1073741825;
                    int i3 = 128;
                    if (!this.sampleSignalByteRead) {
                        extractorInput.readFully(this.scratch.getData(), 0, 1);
                        this.sampleBytesRead++;
                        if ((this.scratch.getData()[0] & 128) != 128) {
                            this.sampleSignalByte = this.scratch.getData()[0];
                            this.sampleSignalByteRead = true;
                        } else {
                            throw new ParserException("Extension bit is set in signal byte");
                        }
                    }
                    byte b = this.sampleSignalByte;
                    if ((b & 1) == 1) {
                        boolean z2 = (b & 2) == 2;
                        this.blockFlags |= 1073741824;
                        if (!this.sampleInitializationVectorRead) {
                            extractorInput.readFully(this.encryptionInitializationVector.getData(), 0, 8);
                            this.sampleBytesRead += 8;
                            this.sampleInitializationVectorRead = true;
                            byte[] data = this.scratch.getData();
                            if (!z2) {
                                i3 = 0;
                            }
                            data[0] = (byte) (i3 | 8);
                            this.scratch.setPosition(0);
                            trackOutput.sampleData(this.scratch, 1, 1);
                            this.sampleBytesWritten++;
                            this.encryptionInitializationVector.setPosition(0);
                            trackOutput.sampleData(this.encryptionInitializationVector, 8, 1);
                            this.sampleBytesWritten += 8;
                        }
                        if (z2) {
                            if (!this.samplePartitionCountRead) {
                                extractorInput.readFully(this.scratch.getData(), 0, 1);
                                this.sampleBytesRead++;
                                this.scratch.setPosition(0);
                                this.samplePartitionCount = this.scratch.readUnsignedByte();
                                this.samplePartitionCountRead = true;
                            }
                            int i4 = this.samplePartitionCount * 4;
                            this.scratch.reset(i4);
                            extractorInput.readFully(this.scratch.getData(), 0, i4);
                            this.sampleBytesRead += i4;
                            short s = (short) ((this.samplePartitionCount / 2) + 1);
                            int i5 = (s * 6) + 2;
                            ByteBuffer byteBuffer = this.encryptionSubsampleDataBuffer;
                            if (byteBuffer == null || byteBuffer.capacity() < i5) {
                                this.encryptionSubsampleDataBuffer = ByteBuffer.allocate(i5);
                            }
                            this.encryptionSubsampleDataBuffer.position(0);
                            this.encryptionSubsampleDataBuffer.putShort(s);
                            int i6 = 0;
                            int i7 = 0;
                            while (true) {
                                i2 = this.samplePartitionCount;
                                if (i6 >= i2) {
                                    break;
                                }
                                int readUnsignedIntToInt = this.scratch.readUnsignedIntToInt();
                                if (i6 % 2 == 0) {
                                    this.encryptionSubsampleDataBuffer.putShort((short) (readUnsignedIntToInt - i7));
                                } else {
                                    this.encryptionSubsampleDataBuffer.putInt(readUnsignedIntToInt - i7);
                                }
                                i6++;
                                i7 = readUnsignedIntToInt;
                            }
                            int i8 = (i - this.sampleBytesRead) - i7;
                            if (i2 % 2 == 1) {
                                this.encryptionSubsampleDataBuffer.putInt(i8);
                            } else {
                                this.encryptionSubsampleDataBuffer.putShort((short) i8);
                                this.encryptionSubsampleDataBuffer.putInt(0);
                            }
                            this.encryptionSubsampleData.reset(this.encryptionSubsampleDataBuffer.array(), i5);
                            trackOutput.sampleData(this.encryptionSubsampleData, i5, 1);
                            this.sampleBytesWritten += i5;
                        }
                    }
                } else {
                    byte[] bArr = track.sampleStrippedBytes;
                    if (bArr != null) {
                        this.sampleStrippedBytes.reset(bArr, bArr.length);
                    }
                }
                if (track.maxBlockAdditionId > 0) {
                    this.blockFlags |= 268435456;
                    this.blockAdditionalData.reset(0);
                    this.scratch.reset(4);
                    this.scratch.getData()[0] = (byte) ((i >> 24) & 255);
                    this.scratch.getData()[1] = (byte) ((i >> 16) & 255);
                    this.scratch.getData()[2] = (byte) ((i >> 8) & 255);
                    this.scratch.getData()[3] = (byte) (i & 255);
                    trackOutput.sampleData(this.scratch, 4, 2);
                    this.sampleBytesWritten += 4;
                }
                this.sampleEncodingHandled = true;
            }
            int limit = this.sampleStrippedBytes.limit() + i;
            if (!CODEC_ID_H264.equals(track.codecId) && !CODEC_ID_H265.equals(track.codecId)) {
                if (track.trueHdSampleRechunker != null) {
                    if (this.sampleStrippedBytes.limit() != 0) {
                        z = false;
                    }
                    Assertions.checkState(z);
                    track.trueHdSampleRechunker.startSample(extractorInput);
                }
                while (true) {
                    int i9 = this.sampleBytesRead;
                    if (i9 >= limit) {
                        break;
                    }
                    int writeToOutput = writeToOutput(extractorInput, trackOutput, limit - i9);
                    this.sampleBytesRead += writeToOutput;
                    this.sampleBytesWritten += writeToOutput;
                }
            } else {
                byte[] data2 = this.nalLength.getData();
                data2[0] = 0;
                data2[1] = 0;
                data2[2] = 0;
                int i10 = track.nalUnitLengthFieldLength;
                int i11 = 4 - i10;
                while (this.sampleBytesRead < limit) {
                    int i12 = this.sampleCurrentNalBytesRemaining;
                    if (i12 == 0) {
                        writeToTarget(extractorInput, data2, i11, i10);
                        this.sampleBytesRead += i10;
                        this.nalLength.setPosition(0);
                        this.sampleCurrentNalBytesRemaining = this.nalLength.readUnsignedIntToInt();
                        this.nalStartCode.setPosition(0);
                        trackOutput.sampleData(this.nalStartCode, 4);
                        this.sampleBytesWritten += 4;
                    } else {
                        int writeToOutput2 = writeToOutput(extractorInput, trackOutput, i12);
                        this.sampleBytesRead += writeToOutput2;
                        this.sampleBytesWritten += writeToOutput2;
                        this.sampleCurrentNalBytesRemaining -= writeToOutput2;
                    }
                }
            }
            if (CODEC_ID_VORBIS.equals(track.codecId)) {
                this.vorbisNumPageSamples.setPosition(0);
                trackOutput.sampleData(this.vorbisNumPageSamples, 4);
                this.sampleBytesWritten += 4;
            }
            return finishWriteSampleData();
        }
    }

    private void writeSubtitleSampleData(ExtractorInput extractorInput, byte[] bArr, int i) {
        int length = bArr.length + i;
        if (this.subtitleSample.capacity() < length) {
            this.subtitleSample.reset(Arrays.copyOf(bArr, length + i));
        } else {
            System.arraycopy(bArr, 0, this.subtitleSample.getData(), 0, bArr.length);
        }
        extractorInput.readFully(this.subtitleSample.getData(), bArr.length, i);
        this.subtitleSample.setPosition(0);
        this.subtitleSample.setLimit(length);
    }

    private int writeToOutput(ExtractorInput extractorInput, TrackOutput trackOutput, int i) {
        int bytesLeft = this.sampleStrippedBytes.bytesLeft();
        if (bytesLeft <= 0) {
            return trackOutput.sampleData((DataReader) extractorInput, i, false);
        }
        int min = Math.min(i, bytesLeft);
        trackOutput.sampleData(this.sampleStrippedBytes, min);
        return min;
    }

    private void writeToTarget(ExtractorInput extractorInput, byte[] bArr, int i, int i2) {
        int min = Math.min(i2, this.sampleStrippedBytes.bytesLeft());
        extractorInput.readFully(bArr, i + min, i2 - min);
        if (min > 0) {
            this.sampleStrippedBytes.readBytes(bArr, i, min);
        }
    }

    @CallSuper
    public void binaryElement(int i, int i2, ExtractorInput extractorInput) {
        long j;
        int i3;
        int i4;
        int[] iArr;
        int i5 = 0;
        int i6 = 1;
        if (i == ID_BLOCK || i == ID_SIMPLE_BLOCK) {
            int i7 = 8;
            if (this.blockState == 0) {
                this.blockTrackNumber = (int) this.varintReader.readUnsignedVarint(extractorInput, false, true, 8);
                this.blockTrackNumberLength = this.varintReader.getLastLength();
                this.blockDurationUs = C.TIME_UNSET;
                this.blockState = 1;
                this.scratch.reset(0);
            }
            Track track = this.tracks.get(this.blockTrackNumber);
            if (track == null) {
                extractorInput.skipFully(i2 - this.blockTrackNumberLength);
                this.blockState = 0;
                return;
            }
            track.assertOutputInitialized();
            if (this.blockState == 1) {
                readScratch(extractorInput, 3);
                int i8 = (this.scratch.getData()[2] & 6) >> 1;
                byte b = ExifInterface.MARKER;
                if (i8 == 0) {
                    this.blockSampleCount = 1;
                    int[] ensureArrayCapacity = ensureArrayCapacity(this.blockSampleSizes, 1);
                    this.blockSampleSizes = ensureArrayCapacity;
                    ensureArrayCapacity[0] = (i2 - this.blockTrackNumberLength) - 3;
                } else {
                    int i9 = 4;
                    readScratch(extractorInput, 4);
                    int i10 = (this.scratch.getData()[3] & ExifInterface.MARKER) + 1;
                    this.blockSampleCount = i10;
                    int[] ensureArrayCapacity2 = ensureArrayCapacity(this.blockSampleSizes, i10);
                    this.blockSampleSizes = ensureArrayCapacity2;
                    if (i8 == 2) {
                        int i11 = this.blockSampleCount;
                        Arrays.fill(ensureArrayCapacity2, 0, i11, ((i2 - this.blockTrackNumberLength) - 4) / i11);
                    } else if (i8 == 1) {
                        int i12 = 0;
                        int i13 = 0;
                        while (true) {
                            i3 = this.blockSampleCount;
                            if (i12 >= i3 - 1) {
                                break;
                            }
                            this.blockSampleSizes[i12] = 0;
                            do {
                                i9++;
                                readScratch(extractorInput, i9);
                                i4 = this.scratch.getData()[i9 - 1] & ExifInterface.MARKER;
                                iArr = this.blockSampleSizes;
                                iArr[i12] = iArr[i12] + i4;
                            } while (i4 == 255);
                            i13 += iArr[i12];
                            i12++;
                        }
                        this.blockSampleSizes[i3 - 1] = ((i2 - this.blockTrackNumberLength) - i9) - i13;
                    } else if (i8 == 3) {
                        int i14 = 0;
                        int i15 = 0;
                        while (true) {
                            int i16 = this.blockSampleCount;
                            if (i14 >= i16 - 1) {
                                this.blockSampleSizes[i16 - 1] = ((i2 - this.blockTrackNumberLength) - i9) - i15;
                                break;
                            }
                            this.blockSampleSizes[i14] = i5;
                            i9++;
                            readScratch(extractorInput, i9);
                            int i17 = i9 - 1;
                            if (this.scratch.getData()[i17] != 0) {
                                int i18 = 0;
                                while (true) {
                                    if (i18 >= i7) {
                                        j = 0;
                                        break;
                                    }
                                    int i19 = i6 << (7 - i18);
                                    if ((this.scratch.getData()[i17] & i19) != 0) {
                                        i9 += i18;
                                        readScratch(extractorInput, i9);
                                        int i20 = i17 + 1;
                                        j = (long) ((i19 ^ -1) & this.scratch.getData()[i17] & b);
                                        while (i20 < i9) {
                                            j = (j << i7) | ((long) (this.scratch.getData()[i20] & b));
                                            i20++;
                                            i7 = 8;
                                            b = ExifInterface.MARKER;
                                        }
                                        if (i14 > 0) {
                                            j -= (1 << ((i18 * 7) + 6)) - 1;
                                        }
                                    } else {
                                        i18++;
                                        i6 = 1;
                                        i7 = 8;
                                        b = ExifInterface.MARKER;
                                    }
                                }
                                if (j >= -2147483648L && j <= 2147483647L) {
                                    int i21 = (int) j;
                                    int[] iArr2 = this.blockSampleSizes;
                                    if (i14 != 0) {
                                        i21 += iArr2[i14 - 1];
                                    }
                                    iArr2[i14] = i21;
                                    i15 += iArr2[i14];
                                    i14++;
                                    i5 = 0;
                                    i6 = 1;
                                    i7 = 8;
                                    b = ExifInterface.MARKER;
                                }
                            } else {
                                throw new ParserException("No valid varint length mask found");
                            }
                        }
                        throw new ParserException("EBML lacing sample size out of range.");
                    } else {
                        throw new ParserException(b2.q(36, "Unexpected lacing value: ", i8));
                    }
                }
                this.blockTimeUs = this.clusterTimecodeUs + scaleTimecodeToUs((long) ((this.scratch.getData()[0] << 8) | (this.scratch.getData()[1] & ExifInterface.MARKER)));
                this.blockFlags = (track.type == 2 || (i == ID_SIMPLE_BLOCK && (this.scratch.getData()[2] & 128) == 128)) ? 1 : 0;
                this.blockState = 2;
                this.blockSampleIndex = 0;
            }
            if (i == ID_SIMPLE_BLOCK) {
                while (true) {
                    int i22 = this.blockSampleIndex;
                    if (i22 < this.blockSampleCount) {
                        commitSampleToOutput(track, ((long) ((this.blockSampleIndex * track.defaultSampleDurationNs) / 1000)) + this.blockTimeUs, this.blockFlags, writeSampleData(extractorInput, track, this.blockSampleSizes[i22]), 0);
                        this.blockSampleIndex++;
                    } else {
                        this.blockState = 0;
                        return;
                    }
                }
            } else {
                while (true) {
                    int i23 = this.blockSampleIndex;
                    if (i23 < this.blockSampleCount) {
                        int[] iArr3 = this.blockSampleSizes;
                        iArr3[i23] = writeSampleData(extractorInput, track, iArr3[i23]);
                        this.blockSampleIndex++;
                    } else {
                        return;
                    }
                }
            }
        } else if (i != ID_BLOCK_ADDITIONAL) {
            if (i == ID_BLOCK_ADD_ID_EXTRA_DATA) {
                handleBlockAddIDExtraData(getCurrentTrack(i), extractorInput, i2);
            } else if (i == ID_CONTENT_COMPRESSION_SETTINGS) {
                assertInTrackEntry(i);
                byte[] bArr = new byte[i2];
                this.currentTrack.sampleStrippedBytes = bArr;
                extractorInput.readFully(bArr, 0, i2);
            } else if (i == ID_CONTENT_ENCRYPTION_KEY_ID) {
                byte[] bArr2 = new byte[i2];
                extractorInput.readFully(bArr2, 0, i2);
                getCurrentTrack(i).cryptoData = new TrackOutput.CryptoData(1, bArr2, 0, 0);
            } else if (i == ID_SEEK_ID) {
                Arrays.fill(this.seekEntryIdBytes.getData(), (byte) 0);
                extractorInput.readFully(this.seekEntryIdBytes.getData(), 4 - i2, i2);
                this.seekEntryIdBytes.setPosition(0);
                this.seekEntryId = (int) this.seekEntryIdBytes.readUnsignedInt();
            } else if (i == ID_CODEC_PRIVATE) {
                assertInTrackEntry(i);
                byte[] bArr3 = new byte[i2];
                this.currentTrack.codecPrivate = bArr3;
                extractorInput.readFully(bArr3, 0, i2);
            } else if (i == ID_PROJECTION_PRIVATE) {
                assertInTrackEntry(i);
                byte[] bArr4 = new byte[i2];
                this.currentTrack.projectionData = bArr4;
                extractorInput.readFully(bArr4, 0, i2);
            } else {
                throw new ParserException(b2.q(26, "Unexpected id: ", i));
            }
        } else if (this.blockState == 2) {
            handleBlockAdditionalData(this.tracks.get(this.blockTrackNumber), this.blockAdditionalId, extractorInput, i2);
        }
    }

    @CallSuper
    public void endMasterElement(int i) {
        assertInitialized();
        if (i != ID_BLOCK_GROUP) {
            if (i == ID_TRACK_ENTRY) {
                Track track = (Track) Assertions.checkStateNotNull(this.currentTrack);
                String str = track.codecId;
                if (str != null) {
                    if (isCodecSupported(str)) {
                        track.initializeOutput(this.extractorOutput, track.number);
                        this.tracks.put(track.number, track);
                    }
                    this.currentTrack = null;
                    return;
                }
                throw new ParserException("CodecId is missing in TrackEntry element");
            } else if (i == ID_SEEK) {
                int i2 = this.seekEntryId;
                if (i2 != -1) {
                    long j = this.seekEntryPosition;
                    if (j != -1) {
                        if (i2 == ID_CUES) {
                            this.cuesContentPosition = j;
                            return;
                        }
                        return;
                    }
                }
                throw new ParserException("Mandatory element SeekID or SeekPosition not found");
            } else if (i == ID_CONTENT_ENCODING) {
                assertInTrackEntry(i);
                Track track2 = this.currentTrack;
                if (!track2.hasContentEncryption) {
                    return;
                }
                if (track2.cryptoData != null) {
                    track2.drmInitData = new DrmInitData(new DrmInitData.SchemeData(C.UUID_NIL, "video/webm", this.currentTrack.cryptoData.encryptionKey));
                    return;
                }
                throw new ParserException("Encrypted Track found but ContentEncKeyID was not found");
            } else if (i == ID_CONTENT_ENCODINGS) {
                assertInTrackEntry(i);
                Track track3 = this.currentTrack;
                if (track3.hasContentEncryption && track3.sampleStrippedBytes != null) {
                    throw new ParserException("Combining encryption and compression is not supported");
                }
            } else if (i == 357149030) {
                if (this.timecodeScale == C.TIME_UNSET) {
                    this.timecodeScale = 1000000;
                }
                long j2 = this.durationTimecode;
                if (j2 != C.TIME_UNSET) {
                    this.durationUs = scaleTimecodeToUs(j2);
                }
            } else if (i != ID_TRACKS) {
                if (i == ID_CUES) {
                    if (!this.sentSeekMap) {
                        this.extractorOutput.seekMap(buildSeekMap(this.cueTimesUs, this.cueClusterPositions));
                        this.sentSeekMap = true;
                    }
                    this.cueTimesUs = null;
                    this.cueClusterPositions = null;
                }
            } else if (this.tracks.size() != 0) {
                this.extractorOutput.endTracks();
            } else {
                throw new ParserException("No valid tracks were found");
            }
        } else if (this.blockState == 2) {
            int i3 = 0;
            for (int i4 = 0; i4 < this.blockSampleCount; i4++) {
                i3 += this.blockSampleSizes[i4];
            }
            Track track4 = this.tracks.get(this.blockTrackNumber);
            track4.assertOutputInitialized();
            for (int i5 = 0; i5 < this.blockSampleCount; i5++) {
                long j3 = ((long) ((track4.defaultSampleDurationNs * i5) / 1000)) + this.blockTimeUs;
                int i6 = this.blockFlags;
                if (i5 == 0 && !this.blockHasReferenceBlock) {
                    i6 |= 1;
                }
                int i7 = this.blockSampleSizes[i5];
                i3 -= i7;
                commitSampleToOutput(track4, j3, i6, i7, i3);
            }
            this.blockState = 0;
        }
    }

    @CallSuper
    public void floatElement(int i, double d) {
        if (i == ID_SAMPLING_FREQUENCY) {
            getCurrentTrack(i).sampleRate = (int) d;
        } else if (i != ID_DURATION) {
            switch (i) {
                case ID_PRIMARY_R_CHROMATICITY_X /*{ENCODED_INT: 21969}*/:
                    getCurrentTrack(i).primaryRChromaticityX = (float) d;
                    return;
                case ID_PRIMARY_R_CHROMATICITY_Y /*{ENCODED_INT: 21970}*/:
                    getCurrentTrack(i).primaryRChromaticityY = (float) d;
                    return;
                case ID_PRIMARY_G_CHROMATICITY_X /*{ENCODED_INT: 21971}*/:
                    getCurrentTrack(i).primaryGChromaticityX = (float) d;
                    return;
                case ID_PRIMARY_G_CHROMATICITY_Y /*{ENCODED_INT: 21972}*/:
                    getCurrentTrack(i).primaryGChromaticityY = (float) d;
                    return;
                case ID_PRIMARY_B_CHROMATICITY_X /*{ENCODED_INT: 21973}*/:
                    getCurrentTrack(i).primaryBChromaticityX = (float) d;
                    return;
                case ID_PRIMARY_B_CHROMATICITY_Y /*{ENCODED_INT: 21974}*/:
                    getCurrentTrack(i).primaryBChromaticityY = (float) d;
                    return;
                case ID_WHITE_POINT_CHROMATICITY_X /*{ENCODED_INT: 21975}*/:
                    getCurrentTrack(i).whitePointChromaticityX = (float) d;
                    return;
                case ID_WHITE_POINT_CHROMATICITY_Y /*{ENCODED_INT: 21976}*/:
                    getCurrentTrack(i).whitePointChromaticityY = (float) d;
                    return;
                case ID_LUMNINANCE_MAX /*{ENCODED_INT: 21977}*/:
                    getCurrentTrack(i).maxMasteringLuminance = (float) d;
                    return;
                case ID_LUMNINANCE_MIN /*{ENCODED_INT: 21978}*/:
                    getCurrentTrack(i).minMasteringLuminance = (float) d;
                    return;
                default:
                    switch (i) {
                        case ID_PROJECTION_POSE_YAW /*{ENCODED_INT: 30323}*/:
                            getCurrentTrack(i).projectionPoseYaw = (float) d;
                            return;
                        case ID_PROJECTION_POSE_PITCH /*{ENCODED_INT: 30324}*/:
                            getCurrentTrack(i).projectionPosePitch = (float) d;
                            return;
                        case ID_PROJECTION_POSE_ROLL /*{ENCODED_INT: 30325}*/:
                            getCurrentTrack(i).projectionPoseRoll = (float) d;
                            return;
                        default:
                            return;
                    }
            }
        } else {
            this.durationTimecode = (long) d;
        }
    }

    @CallSuper
    public int getElementType(int i) {
        switch (i) {
            case ID_TRACK_TYPE /*{ENCODED_INT: 131}*/:
            case ID_FLAG_DEFAULT /*{ENCODED_INT: 136}*/:
            case ID_BLOCK_DURATION /*{ENCODED_INT: 155}*/:
            case ID_CHANNELS /*{ENCODED_INT: 159}*/:
            case ID_PIXEL_WIDTH /*{ENCODED_INT: 176}*/:
            case ID_CUE_TIME /*{ENCODED_INT: 179}*/:
            case ID_PIXEL_HEIGHT /*{ENCODED_INT: 186}*/:
            case ID_TRACK_NUMBER /*{ENCODED_INT: 215}*/:
            case ID_TIME_CODE /*{ENCODED_INT: 231}*/:
            case ID_BLOCK_ADD_ID /*{ENCODED_INT: 238}*/:
            case ID_CUE_CLUSTER_POSITION /*{ENCODED_INT: 241}*/:
            case ID_REFERENCE_BLOCK /*{ENCODED_INT: 251}*/:
            case ID_BLOCK_ADD_ID_TYPE /*{ENCODED_INT: 16871}*/:
            case ID_CONTENT_COMPRESSION_ALGORITHM /*{ENCODED_INT: 16980}*/:
            case ID_DOC_TYPE_READ_VERSION /*{ENCODED_INT: 17029}*/:
            case ID_EBML_READ_VERSION /*{ENCODED_INT: 17143}*/:
            case ID_CONTENT_ENCRYPTION_ALGORITHM /*{ENCODED_INT: 18401}*/:
            case ID_CONTENT_ENCRYPTION_AES_SETTINGS_CIPHER_MODE /*{ENCODED_INT: 18408}*/:
            case ID_CONTENT_ENCODING_ORDER /*{ENCODED_INT: 20529}*/:
            case ID_CONTENT_ENCODING_SCOPE /*{ENCODED_INT: 20530}*/:
            case ID_SEEK_POSITION /*{ENCODED_INT: 21420}*/:
            case ID_STEREO_MODE /*{ENCODED_INT: 21432}*/:
            case ID_DISPLAY_WIDTH /*{ENCODED_INT: 21680}*/:
            case ID_DISPLAY_UNIT /*{ENCODED_INT: 21682}*/:
            case ID_DISPLAY_HEIGHT /*{ENCODED_INT: 21690}*/:
            case ID_FLAG_FORCED /*{ENCODED_INT: 21930}*/:
            case ID_COLOUR_RANGE /*{ENCODED_INT: 21945}*/:
            case ID_COLOUR_TRANSFER /*{ENCODED_INT: 21946}*/:
            case ID_COLOUR_PRIMARIES /*{ENCODED_INT: 21947}*/:
            case ID_MAX_CLL /*{ENCODED_INT: 21948}*/:
            case ID_MAX_FALL /*{ENCODED_INT: 21949}*/:
            case ID_MAX_BLOCK_ADDITION_ID /*{ENCODED_INT: 21998}*/:
            case ID_CODEC_DELAY /*{ENCODED_INT: 22186}*/:
            case ID_SEEK_PRE_ROLL /*{ENCODED_INT: 22203}*/:
            case ID_AUDIO_BIT_DEPTH /*{ENCODED_INT: 25188}*/:
            case ID_PROJECTION_TYPE /*{ENCODED_INT: 30321}*/:
            case ID_DEFAULT_DURATION /*{ENCODED_INT: 2352003}*/:
            case ID_TIMECODE_SCALE /*{ENCODED_INT: 2807729}*/:
                return 2;
            case 134:
            case ID_DOC_TYPE /*{ENCODED_INT: 17026}*/:
            case ID_NAME /*{ENCODED_INT: 21358}*/:
            case ID_LANGUAGE /*{ENCODED_INT: 2274716}*/:
                return 3;
            case ID_BLOCK_GROUP /*{ENCODED_INT: 160}*/:
            case ID_BLOCK_MORE /*{ENCODED_INT: 166}*/:
            case ID_TRACK_ENTRY /*{ENCODED_INT: 174}*/:
            case ID_CUE_TRACK_POSITIONS /*{ENCODED_INT: 183}*/:
            case ID_CUE_POINT /*{ENCODED_INT: 187}*/:
            case 224:
            case ID_AUDIO /*{ENCODED_INT: 225}*/:
            case ID_BLOCK_ADDITION_MAPPING /*{ENCODED_INT: 16868}*/:
            case ID_CONTENT_ENCRYPTION_AES_SETTINGS /*{ENCODED_INT: 18407}*/:
            case ID_SEEK /*{ENCODED_INT: 19899}*/:
            case ID_CONTENT_COMPRESSION /*{ENCODED_INT: 20532}*/:
            case ID_CONTENT_ENCRYPTION /*{ENCODED_INT: 20533}*/:
            case ID_COLOUR /*{ENCODED_INT: 21936}*/:
            case ID_MASTERING_METADATA /*{ENCODED_INT: 21968}*/:
            case ID_CONTENT_ENCODING /*{ENCODED_INT: 25152}*/:
            case ID_CONTENT_ENCODINGS /*{ENCODED_INT: 28032}*/:
            case ID_BLOCK_ADDITIONS /*{ENCODED_INT: 30113}*/:
            case ID_PROJECTION /*{ENCODED_INT: 30320}*/:
            case ID_SEEK_HEAD /*{ENCODED_INT: 290298740}*/:
            case 357149030:
            case ID_TRACKS /*{ENCODED_INT: 374648427}*/:
            case ID_SEGMENT /*{ENCODED_INT: 408125543}*/:
            case ID_EBML /*{ENCODED_INT: 440786851}*/:
            case ID_CUES /*{ENCODED_INT: 475249515}*/:
            case ID_CLUSTER /*{ENCODED_INT: 524531317}*/:
                return 1;
            case ID_BLOCK /*{ENCODED_INT: 161}*/:
            case ID_SIMPLE_BLOCK /*{ENCODED_INT: 163}*/:
            case ID_BLOCK_ADDITIONAL /*{ENCODED_INT: 165}*/:
            case ID_BLOCK_ADD_ID_EXTRA_DATA /*{ENCODED_INT: 16877}*/:
            case ID_CONTENT_COMPRESSION_SETTINGS /*{ENCODED_INT: 16981}*/:
            case ID_CONTENT_ENCRYPTION_KEY_ID /*{ENCODED_INT: 18402}*/:
            case ID_SEEK_ID /*{ENCODED_INT: 21419}*/:
            case ID_CODEC_PRIVATE /*{ENCODED_INT: 25506}*/:
            case ID_PROJECTION_PRIVATE /*{ENCODED_INT: 30322}*/:
                return 4;
            case ID_SAMPLING_FREQUENCY /*{ENCODED_INT: 181}*/:
            case ID_DURATION /*{ENCODED_INT: 17545}*/:
            case ID_PRIMARY_R_CHROMATICITY_X /*{ENCODED_INT: 21969}*/:
            case ID_PRIMARY_R_CHROMATICITY_Y /*{ENCODED_INT: 21970}*/:
            case ID_PRIMARY_G_CHROMATICITY_X /*{ENCODED_INT: 21971}*/:
            case ID_PRIMARY_G_CHROMATICITY_Y /*{ENCODED_INT: 21972}*/:
            case ID_PRIMARY_B_CHROMATICITY_X /*{ENCODED_INT: 21973}*/:
            case ID_PRIMARY_B_CHROMATICITY_Y /*{ENCODED_INT: 21974}*/:
            case ID_WHITE_POINT_CHROMATICITY_X /*{ENCODED_INT: 21975}*/:
            case ID_WHITE_POINT_CHROMATICITY_Y /*{ENCODED_INT: 21976}*/:
            case ID_LUMNINANCE_MAX /*{ENCODED_INT: 21977}*/:
            case ID_LUMNINANCE_MIN /*{ENCODED_INT: 21978}*/:
            case ID_PROJECTION_POSE_YAW /*{ENCODED_INT: 30323}*/:
            case ID_PROJECTION_POSE_PITCH /*{ENCODED_INT: 30324}*/:
            case ID_PROJECTION_POSE_ROLL /*{ENCODED_INT: 30325}*/:
                return 5;
            default:
                return 0;
        }
    }

    public void handleBlockAddIDExtraData(Track track, ExtractorInput extractorInput, int i) {
        if (track.blockAddIdType == 1685485123 || track.blockAddIdType == 1685480259) {
            byte[] bArr = new byte[i];
            track.dolbyVisionConfigBytes = bArr;
            extractorInput.readFully(bArr, 0, i);
            return;
        }
        extractorInput.skipFully(i);
    }

    public void handleBlockAdditionalData(Track track, int i, ExtractorInput extractorInput, int i2) {
        if (i != 4 || !CODEC_ID_VP9.equals(track.codecId)) {
            extractorInput.skipFully(i2);
            return;
        }
        this.blockAdditionalData.reset(i2);
        extractorInput.readFully(this.blockAdditionalData.getData(), 0, i2);
    }

    @Override // com.google.android.exoplayer2.extractor.Extractor
    public final void init(ExtractorOutput extractorOutput2) {
        this.extractorOutput = extractorOutput2;
    }

    @CallSuper
    public void integerElement(int i, long j) {
        if (i != ID_CONTENT_ENCODING_ORDER) {
            if (i != ID_CONTENT_ENCODING_SCOPE) {
                boolean z = false;
                switch (i) {
                    case ID_TRACK_TYPE /*{ENCODED_INT: 131}*/:
                        getCurrentTrack(i).type = (int) j;
                        return;
                    case ID_FLAG_DEFAULT /*{ENCODED_INT: 136}*/:
                        Track currentTrack2 = getCurrentTrack(i);
                        if (j == 1) {
                            z = true;
                        }
                        currentTrack2.flagDefault = z;
                        return;
                    case ID_BLOCK_DURATION /*{ENCODED_INT: 155}*/:
                        this.blockDurationUs = scaleTimecodeToUs(j);
                        return;
                    case ID_CHANNELS /*{ENCODED_INT: 159}*/:
                        getCurrentTrack(i).channelCount = (int) j;
                        return;
                    case ID_PIXEL_WIDTH /*{ENCODED_INT: 176}*/:
                        getCurrentTrack(i).width = (int) j;
                        return;
                    case ID_CUE_TIME /*{ENCODED_INT: 179}*/:
                        assertInCues(i);
                        this.cueTimesUs.add(scaleTimecodeToUs(j));
                        return;
                    case ID_PIXEL_HEIGHT /*{ENCODED_INT: 186}*/:
                        getCurrentTrack(i).height = (int) j;
                        return;
                    case ID_TRACK_NUMBER /*{ENCODED_INT: 215}*/:
                        getCurrentTrack(i).number = (int) j;
                        return;
                    case ID_TIME_CODE /*{ENCODED_INT: 231}*/:
                        this.clusterTimecodeUs = scaleTimecodeToUs(j);
                        return;
                    case ID_BLOCK_ADD_ID /*{ENCODED_INT: 238}*/:
                        this.blockAdditionalId = (int) j;
                        return;
                    case ID_CUE_CLUSTER_POSITION /*{ENCODED_INT: 241}*/:
                        if (!this.seenClusterPositionForCurrentCuePoint) {
                            assertInCues(i);
                            this.cueClusterPositions.add(j);
                            this.seenClusterPositionForCurrentCuePoint = true;
                            return;
                        }
                        return;
                    case ID_REFERENCE_BLOCK /*{ENCODED_INT: 251}*/:
                        this.blockHasReferenceBlock = true;
                        return;
                    case ID_BLOCK_ADD_ID_TYPE /*{ENCODED_INT: 16871}*/:
                        getCurrentTrack(i).blockAddIdType = (int) j;
                        return;
                    case ID_CONTENT_COMPRESSION_ALGORITHM /*{ENCODED_INT: 16980}*/:
                        if (j != 3) {
                            StringBuilder sb = new StringBuilder(50);
                            sb.append("ContentCompAlgo ");
                            sb.append(j);
                            sb.append(" not supported");
                            throw new ParserException(sb.toString());
                        }
                        return;
                    case ID_DOC_TYPE_READ_VERSION /*{ENCODED_INT: 17029}*/:
                        if (j < 1 || j > 2) {
                            StringBuilder sb2 = new StringBuilder(53);
                            sb2.append("DocTypeReadVersion ");
                            sb2.append(j);
                            sb2.append(" not supported");
                            throw new ParserException(sb2.toString());
                        }
                        return;
                    case ID_EBML_READ_VERSION /*{ENCODED_INT: 17143}*/:
                        if (j != 1) {
                            StringBuilder sb3 = new StringBuilder(50);
                            sb3.append("EBMLReadVersion ");
                            sb3.append(j);
                            sb3.append(" not supported");
                            throw new ParserException(sb3.toString());
                        }
                        return;
                    case ID_CONTENT_ENCRYPTION_ALGORITHM /*{ENCODED_INT: 18401}*/:
                        if (j != 5) {
                            StringBuilder sb4 = new StringBuilder(49);
                            sb4.append("ContentEncAlgo ");
                            sb4.append(j);
                            sb4.append(" not supported");
                            throw new ParserException(sb4.toString());
                        }
                        return;
                    case ID_CONTENT_ENCRYPTION_AES_SETTINGS_CIPHER_MODE /*{ENCODED_INT: 18408}*/:
                        if (j != 1) {
                            StringBuilder sb5 = new StringBuilder(56);
                            sb5.append("AESSettingsCipherMode ");
                            sb5.append(j);
                            sb5.append(" not supported");
                            throw new ParserException(sb5.toString());
                        }
                        return;
                    case ID_SEEK_POSITION /*{ENCODED_INT: 21420}*/:
                        this.seekEntryPosition = j + this.segmentContentPosition;
                        return;
                    case ID_STEREO_MODE /*{ENCODED_INT: 21432}*/:
                        int i2 = (int) j;
                        assertInTrackEntry(i);
                        if (i2 == 0) {
                            this.currentTrack.stereoMode = 0;
                            return;
                        } else if (i2 == 1) {
                            this.currentTrack.stereoMode = 2;
                            return;
                        } else if (i2 == 3) {
                            this.currentTrack.stereoMode = 1;
                            return;
                        } else if (i2 == 15) {
                            this.currentTrack.stereoMode = 3;
                            return;
                        } else {
                            return;
                        }
                    case ID_DISPLAY_WIDTH /*{ENCODED_INT: 21680}*/:
                        getCurrentTrack(i).displayWidth = (int) j;
                        return;
                    case ID_DISPLAY_UNIT /*{ENCODED_INT: 21682}*/:
                        getCurrentTrack(i).displayUnit = (int) j;
                        return;
                    case ID_DISPLAY_HEIGHT /*{ENCODED_INT: 21690}*/:
                        getCurrentTrack(i).displayHeight = (int) j;
                        return;
                    case ID_FLAG_FORCED /*{ENCODED_INT: 21930}*/:
                        Track currentTrack3 = getCurrentTrack(i);
                        if (j == 1) {
                            z = true;
                        }
                        currentTrack3.flagForced = z;
                        return;
                    case ID_MAX_BLOCK_ADDITION_ID /*{ENCODED_INT: 21998}*/:
                        getCurrentTrack(i).maxBlockAdditionId = (int) j;
                        return;
                    case ID_CODEC_DELAY /*{ENCODED_INT: 22186}*/:
                        getCurrentTrack(i).codecDelayNs = j;
                        return;
                    case ID_SEEK_PRE_ROLL /*{ENCODED_INT: 22203}*/:
                        getCurrentTrack(i).seekPreRollNs = j;
                        return;
                    case ID_AUDIO_BIT_DEPTH /*{ENCODED_INT: 25188}*/:
                        getCurrentTrack(i).audioBitDepth = (int) j;
                        return;
                    case ID_PROJECTION_TYPE /*{ENCODED_INT: 30321}*/:
                        assertInTrackEntry(i);
                        int i3 = (int) j;
                        if (i3 == 0) {
                            this.currentTrack.projectionType = 0;
                            return;
                        } else if (i3 == 1) {
                            this.currentTrack.projectionType = 1;
                            return;
                        } else if (i3 == 2) {
                            this.currentTrack.projectionType = 2;
                            return;
                        } else if (i3 == 3) {
                            this.currentTrack.projectionType = 3;
                            return;
                        } else {
                            return;
                        }
                    case ID_DEFAULT_DURATION /*{ENCODED_INT: 2352003}*/:
                        getCurrentTrack(i).defaultSampleDurationNs = (int) j;
                        return;
                    case ID_TIMECODE_SCALE /*{ENCODED_INT: 2807729}*/:
                        this.timecodeScale = j;
                        return;
                    default:
                        switch (i) {
                            case ID_COLOUR_RANGE /*{ENCODED_INT: 21945}*/:
                                assertInTrackEntry(i);
                                int i4 = (int) j;
                                if (i4 == 1) {
                                    this.currentTrack.colorRange = 2;
                                    return;
                                } else if (i4 == 2) {
                                    this.currentTrack.colorRange = 1;
                                    return;
                                } else {
                                    return;
                                }
                            case ID_COLOUR_TRANSFER /*{ENCODED_INT: 21946}*/:
                                assertInTrackEntry(i);
                                int i5 = (int) j;
                                if (i5 != 1) {
                                    if (i5 == 16) {
                                        this.currentTrack.colorTransfer = 6;
                                        return;
                                    } else if (i5 == 18) {
                                        this.currentTrack.colorTransfer = 7;
                                        return;
                                    } else if (!(i5 == 6 || i5 == 7)) {
                                        return;
                                    }
                                }
                                this.currentTrack.colorTransfer = 3;
                                return;
                            case ID_COLOUR_PRIMARIES /*{ENCODED_INT: 21947}*/:
                                assertInTrackEntry(i);
                                Track track = this.currentTrack;
                                track.hasColorInfo = true;
                                int i6 = (int) j;
                                if (i6 == 1) {
                                    track.colorSpace = 1;
                                    return;
                                } else if (i6 == 9) {
                                    track.colorSpace = 6;
                                    return;
                                } else if (i6 == 4 || i6 == 5 || i6 == 6 || i6 == 7) {
                                    track.colorSpace = 2;
                                    return;
                                } else {
                                    return;
                                }
                            case ID_MAX_CLL /*{ENCODED_INT: 21948}*/:
                                getCurrentTrack(i).maxContentLuminance = (int) j;
                                return;
                            case ID_MAX_FALL /*{ENCODED_INT: 21949}*/:
                                getCurrentTrack(i).maxFrameAverageLuminance = (int) j;
                                return;
                            default:
                                return;
                        }
                }
            } else if (j != 1) {
                StringBuilder sb6 = new StringBuilder(55);
                sb6.append("ContentEncodingScope ");
                sb6.append(j);
                sb6.append(" not supported");
                throw new ParserException(sb6.toString());
            }
        } else if (j != 0) {
            StringBuilder sb7 = new StringBuilder(55);
            sb7.append("ContentEncodingOrder ");
            sb7.append(j);
            sb7.append(" not supported");
            throw new ParserException(sb7.toString());
        }
    }

    @CallSuper
    public boolean isLevel1Element(int i) {
        return i == 357149030 || i == ID_CLUSTER || i == ID_CUES || i == ID_TRACKS;
    }

    @Override // com.google.android.exoplayer2.extractor.Extractor
    public final int read(ExtractorInput extractorInput, PositionHolder positionHolder) {
        this.haveOutputSample = false;
        boolean z = true;
        while (z && !this.haveOutputSample) {
            z = this.reader.read(extractorInput);
            if (z && maybeSeekForCues(positionHolder, extractorInput.getPosition())) {
                return 1;
            }
        }
        if (z) {
            return 0;
        }
        for (int i = 0; i < this.tracks.size(); i++) {
            Track valueAt = this.tracks.valueAt(i);
            valueAt.assertOutputInitialized();
            valueAt.outputPendingSampleMetadata();
        }
        return -1;
    }

    @Override // com.google.android.exoplayer2.extractor.Extractor
    public final void release() {
    }

    @Override // com.google.android.exoplayer2.extractor.Extractor
    @CallSuper
    public void seek(long j, long j2) {
        this.clusterTimecodeUs = C.TIME_UNSET;
        this.blockState = 0;
        this.reader.reset();
        this.varintReader.reset();
        resetWriteSampleData();
        for (int i = 0; i < this.tracks.size(); i++) {
            this.tracks.valueAt(i).reset();
        }
    }

    @Override // com.google.android.exoplayer2.extractor.Extractor
    public final boolean sniff(ExtractorInput extractorInput) {
        return new Sniffer().sniff(extractorInput);
    }

    @CallSuper
    public void startMasterElement(int i, long j, long j2) {
        assertInitialized();
        if (i == ID_BLOCK_GROUP) {
            this.blockHasReferenceBlock = false;
        } else if (i == ID_TRACK_ENTRY) {
            this.currentTrack = new Track();
        } else if (i == ID_CUE_POINT) {
            this.seenClusterPositionForCurrentCuePoint = false;
        } else if (i == ID_SEEK) {
            this.seekEntryId = -1;
            this.seekEntryPosition = -1;
        } else if (i == ID_CONTENT_ENCRYPTION) {
            getCurrentTrack(i).hasContentEncryption = true;
        } else if (i == ID_MASTERING_METADATA) {
            getCurrentTrack(i).hasColorInfo = true;
        } else if (i == ID_SEGMENT) {
            long j3 = this.segmentContentPosition;
            if (j3 == -1 || j3 == j) {
                this.segmentContentPosition = j;
                this.segmentContentSize = j2;
                return;
            }
            throw new ParserException("Multiple Segment elements not supported");
        } else if (i == ID_CUES) {
            this.cueTimesUs = new LongArray();
            this.cueClusterPositions = new LongArray();
        } else if (i != ID_CLUSTER || this.sentSeekMap) {
        } else {
            if (!this.seekForCuesEnabled || this.cuesContentPosition == -1) {
                this.extractorOutput.seekMap(new SeekMap.Unseekable(this.durationUs));
                this.sentSeekMap = true;
                return;
            }
            this.seekForCues = true;
        }
    }

    @CallSuper
    public void stringElement(int i, String str) {
        if (i == 134) {
            getCurrentTrack(i).codecId = str;
        } else if (i != ID_DOC_TYPE) {
            if (i == ID_NAME) {
                getCurrentTrack(i).name = str;
            } else if (i == ID_LANGUAGE) {
                getCurrentTrack(i).language = str;
            }
        } else if (!DOC_TYPE_WEBM.equals(str) && !DOC_TYPE_MATROSKA.equals(str)) {
            throw new ParserException(b2.r(b2.a(str, 22), "DocType ", str, " not supported"));
        }
    }

    public MatroskaExtractor(int i) {
        this(new DefaultEbmlReader(), i);
    }

    public MatroskaExtractor(EbmlReader ebmlReader, int i) {
        this.segmentContentPosition = -1;
        this.timecodeScale = C.TIME_UNSET;
        this.durationTimecode = C.TIME_UNSET;
        this.durationUs = C.TIME_UNSET;
        this.cuesContentPosition = -1;
        this.seekPositionAfterBuildingCues = -1;
        this.clusterTimecodeUs = C.TIME_UNSET;
        this.reader = ebmlReader;
        ebmlReader.init(new InnerEbmlProcessor());
        this.seekForCuesEnabled = (i & 1) == 0;
        this.varintReader = new VarintReader();
        this.tracks = new SparseArray<>();
        this.scratch = new ParsableByteArray(4);
        this.vorbisNumPageSamples = new ParsableByteArray(ByteBuffer.allocate(4).putInt(-1).array());
        this.seekEntryIdBytes = new ParsableByteArray(4);
        this.nalStartCode = new ParsableByteArray(NalUnitUtil.NAL_START_CODE);
        this.nalLength = new ParsableByteArray(4);
        this.sampleStrippedBytes = new ParsableByteArray();
        this.subtitleSample = new ParsableByteArray();
        this.encryptionInitializationVector = new ParsableByteArray(8);
        this.encryptionSubsampleData = new ParsableByteArray();
        this.blockAdditionalData = new ParsableByteArray();
        this.blockSampleSizes = new int[1];
    }
}
