package com.google.android.exoplayer2.extractor.mp4;

import android.util.Pair;
import androidx.annotation.Nullable;
import androidx.base.b2;
import androidx.base.bs;
import androidx.base.qq;
import com.google.android.exoplayer2.C;
import com.google.android.exoplayer2.Format;
import com.google.android.exoplayer2.ParserException;
import com.google.android.exoplayer2.audio.AacUtil;
import com.google.android.exoplayer2.audio.Ac3Util;
import com.google.android.exoplayer2.audio.Ac4Util;
import com.google.android.exoplayer2.audio.OpusUtil;
import com.google.android.exoplayer2.drm.DrmInitData;
import com.google.android.exoplayer2.extractor.GaplessInfoHolder;
import com.google.android.exoplayer2.extractor.mp4.Atom;
import com.google.android.exoplayer2.extractor.mp4.FixedSampleSizeRechunker;
import com.google.android.exoplayer2.extractor.ts.PsExtractor;
import com.google.android.exoplayer2.metadata.Metadata;
import com.google.android.exoplayer2.metadata.mp4.MdtaMetadataEntry;
import com.google.android.exoplayer2.metadata.mp4.SmtaMetadataEntry;
import com.google.android.exoplayer2.util.Assertions;
import com.google.android.exoplayer2.util.CodecSpecificDataUtil;
import com.google.android.exoplayer2.util.Log;
import com.google.android.exoplayer2.util.MimeTypes;
import com.google.android.exoplayer2.util.ParsableByteArray;
import com.google.android.exoplayer2.util.Util;
import com.google.android.exoplayer2.video.AvcConfig;
import com.google.android.exoplayer2.video.DolbyVisionConfig;
import com.google.android.exoplayer2.video.HevcConfig;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

public final class AtomParsers {
    private static final int MAX_GAPLESS_TRIM_SIZE_SAMPLES = 4;
    private static final String TAG = "AtomParsers";
    private static final int TYPE_clcp = 1668047728;
    private static final int TYPE_mdta = 1835299937;
    private static final int TYPE_meta = 1835365473;
    private static final int TYPE_sbtl = 1935832172;
    private static final int TYPE_soun = 1936684398;
    private static final int TYPE_subt = 1937072756;
    private static final int TYPE_text = 1952807028;
    private static final int TYPE_vide = 1986618469;
    private static final byte[] opusMagic = Util.getUtf8Bytes("OpusHead");

    public static final class ChunkIterator {
        private final ParsableByteArray chunkOffsets;
        private final boolean chunkOffsetsAreLongs;
        public int index;
        public final int length;
        private int nextSamplesPerChunkChangeIndex;
        public int numSamples;
        public long offset;
        private int remainingSamplesPerChunkChanges;
        private final ParsableByteArray stsc;

        public ChunkIterator(ParsableByteArray parsableByteArray, ParsableByteArray parsableByteArray2, boolean z) {
            this.stsc = parsableByteArray;
            this.chunkOffsets = parsableByteArray2;
            this.chunkOffsetsAreLongs = z;
            parsableByteArray2.setPosition(12);
            this.length = parsableByteArray2.readUnsignedIntToInt();
            parsableByteArray.setPosition(12);
            this.remainingSamplesPerChunkChanges = parsableByteArray.readUnsignedIntToInt();
            Assertions.checkState(parsableByteArray.readInt() != 1 ? false : true, "first_chunk must be 1");
            this.index = -1;
        }

        public boolean moveNext() {
            long j;
            int i = this.index + 1;
            this.index = i;
            if (i == this.length) {
                return false;
            }
            if (this.chunkOffsetsAreLongs) {
                j = this.chunkOffsets.readUnsignedLongToLong();
            } else {
                j = this.chunkOffsets.readUnsignedInt();
            }
            this.offset = j;
            if (this.index == this.nextSamplesPerChunkChangeIndex) {
                this.numSamples = this.stsc.readUnsignedIntToInt();
                this.stsc.skipBytes(4);
                int i2 = this.remainingSamplesPerChunkChanges - 1;
                this.remainingSamplesPerChunkChanges = i2;
                this.nextSamplesPerChunkChangeIndex = i2 > 0 ? this.stsc.readUnsignedIntToInt() - 1 : -1;
            }
            return true;
        }
    }

    public interface SampleSizeBox {
        int getFixedSampleSize();

        int getSampleCount();

        int readNextSampleSize();
    }

    public static final class StsdData {
        public static final int STSD_HEADER_SIZE = 8;
        @Nullable
        public Format format;
        public int nalUnitLengthFieldLength;
        public int requiredSampleTransformation = 0;
        public final TrackEncryptionBox[] trackEncryptionBoxes;

        public StsdData(int i) {
            this.trackEncryptionBoxes = new TrackEncryptionBox[i];
        }
    }

    public static final class StszSampleSizeBox implements SampleSizeBox {
        private final ParsableByteArray data;
        private final int fixedSampleSize;
        private final int sampleCount;

        public StszSampleSizeBox(Atom.LeafAtom leafAtom, Format format) {
            ParsableByteArray parsableByteArray = leafAtom.data;
            this.data = parsableByteArray;
            parsableByteArray.setPosition(12);
            int readUnsignedIntToInt = parsableByteArray.readUnsignedIntToInt();
            if (MimeTypes.AUDIO_RAW.equals(format.sampleMimeType)) {
                int pcmFrameSize = Util.getPcmFrameSize(format.pcmEncoding, format.channelCount);
                if (readUnsignedIntToInt == 0 || readUnsignedIntToInt % pcmFrameSize != 0) {
                    StringBuilder sb = new StringBuilder(88);
                    sb.append("Audio sample size mismatch. stsd sample size: ");
                    sb.append(pcmFrameSize);
                    sb.append(", stsz sample size: ");
                    sb.append(readUnsignedIntToInt);
                    Log.w(AtomParsers.TAG, sb.toString());
                    readUnsignedIntToInt = pcmFrameSize;
                }
            }
            this.fixedSampleSize = readUnsignedIntToInt == 0 ? -1 : readUnsignedIntToInt;
            this.sampleCount = parsableByteArray.readUnsignedIntToInt();
        }

        @Override // com.google.android.exoplayer2.extractor.mp4.AtomParsers.SampleSizeBox
        public int getFixedSampleSize() {
            return this.fixedSampleSize;
        }

        @Override // com.google.android.exoplayer2.extractor.mp4.AtomParsers.SampleSizeBox
        public int getSampleCount() {
            return this.sampleCount;
        }

        @Override // com.google.android.exoplayer2.extractor.mp4.AtomParsers.SampleSizeBox
        public int readNextSampleSize() {
            int i = this.fixedSampleSize;
            return i == -1 ? this.data.readUnsignedIntToInt() : i;
        }
    }

    public static final class Stz2SampleSizeBox implements SampleSizeBox {
        private int currentByte;
        private final ParsableByteArray data;
        private final int fieldSize;
        private final int sampleCount;
        private int sampleIndex;

        public Stz2SampleSizeBox(Atom.LeafAtom leafAtom) {
            ParsableByteArray parsableByteArray = leafAtom.data;
            this.data = parsableByteArray;
            parsableByteArray.setPosition(12);
            this.fieldSize = parsableByteArray.readUnsignedIntToInt() & 255;
            this.sampleCount = parsableByteArray.readUnsignedIntToInt();
        }

        @Override // com.google.android.exoplayer2.extractor.mp4.AtomParsers.SampleSizeBox
        public int getFixedSampleSize() {
            return -1;
        }

        @Override // com.google.android.exoplayer2.extractor.mp4.AtomParsers.SampleSizeBox
        public int getSampleCount() {
            return this.sampleCount;
        }

        @Override // com.google.android.exoplayer2.extractor.mp4.AtomParsers.SampleSizeBox
        public int readNextSampleSize() {
            int i = this.fieldSize;
            if (i == 8) {
                return this.data.readUnsignedByte();
            }
            if (i == 16) {
                return this.data.readUnsignedShort();
            }
            int i2 = this.sampleIndex;
            this.sampleIndex = i2 + 1;
            if (i2 % 2 != 0) {
                return this.currentByte & 15;
            }
            int readUnsignedByte = this.data.readUnsignedByte();
            this.currentByte = readUnsignedByte;
            return (readUnsignedByte & PsExtractor.VIDEO_STREAM_MASK) >> 4;
        }
    }

    public static final class TkhdData {
        private final long duration;
        private final int id;
        private final int rotationDegrees;

        public TkhdData(int i, long j, int i2) {
            this.id = i;
            this.duration = j;
            this.rotationDegrees = i2;
        }
    }

    private AtomParsers() {
    }

    private static boolean canApplyEditWithGaplessInfo(long[] jArr, long j, long j2, long j3) {
        int length = jArr.length - 1;
        int constrainValue = Util.constrainValue(4, 0, length);
        int constrainValue2 = Util.constrainValue(jArr.length - 4, 0, length);
        if (jArr[0] > j2 || j2 >= jArr[constrainValue] || jArr[constrainValue2] >= j3 || j3 > j) {
            return false;
        }
        return true;
    }

    private static int findEsdsPosition(ParsableByteArray parsableByteArray, int i, int i2) {
        int position = parsableByteArray.getPosition();
        while (position - i < i2) {
            parsableByteArray.setPosition(position);
            int readInt = parsableByteArray.readInt();
            Assertions.checkState(readInt > 0, "childAtomSize should be positive");
            if (parsableByteArray.readInt() == 1702061171) {
                return position;
            }
            position += readInt;
        }
        return -1;
    }

    private static int getTrackTypeForHdlr(int i) {
        if (i == TYPE_soun) {
            return 1;
        }
        if (i == TYPE_vide) {
            return 2;
        }
        if (i == TYPE_text || i == TYPE_sbtl || i == TYPE_subt || i == TYPE_clcp) {
            return 3;
        }
        return i == 1835365473 ? 5 : -1;
    }

    public static void maybeSkipRemainingMetaAtomHeaderBytes(ParsableByteArray parsableByteArray) {
        int position = parsableByteArray.getPosition();
        parsableByteArray.skipBytes(4);
        if (parsableByteArray.readInt() != 1751411826) {
            position += 4;
        }
        parsableByteArray.setPosition(position);
    }

    /* JADX WARNING: Removed duplicated region for block: B:142:0x02c2 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:151:? A[ADDED_TO_REGION, RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:90:0x0148  */
    private static void parseAudioSampleEntry(ParsableByteArray parsableByteArray, int i, int i2, int i3, int i4, String str, boolean z, @Nullable DrmInitData drmInitData, StsdData stsdData, int i5) {
        int i6;
        int i7;
        int i8;
        DrmInitData drmInitData2;
        int i9;
        int i10;
        List<byte[]> buildInitializationData;
        int i11 = i2;
        int i12 = i3;
        parsableByteArray.setPosition(i11 + 8 + 8);
        if (z) {
            i6 = parsableByteArray.readUnsignedShort();
            parsableByteArray.skipBytes(6);
        } else {
            parsableByteArray.skipBytes(8);
            i6 = 0;
        }
        boolean z2 = true;
        if (i6 == 0 || i6 == 1) {
            int readUnsignedShort = parsableByteArray.readUnsignedShort();
            parsableByteArray.skipBytes(6);
            int readUnsignedFixedPoint1616 = parsableByteArray.readUnsignedFixedPoint1616();
            if (i6 == 1) {
                parsableByteArray.skipBytes(16);
            }
            i7 = readUnsignedFixedPoint1616;
            i8 = readUnsignedShort;
        } else if (i6 == 2) {
            parsableByteArray.skipBytes(16);
            i7 = (int) Math.round(parsableByteArray.readDouble());
            i8 = parsableByteArray.readUnsignedIntToInt();
            parsableByteArray.skipBytes(20);
        } else {
            return;
        }
        int position = parsableByteArray.getPosition();
        int i13 = i;
        if (i13 == 1701733217) {
            Pair<Integer, TrackEncryptionBox> parseSampleEntryEncryptionData = parseSampleEntryEncryptionData(parsableByteArray, i11, i12);
            if (parseSampleEntryEncryptionData != null) {
                i13 = ((Integer) parseSampleEntryEncryptionData.first).intValue();
                if (drmInitData == null) {
                    drmInitData2 = null;
                } else {
                    drmInitData2 = drmInitData.copyWithSchemeType(((TrackEncryptionBox) parseSampleEntryEncryptionData.second).schemeType);
                }
                stsdData.trackEncryptionBoxes[i5] = (TrackEncryptionBox) parseSampleEntryEncryptionData.second;
            } else {
                drmInitData2 = drmInitData;
            }
            parsableByteArray.setPosition(position);
        } else {
            drmInitData2 = drmInitData;
        }
        String str2 = MimeTypes.AUDIO_RAW;
        if (i13 == 1633889587) {
            str2 = MimeTypes.AUDIO_AC3;
        } else if (i13 == 1700998451) {
            str2 = MimeTypes.AUDIO_E_AC3;
        } else if (i13 == 1633889588) {
            str2 = MimeTypes.AUDIO_AC4;
        } else if (i13 == 1685353315) {
            str2 = MimeTypes.AUDIO_DTS;
        } else if (i13 == 1685353320 || i13 == 1685353324) {
            str2 = MimeTypes.AUDIO_DTS_HD;
        } else if (i13 == 1685353317) {
            str2 = MimeTypes.AUDIO_DTS_EXPRESS;
        } else if (i13 == 1935764850) {
            str2 = MimeTypes.AUDIO_AMR_NB;
        } else if (i13 == 1935767394) {
            str2 = MimeTypes.AUDIO_AMR_WB;
        } else if (i13 == 1819304813 || i13 == 1936684916) {
            i9 = 2;
            String str3 = str2;
            String str4 = null;
            bs bsVar = null;
            while (position - i11 < i12) {
                parsableByteArray.setPosition(position);
                int readInt = parsableByteArray.readInt();
                if (readInt <= 0) {
                    z2 = false;
                }
                Assertions.checkState(z2, "childAtomSize should be positive");
                int readInt2 = parsableByteArray.readInt();
                if (readInt2 == 1835557187) {
                    int i14 = readInt - 13;
                    byte[] bArr = new byte[i14];
                    parsableByteArray.setPosition(position + 13);
                    parsableByteArray.readBytes(bArr, 0, i14);
                    buildInitializationData = bs.of(bArr);
                } else if (readInt2 == 1702061171 || (z && readInt2 == 2002876005)) {
                    z2 = true;
                    if (readInt2 == 1702061171) {
                        i10 = position;
                    } else {
                        i10 = findEsdsPosition(parsableByteArray, position, readInt);
                    }
                    if (i10 != -1) {
                        Pair<String, byte[]> parseEsdsFromParent = parseEsdsFromParent(parsableByteArray, i10);
                        str3 = (String) parseEsdsFromParent.first;
                        byte[] bArr2 = (byte[]) parseEsdsFromParent.second;
                        if (bArr2 != null) {
                            if (MimeTypes.AUDIO_AAC.equals(str3)) {
                                AacUtil.Config parseAudioSpecificConfig = AacUtil.parseAudioSpecificConfig(bArr2);
                                i7 = parseAudioSpecificConfig.sampleRateHz;
                                i8 = parseAudioSpecificConfig.channelCount;
                                str4 = parseAudioSpecificConfig.codecs;
                            }
                            bsVar = bs.of(bArr2);
                        }
                    }
                    position += readInt;
                    i11 = i2;
                    i12 = i3;
                } else {
                    if (readInt2 == 1684103987) {
                        parsableByteArray.setPosition(position + 8);
                        stsdData.format = Ac3Util.parseAc3AnnexFFormat(parsableByteArray, Integer.toString(i4), str, drmInitData2);
                    } else if (readInt2 == 1684366131) {
                        parsableByteArray.setPosition(position + 8);
                        stsdData.format = Ac3Util.parseEAc3AnnexFFormat(parsableByteArray, Integer.toString(i4), str, drmInitData2);
                    } else if (readInt2 == 1684103988) {
                        parsableByteArray.setPosition(position + 8);
                        stsdData.format = Ac4Util.parseAc4AnnexEFormat(parsableByteArray, Integer.toString(i4), str, drmInitData2);
                    } else if (readInt2 == 1684305011) {
                        stsdData.format = new Format.Builder().setId(i4).setSampleMimeType(str3).setChannelCount(i8).setSampleRate(i7).setDrmInitData(drmInitData2).setLanguage(str).build();
                    } else if (readInt2 == 1682927731) {
                        int i15 = readInt - 8;
                        byte[] bArr3 = opusMagic;
                        byte[] copyOf = Arrays.copyOf(bArr3, bArr3.length + i15);
                        parsableByteArray.setPosition(position + 8);
                        parsableByteArray.readBytes(copyOf, bArr3.length, i15);
                        buildInitializationData = OpusUtil.buildInitializationData(copyOf);
                    } else {
                        if (readInt2 == 1684425825) {
                            int i16 = readInt - 12;
                            byte[] bArr4 = new byte[(i16 + 4)];
                            bArr4[0] = 102;
                            z2 = true;
                            bArr4[1] = 76;
                            bArr4[2] = 97;
                            bArr4[3] = 67;
                            parsableByteArray.setPosition(position + 12);
                            parsableByteArray.readBytes(bArr4, 4, i16);
                            bsVar = bs.of(bArr4);
                        } else {
                            z2 = true;
                            if (readInt2 == 1634492771) {
                                int i17 = readInt - 12;
                                byte[] bArr5 = new byte[i17];
                                parsableByteArray.setPosition(position + 12);
                                parsableByteArray.readBytes(bArr5, 0, i17);
                                Pair<Integer, Integer> parseAlacAudioSpecificConfig = CodecSpecificDataUtil.parseAlacAudioSpecificConfig(bArr5);
                                i7 = ((Integer) parseAlacAudioSpecificConfig.first).intValue();
                                int intValue = ((Integer) parseAlacAudioSpecificConfig.second).intValue();
                                bsVar = bs.of(bArr5);
                                i8 = intValue;
                                position += readInt;
                                i11 = i2;
                                i12 = i3;
                            }
                        }
                        position += readInt;
                        i11 = i2;
                        i12 = i3;
                    }
                    z2 = true;
                    position += readInt;
                    i11 = i2;
                    i12 = i3;
                }
                bsVar = buildInitializationData;
                z2 = true;
                position += readInt;
                i11 = i2;
                i12 = i3;
            }
            if (stsdData.format != null && str3 != null) {
                stsdData.format = new Format.Builder().setId(i4).setSampleMimeType(str3).setCodecs(str4).setChannelCount(i8).setSampleRate(i7).setPcmEncoding(i9).setInitializationData(bsVar).setDrmInitData(drmInitData2).setLanguage(str).build();
                return;
            }
            return;
        } else {
            if (i13 == 1953984371) {
                i9 = 268435456;
            } else if (i13 == 778924082 || i13 == 778924083) {
                str2 = MimeTypes.AUDIO_MPEG;
            } else if (i13 == 1835557169) {
                str2 = MimeTypes.AUDIO_MPEGH_MHA1;
            } else if (i13 == 1835560241) {
                str2 = MimeTypes.AUDIO_MPEGH_MHM1;
            } else if (i13 == 1634492771) {
                str2 = MimeTypes.AUDIO_ALAC;
            } else if (i13 == 1634492791) {
                str2 = MimeTypes.AUDIO_ALAW;
            } else if (i13 == 1970037111) {
                str2 = MimeTypes.AUDIO_MLAW;
            } else if (i13 == 1332770163) {
                str2 = MimeTypes.AUDIO_OPUS;
            } else if (i13 == 1716281667) {
                str2 = MimeTypes.AUDIO_FLAC;
            } else {
                i9 = -1;
                str2 = null;
            }
            String str32 = str2;
            String str42 = null;
            bs bsVar2 = null;
            while (position - i11 < i12) {
            }
            if (stsdData.format != null) {
                return;
            }
            return;
        }
        i9 = -1;
        String str322 = str2;
        String str422 = null;
        bs bsVar22 = null;
        while (position - i11 < i12) {
        }
        if (stsdData.format != null) {
        }
    }

    @Nullable
    public static Pair<Integer, TrackEncryptionBox> parseCommonEncryptionSinfFromParent(ParsableByteArray parsableByteArray, int i, int i2) {
        int i3 = i + 8;
        boolean z = false;
        String str = null;
        Integer num = null;
        int i4 = -1;
        int i5 = 0;
        while (i3 - i < i2) {
            parsableByteArray.setPosition(i3);
            int readInt = parsableByteArray.readInt();
            int readInt2 = parsableByteArray.readInt();
            if (readInt2 == 1718775137) {
                num = Integer.valueOf(parsableByteArray.readInt());
            } else if (readInt2 == 1935894637) {
                parsableByteArray.skipBytes(4);
                str = parsableByteArray.readString(4);
            } else if (readInt2 == 1935894633) {
                i4 = i3;
                i5 = readInt;
            }
            i3 += readInt;
        }
        if (!C.CENC_TYPE_cenc.equals(str) && !C.CENC_TYPE_cbc1.equals(str) && !C.CENC_TYPE_cens.equals(str) && !C.CENC_TYPE_cbcs.equals(str)) {
            return null;
        }
        Assertions.checkStateNotNull(num, "frma atom is mandatory");
        if (i4 != -1) {
            z = true;
        }
        Assertions.checkState(z, "schi atom is mandatory");
        return Pair.create(num, (TrackEncryptionBox) Assertions.checkStateNotNull(parseSchiFromParent(parsableByteArray, i4, i5, str), "tenc atom is mandatory"));
    }

    @Nullable
    private static Pair<long[], long[]> parseEdts(Atom.ContainerAtom containerAtom) {
        Atom.LeafAtom leafAtomOfType = containerAtom.getLeafAtomOfType(Atom.TYPE_elst);
        if (leafAtomOfType == null) {
            return null;
        }
        ParsableByteArray parsableByteArray = leafAtomOfType.data;
        parsableByteArray.setPosition(8);
        int parseFullAtomVersion = Atom.parseFullAtomVersion(parsableByteArray.readInt());
        int readUnsignedIntToInt = parsableByteArray.readUnsignedIntToInt();
        long[] jArr = new long[readUnsignedIntToInt];
        long[] jArr2 = new long[readUnsignedIntToInt];
        for (int i = 0; i < readUnsignedIntToInt; i++) {
            jArr[i] = parseFullAtomVersion == 1 ? parsableByteArray.readUnsignedLongToLong() : parsableByteArray.readUnsignedInt();
            jArr2[i] = parseFullAtomVersion == 1 ? parsableByteArray.readLong() : (long) parsableByteArray.readInt();
            if (parsableByteArray.readShort() == 1) {
                parsableByteArray.skipBytes(2);
            } else {
                throw new IllegalArgumentException("Unsupported media rate.");
            }
        }
        return Pair.create(jArr, jArr2);
    }

    private static Pair<String, byte[]> parseEsdsFromParent(ParsableByteArray parsableByteArray, int i) {
        parsableByteArray.setPosition(i + 8 + 4);
        parsableByteArray.skipBytes(1);
        parseExpandableClassSize(parsableByteArray);
        parsableByteArray.skipBytes(2);
        int readUnsignedByte = parsableByteArray.readUnsignedByte();
        if ((readUnsignedByte & 128) != 0) {
            parsableByteArray.skipBytes(2);
        }
        if ((readUnsignedByte & 64) != 0) {
            parsableByteArray.skipBytes(parsableByteArray.readUnsignedShort());
        }
        if ((readUnsignedByte & 32) != 0) {
            parsableByteArray.skipBytes(2);
        }
        parsableByteArray.skipBytes(1);
        parseExpandableClassSize(parsableByteArray);
        String mimeTypeFromMp4ObjectType = MimeTypes.getMimeTypeFromMp4ObjectType(parsableByteArray.readUnsignedByte());
        if (MimeTypes.AUDIO_MPEG.equals(mimeTypeFromMp4ObjectType) || MimeTypes.AUDIO_DTS.equals(mimeTypeFromMp4ObjectType) || MimeTypes.AUDIO_DTS_HD.equals(mimeTypeFromMp4ObjectType)) {
            return Pair.create(mimeTypeFromMp4ObjectType, null);
        }
        parsableByteArray.skipBytes(12);
        parsableByteArray.skipBytes(1);
        int parseExpandableClassSize = parseExpandableClassSize(parsableByteArray);
        byte[] bArr = new byte[parseExpandableClassSize];
        parsableByteArray.readBytes(bArr, 0, parseExpandableClassSize);
        return Pair.create(mimeTypeFromMp4ObjectType, bArr);
    }

    private static int parseExpandableClassSize(ParsableByteArray parsableByteArray) {
        int readUnsignedByte = parsableByteArray.readUnsignedByte();
        int i = readUnsignedByte & 127;
        while ((readUnsignedByte & 128) == 128) {
            readUnsignedByte = parsableByteArray.readUnsignedByte();
            i = (i << 7) | (readUnsignedByte & 127);
        }
        return i;
    }

    private static int parseHdlr(ParsableByteArray parsableByteArray) {
        parsableByteArray.setPosition(16);
        return parsableByteArray.readInt();
    }

    @Nullable
    private static Metadata parseIlst(ParsableByteArray parsableByteArray, int i) {
        parsableByteArray.skipBytes(8);
        ArrayList arrayList = new ArrayList();
        while (parsableByteArray.getPosition() < i) {
            Metadata.Entry parseIlstElement = MetadataUtil.parseIlstElement(parsableByteArray);
            if (parseIlstElement != null) {
                arrayList.add(parseIlstElement);
            }
        }
        if (arrayList.isEmpty()) {
            return null;
        }
        return new Metadata(arrayList);
    }

    private static Pair<Long, String> parseMdhd(ParsableByteArray parsableByteArray) {
        int i = 8;
        parsableByteArray.setPosition(8);
        int parseFullAtomVersion = Atom.parseFullAtomVersion(parsableByteArray.readInt());
        parsableByteArray.skipBytes(parseFullAtomVersion == 0 ? 8 : 16);
        long readUnsignedInt = parsableByteArray.readUnsignedInt();
        if (parseFullAtomVersion == 0) {
            i = 4;
        }
        parsableByteArray.skipBytes(i);
        int readUnsignedShort = parsableByteArray.readUnsignedShort();
        StringBuilder sb = new StringBuilder(3);
        sb.append((char) (((readUnsignedShort >> 10) & 31) + 96));
        sb.append((char) (((readUnsignedShort >> 5) & 31) + 96));
        sb.append((char) ((readUnsignedShort & 31) + 96));
        return Pair.create(Long.valueOf(readUnsignedInt), sb.toString());
    }

    @Nullable
    public static Metadata parseMdtaFromMeta(Atom.ContainerAtom containerAtom) {
        Atom.LeafAtom leafAtomOfType = containerAtom.getLeafAtomOfType(Atom.TYPE_hdlr);
        Atom.LeafAtom leafAtomOfType2 = containerAtom.getLeafAtomOfType(Atom.TYPE_keys);
        Atom.LeafAtom leafAtomOfType3 = containerAtom.getLeafAtomOfType(Atom.TYPE_ilst);
        if (leafAtomOfType == null || leafAtomOfType2 == null || leafAtomOfType3 == null || parseHdlr(leafAtomOfType.data) != TYPE_mdta) {
            return null;
        }
        ParsableByteArray parsableByteArray = leafAtomOfType2.data;
        parsableByteArray.setPosition(12);
        int readInt = parsableByteArray.readInt();
        String[] strArr = new String[readInt];
        for (int i = 0; i < readInt; i++) {
            int readInt2 = parsableByteArray.readInt();
            parsableByteArray.skipBytes(4);
            strArr[i] = parsableByteArray.readString(readInt2 - 8);
        }
        ParsableByteArray parsableByteArray2 = leafAtomOfType3.data;
        parsableByteArray2.setPosition(8);
        ArrayList arrayList = new ArrayList();
        while (parsableByteArray2.bytesLeft() > 8) {
            int position = parsableByteArray2.getPosition();
            int readInt3 = parsableByteArray2.readInt();
            int readInt4 = parsableByteArray2.readInt() - 1;
            if (readInt4 < 0 || readInt4 >= readInt) {
                b2.o(52, "Skipped metadata with unknown key index: ", readInt4, TAG);
            } else {
                MdtaMetadataEntry parseMdtaMetadataEntryFromIlst = MetadataUtil.parseMdtaMetadataEntryFromIlst(parsableByteArray2, position + readInt3, strArr[readInt4]);
                if (parseMdtaMetadataEntryFromIlst != null) {
                    arrayList.add(parseMdtaMetadataEntryFromIlst);
                }
            }
            parsableByteArray2.setPosition(position + readInt3);
        }
        if (arrayList.isEmpty()) {
            return null;
        }
        return new Metadata(arrayList);
    }

    private static void parseMetaDataSampleEntry(ParsableByteArray parsableByteArray, int i, int i2, int i3, StsdData stsdData) {
        parsableByteArray.setPosition(i2 + 8 + 8);
        if (i == 1835365492) {
            parsableByteArray.readNullTerminatedString();
            String readNullTerminatedString = parsableByteArray.readNullTerminatedString();
            if (readNullTerminatedString != null) {
                stsdData.format = new Format.Builder().setId(i3).setSampleMimeType(readNullTerminatedString).build();
            }
        }
    }

    private static long parseMvhd(ParsableByteArray parsableByteArray) {
        int i = 8;
        parsableByteArray.setPosition(8);
        if (Atom.parseFullAtomVersion(parsableByteArray.readInt()) != 0) {
            i = 16;
        }
        parsableByteArray.skipBytes(i);
        return parsableByteArray.readUnsignedInt();
    }

    private static float parsePaspFromParent(ParsableByteArray parsableByteArray, int i) {
        parsableByteArray.setPosition(i + 8);
        return ((float) parsableByteArray.readUnsignedIntToInt()) / ((float) parsableByteArray.readUnsignedIntToInt());
    }

    @Nullable
    private static byte[] parseProjFromParent(ParsableByteArray parsableByteArray, int i, int i2) {
        int i3 = i + 8;
        while (i3 - i < i2) {
            parsableByteArray.setPosition(i3);
            int readInt = parsableByteArray.readInt();
            if (parsableByteArray.readInt() == 1886547818) {
                return Arrays.copyOfRange(parsableByteArray.getData(), i3, readInt + i3);
            }
            i3 += readInt;
        }
        return null;
    }

    @Nullable
    private static Pair<Integer, TrackEncryptionBox> parseSampleEntryEncryptionData(ParsableByteArray parsableByteArray, int i, int i2) {
        Pair<Integer, TrackEncryptionBox> parseCommonEncryptionSinfFromParent;
        int position = parsableByteArray.getPosition();
        while (position - i < i2) {
            parsableByteArray.setPosition(position);
            int readInt = parsableByteArray.readInt();
            Assertions.checkState(readInt > 0, "childAtomSize should be positive");
            if (parsableByteArray.readInt() == 1936289382 && (parseCommonEncryptionSinfFromParent = parseCommonEncryptionSinfFromParent(parsableByteArray, position, readInt)) != null) {
                return parseCommonEncryptionSinfFromParent;
            }
            position += readInt;
        }
        return null;
    }

    @Nullable
    private static TrackEncryptionBox parseSchiFromParent(ParsableByteArray parsableByteArray, int i, int i2, String str) {
        int i3;
        int i4;
        int i5 = i + 8;
        while (true) {
            byte[] bArr = null;
            if (i5 - i >= i2) {
                return null;
            }
            parsableByteArray.setPosition(i5);
            int readInt = parsableByteArray.readInt();
            if (parsableByteArray.readInt() == 1952804451) {
                int parseFullAtomVersion = Atom.parseFullAtomVersion(parsableByteArray.readInt());
                parsableByteArray.skipBytes(1);
                if (parseFullAtomVersion == 0) {
                    parsableByteArray.skipBytes(1);
                    i4 = 0;
                    i3 = 0;
                } else {
                    int readUnsignedByte = parsableByteArray.readUnsignedByte();
                    i3 = readUnsignedByte & 15;
                    i4 = (readUnsignedByte & PsExtractor.VIDEO_STREAM_MASK) >> 4;
                }
                boolean z = parsableByteArray.readUnsignedByte() == 1;
                int readUnsignedByte2 = parsableByteArray.readUnsignedByte();
                byte[] bArr2 = new byte[16];
                parsableByteArray.readBytes(bArr2, 0, 16);
                if (z && readUnsignedByte2 == 0) {
                    int readUnsignedByte3 = parsableByteArray.readUnsignedByte();
                    bArr = new byte[readUnsignedByte3];
                    parsableByteArray.readBytes(bArr, 0, readUnsignedByte3);
                }
                return new TrackEncryptionBox(z, str, readUnsignedByte2, bArr2, i4, i3, bArr);
            }
            i5 += readInt;
        }
    }

    @Nullable
    private static Metadata parseSmta(ParsableByteArray parsableByteArray, int i) {
        parsableByteArray.skipBytes(12);
        while (parsableByteArray.getPosition() < i) {
            int position = parsableByteArray.getPosition();
            int readInt = parsableByteArray.readInt();
            if (parsableByteArray.readInt() != 1935766900) {
                parsableByteArray.setPosition(position + readInt);
            } else if (readInt < 14) {
                return null;
            } else {
                parsableByteArray.skipBytes(5);
                int readUnsignedByte = parsableByteArray.readUnsignedByte();
                if (readUnsignedByte != 12 && readUnsignedByte != 13) {
                    return null;
                }
                float f = readUnsignedByte == 12 ? 240.0f : 120.0f;
                parsableByteArray.skipBytes(1);
                return new Metadata(new SmtaMetadataEntry(f, parsableByteArray.readUnsignedByte()));
            }
        }
        return null;
    }

    /* JADX WARNING: Removed duplicated region for block: B:107:0x0252  */
    /* JADX WARNING: Removed duplicated region for block: B:108:0x0255  */
    /* JADX WARNING: Removed duplicated region for block: B:113:0x02bb  */
    /* JADX WARNING: Removed duplicated region for block: B:115:0x02cb  */
    /* JADX WARNING: Removed duplicated region for block: B:147:0x03bb  */
    /* JADX WARNING: Removed duplicated region for block: B:148:0x03bd  */
    /* JADX WARNING: Removed duplicated region for block: B:152:0x03d5  */
    /* JADX WARNING: Removed duplicated region for block: B:169:0x0446  */
    /* JADX WARNING: Removed duplicated region for block: B:170:0x0448  */
    /* JADX WARNING: Removed duplicated region for block: B:173:0x044d  */
    /* JADX WARNING: Removed duplicated region for block: B:174:0x0450  */
    /* JADX WARNING: Removed duplicated region for block: B:176:0x0454  */
    /* JADX WARNING: Removed duplicated region for block: B:177:0x0457  */
    /* JADX WARNING: Removed duplicated region for block: B:179:0x045b  */
    /* JADX WARNING: Removed duplicated region for block: B:181:0x045e  */
    /* JADX WARNING: Removed duplicated region for block: B:182:0x0461  */
    /* JADX WARNING: Removed duplicated region for block: B:186:0x046d  */
    /* JADX WARNING: Removed duplicated region for block: B:215:0x043b A[EDGE_INSN: B:215:0x043b->B:167:0x043b ?: BREAK  , SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x0104  */
    /* JADX WARNING: Removed duplicated region for block: B:53:0x0135  */
    private static TrackSampleTable parseStbl(Track track, Atom.ContainerAtom containerAtom, GaplessInfoHolder gaplessInfoHolder) {
        SampleSizeBox sampleSizeBox;
        boolean z;
        int i;
        int i2;
        int i3;
        int fixedSampleSize;
        int i4;
        int i5;
        boolean z2;
        long j;
        int[] iArr;
        int i6;
        long[] jArr;
        Track track2;
        int[] iArr2;
        long[] jArr2;
        int i7;
        long[] jArr3;
        int[] iArr3;
        int i8;
        long j2;
        long[] jArr4;
        long[] jArr5;
        int i9;
        long[] jArr6;
        int i10;
        boolean z3;
        int i11;
        int[] iArr4;
        int[] iArr5;
        int[] iArr6;
        long[] jArr7;
        int[] iArr7;
        long[] jArr8;
        int i12;
        int i13;
        int i14;
        int i15;
        boolean z4;
        int i16;
        int i17;
        int i18;
        int i19;
        Atom.LeafAtom leafAtomOfType = containerAtom.getLeafAtomOfType(Atom.TYPE_stsz);
        if (leafAtomOfType != null) {
            sampleSizeBox = new StszSampleSizeBox(leafAtomOfType, track.format);
        } else {
            Atom.LeafAtom leafAtomOfType2 = containerAtom.getLeafAtomOfType(Atom.TYPE_stz2);
            if (leafAtomOfType2 != null) {
                sampleSizeBox = new Stz2SampleSizeBox(leafAtomOfType2);
            } else {
                throw new ParserException("Track has no sample table size information");
            }
        }
        int sampleCount = sampleSizeBox.getSampleCount();
        if (sampleCount == 0) {
            return new TrackSampleTable(track, new long[0], new int[0], 0, new long[0], new int[0], 0);
        }
        Atom.LeafAtom leafAtomOfType3 = containerAtom.getLeafAtomOfType(Atom.TYPE_stco);
        if (leafAtomOfType3 == null) {
            leafAtomOfType3 = (Atom.LeafAtom) Assertions.checkNotNull(containerAtom.getLeafAtomOfType(Atom.TYPE_co64));
            z = true;
        } else {
            z = false;
        }
        ParsableByteArray parsableByteArray = leafAtomOfType3.data;
        ParsableByteArray parsableByteArray2 = ((Atom.LeafAtom) Assertions.checkNotNull(containerAtom.getLeafAtomOfType(Atom.TYPE_stsc))).data;
        ParsableByteArray parsableByteArray3 = ((Atom.LeafAtom) Assertions.checkNotNull(containerAtom.getLeafAtomOfType(Atom.TYPE_stts))).data;
        Atom.LeafAtom leafAtomOfType4 = containerAtom.getLeafAtomOfType(Atom.TYPE_stss);
        ParsableByteArray parsableByteArray4 = leafAtomOfType4 != null ? leafAtomOfType4.data : null;
        Atom.LeafAtom leafAtomOfType5 = containerAtom.getLeafAtomOfType(Atom.TYPE_ctts);
        ParsableByteArray parsableByteArray5 = leafAtomOfType5 != null ? leafAtomOfType5.data : null;
        ChunkIterator chunkIterator = new ChunkIterator(parsableByteArray2, parsableByteArray, z);
        parsableByteArray3.setPosition(12);
        int readUnsignedIntToInt = parsableByteArray3.readUnsignedIntToInt() - 1;
        int readUnsignedIntToInt2 = parsableByteArray3.readUnsignedIntToInt();
        int readUnsignedIntToInt3 = parsableByteArray3.readUnsignedIntToInt();
        if (parsableByteArray5 != null) {
            parsableByteArray5.setPosition(12);
            i = parsableByteArray5.readUnsignedIntToInt();
        } else {
            i = 0;
        }
        if (parsableByteArray4 != null) {
            parsableByteArray4.setPosition(12);
            i3 = parsableByteArray4.readUnsignedIntToInt();
            if (i3 > 0) {
                i2 = parsableByteArray4.readUnsignedIntToInt() - 1;
                fixedSampleSize = sampleSizeBox.getFixedSampleSize();
                String str = track.format.sampleMimeType;
                if (fixedSampleSize == -1 && ((MimeTypes.AUDIO_RAW.equals(str) || MimeTypes.AUDIO_MLAW.equals(str) || MimeTypes.AUDIO_ALAW.equals(str)) && readUnsignedIntToInt == 0 && i == 0 && i3 == 0)) {
                    i4 = readUnsignedIntToInt;
                    i5 = readUnsignedIntToInt2;
                    z2 = true;
                } else {
                    i4 = readUnsignedIntToInt;
                    i5 = readUnsignedIntToInt2;
                    z2 = false;
                }
                if (!z2) {
                    int i20 = chunkIterator.length;
                    long[] jArr9 = new long[i20];
                    int[] iArr8 = new int[i20];
                    while (chunkIterator.moveNext()) {
                        int i21 = chunkIterator.index;
                        jArr9[i21] = chunkIterator.offset;
                        iArr8[i21] = chunkIterator.numSamples;
                    }
                    FixedSampleSizeRechunker.Results rechunk = FixedSampleSizeRechunker.rechunk(fixedSampleSize, jArr9, iArr8, (long) readUnsignedIntToInt3);
                    long[] jArr10 = rechunk.offsets;
                    int[] iArr9 = rechunk.sizes;
                    i6 = rechunk.maximumSize;
                    long[] jArr11 = rechunk.timestamps;
                    int[] iArr10 = rechunk.flags;
                    long j3 = rechunk.duration;
                    i7 = sampleCount;
                    jArr2 = jArr10;
                    iArr2 = iArr9;
                    jArr = jArr11;
                    iArr = iArr10;
                    j = j3;
                    track2 = track;
                } else {
                    long[] jArr12 = new long[sampleCount];
                    int[] iArr11 = new int[sampleCount];
                    long[] jArr13 = new long[sampleCount];
                    int[] iArr12 = new int[sampleCount];
                    int i22 = i2;
                    int i23 = 0;
                    int i24 = 0;
                    int i25 = 0;
                    int i26 = 0;
                    int i27 = 0;
                    long j4 = 0;
                    long j5 = 0;
                    int i28 = i;
                    int i29 = readUnsignedIntToInt3;
                    int i30 = i5;
                    while (true) {
                        if (i23 >= sampleCount) {
                            i13 = i30;
                            i14 = i25;
                            i15 = i26;
                            break;
                        }
                        long j6 = j5;
                        int i31 = i26;
                        boolean z5 = true;
                        while (i31 == 0) {
                            z5 = chunkIterator.moveNext();
                            if (!z5) {
                                break;
                            }
                            long j7 = chunkIterator.offset;
                            i31 = chunkIterator.numSamples;
                            j6 = j7;
                            i30 = i30;
                            i29 = i29;
                            sampleCount = sampleCount;
                        }
                        i13 = i30;
                        if (!z5) {
                            Log.w(TAG, "Unexpected end of chunk data");
                            jArr12 = Arrays.copyOf(jArr12, i23);
                            iArr11 = Arrays.copyOf(iArr11, i23);
                            jArr13 = Arrays.copyOf(jArr13, i23);
                            iArr12 = Arrays.copyOf(iArr12, i23);
                            sampleCount = i23;
                            i14 = i25;
                            i15 = i31;
                            break;
                        }
                        if (parsableByteArray5 != null) {
                            while (i27 == 0 && i28 > 0) {
                                i27 = parsableByteArray5.readUnsignedIntToInt();
                                i25 = parsableByteArray5.readInt();
                                i28--;
                            }
                            i27--;
                        }
                        jArr12[i23] = j6;
                        iArr11[i23] = sampleSizeBox.readNextSampleSize();
                        if (iArr11[i23] > i24) {
                            i24 = iArr11[i23];
                        }
                        jArr13[i23] = j4 + ((long) i25);
                        iArr12[i23] = parsableByteArray4 == null ? 1 : 0;
                        if (i23 == i22) {
                            iArr12[i23] = 1;
                            i3--;
                            if (i3 > 0) {
                                i22 = ((ParsableByteArray) Assertions.checkNotNull(parsableByteArray4)).readUnsignedIntToInt() - 1;
                            }
                        }
                        j4 += (long) i29;
                        int i32 = i13 - 1;
                        if (i32 != 0 || i4 <= 0) {
                            i19 = i29;
                            i18 = i4;
                        } else {
                            i32 = parsableByteArray3.readUnsignedIntToInt();
                            i19 = parsableByteArray3.readInt();
                            i18 = i4 - 1;
                        }
                        i26 = i31 - 1;
                        i23++;
                        j5 = j6 + ((long) iArr11[i23]);
                        i22 = i22;
                        i29 = i19;
                        sampleCount = sampleCount;
                        i25 = i25;
                        i30 = i32;
                        i4 = i18;
                    }
                    long j8 = j4 + ((long) i14);
                    if (parsableByteArray5 != null) {
                        while (true) {
                            if (i28 <= 0) {
                                break;
                            } else if (parsableByteArray5.readUnsignedIntToInt() != 0) {
                                z4 = false;
                                break;
                            } else {
                                parsableByteArray5.readInt();
                                i28--;
                            }
                        }
                        if (i3 != 0 && i13 == 0 && i15 == 0 && i4 == 0) {
                            i17 = i27;
                            if (i17 == 0 && z4) {
                                track2 = track;
                                i16 = sampleCount;
                                jArr2 = jArr12;
                                iArr2 = iArr11;
                                jArr = jArr13;
                                i6 = i24;
                                i7 = i16;
                                j = j8;
                                iArr = iArr12;
                            }
                        } else {
                            i17 = i27;
                        }
                        track2 = track;
                        int i33 = track2.id;
                        String str2 = z4 ? ", ctts invalid" : "";
                        i16 = sampleCount;
                        StringBuilder sb = new StringBuilder(str2.length() + 262);
                        sb.append("Inconsistent stbl box for track ");
                        sb.append(i33);
                        sb.append(": remainingSynchronizationSamples ");
                        sb.append(i3);
                        sb.append(", remainingSamplesAtTimestampDelta ");
                        sb.append(i13);
                        sb.append(", remainingSamplesInChunk ");
                        sb.append(i15);
                        sb.append(", remainingTimestampDeltaChanges ");
                        sb.append(i4);
                        sb.append(", remainingSamplesAtTimestampOffset ");
                        sb.append(i17);
                        sb.append(str2);
                        Log.w(TAG, sb.toString());
                        jArr2 = jArr12;
                        iArr2 = iArr11;
                        jArr = jArr13;
                        i6 = i24;
                        i7 = i16;
                        j = j8;
                        iArr = iArr12;
                    }
                    z4 = true;
                    if (i3 != 0) {
                    }
                    i17 = i27;
                    track2 = track;
                    int i332 = track2.id;
                    if (z4) {
                    }
                    i16 = sampleCount;
                    StringBuilder sb2 = new StringBuilder(str2.length() + 262);
                    sb2.append("Inconsistent stbl box for track ");
                    sb2.append(i332);
                    sb2.append(": remainingSynchronizationSamples ");
                    sb2.append(i3);
                    sb2.append(", remainingSamplesAtTimestampDelta ");
                    sb2.append(i13);
                    sb2.append(", remainingSamplesInChunk ");
                    sb2.append(i15);
                    sb2.append(", remainingTimestampDeltaChanges ");
                    sb2.append(i4);
                    sb2.append(", remainingSamplesAtTimestampOffset ");
                    sb2.append(i17);
                    sb2.append(str2);
                    Log.w(TAG, sb2.toString());
                    jArr2 = jArr12;
                    iArr2 = iArr11;
                    jArr = jArr13;
                    i6 = i24;
                    i7 = i16;
                    j = j8;
                    iArr = iArr12;
                }
                long scaleLargeTimestamp = Util.scaleLargeTimestamp(j, 1000000, track2.timescale);
                jArr3 = track2.editListDurations;
                if (jArr3 != null) {
                    Util.scaleLargeTimestampsInPlace(jArr, 1000000, track2.timescale);
                    return new TrackSampleTable(track, jArr2, iArr2, i6, jArr, iArr, scaleLargeTimestamp);
                }
                if (jArr3.length == 1 && track2.type == 1 && jArr.length >= 2) {
                    long j9 = ((long[]) Assertions.checkNotNull(track2.editListMediaTimes))[0];
                    long scaleLargeTimestamp2 = j9 + Util.scaleLargeTimestamp(track2.editListDurations[0], track2.timescale, track2.movieTimescale);
                    i8 = i7;
                    if (canApplyEditWithGaplessInfo(jArr, j, j9, scaleLargeTimestamp2)) {
                        long scaleLargeTimestamp3 = Util.scaleLargeTimestamp(j9 - jArr[0], (long) track2.format.sampleRate, track2.timescale);
                        iArr3 = iArr;
                        j2 = j;
                        long scaleLargeTimestamp4 = Util.scaleLargeTimestamp(j - scaleLargeTimestamp2, (long) track2.format.sampleRate, track2.timescale);
                        if (!(scaleLargeTimestamp3 == 0 && scaleLargeTimestamp4 == 0) && scaleLargeTimestamp3 <= 2147483647L && scaleLargeTimestamp4 <= 2147483647L) {
                            gaplessInfoHolder.encoderDelay = (int) scaleLargeTimestamp3;
                            gaplessInfoHolder.encoderPadding = (int) scaleLargeTimestamp4;
                            Util.scaleLargeTimestampsInPlace(jArr, 1000000, track2.timescale);
                            return new TrackSampleTable(track, jArr2, iArr2, i6, jArr, iArr3, Util.scaleLargeTimestamp(track2.editListDurations[0], 1000000, track2.movieTimescale));
                        }
                        jArr4 = track2.editListDurations;
                        if (jArr4.length == 1 || jArr4[0] != 0) {
                            boolean z6 = track2.type != 1;
                            int[] iArr13 = new int[jArr4.length];
                            int[] iArr14 = new int[jArr4.length];
                            jArr5 = (long[]) Assertions.checkNotNull(track2.editListMediaTimes);
                            i9 = 0;
                            boolean z7 = false;
                            int i34 = 0;
                            int i35 = 0;
                            while (true) {
                                jArr6 = track2.editListDurations;
                                if (i9 < jArr6.length) {
                                    break;
                                }
                                long j10 = jArr5[i9];
                                if (j10 != -1) {
                                    long j11 = jArr6[i9];
                                    i12 = i6;
                                    jArr7 = jArr5;
                                    jArr8 = jArr2;
                                    iArr7 = iArr2;
                                    long scaleLargeTimestamp5 = Util.scaleLargeTimestamp(j11, track2.timescale, track2.movieTimescale);
                                    iArr13[i9] = Util.binarySearchFloor(jArr, j10, true, true);
                                    iArr14[i9] = Util.binarySearchCeil(jArr, j10 + scaleLargeTimestamp5, z6, false);
                                    while (iArr13[i9] < iArr14[i9] && (iArr3[iArr13[i9]] & 1) == 0) {
                                        iArr13[i9] = iArr13[i9] + 1;
                                    }
                                    int i36 = (iArr14[i9] - iArr13[i9]) + i34;
                                    boolean z8 = i35 != iArr13[i9];
                                    i34 = i36;
                                    i35 = iArr14[i9];
                                    z7 = z8 | z7;
                                } else {
                                    jArr8 = jArr2;
                                    iArr7 = iArr2;
                                    i12 = i6;
                                    jArr7 = jArr5;
                                }
                                i9++;
                                jArr5 = jArr7;
                                i6 = i12;
                                jArr2 = jArr8;
                                iArr2 = iArr7;
                            }
                            int[] iArr15 = iArr2;
                            int i37 = i6;
                            i10 = 0;
                            z3 = z7 | (i34 == i8);
                            long[] jArr14 = !z3 ? new long[i34] : jArr2;
                            int[] iArr16 = !z3 ? new int[i34] : iArr15;
                            if (z3) {
                                i37 = 0;
                            }
                            int[] iArr17 = !z3 ? new int[i34] : iArr3;
                            long[] jArr15 = new long[i34];
                            int i38 = 0;
                            long j12 = 0;
                            while (i10 < track2.editListDurations.length) {
                                long j13 = track2.editListMediaTimes[i10];
                                int i39 = iArr13[i10];
                                int i40 = iArr14[i10];
                                if (z3) {
                                    int i41 = i40 - i39;
                                    iArr4 = iArr13;
                                    System.arraycopy(jArr2, i39, jArr14, i38, i41);
                                    iArr6 = iArr15;
                                    System.arraycopy(iArr6, i39, iArr16, i38, i41);
                                    i11 = i37;
                                    iArr5 = iArr3;
                                    System.arraycopy(iArr5, i39, iArr17, i38, i41);
                                } else {
                                    iArr4 = iArr13;
                                    i11 = i37;
                                    iArr6 = iArr15;
                                    iArr5 = iArr3;
                                }
                                int i42 = i11;
                                while (i39 < i40) {
                                    jArr15[i38] = Util.scaleLargeTimestamp(j12, 1000000, track2.movieTimescale) + Util.scaleLargeTimestamp(Math.max(0L, jArr[i39] - j13), 1000000, track2.timescale);
                                    if (z3 && iArr16[i38] > i42) {
                                        i42 = iArr6[i39];
                                    }
                                    i38++;
                                    i39++;
                                    i10 = i10;
                                    j12 = j12;
                                    jArr = jArr;
                                    iArr6 = iArr6;
                                    jArr14 = jArr14;
                                }
                                j12 += track2.editListDurations[i10];
                                i10++;
                                iArr3 = iArr5;
                                jArr = jArr;
                                iArr13 = iArr4;
                                iArr15 = iArr6;
                                jArr14 = jArr14;
                                i37 = i42;
                                iArr14 = iArr14;
                            }
                            return new TrackSampleTable(track, jArr14, iArr16, i37, jArr15, iArr17, Util.scaleLargeTimestamp(j12, 1000000, track2.movieTimescale));
                        }
                        long j14 = ((long[]) Assertions.checkNotNull(track2.editListMediaTimes))[0];
                        for (int i43 = 0; i43 < jArr.length; i43++) {
                            jArr[i43] = Util.scaleLargeTimestamp(jArr[i43] - j14, 1000000, track2.timescale);
                        }
                        return new TrackSampleTable(track, jArr2, iArr2, i6, jArr, iArr3, Util.scaleLargeTimestamp(j2 - j14, 1000000, track2.timescale));
                    }
                } else {
                    i8 = i7;
                }
                iArr3 = iArr;
                j2 = j;
                jArr4 = track2.editListDurations;
                if (jArr4.length == 1) {
                }
                if (track2.type != 1) {
                }
                int[] iArr132 = new int[jArr4.length];
                int[] iArr142 = new int[jArr4.length];
                jArr5 = (long[]) Assertions.checkNotNull(track2.editListMediaTimes);
                i9 = 0;
                boolean z72 = false;
                int i342 = 0;
                int i352 = 0;
                while (true) {
                    jArr6 = track2.editListDurations;
                    if (i9 < jArr6.length) {
                    }
                    i9++;
                    jArr5 = jArr7;
                    i6 = i12;
                    jArr2 = jArr8;
                    iArr2 = iArr7;
                }
                int[] iArr152 = iArr2;
                int i372 = i6;
                i10 = 0;
                z3 = z72 | (i342 == i8);
                if (!z3) {
                }
                if (!z3) {
                }
                if (z3) {
                }
                if (!z3) {
                }
                long[] jArr152 = new long[i342];
                int i382 = 0;
                long j122 = 0;
                while (i10 < track2.editListDurations.length) {
                }
                return new TrackSampleTable(track, jArr14, iArr16, i372, jArr152, iArr17, Util.scaleLargeTimestamp(j122, 1000000, track2.movieTimescale));
            }
            parsableByteArray4 = null;
        } else {
            i3 = 0;
        }
        i2 = -1;
        fixedSampleSize = sampleSizeBox.getFixedSampleSize();
        String str3 = track.format.sampleMimeType;
        if (fixedSampleSize == -1) {
        }
        i4 = readUnsignedIntToInt;
        i5 = readUnsignedIntToInt2;
        z2 = false;
        if (!z2) {
        }
        long scaleLargeTimestamp6 = Util.scaleLargeTimestamp(j, 1000000, track2.timescale);
        jArr3 = track2.editListDurations;
        if (jArr3 != null) {
        }
    }

    private static StsdData parseStsd(ParsableByteArray parsableByteArray, int i, int i2, String str, @Nullable DrmInitData drmInitData, boolean z) {
        int i3;
        parsableByteArray.setPosition(12);
        int readInt = parsableByteArray.readInt();
        StsdData stsdData = new StsdData(readInt);
        for (int i4 = 0; i4 < readInt; i4++) {
            int position = parsableByteArray.getPosition();
            int readInt2 = parsableByteArray.readInt();
            Assertions.checkState(readInt2 > 0, "childAtomSize should be positive");
            int readInt3 = parsableByteArray.readInt();
            if (readInt3 == 1635148593 || readInt3 == 1635148595 || readInt3 == 1701733238 || readInt3 == 1831958048 || readInt3 == 1836070006 || readInt3 == 1752589105 || readInt3 == 1751479857 || readInt3 == 1932670515 || readInt3 == 1211250227 || readInt3 == 1987063864 || readInt3 == 1987063865 || readInt3 == 1635135537 || readInt3 == 1685479798 || readInt3 == 1685479729 || readInt3 == 1685481573 || readInt3 == 1685481521) {
                i3 = position;
                parseVideoSampleEntry(parsableByteArray, readInt3, i3, readInt2, i, i2, drmInitData, stsdData, i4);
            } else if (readInt3 == 1836069985 || readInt3 == 1701733217 || readInt3 == 1633889587 || readInt3 == 1700998451 || readInt3 == 1633889588 || readInt3 == 1685353315 || readInt3 == 1685353317 || readInt3 == 1685353320 || readInt3 == 1685353324 || readInt3 == 1935764850 || readInt3 == 1935767394 || readInt3 == 1819304813 || readInt3 == 1936684916 || readInt3 == 1953984371 || readInt3 == 778924082 || readInt3 == 778924083 || readInt3 == 1835557169 || readInt3 == 1835560241 || readInt3 == 1634492771 || readInt3 == 1634492791 || readInt3 == 1970037111 || readInt3 == 1332770163 || readInt3 == 1716281667) {
                i3 = position;
                parseAudioSampleEntry(parsableByteArray, readInt3, position, readInt2, i, str, z, drmInitData, stsdData, i4);
            } else {
                if (readInt3 == 1414810956 || readInt3 == 1954034535 || readInt3 == 2004251764 || readInt3 == 1937010800 || readInt3 == 1664495672) {
                    parseTextSampleEntry(parsableByteArray, readInt3, position, readInt2, i, str, stsdData);
                } else if (readInt3 == 1835365492) {
                    parseMetaDataSampleEntry(parsableByteArray, readInt3, position, i, stsdData);
                } else if (readInt3 == 1667329389) {
                    stsdData.format = new Format.Builder().setId(i).setSampleMimeType(MimeTypes.APPLICATION_CAMERA_MOTION).build();
                }
                i3 = position;
            }
            parsableByteArray.setPosition(i3 + readInt2);
        }
        return stsdData;
    }

    private static void parseTextSampleEntry(ParsableByteArray parsableByteArray, int i, int i2, int i3, int i4, String str, StsdData stsdData) {
        parsableByteArray.setPosition(i2 + 8 + 8);
        String str2 = MimeTypes.APPLICATION_TTML;
        bs bsVar = null;
        long j = Long.MAX_VALUE;
        if (i != 1414810956) {
            if (i == 1954034535) {
                int i5 = (i3 - 8) - 8;
                byte[] bArr = new byte[i5];
                parsableByteArray.readBytes(bArr, 0, i5);
                bsVar = bs.of(bArr);
                str2 = MimeTypes.APPLICATION_TX3G;
            } else if (i == 2004251764) {
                str2 = MimeTypes.APPLICATION_MP4VTT;
            } else if (i == 1937010800) {
                j = 0;
            } else if (i == 1664495672) {
                stsdData.requiredSampleTransformation = 1;
                str2 = MimeTypes.APPLICATION_MP4CEA608;
            } else {
                throw new IllegalStateException();
            }
        }
        stsdData.format = new Format.Builder().setId(i4).setSampleMimeType(str2).setLanguage(str).setSubsampleOffsetUs(j).setInitializationData(bsVar).build();
    }

    private static TkhdData parseTkhd(ParsableByteArray parsableByteArray) {
        boolean z;
        int i = 8;
        parsableByteArray.setPosition(8);
        int parseFullAtomVersion = Atom.parseFullAtomVersion(parsableByteArray.readInt());
        parsableByteArray.skipBytes(parseFullAtomVersion == 0 ? 8 : 16);
        int readInt = parsableByteArray.readInt();
        parsableByteArray.skipBytes(4);
        int position = parsableByteArray.getPosition();
        if (parseFullAtomVersion == 0) {
            i = 4;
        }
        int i2 = 0;
        int i3 = 0;
        while (true) {
            if (i3 >= i) {
                z = true;
                break;
            } else if (parsableByteArray.getData()[position + i3] != -1) {
                z = false;
                break;
            } else {
                i3++;
            }
        }
        long j = C.TIME_UNSET;
        if (z) {
            parsableByteArray.skipBytes(i);
        } else {
            long readUnsignedInt = parseFullAtomVersion == 0 ? parsableByteArray.readUnsignedInt() : parsableByteArray.readUnsignedLongToLong();
            if (readUnsignedInt != 0) {
                j = readUnsignedInt;
            }
        }
        parsableByteArray.skipBytes(16);
        int readInt2 = parsableByteArray.readInt();
        int readInt3 = parsableByteArray.readInt();
        parsableByteArray.skipBytes(4);
        int readInt4 = parsableByteArray.readInt();
        int readInt5 = parsableByteArray.readInt();
        if (readInt2 == 0 && readInt3 == 65536 && readInt4 == -65536 && readInt5 == 0) {
            i2 = 90;
        } else if (readInt2 == 0 && readInt3 == -65536 && readInt4 == 65536 && readInt5 == 0) {
            i2 = 270;
        } else if (readInt2 == -65536 && readInt3 == 0 && readInt4 == 0 && readInt5 == -65536) {
            i2 = 180;
        }
        return new TkhdData(readInt, j, i2);
    }

    @Nullable
    private static Track parseTrak(Atom.ContainerAtom containerAtom, Atom.LeafAtom leafAtom, long j, @Nullable DrmInitData drmInitData, boolean z, boolean z2) {
        long j2;
        Atom.LeafAtom leafAtom2;
        long[] jArr;
        long[] jArr2;
        Atom.ContainerAtom containerAtomOfType;
        Pair<long[], long[]> parseEdts;
        Atom.ContainerAtom containerAtom2 = (Atom.ContainerAtom) Assertions.checkNotNull(containerAtom.getContainerAtomOfType(Atom.TYPE_mdia));
        int trackTypeForHdlr = getTrackTypeForHdlr(parseHdlr(((Atom.LeafAtom) Assertions.checkNotNull(containerAtom2.getLeafAtomOfType(Atom.TYPE_hdlr))).data));
        if (trackTypeForHdlr == -1) {
            return null;
        }
        TkhdData parseTkhd = parseTkhd(((Atom.LeafAtom) Assertions.checkNotNull(containerAtom.getLeafAtomOfType(Atom.TYPE_tkhd))).data);
        long j3 = C.TIME_UNSET;
        if (j == C.TIME_UNSET) {
            leafAtom2 = leafAtom;
            j2 = parseTkhd.duration;
        } else {
            leafAtom2 = leafAtom;
            j2 = j;
        }
        long parseMvhd = parseMvhd(leafAtom2.data);
        if (j2 != C.TIME_UNSET) {
            j3 = Util.scaleLargeTimestamp(j2, 1000000, parseMvhd);
        }
        Pair<Long, String> parseMdhd = parseMdhd(((Atom.LeafAtom) Assertions.checkNotNull(containerAtom2.getLeafAtomOfType(Atom.TYPE_mdhd))).data);
        StsdData parseStsd = parseStsd(((Atom.LeafAtom) Assertions.checkNotNull(((Atom.ContainerAtom) Assertions.checkNotNull(((Atom.ContainerAtom) Assertions.checkNotNull(containerAtom2.getContainerAtomOfType(Atom.TYPE_minf))).getContainerAtomOfType(Atom.TYPE_stbl))).getLeafAtomOfType(Atom.TYPE_stsd))).data, parseTkhd.id, parseTkhd.rotationDegrees, (String) parseMdhd.second, drmInitData, z2);
        if (z || (containerAtomOfType = containerAtom.getContainerAtomOfType(Atom.TYPE_edts)) == null || (parseEdts = parseEdts(containerAtomOfType)) == null) {
            jArr2 = null;
            jArr = null;
        } else {
            jArr = (long[]) parseEdts.second;
            jArr2 = (long[]) parseEdts.first;
        }
        if (parseStsd.format == null) {
            return null;
        }
        return new Track(parseTkhd.id, trackTypeForHdlr, ((Long) parseMdhd.first).longValue(), parseMvhd, j3, parseStsd.format, parseStsd.requiredSampleTransformation, parseStsd.trackEncryptionBoxes, parseStsd.nalUnitLengthFieldLength, jArr2, jArr);
    }

    public static List<TrackSampleTable> parseTraks(Atom.ContainerAtom containerAtom, GaplessInfoHolder gaplessInfoHolder, long j, @Nullable DrmInitData drmInitData, boolean z, boolean z2, qq<Track, Track> qqVar) {
        ArrayList arrayList = new ArrayList();
        for (int i = 0; i < containerAtom.containerChildren.size(); i++) {
            Atom.ContainerAtom containerAtom2 = containerAtom.containerChildren.get(i);
            if (containerAtom2.type == 1953653099) {
                Track apply = qqVar.apply(parseTrak(containerAtom2, (Atom.LeafAtom) Assertions.checkNotNull(containerAtom.getLeafAtomOfType(Atom.TYPE_mvhd)), j, drmInitData, z, z2));
                if (apply != null) {
                    arrayList.add(parseStbl(apply, (Atom.ContainerAtom) Assertions.checkNotNull(((Atom.ContainerAtom) Assertions.checkNotNull(((Atom.ContainerAtom) Assertions.checkNotNull(containerAtom2.getContainerAtomOfType(Atom.TYPE_mdia))).getContainerAtomOfType(Atom.TYPE_minf))).getContainerAtomOfType(Atom.TYPE_stbl)), gaplessInfoHolder));
                }
            }
        }
        return arrayList;
    }

    public static Pair<Metadata, Metadata> parseUdta(Atom.LeafAtom leafAtom) {
        ParsableByteArray parsableByteArray = leafAtom.data;
        parsableByteArray.setPosition(8);
        Metadata metadata = null;
        Metadata metadata2 = null;
        while (parsableByteArray.bytesLeft() >= 8) {
            int position = parsableByteArray.getPosition();
            int readInt = parsableByteArray.readInt();
            int readInt2 = parsableByteArray.readInt();
            if (readInt2 == 1835365473) {
                parsableByteArray.setPosition(position);
                metadata = parseUdtaMeta(parsableByteArray, position + readInt);
            } else if (readInt2 == 1936553057) {
                parsableByteArray.setPosition(position);
                metadata2 = parseSmta(parsableByteArray, position + readInt);
            }
            parsableByteArray.setPosition(position + readInt);
        }
        return Pair.create(metadata, metadata2);
    }

    @Nullable
    private static Metadata parseUdtaMeta(ParsableByteArray parsableByteArray, int i) {
        parsableByteArray.skipBytes(8);
        maybeSkipRemainingMetaAtomHeaderBytes(parsableByteArray);
        while (parsableByteArray.getPosition() < i) {
            int position = parsableByteArray.getPosition();
            int readInt = parsableByteArray.readInt();
            if (parsableByteArray.readInt() == 1768715124) {
                parsableByteArray.setPosition(position);
                return parseIlst(parsableByteArray, position + readInt);
            }
            parsableByteArray.setPosition(position + readInt);
        }
        return null;
    }

    private static void parseVideoSampleEntry(ParsableByteArray parsableByteArray, int i, int i2, int i3, int i4, int i5, @Nullable DrmInitData drmInitData, StsdData stsdData, int i6) {
        String str;
        DrmInitData drmInitData2;
        List<byte[]> list;
        String str2;
        List<byte[]> list2;
        String str3;
        String str4;
        int i7 = i2;
        int i8 = i3;
        DrmInitData drmInitData3 = drmInitData;
        parsableByteArray.setPosition(i7 + 8 + 8);
        parsableByteArray.skipBytes(16);
        int readUnsignedShort = parsableByteArray.readUnsignedShort();
        int readUnsignedShort2 = parsableByteArray.readUnsignedShort();
        parsableByteArray.skipBytes(50);
        int position = parsableByteArray.getPosition();
        String str5 = null;
        int i9 = i;
        if (i9 == 1701733238) {
            Pair<Integer, TrackEncryptionBox> parseSampleEntryEncryptionData = parseSampleEntryEncryptionData(parsableByteArray, i7, i8);
            if (parseSampleEntryEncryptionData != null) {
                i9 = ((Integer) parseSampleEntryEncryptionData.first).intValue();
                if (drmInitData3 == null) {
                    drmInitData3 = null;
                } else {
                    drmInitData3 = drmInitData3.copyWithSchemeType(((TrackEncryptionBox) parseSampleEntryEncryptionData.second).schemeType);
                }
                stsdData.trackEncryptionBoxes[i6] = (TrackEncryptionBox) parseSampleEntryEncryptionData.second;
            }
            parsableByteArray.setPosition(position);
        }
        if (i9 == 1831958048) {
            str = MimeTypes.VIDEO_MPEG;
        } else {
            str = i9 == 1211250227 ? MimeTypes.VIDEO_H263 : null;
        }
        List<byte[]> list3 = null;
        String str6 = str;
        float f = 1.0f;
        int i10 = -1;
        boolean z = false;
        byte[] bArr = null;
        while (true) {
            if (position - i7 >= i8) {
                drmInitData2 = drmInitData3;
                list = list3;
                break;
            }
            parsableByteArray.setPosition(position);
            int position2 = parsableByteArray.getPosition();
            drmInitData2 = drmInitData3;
            int readInt = parsableByteArray.readInt();
            if (readInt == 0) {
                list = list3;
                if (parsableByteArray.getPosition() - i7 == i8) {
                    break;
                }
            } else {
                list = list3;
            }
            Assertions.checkState(readInt > 0, "childAtomSize should be positive");
            int readInt2 = parsableByteArray.readInt();
            if (readInt2 == 1635148611) {
                Assertions.checkState(str6 == null);
                parsableByteArray.setPosition(position2 + 8);
                AvcConfig parse = AvcConfig.parse(parsableByteArray);
                list2 = parse.initializationData;
                stsdData.nalUnitLengthFieldLength = parse.nalUnitLengthFieldLength;
                if (!z) {
                    f = parse.pixelWidthAspectRatio;
                }
                str3 = parse.codecs;
                str2 = "video/avc";
            } else if (readInt2 == 1752589123) {
                Assertions.checkState(str6 == null);
                parsableByteArray.setPosition(position2 + 8);
                HevcConfig parse2 = HevcConfig.parse(parsableByteArray);
                list2 = parse2.initializationData;
                stsdData.nalUnitLengthFieldLength = parse2.nalUnitLengthFieldLength;
                str3 = parse2.codecs;
                str2 = "video/hevc";
            } else {
                if (readInt2 == 1685480259 || readInt2 == 1685485123) {
                    DolbyVisionConfig parse3 = DolbyVisionConfig.parse(parsableByteArray);
                    if (parse3 != null) {
                        str5 = parse3.codecs;
                        str6 = MimeTypes.VIDEO_DOLBY_VISION;
                    }
                } else {
                    if (readInt2 == 1987076931) {
                        Assertions.checkState(str6 == null);
                        str4 = i9 == 1987063864 ? "video/x-vnd.on2.vp8" : "video/x-vnd.on2.vp9";
                    } else if (readInt2 == 1635135811) {
                        Assertions.checkState(str6 == null);
                        str4 = MimeTypes.VIDEO_AV1;
                    } else if (readInt2 == 1681012275) {
                        Assertions.checkState(str6 == null);
                        str6 = MimeTypes.VIDEO_H263;
                    } else {
                        if (readInt2 == 1702061171) {
                            Assertions.checkState(str6 == null);
                            Pair<String, byte[]> parseEsdsFromParent = parseEsdsFromParent(parsableByteArray, position2);
                            String str7 = (String) parseEsdsFromParent.first;
                            byte[] bArr2 = (byte[]) parseEsdsFromParent.second;
                            list3 = bArr2 != null ? bs.of(bArr2) : list;
                            str6 = str7;
                        } else if (readInt2 == 1885434736) {
                            f = parsePaspFromParent(parsableByteArray, position2);
                            list3 = list;
                            z = true;
                        } else if (readInt2 == 1937126244) {
                            bArr = parseProjFromParent(parsableByteArray, position2, readInt);
                        } else if (readInt2 == 1936995172) {
                            int readUnsignedByte = parsableByteArray.readUnsignedByte();
                            parsableByteArray.skipBytes(3);
                            if (readUnsignedByte == 0) {
                                int readUnsignedByte2 = parsableByteArray.readUnsignedByte();
                                if (readUnsignedByte2 == 0) {
                                    list3 = list;
                                    i10 = 0;
                                } else if (readUnsignedByte2 == 1) {
                                    list3 = list;
                                    i10 = 1;
                                } else if (readUnsignedByte2 == 2) {
                                    list3 = list;
                                    i10 = 2;
                                } else if (readUnsignedByte2 == 3) {
                                    list3 = list;
                                    i10 = 3;
                                }
                            }
                        }
                        position += readInt;
                        i7 = i2;
                        i8 = i3;
                        drmInitData3 = drmInitData2;
                    }
                    str6 = str4;
                }
                list3 = list;
                position += readInt;
                i7 = i2;
                i8 = i3;
                drmInitData3 = drmInitData2;
            }
            list3 = list2;
            str6 = str2;
            str5 = str3;
            position += readInt;
            i7 = i2;
            i8 = i3;
            drmInitData3 = drmInitData2;
        }
        if (str6 != null) {
            stsdData.format = new Format.Builder().setId(i4).setSampleMimeType(str6).setCodecs(str5).setWidth(readUnsignedShort).setHeight(readUnsignedShort2).setPixelWidthHeightRatio(f).setRotationDegrees(i5).setProjectionData(bArr).setStereoMode(i10).setInitializationData(list).setDrmInitData(drmInitData2).build();
        }
    }
}
