package com.google.android.exoplayer2.offline;

import android.net.Uri;
import androidx.annotation.Nullable;
import androidx.base.np;
import com.google.android.exoplayer2.MediaItem;
import com.google.android.exoplayer2.offline.Downloader;
import com.google.android.exoplayer2.offline.FilterableManifest;
import com.google.android.exoplayer2.upstream.DataSource;
import com.google.android.exoplayer2.upstream.DataSpec;
import com.google.android.exoplayer2.upstream.ParsingLoadable;
import com.google.android.exoplayer2.upstream.cache.Cache;
import com.google.android.exoplayer2.upstream.cache.CacheDataSource;
import com.google.android.exoplayer2.upstream.cache.CacheKeyFactory;
import com.google.android.exoplayer2.upstream.cache.CacheWriter;
import com.google.android.exoplayer2.util.Assertions;
import com.google.android.exoplayer2.util.PriorityTaskManager;
import com.google.android.exoplayer2.util.RunnableFutureTask;
import com.google.android.exoplayer2.util.Util;
import java.io.IOException;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.Executor;

public abstract class SegmentDownloader<M extends FilterableManifest<M>> implements Downloader {
    private static final int BUFFER_SIZE_BYTES = 131072;
    private static final long MAX_MERGED_SEGMENT_START_TIME_DIFF_US = 20000000;
    private final ArrayList<RunnableFutureTask<?, ?>> activeRunnables = new ArrayList<>();
    private final Cache cache;
    private final CacheDataSource.Factory cacheDataSourceFactory;
    private final CacheKeyFactory cacheKeyFactory;
    private final Executor executor;
    private volatile boolean isCanceled;
    private final DataSpec manifestDataSpec;
    private final ParsingLoadable.Parser<M> manifestParser;
    @Nullable
    private final PriorityTaskManager priorityTaskManager;
    private final ArrayList<StreamKey> streamKeys;

    public static final class ProgressNotifier implements CacheWriter.ProgressListener {
        private long bytesDownloaded;
        private final long contentLength;
        private final Downloader.ProgressListener progressListener;
        private int segmentsDownloaded;
        private final int totalSegments;

        public ProgressNotifier(Downloader.ProgressListener progressListener2, long j, int i, long j2, int i2) {
            this.progressListener = progressListener2;
            this.contentLength = j;
            this.totalSegments = i;
            this.bytesDownloaded = j2;
            this.segmentsDownloaded = i2;
        }

        private float getPercentDownloaded() {
            long j = this.contentLength;
            if (j != -1 && j != 0) {
                return (((float) this.bytesDownloaded) * 100.0f) / ((float) j);
            }
            int i = this.totalSegments;
            if (i != 0) {
                return (((float) this.segmentsDownloaded) * 100.0f) / ((float) i);
            }
            return -1.0f;
        }

        @Override // com.google.android.exoplayer2.upstream.cache.CacheWriter.ProgressListener
        public void onProgress(long j, long j2, long j3) {
            long j4 = this.bytesDownloaded + j3;
            this.bytesDownloaded = j4;
            this.progressListener.onProgress(this.contentLength, j4, getPercentDownloaded());
        }

        public void onSegmentDownloaded() {
            this.segmentsDownloaded++;
            this.progressListener.onProgress(this.contentLength, this.bytesDownloaded, getPercentDownloaded());
        }
    }

    public static class Segment implements Comparable<Segment> {
        public final DataSpec dataSpec;
        public final long startTimeUs;

        public Segment(long j, DataSpec dataSpec2) {
            this.startTimeUs = j;
            this.dataSpec = dataSpec2;
        }

        public int compareTo(Segment segment) {
            return Util.compareLong(this.startTimeUs, segment.startTimeUs);
        }
    }

    public static final class SegmentDownloadRunnable extends RunnableFutureTask<Void, IOException> {
        private final CacheWriter cacheWriter;
        public final CacheDataSource dataSource;
        @Nullable
        private final ProgressNotifier progressNotifier;
        public final Segment segment;
        public final byte[] temporaryBuffer;

        public SegmentDownloadRunnable(Segment segment2, CacheDataSource cacheDataSource, @Nullable ProgressNotifier progressNotifier2, byte[] bArr) {
            this.segment = segment2;
            this.dataSource = cacheDataSource;
            this.progressNotifier = progressNotifier2;
            this.temporaryBuffer = bArr;
            this.cacheWriter = new CacheWriter(cacheDataSource, segment2.dataSpec, bArr, progressNotifier2);
        }

        @Override // com.google.android.exoplayer2.util.RunnableFutureTask
        public void cancelWork() {
            this.cacheWriter.cancel();
        }

        @Override // com.google.android.exoplayer2.util.RunnableFutureTask
        public Void doWork() {
            this.cacheWriter.cache();
            ProgressNotifier progressNotifier2 = this.progressNotifier;
            if (progressNotifier2 == null) {
                return null;
            }
            progressNotifier2.onSegmentDownloaded();
            return null;
        }
    }

    public SegmentDownloader(MediaItem mediaItem, ParsingLoadable.Parser<M> parser, CacheDataSource.Factory factory, Executor executor2) {
        Assertions.checkNotNull(mediaItem.playbackProperties);
        this.manifestDataSpec = getCompressibleDataSpec(mediaItem.playbackProperties.uri);
        this.manifestParser = parser;
        this.streamKeys = new ArrayList<>(mediaItem.playbackProperties.streamKeys);
        this.cacheDataSourceFactory = factory;
        this.executor = executor2;
        this.cache = (Cache) Assertions.checkNotNull(factory.getCache());
        this.cacheKeyFactory = factory.getCacheKeyFactory();
        this.priorityTaskManager = factory.getUpstreamPriorityTaskManager();
    }

    private <T> void addActiveRunnable(RunnableFutureTask<T, ?> runnableFutureTask) {
        synchronized (this.activeRunnables) {
            if (!this.isCanceled) {
                this.activeRunnables.add(runnableFutureTask);
            } else {
                throw new InterruptedException();
            }
        }
    }

    private static boolean canMergeSegments(DataSpec dataSpec, DataSpec dataSpec2) {
        if (dataSpec.uri.equals(dataSpec2.uri)) {
            long j = dataSpec.length;
            return j != -1 && dataSpec.position + j == dataSpec2.position && Util.areEqual(dataSpec.key, dataSpec2.key) && dataSpec.flags == dataSpec2.flags && dataSpec.httpMethod == dataSpec2.httpMethod && dataSpec.httpRequestHeaders.equals(dataSpec2.httpRequestHeaders);
        }
    }

    public static DataSpec getCompressibleDataSpec(Uri uri) {
        return new DataSpec.Builder().setUri(uri).setFlags(1).build();
    }

    private static void mergeSegments(List<Segment> list, CacheKeyFactory cacheKeyFactory2) {
        Segment segment;
        HashMap hashMap = new HashMap();
        int i = 0;
        for (int i2 = 0; i2 < list.size(); i2++) {
            Segment segment2 = list.get(i2);
            String buildCacheKey = cacheKeyFactory2.buildCacheKey(segment2.dataSpec);
            Integer num = (Integer) hashMap.get(buildCacheKey);
            if (num == null) {
                segment = null;
            } else {
                segment = list.get(num.intValue());
            }
            if (segment == null || segment2.startTimeUs > segment.startTimeUs + MAX_MERGED_SEGMENT_START_TIME_DIFF_US || !canMergeSegments(segment.dataSpec, segment2.dataSpec)) {
                hashMap.put(buildCacheKey, Integer.valueOf(i));
                list.set(i, segment2);
                i++;
            } else {
                long j = segment2.dataSpec.length;
                long j2 = -1;
                if (j != -1) {
                    j2 = segment.dataSpec.length + j;
                }
                list.set(((Integer) Assertions.checkNotNull(num)).intValue(), new Segment(segment.startTimeUs, segment.dataSpec.subrange(0, j2)));
            }
        }
        Util.removeRange(list, i, list.size());
    }

    private void removeActiveRunnable(RunnableFutureTask<?, ?> runnableFutureTask) {
        synchronized (this.activeRunnables) {
            this.activeRunnables.remove(runnableFutureTask);
        }
    }

    @Override // com.google.android.exoplayer2.offline.Downloader
    public void cancel() {
        synchronized (this.activeRunnables) {
            this.isCanceled = true;
            for (int i = 0; i < this.activeRunnables.size(); i++) {
                this.activeRunnables.get(i).cancel(true);
            }
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r1v12, types: [com.google.android.exoplayer2.offline.SegmentDownloader] */
    /* JADX WARNING: Removed duplicated region for block: B:82:0x01a7 A[LOOP:5: B:80:0x019f->B:82:0x01a7, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:85:0x01c0 A[LOOP:6: B:84:0x01be->B:85:0x01c0, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:88:0x01d5  */
    @Override // com.google.android.exoplayer2.offline.Downloader
    public final void download(@Nullable Downloader.ProgressListener progressListener) {
        SegmentDownloader<M> segmentDownloader;
        Throwable th;
        int i;
        int size;
        PriorityTaskManager priorityTaskManager2;
        CacheDataSource cacheDataSource;
        byte[] bArr;
        SegmentDownloader<M> segmentDownloader2 = this;
        ArrayDeque arrayDeque = new ArrayDeque();
        ArrayDeque arrayDeque2 = new ArrayDeque();
        PriorityTaskManager priorityTaskManager3 = segmentDownloader2.priorityTaskManager;
        if (priorityTaskManager3 != null) {
            priorityTaskManager3.add(-1000);
        }
        try {
            CacheDataSource createDataSourceForDownloading = segmentDownloader2.cacheDataSourceFactory.createDataSourceForDownloading();
            M manifest = segmentDownloader2.getManifest(createDataSourceForDownloading, segmentDownloader2.manifestDataSpec, false);
            if (!segmentDownloader2.streamKeys.isEmpty()) {
                manifest = (M) ((FilterableManifest) manifest.copy(segmentDownloader2.streamKeys));
            }
            List<Segment> segments = segmentDownloader2.getSegments(createDataSourceForDownloading, manifest, false);
            Collections.sort(segments);
            mergeSegments(segments, segmentDownloader2.cacheKeyFactory);
            int size2 = segments.size();
            int size3 = segments.size() - 1;
            long j = 0;
            long j2 = 0;
            int i2 = 0;
            while (size3 >= 0) {
                try {
                    DataSpec dataSpec = segments.get(size3).dataSpec;
                    String buildCacheKey = segmentDownloader2.cacheKeyFactory.buildCacheKey(dataSpec);
                    long j3 = dataSpec.length;
                    if (j3 == -1) {
                        long a = np.a(segmentDownloader2.cache.getContentMetadata(buildCacheKey));
                        if (a != -1) {
                            j3 = a - dataSpec.position;
                        }
                    }
                    long cachedBytes = segmentDownloader2.cache.getCachedBytes(buildCacheKey, dataSpec.position, j3);
                    j2 += cachedBytes;
                    if (j3 != -1) {
                        if (j3 == cachedBytes) {
                            i2++;
                            segments.remove(size3);
                        }
                        if (j != -1) {
                            j += j3;
                        }
                    } else {
                        j = -1;
                    }
                    size3--;
                    segmentDownloader2 = this;
                    arrayDeque = arrayDeque;
                } catch (Throwable th2) {
                    th = th2;
                    segmentDownloader = this;
                    while (i < segmentDownloader.activeRunnables.size()) {
                    }
                    while (size >= 0) {
                    }
                    priorityTaskManager2 = segmentDownloader.priorityTaskManager;
                    if (priorityTaskManager2 != null) {
                    }
                    throw th;
                }
            }
            ProgressNotifier progressNotifier = progressListener != null ? new ProgressNotifier(progressListener, j, size2, j2, i2) : null;
            arrayDeque.addAll(segments);
            segmentDownloader = this;
            while (!segmentDownloader.isCanceled && !arrayDeque.isEmpty()) {
                try {
                    PriorityTaskManager priorityTaskManager4 = segmentDownloader.priorityTaskManager;
                    if (priorityTaskManager4 != null) {
                        priorityTaskManager4.proceed(-1000);
                    }
                    if (!arrayDeque2.isEmpty()) {
                        SegmentDownloadRunnable segmentDownloadRunnable = (SegmentDownloadRunnable) arrayDeque2.removeFirst();
                        cacheDataSource = segmentDownloadRunnable.dataSource;
                        bArr = segmentDownloadRunnable.temporaryBuffer;
                    } else {
                        cacheDataSource = segmentDownloader.cacheDataSourceFactory.createDataSourceForDownloading();
                        bArr = new byte[131072];
                    }
                    SegmentDownloadRunnable segmentDownloadRunnable2 = new SegmentDownloadRunnable((Segment) arrayDeque.removeFirst(), cacheDataSource, progressNotifier, bArr);
                    segmentDownloader.addActiveRunnable(segmentDownloadRunnable2);
                    segmentDownloader.executor.execute(segmentDownloadRunnable2);
                    for (int size4 = segmentDownloader.activeRunnables.size() - 1; size4 >= 0; size4--) {
                        SegmentDownloadRunnable segmentDownloadRunnable3 = (SegmentDownloadRunnable) segmentDownloader.activeRunnables.get(size4);
                        if (arrayDeque.isEmpty() || segmentDownloadRunnable3.isDone()) {
                            try {
                                segmentDownloadRunnable3.get();
                                segmentDownloader.removeActiveRunnable(size4);
                                arrayDeque2.addLast(segmentDownloadRunnable3);
                            } catch (ExecutionException e) {
                                Throwable th3 = (Throwable) Assertions.checkNotNull(e.getCause());
                                if (th3 instanceof PriorityTaskManager.PriorityTooLowException) {
                                    arrayDeque.addFirst(segmentDownloadRunnable3.segment);
                                    segmentDownloader.removeActiveRunnable(size4);
                                    arrayDeque2.addLast(segmentDownloadRunnable3);
                                } else if (!(th3 instanceof IOException)) {
                                    Util.sneakyThrow(th3);
                                } else {
                                    throw ((IOException) th3);
                                }
                            }
                        }
                    }
                    segmentDownloadRunnable2.blockUntilStarted();
                } catch (Throwable th4) {
                    th = th4;
                    for (i = 0; i < segmentDownloader.activeRunnables.size(); i++) {
                        segmentDownloader.activeRunnables.get(i).cancel(true);
                    }
                    for (size = segmentDownloader.activeRunnables.size() - 1; size >= 0; size--) {
                        segmentDownloader.activeRunnables.get(size).blockUntilFinished();
                        segmentDownloader.removeActiveRunnable(size);
                    }
                    priorityTaskManager2 = segmentDownloader.priorityTaskManager;
                    if (priorityTaskManager2 != null) {
                        priorityTaskManager2.remove(-1000);
                    }
                    throw th;
                }
            }
            for (int i3 = 0; i3 < segmentDownloader.activeRunnables.size(); i3++) {
                segmentDownloader.activeRunnables.get(i3).cancel(true);
            }
            for (int size5 = segmentDownloader.activeRunnables.size() - 1; size5 >= 0; size5--) {
                segmentDownloader.activeRunnables.get(size5).blockUntilFinished();
                segmentDownloader.removeActiveRunnable(size5);
            }
            PriorityTaskManager priorityTaskManager5 = segmentDownloader.priorityTaskManager;
            if (priorityTaskManager5 != null) {
                priorityTaskManager5.remove(-1000);
            }
        } catch (Throwable th5) {
            th = th5;
            segmentDownloader = segmentDownloader2;
            while (i < segmentDownloader.activeRunnables.size()) {
            }
            while (size >= 0) {
            }
            priorityTaskManager2 = segmentDownloader.priorityTaskManager;
            if (priorityTaskManager2 != null) {
            }
            throw th;
        }
    }

    public final <T> T execute(RunnableFutureTask<T, ?> runnableFutureTask, boolean z) {
        if (z) {
            runnableFutureTask.run();
            try {
                return runnableFutureTask.get();
            } catch (ExecutionException e) {
                Throwable th = (Throwable) Assertions.checkNotNull(e.getCause());
                if (!(th instanceof IOException)) {
                    Util.sneakyThrow(e);
                } else {
                    throw ((IOException) th);
                }
            }
        }
        while (!this.isCanceled) {
            PriorityTaskManager priorityTaskManager2 = this.priorityTaskManager;
            if (priorityTaskManager2 != null) {
                priorityTaskManager2.proceed(-1000);
            }
            addActiveRunnable(runnableFutureTask);
            this.executor.execute(runnableFutureTask);
            try {
                return runnableFutureTask.get();
            } catch (ExecutionException e2) {
                Throwable th2 = (Throwable) Assertions.checkNotNull(e2.getCause());
                if (!(th2 instanceof PriorityTaskManager.PriorityTooLowException)) {
                    if (!(th2 instanceof IOException)) {
                        Util.sneakyThrow(e2);
                    } else {
                        throw ((IOException) th2);
                    }
                }
            } finally {
                runnableFutureTask.blockUntilFinished();
                removeActiveRunnable((RunnableFutureTask<?, ?>) runnableFutureTask);
            }
        }
        throw new InterruptedException();
    }

    public final M getManifest(final DataSource dataSource, final DataSpec dataSpec, boolean z) {
        return (M) ((FilterableManifest) execute(new RunnableFutureTask<M, IOException>() {
            /* class com.google.android.exoplayer2.offline.SegmentDownloader.AnonymousClass1 */

            @Override // com.google.android.exoplayer2.util.RunnableFutureTask
            public M doWork() {
                return (M) ((FilterableManifest) ParsingLoadable.load(dataSource, SegmentDownloader.this.manifestParser, dataSpec, 4));
            }
        }, z));
    }

    public abstract List<Segment> getSegments(DataSource dataSource, M m, boolean z);

    /* JADX WARNING: Missing exception handler attribute for start block: B:10:0x003e */
    @Override // com.google.android.exoplayer2.offline.Downloader
    public final void remove() {
        CacheDataSource createDataSourceForRemovingDownload = this.cacheDataSourceFactory.createDataSourceForRemovingDownload();
        try {
            List<Segment> segments = getSegments(createDataSourceForRemovingDownload, getManifest(createDataSourceForRemovingDownload, this.manifestDataSpec, true), true);
            for (int i = 0; i < segments.size(); i++) {
                this.cache.removeResource(this.cacheKeyFactory.buildCacheKey(segments.get(i).dataSpec));
            }
        } catch (InterruptedException unknown) {
            try {
                Thread.currentThread().interrupt();
            } catch (Throwable th) {
                this.cache.removeResource(this.cacheKeyFactory.buildCacheKey(this.manifestDataSpec));
                throw th;
            }
        } catch (Exception unused) {
        }
        this.cache.removeResource(this.cacheKeyFactory.buildCacheKey(this.manifestDataSpec));
    }

    private void removeActiveRunnable(int i) {
        synchronized (this.activeRunnables) {
            this.activeRunnables.remove(i);
        }
    }
}
