package com.google.android.exoplayer2.source.rtsp;

import androidx.annotation.Nullable;
import androidx.base.b;
import androidx.base.b2;
import androidx.base.ds;
import androidx.base.wt;
import androidx.base.zr;
import com.google.android.exoplayer2.ParserException;
import com.google.android.exoplayer2.util.Assertions;
import com.google.android.exoplayer2.util.Util;
import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.util.Arrays;
import java.util.HashMap;

public final class MediaDescription {
    public static final String MEDIA_TYPE_AUDIO = "audio";
    public static final String MEDIA_TYPE_VIDEO = "video";
    public static final String RTP_AVP_PROFILE = "RTP/AVP";
    public final ds<String, String> attributes;
    public final int bitrate;
    @Nullable
    public final String connection;
    @Nullable
    public final String key;
    @Nullable
    public final String mediaTitle;
    public final String mediaType;
    public final int payloadType;
    public final int port;
    public final RtpMapAttribute rtpMapAttribute;
    public final String transportProtocol;

    public static final class Builder {
        private final HashMap<String, String> attributes = new HashMap<>();
        private int bitrate = -1;
        @Nullable
        private String connection;
        @Nullable
        private String key;
        @Nullable
        private String mediaTitle;
        private final String mediaType;
        private final int payloadType;
        private final int port;
        private final String transportProtocol;

        public Builder(String str, int i, String str2, int i2) {
            this.mediaType = str;
            this.port = i;
            this.transportProtocol = str2;
            this.payloadType = i2;
        }

        public Builder addAttribute(String str, String str2) {
            this.attributes.put(str, str2);
            return this;
        }

        public MediaDescription build() {
            try {
                Assertions.checkState(this.attributes.containsKey(SessionDescription.ATTR_RTPMAP));
                return new MediaDescription(this, ds.copyOf(this.attributes), RtpMapAttribute.parse((String) Util.castNonNull(this.attributes.get(SessionDescription.ATTR_RTPMAP))));
            } catch (ParserException e) {
                throw new IllegalStateException(e);
            }
        }

        public Builder setBitrate(int i) {
            this.bitrate = i;
            return this;
        }

        public Builder setConnection(String str) {
            this.connection = str;
            return this;
        }

        public Builder setKey(String str) {
            this.key = str;
            return this;
        }

        public Builder setMediaTitle(String str) {
            this.mediaTitle = str;
            return this;
        }
    }

    @Documented
    @Retention(RetentionPolicy.SOURCE)
    public @interface MediaType {
    }

    public static final class RtpMapAttribute {
        public final int clockRate;
        public final int encodingParameters;
        public final String mediaEncoding;
        public final int payloadType;

        private RtpMapAttribute(int i, String str, int i2, int i3) {
            this.payloadType = i;
            this.mediaEncoding = str;
            this.clockRate = i2;
            this.encodingParameters = i3;
        }

        public static RtpMapAttribute parse(String str) {
            String[] split = Util.split(str, " ");
            Assertions.checkArgument(split.length == 2);
            int parseInt = RtspMessageUtil.parseInt(split[0]);
            String[] split2 = Util.split(split[1], "/");
            Assertions.checkArgument(split2.length >= 2);
            int parseInt2 = RtspMessageUtil.parseInt(split2[1]);
            int i = -1;
            if (split2.length == 3) {
                i = RtspMessageUtil.parseInt(split2[2]);
            }
            return new RtpMapAttribute(parseInt, split2[0], parseInt2, i);
        }

        public boolean equals(@Nullable Object obj) {
            if (this == obj) {
                return true;
            }
            if (obj == null || RtpMapAttribute.class != obj.getClass()) {
                return false;
            }
            RtpMapAttribute rtpMapAttribute = (RtpMapAttribute) obj;
            if (this.payloadType == rtpMapAttribute.payloadType && this.mediaEncoding.equals(rtpMapAttribute.mediaEncoding) && this.clockRate == rtpMapAttribute.clockRate && this.encodingParameters == rtpMapAttribute.encodingParameters) {
                return true;
            }
            return false;
        }

        public int hashCode() {
            return ((b2.b(this.mediaEncoding, (this.payloadType + 217) * 31, 31) + this.clockRate) * 31) + this.encodingParameters;
        }
    }

    public boolean equals(@Nullable Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || MediaDescription.class != obj.getClass()) {
            return false;
        }
        MediaDescription mediaDescription = (MediaDescription) obj;
        if (!this.mediaType.equals(mediaDescription.mediaType) || this.port != mediaDescription.port || !this.transportProtocol.equals(mediaDescription.transportProtocol) || this.payloadType != mediaDescription.payloadType || this.bitrate != mediaDescription.bitrate || !this.attributes.equals(mediaDescription.attributes) || !this.rtpMapAttribute.equals(mediaDescription.rtpMapAttribute) || !Util.areEqual(this.mediaTitle, mediaDescription.mediaTitle) || !Util.areEqual(this.connection, mediaDescription.connection) || !Util.areEqual(this.key, mediaDescription.key)) {
            return false;
        }
        return true;
    }

    public ds<String, String> getFmtpParametersAsMap() {
        String str = this.attributes.get(SessionDescription.ATTR_FMTP);
        if (str == null) {
            return ds.of();
        }
        String[] splitAtFirst = Util.splitAtFirst(str, " ");
        Assertions.checkArgument(splitAtFirst.length == 2, str);
        String[] split = Util.split(splitAtFirst[1], ";\\s?");
        Object[] objArr = new Object[8];
        int length = split.length;
        int i = 0;
        int i2 = 0;
        while (i < length) {
            String[] splitAtFirst2 = Util.splitAtFirst(split[i], "=");
            String str2 = splitAtFirst2[0];
            String str3 = splitAtFirst2[1];
            int i3 = i2 + 1;
            int i4 = i3 * 2;
            if (i4 > objArr.length) {
                objArr = Arrays.copyOf(objArr, zr.b.a(objArr.length, i4));
            }
            b.h(str2, str3);
            int i5 = i2 * 2;
            objArr[i5] = str2;
            objArr[i5 + 1] = str3;
            i++;
            i2 = i3;
        }
        return wt.create(i2, objArr);
    }

    public int hashCode() {
        int hashCode = (this.rtpMapAttribute.hashCode() + ((this.attributes.hashCode() + ((((b2.b(this.transportProtocol, (b2.b(this.mediaType, 217, 31) + this.port) * 31, 31) + this.payloadType) * 31) + this.bitrate) * 31)) * 31)) * 31;
        String str = this.mediaTitle;
        int i = 0;
        int hashCode2 = (hashCode + (str == null ? 0 : str.hashCode())) * 31;
        String str2 = this.connection;
        int hashCode3 = (hashCode2 + (str2 == null ? 0 : str2.hashCode())) * 31;
        String str3 = this.key;
        if (str3 != null) {
            i = str3.hashCode();
        }
        return hashCode3 + i;
    }

    private MediaDescription(Builder builder, ds<String, String> dsVar, RtpMapAttribute rtpMapAttribute2) {
        this.mediaType = builder.mediaType;
        this.port = builder.port;
        this.transportProtocol = builder.transportProtocol;
        this.payloadType = builder.payloadType;
        this.mediaTitle = builder.mediaTitle;
        this.connection = builder.connection;
        this.bitrate = builder.bitrate;
        this.key = builder.key;
        this.attributes = dsVar;
        this.rtpMapAttribute = rtpMapAttribute2;
    }
}
