package com.google.android.exoplayer2.video;

import android.annotation.SuppressLint;
import android.annotation.TargetApi;
import android.content.Context;
import android.graphics.Point;
import android.media.MediaCrypto;
import android.media.MediaFormat;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.os.SystemClock;
import android.util.Pair;
import android.view.Surface;
import androidx.annotation.CallSuper;
import androidx.annotation.Nullable;
import androidx.annotation.RequiresApi;
import androidx.base.ex;
import com.google.android.exoplayer2.C;
import com.google.android.exoplayer2.ExoPlaybackException;
import com.google.android.exoplayer2.Format;
import com.google.android.exoplayer2.FormatHolder;
import com.google.android.exoplayer2.decoder.DecoderCounters;
import com.google.android.exoplayer2.decoder.DecoderInputBuffer;
import com.google.android.exoplayer2.decoder.DecoderReuseEvaluation;
import com.google.android.exoplayer2.extractor.mp3.IndexSeeker;
import com.google.android.exoplayer2.extractor.ts.TsExtractor;
import com.google.android.exoplayer2.mediacodec.MediaCodecAdapter;
import com.google.android.exoplayer2.mediacodec.MediaCodecDecoderException;
import com.google.android.exoplayer2.mediacodec.MediaCodecInfo;
import com.google.android.exoplayer2.mediacodec.MediaCodecRenderer;
import com.google.android.exoplayer2.mediacodec.MediaCodecSelector;
import com.google.android.exoplayer2.mediacodec.MediaCodecUtil;
import com.google.android.exoplayer2.util.Assertions;
import com.google.android.exoplayer2.util.Log;
import com.google.android.exoplayer2.util.MediaFormatUtil;
import com.google.android.exoplayer2.util.MimeTypes;
import com.google.android.exoplayer2.util.TraceUtil;
import com.google.android.exoplayer2.util.Util;
import com.google.android.exoplayer2.video.VideoRendererEventListener;
import com.orhanobut.hawk.DataInfo;
import java.nio.ByteBuffer;
import java.util.Collections;
import java.util.List;
import tv.danmaku.ijk.media.player.misc.IMediaFormat;

public class MediaCodecVideoRenderer extends MediaCodecRenderer {
    private static final float INITIAL_FORMAT_MAX_INPUT_SIZE_SCALE_FACTOR = 1.5f;
    private static final String KEY_CROP_BOTTOM = "crop-bottom";
    private static final String KEY_CROP_LEFT = "crop-left";
    private static final String KEY_CROP_RIGHT = "crop-right";
    private static final String KEY_CROP_TOP = "crop-top";
    private static final int[] STANDARD_LONG_EDGE_VIDEO_PX = {1920, 1600, 1440, 1280, 960, 854, 640, 540, 480};
    private static final String TAG = "MediaCodecVideoRenderer";
    private static final long TUNNELING_EOS_PRESENTATION_TIME_US = Long.MAX_VALUE;
    private static boolean deviceNeedsSetOutputSurfaceWorkaround;
    private static boolean evaluatedDeviceNeedsSetOutputSurfaceWorkaround;
    private final long allowedJoiningTimeMs;
    private int buffersInCodecCount;
    private boolean codecHandlesHdr10PlusOutOfBandMetadata;
    private CodecMaxValues codecMaxValues;
    private boolean codecNeedsSetOutputSurfaceWorkaround;
    private int consecutiveDroppedFrameCount;
    private final Context context;
    private int currentHeight;
    private float currentPixelWidthHeightRatio;
    private int currentUnappliedRotationDegrees;
    private int currentWidth;
    private final boolean deviceNeedsNoPostProcessWorkaround;
    private long droppedFrameAccumulationStartTimeMs;
    private int droppedFrames;
    @Nullable
    private DummySurface dummySurface;
    private final VideoRendererEventListener.EventDispatcher eventDispatcher;
    @Nullable
    private VideoFrameMetadataListener frameMetadataListener;
    private final VideoFrameReleaseHelper frameReleaseHelper;
    private boolean haveReportedFirstFrameRenderedForCurrentSurface;
    private long initialPositionUs;
    private long joiningDeadlineMs;
    private long lastBufferPresentationTimeUs;
    private long lastRenderRealtimeUs;
    private final int maxDroppedFramesToNotify;
    private boolean mayRenderFirstFrameAfterEnableIfNotStarted;
    private boolean renderedFirstFrameAfterEnable;
    private boolean renderedFirstFrameAfterReset;
    @Nullable
    private VideoSize reportedVideoSize;
    private int scalingMode;
    @Nullable
    private Surface surface;
    private long totalVideoFrameProcessingOffsetUs;
    private boolean tunneling;
    private int tunnelingAudioSessionId;
    @Nullable
    public OnFrameRenderedListenerV23 tunnelingOnFrameRenderedListener;
    private int videoFrameProcessingOffsetCount;

    public static final class CodecMaxValues {
        public final int height;
        public final int inputSize;
        public final int width;

        public CodecMaxValues(int i, int i2, int i3) {
            this.width = i;
            this.height = i2;
            this.inputSize = i3;
        }
    }

    @RequiresApi(23)
    public final class OnFrameRenderedListenerV23 implements MediaCodecAdapter.OnFrameRenderedListener, Handler.Callback {
        private static final int HANDLE_FRAME_RENDERED = 0;
        private final Handler handler;

        public OnFrameRenderedListenerV23(MediaCodecAdapter mediaCodecAdapter) {
            Handler createHandlerForCurrentLooper = Util.createHandlerForCurrentLooper(this);
            this.handler = createHandlerForCurrentLooper;
            mediaCodecAdapter.setOnFrameRenderedListener(this, createHandlerForCurrentLooper);
        }

        private void handleFrameRendered(long j) {
            MediaCodecVideoRenderer mediaCodecVideoRenderer = MediaCodecVideoRenderer.this;
            if (this == mediaCodecVideoRenderer.tunnelingOnFrameRenderedListener) {
                if (j == Long.MAX_VALUE) {
                    mediaCodecVideoRenderer.onProcessedTunneledEndOfStream();
                    return;
                }
                try {
                    mediaCodecVideoRenderer.onProcessedTunneledBuffer(j);
                } catch (ExoPlaybackException e) {
                    MediaCodecVideoRenderer.this.setPendingPlaybackException(e);
                }
            }
        }

        public boolean handleMessage(Message message) {
            if (message.what != 0) {
                return false;
            }
            handleFrameRendered(Util.toLong(message.arg1, message.arg2));
            return true;
        }

        @Override // com.google.android.exoplayer2.mediacodec.MediaCodecAdapter.OnFrameRenderedListener
        public void onFrameRendered(MediaCodecAdapter mediaCodecAdapter, long j, long j2) {
            if (Util.SDK_INT < 30) {
                this.handler.sendMessageAtFrontOfQueue(Message.obtain(this.handler, 0, (int) (j >> 32), (int) j));
                return;
            }
            handleFrameRendered(j);
        }
    }

    public MediaCodecVideoRenderer(Context context2, MediaCodecSelector mediaCodecSelector) {
        this(context2, mediaCodecSelector, 0);
    }

    private void clearRenderedFirstFrame() {
        MediaCodecAdapter codec;
        this.renderedFirstFrameAfterReset = false;
        if (Util.SDK_INT >= 23 && this.tunneling && (codec = getCodec()) != null) {
            this.tunnelingOnFrameRenderedListener = new OnFrameRenderedListenerV23(codec);
        }
    }

    private void clearReportedVideoSize() {
        this.reportedVideoSize = null;
    }

    @RequiresApi(21)
    private static void configureTunnelingV21(MediaFormat mediaFormat, int i) {
        mediaFormat.setFeatureEnabled("tunneled-playback", true);
        mediaFormat.setInteger("audio-session-id", i);
    }

    private static boolean deviceNeedsNoPostProcessWorkaround() {
        return "NVIDIA".equals(Util.MANUFACTURER);
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Code restructure failed: missing block: B:438:0x07d4, code lost:
        if (r0.equals("NX573J") == false) goto L_0x008c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:462:0x0836, code lost:
        if (r0.equals("AFTN") == false) goto L_0x082e;
     */
    private static boolean evaluateDeviceNeedsSetOutputSurfaceWorkaround() {
        char c;
        int i = Util.SDK_INT;
        char c2 = 6;
        char c3 = 2;
        if (i <= 28) {
            String str = Util.DEVICE;
            str.hashCode();
            switch (str.hashCode()) {
                case -1339091551:
                    if (str.equals("dangal")) {
                        c = 0;
                        break;
                    }
                    c = 65535;
                    break;
                case -1220081023:
                    if (str.equals("dangalFHD")) {
                        c = 1;
                        break;
                    }
                    c = 65535;
                    break;
                case -1220066608:
                    if (str.equals("dangalUHD")) {
                        c = 2;
                        break;
                    }
                    c = 65535;
                    break;
                case -1012436106:
                    if (str.equals("oneday")) {
                        c = 3;
                        break;
                    }
                    c = 65535;
                    break;
                case -64886864:
                    if (str.equals("magnolia")) {
                        c = 4;
                        break;
                    }
                    c = 65535;
                    break;
                case 3415681:
                    if (str.equals("once")) {
                        c = 5;
                        break;
                    }
                    c = 65535;
                    break;
                case 825323514:
                    if (str.equals("machuca")) {
                        c = 6;
                        break;
                    }
                    c = 65535;
                    break;
                default:
                    c = 65535;
                    break;
            }
            switch (c) {
                case 0:
                case 1:
                case 2:
                case 3:
                case 4:
                case 5:
                case 6:
                    return true;
            }
        }
        if (i <= 27 && "HWEML".equals(Util.DEVICE)) {
            return true;
        }
        if (i <= 26) {
            String str2 = Util.DEVICE;
            str2.hashCode();
            switch (str2.hashCode()) {
                case -2144781245:
                    if (str2.equals("GIONEE_SWW1609")) {
                        c2 = 0;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -2144781185:
                    if (str2.equals("GIONEE_SWW1627")) {
                        c2 = 1;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -2144781160:
                    if (str2.equals("GIONEE_SWW1631")) {
                        c2 = 2;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -2097309513:
                    if (str2.equals("K50a40")) {
                        c2 = 3;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -2022874474:
                    if (str2.equals("CP8676_I02")) {
                        c2 = 4;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1978993182:
                    if (str2.equals("NX541J")) {
                        c2 = 5;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1978990237:
                    break;
                case -1936688988:
                    if (str2.equals("PGN528")) {
                        c2 = 7;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1936688066:
                    if (str2.equals("PGN610")) {
                        c2 = '\b';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1936688065:
                    if (str2.equals("PGN611")) {
                        c2 = '\t';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1931988508:
                    if (str2.equals("AquaPowerM")) {
                        c2 = '\n';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1885099851:
                    if (str2.equals("RAIJIN")) {
                        c2 = 11;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1696512866:
                    if (str2.equals("XT1663")) {
                        c2 = '\f';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1680025915:
                    if (str2.equals("ComioS1")) {
                        c2 = '\r';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1615810839:
                    if (str2.equals("Phantom6")) {
                        c2 = 14;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1600724499:
                    if (str2.equals("pacificrim")) {
                        c2 = 15;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1554255044:
                    if (str2.equals("vernee_M5")) {
                        c2 = 16;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1481772737:
                    if (str2.equals("panell_dl")) {
                        c2 = 17;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1481772730:
                    if (str2.equals("panell_ds")) {
                        c2 = 18;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1481772729:
                    if (str2.equals("panell_dt")) {
                        c2 = 19;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1320080169:
                    if (str2.equals("GiONEE_GBL7319")) {
                        c2 = 20;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1217592143:
                    if (str2.equals("BRAVIA_ATV2")) {
                        c2 = 21;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1180384755:
                    if (str2.equals("iris60")) {
                        c2 = 22;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1139198265:
                    if (str2.equals("Slate_Pro")) {
                        c2 = 23;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1052835013:
                    if (str2.equals("namath")) {
                        c2 = 24;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -993250464:
                    if (str2.equals("A10-70F")) {
                        c2 = 25;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -993250458:
                    if (str2.equals("A10-70L")) {
                        c2 = 26;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -965403638:
                    if (str2.equals("s905x018")) {
                        c2 = 27;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -958336948:
                    if (str2.equals("ELUGA_Ray_X")) {
                        c2 = 28;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -879245230:
                    if (str2.equals("tcl_eu")) {
                        c2 = 29;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -842500323:
                    if (str2.equals("nicklaus_f")) {
                        c2 = 30;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -821392978:
                    if (str2.equals("A7000-a")) {
                        c2 = 31;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -797483286:
                    if (str2.equals("SVP-DTV15")) {
                        c2 = ' ';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -794946968:
                    if (str2.equals("watson")) {
                        c2 = '!';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -788334647:
                    if (str2.equals("whyred")) {
                        c2 = '\"';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -782144577:
                    if (str2.equals("OnePlus5T")) {
                        c2 = '#';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -575125681:
                    if (str2.equals("GiONEE_CBL7513")) {
                        c2 = '$';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -521118391:
                    if (str2.equals("GIONEE_GBL7360")) {
                        c2 = '%';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -430914369:
                    if (str2.equals("Pixi4-7_3G")) {
                        c2 = '&';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -290434366:
                    if (str2.equals("taido_row")) {
                        c2 = '\'';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -282781963:
                    if (str2.equals("BLACK-1X")) {
                        c2 = '(';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -277133239:
                    if (str2.equals("Z12_PRO")) {
                        c2 = ')';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -173639913:
                    if (str2.equals("ELUGA_A3_Pro")) {
                        c2 = '*';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -56598463:
                    if (str2.equals("woods_fn")) {
                        c2 = '+';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2126:
                    if (str2.equals("C1")) {
                        c2 = ',';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2564:
                    if (str2.equals("Q5")) {
                        c2 = '-';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2715:
                    if (str2.equals("V1")) {
                        c2 = '.';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2719:
                    if (str2.equals("V5")) {
                        c2 = '/';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 3091:
                    if (str2.equals("b5")) {
                        c2 = DataInfo.TYPE_OBJECT;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 3483:
                    if (str2.equals("mh")) {
                        c2 = DataInfo.TYPE_LIST;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 73405:
                    if (str2.equals("JGZ")) {
                        c2 = DataInfo.TYPE_MAP;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 75537:
                    if (str2.equals("M04")) {
                        c2 = DataInfo.TYPE_SET;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 75739:
                    if (str2.equals("M5c")) {
                        c2 = '4';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 76779:
                    if (str2.equals("MX6")) {
                        c2 = '5';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 78669:
                    if (str2.equals("P85")) {
                        c2 = '6';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 79305:
                    if (str2.equals("PLE")) {
                        c2 = '7';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 80618:
                    if (str2.equals("QX1")) {
                        c2 = '8';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 88274:
                    if (str2.equals("Z80")) {
                        c2 = '9';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 98846:
                    if (str2.equals("cv1")) {
                        c2 = ':';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 98848:
                    if (str2.equals("cv3")) {
                        c2 = ';';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 99329:
                    if (str2.equals("deb")) {
                        c2 = '<';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 101481:
                    if (str2.equals("flo")) {
                        c2 = '=';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1513190:
                    if (str2.equals("1601")) {
                        c2 = '>';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1514184:
                    if (str2.equals("1713")) {
                        c2 = '?';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1514185:
                    if (str2.equals("1714")) {
                        c2 = '@';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2133089:
                    if (str2.equals("F01H")) {
                        c2 = 'A';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2133091:
                    if (str2.equals("F01J")) {
                        c2 = 'B';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2133120:
                    if (str2.equals("F02H")) {
                        c2 = 'C';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2133151:
                    if (str2.equals("F03H")) {
                        c2 = 'D';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2133182:
                    if (str2.equals("F04H")) {
                        c2 = 'E';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2133184:
                    if (str2.equals("F04J")) {
                        c2 = 'F';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2436959:
                    if (str2.equals("P681")) {
                        c2 = 'G';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2463773:
                    if (str2.equals("Q350")) {
                        c2 = 'H';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2464648:
                    if (str2.equals("Q427")) {
                        c2 = 'I';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2689555:
                    if (str2.equals("XE2X")) {
                        c2 = 'J';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 3154429:
                    if (str2.equals("fugu")) {
                        c2 = 'K';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 3284551:
                    if (str2.equals("kate")) {
                        c2 = 'L';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 3351335:
                    if (str2.equals("mido")) {
                        c2 = 'M';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 3386211:
                    if (str2.equals("p212")) {
                        c2 = 'N';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 41325051:
                    if (str2.equals("MEIZU_M5")) {
                        c2 = 'O';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 51349633:
                    if (str2.equals("601LV")) {
                        c2 = 'P';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 51350594:
                    if (str2.equals("602LV")) {
                        c2 = 'Q';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 55178625:
                    if (str2.equals("Aura_Note_2")) {
                        c2 = 'R';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 61542055:
                    if (str2.equals("A1601")) {
                        c2 = 'S';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 65355429:
                    if (str2.equals("E5643")) {
                        c2 = 'T';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 66214468:
                    if (str2.equals("F3111")) {
                        c2 = 'U';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 66214470:
                    if (str2.equals("F3113")) {
                        c2 = 'V';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 66214473:
                    if (str2.equals("F3116")) {
                        c2 = 'W';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 66215429:
                    if (str2.equals("F3211")) {
                        c2 = 'X';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 66215431:
                    if (str2.equals("F3213")) {
                        c2 = 'Y';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 66215433:
                    if (str2.equals("F3215")) {
                        c2 = 'Z';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 66216390:
                    if (str2.equals("F3311")) {
                        c2 = '[';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 76402249:
                    if (str2.equals("PRO7S")) {
                        c2 = '\\';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 76404105:
                    if (str2.equals("Q4260")) {
                        c2 = ']';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 76404911:
                    if (str2.equals("Q4310")) {
                        c2 = '^';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 80963634:
                    if (str2.equals("V23GB")) {
                        c2 = '_';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 82882791:
                    if (str2.equals("X3_HK")) {
                        c2 = '`';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 98715550:
                    if (str2.equals("i9031")) {
                        c2 = 'a';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 101370885:
                    if (str2.equals("l5460")) {
                        c2 = 'b';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 102844228:
                    if (str2.equals("le_x6")) {
                        c2 = 'c';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 165221241:
                    if (str2.equals("A2016a40")) {
                        c2 = 'd';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 182191441:
                    if (str2.equals("CPY83_I00")) {
                        c2 = 'e';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 245388979:
                    if (str2.equals("marino_f")) {
                        c2 = 'f';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 287431619:
                    if (str2.equals("griffin")) {
                        c2 = 'g';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 307593612:
                    if (str2.equals("A7010a48")) {
                        c2 = 'h';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 308517133:
                    if (str2.equals("A7020a48")) {
                        c2 = 'i';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 316215098:
                    if (str2.equals("TB3-730F")) {
                        c2 = 'j';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 316215116:
                    if (str2.equals("TB3-730X")) {
                        c2 = 'k';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 316246811:
                    if (str2.equals("TB3-850F")) {
                        c2 = 'l';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 316246818:
                    if (str2.equals("TB3-850M")) {
                        c2 = 'm';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 407160593:
                    if (str2.equals("Pixi5-10_4G")) {
                        c2 = 'n';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 507412548:
                    if (str2.equals("QM16XE_U")) {
                        c2 = 'o';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 793982701:
                    if (str2.equals("GIONEE_WBL5708")) {
                        c2 = 'p';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 794038622:
                    if (str2.equals("GIONEE_WBL7365")) {
                        c2 = 'q';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 794040393:
                    if (str2.equals("GIONEE_WBL7519")) {
                        c2 = 'r';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 835649806:
                    if (str2.equals("manning")) {
                        c2 = 's';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 917340916:
                    if (str2.equals("A7000plus")) {
                        c2 = 't';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 958008161:
                    if (str2.equals("j2xlteins")) {
                        c2 = 'u';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1060579533:
                    if (str2.equals("panell_d")) {
                        c2 = 'v';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1150207623:
                    if (str2.equals("LS-5017")) {
                        c2 = 'w';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1176899427:
                    if (str2.equals("itel_S41")) {
                        c2 = 'x';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1280332038:
                    if (str2.equals("hwALE-H")) {
                        c2 = 'y';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1306947716:
                    if (str2.equals("EverStar_S")) {
                        c2 = 'z';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1349174697:
                    if (str2.equals("htc_e56ml_dtul")) {
                        c2 = '{';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1522194893:
                    if (str2.equals("woods_f")) {
                        c2 = '|';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1691543273:
                    if (str2.equals("CPH1609")) {
                        c2 = '}';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1691544261:
                    if (str2.equals("CPH1715")) {
                        c2 = '~';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1709443163:
                    if (str2.equals("iball8735_9806")) {
                        c2 = 127;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1865889110:
                    if (str2.equals("santoni")) {
                        c2 = 128;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1906253259:
                    if (str2.equals("PB2-670M")) {
                        c2 = 129;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1977196784:
                    if (str2.equals("Infinix-X572")) {
                        c2 = 130;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2006372676:
                    if (str2.equals("BRAVIA_ATV3_4K")) {
                        c2 = 131;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2019281702:
                    if (str2.equals("DM-01K")) {
                        c2 = 132;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2029784656:
                    if (str2.equals("HWBLN-H")) {
                        c2 = 133;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2030379515:
                    if (str2.equals("HWCAM-H")) {
                        c2 = 134;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2033393791:
                    if (str2.equals("ASUS_X00AD_2")) {
                        c2 = 135;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2047190025:
                    if (str2.equals("ELUGA_Note")) {
                        c2 = 136;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2047252157:
                    if (str2.equals("ELUGA_Prim")) {
                        c2 = 137;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2048319463:
                    if (str2.equals("HWVNS-H")) {
                        c2 = 138;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2048855701:
                    if (str2.equals("HWWAS-H")) {
                        c2 = 139;
                        break;
                    }
                    c2 = 65535;
                    break;
                default:
                    c2 = 65535;
                    break;
            }
            switch (c2) {
                case 0:
                case 1:
                case 2:
                case 3:
                case 4:
                case 5:
                case 6:
                case 7:
                case '\b':
                case '\t':
                case '\n':
                case 11:
                case '\f':
                case '\r':
                case 14:
                case 15:
                case 16:
                case 17:
                case 18:
                case 19:
                case 20:
                case 21:
                case 22:
                case 23:
                case 24:
                case 25:
                case 26:
                case 27:
                case 28:
                case 29:
                case 30:
                case 31:
                case ' ':
                case '!':
                case '\"':
                case '#':
                case '$':
                case '%':
                case '&':
                case '\'':
                case '(':
                case ')':
                case '*':
                case '+':
                case ',':
                case '-':
                case '.':
                case '/':
                case '0':
                case '1':
                case '2':
                case '3':
                case '4':
                case '5':
                case '6':
                case '7':
                case '8':
                case '9':
                case ':':
                case ';':
                case '<':
                case '=':
                case '>':
                case '?':
                case '@':
                case 'A':
                case 'B':
                case 'C':
                case 'D':
                case 'E':
                case 'F':
                case 'G':
                case 'H':
                case 'I':
                case 'J':
                case 'K':
                case 'L':
                case 'M':
                case 'N':
                case 'O':
                case 'P':
                case 'Q':
                case 'R':
                case 'S':
                case 'T':
                case 'U':
                case 'V':
                case 'W':
                case 'X':
                case 'Y':
                case 'Z':
                case '[':
                case '\\':
                case ']':
                case '^':
                case '_':
                case '`':
                case 'a':
                case 'b':
                case 'c':
                case 'd':
                case 'e':
                case 'f':
                case 'g':
                case 'h':
                case 'i':
                case 'j':
                case 'k':
                case 'l':
                case 'm':
                case 'n':
                case 'o':
                case 'p':
                case 'q':
                case 'r':
                case 's':
                case 't':
                case 'u':
                case 'v':
                case 'w':
                case 'x':
                case 'y':
                case 'z':
                case '{':
                case '|':
                case '}':
                case '~':
                case 127:
                case 128:
                case TsExtractor.TS_STREAM_TYPE_AC3:
                case TsExtractor.TS_STREAM_TYPE_HDMV_DTS:
                case 131:
                case 132:
                case 133:
                case TsExtractor.TS_STREAM_TYPE_SPLICE_INFO:
                case TsExtractor.TS_STREAM_TYPE_E_AC3:
                case 136:
                case 137:
                case TsExtractor.TS_STREAM_TYPE_DTS:
                case 139:
                    break;
                default:
                    String str3 = Util.MODEL;
                    str3.hashCode();
                    switch (str3.hashCode()) {
                        case -594534941:
                            if (str3.equals("JSN-L21")) {
                                c3 = 0;
                                break;
                            }
                            c3 = 65535;
                            break;
                        case 2006354:
                            if (str3.equals("AFTA")) {
                                c3 = 1;
                                break;
                            }
                            c3 = 65535;
                            break;
                        case 2006367:
                            break;
                        default:
                            c3 = 65535;
                            break;
                    }
                    switch (c3) {
                    }
            }
            return true;
        }
        return false;
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    private static int getCodecMaxInputSize(MediaCodecInfo mediaCodecInfo, String str, int i, int i2) {
        char c;
        int i3;
        if (!(i == -1 || i2 == -1)) {
            str.hashCode();
            int i4 = 4;
            switch (str.hashCode()) {
                case -1851077871:
                    if (str.equals(MimeTypes.VIDEO_DOLBY_VISION)) {
                        c = 0;
                        break;
                    }
                    c = 65535;
                    break;
                case -1664118616:
                    if (str.equals(MimeTypes.VIDEO_H263)) {
                        c = 1;
                        break;
                    }
                    c = 65535;
                    break;
                case -1662541442:
                    if (str.equals("video/hevc")) {
                        c = 2;
                        break;
                    }
                    c = 65535;
                    break;
                case 1187890754:
                    if (str.equals(MimeTypes.VIDEO_MP4V)) {
                        c = 3;
                        break;
                    }
                    c = 65535;
                    break;
                case 1331836730:
                    if (str.equals("video/avc")) {
                        c = 4;
                        break;
                    }
                    c = 65535;
                    break;
                case 1599127256:
                    if (str.equals("video/x-vnd.on2.vp8")) {
                        c = 5;
                        break;
                    }
                    c = 65535;
                    break;
                case 1599127257:
                    if (str.equals("video/x-vnd.on2.vp9")) {
                        c = 6;
                        break;
                    }
                    c = 65535;
                    break;
                default:
                    c = 65535;
                    break;
            }
            switch (c) {
                case 0:
                case 4:
                    String str2 = Util.MODEL;
                    if (!"BRAVIA 4K 2015".equals(str2) && (!"Amazon".equals(Util.MANUFACTURER) || (!"KFSOWI".equals(str2) && (!"AFTS".equals(str2) || !mediaCodecInfo.secure)))) {
                        i3 = Util.ceilDivide(i2, 16) * Util.ceilDivide(i, 16) * 16 * 16;
                        i4 = 2;
                        break;
                    }
                case 1:
                case 3:
                case 5:
                    i3 = i * i2;
                    i4 = 2;
                    break;
                case 2:
                case 6:
                    i3 = i * i2;
                    break;
                default:
                    return -1;
            }
            return (i3 * 3) / (i4 * 2);
        }
        return -1;
    }

    private static Point getCodecMaxSize(MediaCodecInfo mediaCodecInfo, Format format) {
        int i = format.height;
        int i2 = format.width;
        boolean z = i > i2;
        int i3 = z ? i : i2;
        if (z) {
            i = i2;
        }
        float f = ((float) i) / ((float) i3);
        int[] iArr = STANDARD_LONG_EDGE_VIDEO_PX;
        for (int i4 : iArr) {
            int i5 = (int) (((float) i4) * f);
            if (i4 <= i3 || i5 <= i) {
                break;
            }
            if (Util.SDK_INT >= 21) {
                int i6 = z ? i5 : i4;
                if (!z) {
                    i4 = i5;
                }
                Point alignVideoSizeV21 = mediaCodecInfo.alignVideoSizeV21(i6, i4);
                if (mediaCodecInfo.isVideoSizeAndRateSupportedV21(alignVideoSizeV21.x, alignVideoSizeV21.y, (double) format.frameRate)) {
                    return alignVideoSizeV21;
                }
            } else {
                try {
                    int ceilDivide = Util.ceilDivide(i4, 16) * 16;
                    int ceilDivide2 = Util.ceilDivide(i5, 16) * 16;
                    if (ceilDivide * ceilDivide2 <= MediaCodecUtil.maxH264DecodableFrameSize()) {
                        int i7 = z ? ceilDivide2 : ceilDivide;
                        if (!z) {
                            ceilDivide = ceilDivide2;
                        }
                        return new Point(i7, ceilDivide);
                    }
                } catch (MediaCodecUtil.DecoderQueryException unused) {
                }
            }
        }
        return null;
    }

    public static int getMaxInputSize(MediaCodecInfo mediaCodecInfo, Format format) {
        if (format.maxInputSize == -1) {
            return getCodecMaxInputSize(mediaCodecInfo, format.sampleMimeType, format.width, format.height);
        }
        int size = format.initializationData.size();
        int i = 0;
        for (int i2 = 0; i2 < size; i2++) {
            i += format.initializationData.get(i2).length;
        }
        return format.maxInputSize + i;
    }

    private static boolean isBufferLate(long j) {
        return j < -30000;
    }

    private static boolean isBufferVeryLate(long j) {
        return j < -500000;
    }

    private void maybeNotifyDroppedFrames() {
        if (this.droppedFrames > 0) {
            long elapsedRealtime = SystemClock.elapsedRealtime();
            this.eventDispatcher.droppedFrames(this.droppedFrames, elapsedRealtime - this.droppedFrameAccumulationStartTimeMs);
            this.droppedFrames = 0;
            this.droppedFrameAccumulationStartTimeMs = elapsedRealtime;
        }
    }

    private void maybeNotifyVideoFrameProcessingOffset() {
        int i = this.videoFrameProcessingOffsetCount;
        if (i != 0) {
            this.eventDispatcher.reportVideoFrameProcessingOffset(this.totalVideoFrameProcessingOffsetUs, i);
            this.totalVideoFrameProcessingOffsetUs = 0;
            this.videoFrameProcessingOffsetCount = 0;
        }
    }

    private void maybeNotifyVideoSizeChanged() {
        int i = this.currentWidth;
        if (i != -1 || this.currentHeight != -1) {
            VideoSize videoSize = this.reportedVideoSize;
            if (videoSize == null || videoSize.width != i || videoSize.height != this.currentHeight || videoSize.unappliedRotationDegrees != this.currentUnappliedRotationDegrees || videoSize.pixelWidthHeightRatio != this.currentPixelWidthHeightRatio) {
                VideoSize videoSize2 = new VideoSize(this.currentWidth, this.currentHeight, this.currentUnappliedRotationDegrees, this.currentPixelWidthHeightRatio);
                this.reportedVideoSize = videoSize2;
                this.eventDispatcher.videoSizeChanged(videoSize2);
            }
        }
    }

    private void maybeRenotifyRenderedFirstFrame() {
        if (this.haveReportedFirstFrameRenderedForCurrentSurface) {
            this.eventDispatcher.renderedFirstFrame(this.surface);
        }
    }

    private void maybeRenotifyVideoSizeChanged() {
        VideoSize videoSize = this.reportedVideoSize;
        if (videoSize != null) {
            this.eventDispatcher.videoSizeChanged(videoSize);
        }
    }

    private void notifyFrameMetadataListener(long j, long j2, Format format) {
        VideoFrameMetadataListener videoFrameMetadataListener = this.frameMetadataListener;
        if (videoFrameMetadataListener != null) {
            videoFrameMetadataListener.onVideoFrameAboutToBeRendered(j, j2, format, getCodecOutputMediaFormat());
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onProcessedTunneledEndOfStream() {
        setPendingOutputEndOfStream();
    }

    @RequiresApi(29)
    private static void setHdr10PlusInfoV29(MediaCodecAdapter mediaCodecAdapter, byte[] bArr) {
        Bundle bundle = new Bundle();
        bundle.putByteArray("hdr10-plus-info", bArr);
        mediaCodecAdapter.setParameters(bundle);
    }

    private void setJoiningDeadlineMs() {
        this.joiningDeadlineMs = this.allowedJoiningTimeMs > 0 ? SystemClock.elapsedRealtime() + this.allowedJoiningTimeMs : C.TIME_UNSET;
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:4:0x0008 */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r4v0, types: [com.google.android.exoplayer2.BaseRenderer, com.google.android.exoplayer2.mediacodec.MediaCodecRenderer, com.google.android.exoplayer2.video.MediaCodecVideoRenderer] */
    /* JADX WARN: Type inference failed for: r5v8, types: [android.view.Surface] */
    /* JADX WARNING: Unknown variable types count: 1 */
    private void setOutput(@Nullable Object obj) {
        DummySurface dummySurface2 = obj instanceof Surface ? (Surface) obj : null;
        if (dummySurface2 == null) {
            DummySurface dummySurface3 = this.dummySurface;
            if (dummySurface3 != null) {
                dummySurface2 = dummySurface3;
            } else {
                MediaCodecInfo codecInfo = getCodecInfo();
                if (codecInfo != null && shouldUseDummySurface(codecInfo)) {
                    dummySurface2 = DummySurface.newInstanceV17(this.context, codecInfo.secure);
                    this.dummySurface = dummySurface2;
                }
            }
        }
        if (this.surface != dummySurface2) {
            this.surface = dummySurface2;
            this.frameReleaseHelper.onSurfaceChanged(dummySurface2);
            this.haveReportedFirstFrameRenderedForCurrentSurface = false;
            int state = getState();
            MediaCodecAdapter codec = getCodec();
            if (codec != null) {
                if (Util.SDK_INT < 23 || dummySurface2 == null || this.codecNeedsSetOutputSurfaceWorkaround) {
                    releaseCodec();
                    maybeInitCodecOrBypass();
                } else {
                    setOutputSurfaceV23(codec, dummySurface2);
                }
            }
            if (dummySurface2 == null || dummySurface2 == this.dummySurface) {
                clearReportedVideoSize();
                clearRenderedFirstFrame();
                return;
            }
            maybeRenotifyVideoSizeChanged();
            clearRenderedFirstFrame();
            if (state == 2) {
                setJoiningDeadlineMs();
            }
        } else if (dummySurface2 != null && dummySurface2 != this.dummySurface) {
            maybeRenotifyVideoSizeChanged();
            maybeRenotifyRenderedFirstFrame();
        }
    }

    private boolean shouldUseDummySurface(MediaCodecInfo mediaCodecInfo) {
        return Util.SDK_INT >= 23 && !this.tunneling && !codecNeedsSetOutputSurfaceWorkaround(mediaCodecInfo.name) && (!mediaCodecInfo.secure || DummySurface.isSecureSupported(this.context));
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public DecoderReuseEvaluation canReuseCodec(MediaCodecInfo mediaCodecInfo, Format format, Format format2) {
        int i;
        DecoderReuseEvaluation canReuseCodec = mediaCodecInfo.canReuseCodec(format, format2);
        int i2 = canReuseCodec.discardReasons;
        int i3 = format2.width;
        CodecMaxValues codecMaxValues2 = this.codecMaxValues;
        if (i3 > codecMaxValues2.width || format2.height > codecMaxValues2.height) {
            i2 |= 256;
        }
        if (getMaxInputSize(mediaCodecInfo, format2) > this.codecMaxValues.inputSize) {
            i2 |= 64;
        }
        String str = mediaCodecInfo.name;
        if (i2 != 0) {
            i = 0;
        } else {
            i = canReuseCodec.result;
        }
        return new DecoderReuseEvaluation(str, format, format2, i, i2);
    }

    public boolean codecNeedsSetOutputSurfaceWorkaround(String str) {
        if (str.startsWith("OMX.google")) {
            return false;
        }
        synchronized (MediaCodecVideoRenderer.class) {
            if (!evaluatedDeviceNeedsSetOutputSurfaceWorkaround) {
                deviceNeedsSetOutputSurfaceWorkaround = evaluateDeviceNeedsSetOutputSurfaceWorkaround();
                evaluatedDeviceNeedsSetOutputSurfaceWorkaround = true;
            }
        }
        return deviceNeedsSetOutputSurfaceWorkaround;
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public MediaCodecDecoderException createDecoderException(Throwable th, @Nullable MediaCodecInfo mediaCodecInfo) {
        return new MediaCodecVideoDecoderException(th, mediaCodecInfo, this.surface);
    }

    public void dropOutputBuffer(MediaCodecAdapter mediaCodecAdapter, int i, long j) {
        TraceUtil.beginSection("dropVideoBuffer");
        mediaCodecAdapter.releaseOutputBuffer(i, false);
        TraceUtil.endSection();
        updateDroppedBufferCounters(1);
    }

    public CodecMaxValues getCodecMaxValues(MediaCodecInfo mediaCodecInfo, Format format, Format[] formatArr) {
        int codecMaxInputSize;
        int i = format.width;
        int i2 = format.height;
        int maxInputSize = getMaxInputSize(mediaCodecInfo, format);
        if (formatArr.length == 1) {
            if (!(maxInputSize == -1 || (codecMaxInputSize = getCodecMaxInputSize(mediaCodecInfo, format.sampleMimeType, format.width, format.height)) == -1)) {
                maxInputSize = Math.min((int) (((float) maxInputSize) * INITIAL_FORMAT_MAX_INPUT_SIZE_SCALE_FACTOR), codecMaxInputSize);
            }
            return new CodecMaxValues(i, i2, maxInputSize);
        }
        int length = formatArr.length;
        boolean z = false;
        for (int i3 = 0; i3 < length; i3++) {
            Format format2 = formatArr[i3];
            if (format.colorInfo != null && format2.colorInfo == null) {
                format2 = format2.buildUpon().setColorInfo(format.colorInfo).build();
            }
            if (mediaCodecInfo.canReuseCodec(format, format2).result != 0) {
                int i4 = format2.width;
                z |= i4 == -1 || format2.height == -1;
                i = Math.max(i, i4);
                i2 = Math.max(i2, format2.height);
                maxInputSize = Math.max(maxInputSize, getMaxInputSize(mediaCodecInfo, format2));
            }
        }
        if (z) {
            StringBuilder sb = new StringBuilder(66);
            sb.append("Resolutions unknown. Codec max resolution: ");
            sb.append(i);
            sb.append("x");
            sb.append(i2);
            Log.w(TAG, sb.toString());
            Point codecMaxSize = getCodecMaxSize(mediaCodecInfo, format);
            if (codecMaxSize != null) {
                i = Math.max(i, codecMaxSize.x);
                i2 = Math.max(i2, codecMaxSize.y);
                maxInputSize = Math.max(maxInputSize, getCodecMaxInputSize(mediaCodecInfo, format.sampleMimeType, i, i2));
                StringBuilder sb2 = new StringBuilder(57);
                sb2.append("Codec max resolution adjusted to: ");
                sb2.append(i);
                sb2.append("x");
                sb2.append(i2);
                Log.w(TAG, sb2.toString());
            }
        }
        return new CodecMaxValues(i, i2, maxInputSize);
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public boolean getCodecNeedsEosPropagation() {
        return this.tunneling && Util.SDK_INT < 23;
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public float getCodecOperatingRateV23(float f, Format format, Format[] formatArr) {
        float f2 = -1.0f;
        for (Format format2 : formatArr) {
            float f3 = format2.frameRate;
            if (f3 != -1.0f) {
                f2 = Math.max(f2, f3);
            }
        }
        if (f2 == -1.0f) {
            return -1.0f;
        }
        return f2 * f;
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public List<MediaCodecInfo> getDecoderInfos(MediaCodecSelector mediaCodecSelector, Format format, boolean z) {
        return getDecoderInfos(mediaCodecSelector, format, z, this.tunneling);
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    @TargetApi(17)
    public MediaCodecAdapter.Configuration getMediaCodecConfiguration(MediaCodecInfo mediaCodecInfo, Format format, @Nullable MediaCrypto mediaCrypto, float f) {
        DummySurface dummySurface2 = this.dummySurface;
        if (!(dummySurface2 == null || dummySurface2.secure == mediaCodecInfo.secure)) {
            dummySurface2.release();
            this.dummySurface = null;
        }
        String str = mediaCodecInfo.codecMimeType;
        CodecMaxValues codecMaxValues2 = getCodecMaxValues(mediaCodecInfo, format, getStreamFormats());
        this.codecMaxValues = codecMaxValues2;
        MediaFormat mediaFormat = getMediaFormat(format, str, codecMaxValues2, f, this.deviceNeedsNoPostProcessWorkaround, this.tunneling ? this.tunnelingAudioSessionId : 0);
        if (this.surface == null) {
            if (shouldUseDummySurface(mediaCodecInfo)) {
                if (this.dummySurface == null) {
                    this.dummySurface = DummySurface.newInstanceV17(this.context, mediaCodecInfo.secure);
                }
                this.surface = this.dummySurface;
            } else {
                throw new IllegalStateException();
            }
        }
        return new MediaCodecAdapter.Configuration(mediaCodecInfo, mediaFormat, format, this.surface, mediaCrypto, 0);
    }

    @SuppressLint({"InlinedApi"})
    @TargetApi(21)
    public MediaFormat getMediaFormat(Format format, String str, CodecMaxValues codecMaxValues2, float f, boolean z, int i) {
        Pair<Integer, Integer> codecProfileAndLevel;
        MediaFormat mediaFormat = new MediaFormat();
        mediaFormat.setString(IMediaFormat.KEY_MIME, str);
        mediaFormat.setInteger("width", format.width);
        mediaFormat.setInteger("height", format.height);
        MediaFormatUtil.setCsdBuffers(mediaFormat, format.initializationData);
        MediaFormatUtil.maybeSetFloat(mediaFormat, "frame-rate", format.frameRate);
        MediaFormatUtil.maybeSetInteger(mediaFormat, "rotation-degrees", format.rotationDegrees);
        MediaFormatUtil.maybeSetColorInfo(mediaFormat, format.colorInfo);
        if (MimeTypes.VIDEO_DOLBY_VISION.equals(format.sampleMimeType) && (codecProfileAndLevel = MediaCodecUtil.getCodecProfileAndLevel(format)) != null) {
            MediaFormatUtil.maybeSetInteger(mediaFormat, "profile", ((Integer) codecProfileAndLevel.first).intValue());
        }
        mediaFormat.setInteger("max-width", codecMaxValues2.width);
        mediaFormat.setInteger("max-height", codecMaxValues2.height);
        MediaFormatUtil.maybeSetInteger(mediaFormat, "max-input-size", codecMaxValues2.inputSize);
        if (Util.SDK_INT >= 23) {
            mediaFormat.setInteger(ex.PRIORITY, 0);
            if (f != -1.0f) {
                mediaFormat.setFloat("operating-rate", f);
            }
        }
        if (z) {
            mediaFormat.setInteger("no-post-process", 1);
            mediaFormat.setInteger("auto-frc", 0);
        }
        if (i != 0) {
            configureTunnelingV21(mediaFormat, i);
        }
        return mediaFormat;
    }

    @Override // com.google.android.exoplayer2.RendererCapabilities, com.google.android.exoplayer2.Renderer
    public String getName() {
        return TAG;
    }

    public Surface getSurface() {
        return this.surface;
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    @TargetApi(29)
    public void handleInputBufferSupplementalData(DecoderInputBuffer decoderInputBuffer) {
        if (this.codecHandlesHdr10PlusOutOfBandMetadata) {
            ByteBuffer byteBuffer = (ByteBuffer) Assertions.checkNotNull(decoderInputBuffer.supplementalData);
            if (byteBuffer.remaining() >= 7) {
                byte b = byteBuffer.get();
                short s = byteBuffer.getShort();
                short s2 = byteBuffer.getShort();
                byte b2 = byteBuffer.get();
                byte b3 = byteBuffer.get();
                byteBuffer.position(0);
                if (b == -75 && s == 60 && s2 == 1 && b2 == 4 && b3 == 0) {
                    byte[] bArr = new byte[byteBuffer.remaining()];
                    byteBuffer.get(bArr);
                    byteBuffer.position(0);
                    setHdr10PlusInfoV29(getCodec(), bArr);
                }
            }
        }
    }

    @Override // com.google.android.exoplayer2.BaseRenderer, com.google.android.exoplayer2.PlayerMessage.Target
    public void handleMessage(int i, @Nullable Object obj) {
        if (i == 1) {
            setOutput(obj);
        } else if (i == 4) {
            this.scalingMode = ((Integer) obj).intValue();
            MediaCodecAdapter codec = getCodec();
            if (codec != null) {
                codec.setVideoScalingMode(this.scalingMode);
            }
        } else if (i == 6) {
            this.frameMetadataListener = (VideoFrameMetadataListener) obj;
        } else if (i != 102) {
            super.handleMessage(i, obj);
        } else {
            int intValue = ((Integer) obj).intValue();
            if (this.tunnelingAudioSessionId != intValue) {
                this.tunnelingAudioSessionId = intValue;
                if (this.tunneling) {
                    releaseCodec();
                }
            }
        }
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer, com.google.android.exoplayer2.Renderer
    public boolean isReady() {
        DummySurface dummySurface2;
        if (super.isReady() && (this.renderedFirstFrameAfterReset || (((dummySurface2 = this.dummySurface) != null && this.surface == dummySurface2) || getCodec() == null || this.tunneling))) {
            this.joiningDeadlineMs = C.TIME_UNSET;
            return true;
        } else if (this.joiningDeadlineMs == C.TIME_UNSET) {
            return false;
        } else {
            if (SystemClock.elapsedRealtime() < this.joiningDeadlineMs) {
                return true;
            }
            this.joiningDeadlineMs = C.TIME_UNSET;
            return false;
        }
    }

    public boolean maybeDropBuffersToKeyframe(long j, boolean z) {
        int skipSource = skipSource(j);
        if (skipSource == 0) {
            return false;
        }
        DecoderCounters decoderCounters = this.decoderCounters;
        decoderCounters.droppedToKeyframeCount++;
        int i = this.buffersInCodecCount + skipSource;
        if (z) {
            decoderCounters.skippedOutputBufferCount += i;
        } else {
            updateDroppedBufferCounters(i);
        }
        flushOrReinitializeCodec();
        return true;
    }

    public void maybeNotifyRenderedFirstFrame() {
        this.renderedFirstFrameAfterEnable = true;
        if (!this.renderedFirstFrameAfterReset) {
            this.renderedFirstFrameAfterReset = true;
            this.eventDispatcher.renderedFirstFrame(this.surface);
            this.haveReportedFirstFrameRenderedForCurrentSurface = true;
        }
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public void onCodecError(Exception exc) {
        Log.e(TAG, "Video codec error", exc);
        this.eventDispatcher.videoCodecError(exc);
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public void onCodecInitialized(String str, long j, long j2) {
        this.eventDispatcher.decoderInitialized(str, j, j2);
        this.codecNeedsSetOutputSurfaceWorkaround = codecNeedsSetOutputSurfaceWorkaround(str);
        this.codecHandlesHdr10PlusOutOfBandMetadata = ((MediaCodecInfo) Assertions.checkNotNull(getCodecInfo())).isHdr10PlusOutOfBandMetadataSupported();
        if (Util.SDK_INT >= 23 && this.tunneling) {
            this.tunnelingOnFrameRenderedListener = new OnFrameRenderedListenerV23((MediaCodecAdapter) Assertions.checkNotNull(getCodec()));
        }
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public void onCodecReleased(String str) {
        this.eventDispatcher.decoderReleased(str);
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer, com.google.android.exoplayer2.BaseRenderer
    public void onDisabled() {
        clearReportedVideoSize();
        clearRenderedFirstFrame();
        this.haveReportedFirstFrameRenderedForCurrentSurface = false;
        this.frameReleaseHelper.onDisabled();
        this.tunnelingOnFrameRenderedListener = null;
        try {
            super.onDisabled();
        } finally {
            this.eventDispatcher.disabled(this.decoderCounters);
        }
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer, com.google.android.exoplayer2.BaseRenderer
    public void onEnabled(boolean z, boolean z2) {
        super.onEnabled(z, z2);
        boolean z3 = getConfiguration().tunneling;
        Assertions.checkState(!z3 || this.tunnelingAudioSessionId != 0);
        if (this.tunneling != z3) {
            this.tunneling = z3;
            releaseCodec();
        }
        this.eventDispatcher.enabled(this.decoderCounters);
        this.frameReleaseHelper.onEnabled();
        this.mayRenderFirstFrameAfterEnableIfNotStarted = z2;
        this.renderedFirstFrameAfterEnable = false;
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    @Nullable
    public DecoderReuseEvaluation onInputFormatChanged(FormatHolder formatHolder) {
        DecoderReuseEvaluation onInputFormatChanged = super.onInputFormatChanged(formatHolder);
        this.eventDispatcher.inputFormatChanged(formatHolder.format, onInputFormatChanged);
        return onInputFormatChanged;
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public void onOutputFormatChanged(Format format, @Nullable MediaFormat mediaFormat) {
        int i;
        int i2;
        MediaCodecAdapter codec = getCodec();
        if (codec != null) {
            codec.setVideoScalingMode(this.scalingMode);
        }
        if (this.tunneling) {
            this.currentWidth = format.width;
            this.currentHeight = format.height;
        } else {
            Assertions.checkNotNull(mediaFormat);
            boolean z = mediaFormat.containsKey(KEY_CROP_RIGHT) && mediaFormat.containsKey(KEY_CROP_LEFT) && mediaFormat.containsKey(KEY_CROP_BOTTOM) && mediaFormat.containsKey(KEY_CROP_TOP);
            if (z) {
                i = (mediaFormat.getInteger(KEY_CROP_RIGHT) - mediaFormat.getInteger(KEY_CROP_LEFT)) + 1;
            } else {
                i = mediaFormat.getInteger("width");
            }
            this.currentWidth = i;
            if (z) {
                i2 = (mediaFormat.getInteger(KEY_CROP_BOTTOM) - mediaFormat.getInteger(KEY_CROP_TOP)) + 1;
            } else {
                i2 = mediaFormat.getInteger("height");
            }
            this.currentHeight = i2;
        }
        float f = format.pixelWidthHeightRatio;
        this.currentPixelWidthHeightRatio = f;
        if (Util.SDK_INT >= 21) {
            int i3 = format.rotationDegrees;
            if (i3 == 90 || i3 == 270) {
                int i4 = this.currentWidth;
                this.currentWidth = this.currentHeight;
                this.currentHeight = i4;
                this.currentPixelWidthHeightRatio = 1.0f / f;
            }
        } else {
            this.currentUnappliedRotationDegrees = format.rotationDegrees;
        }
        this.frameReleaseHelper.onFormatChanged(format.frameRate);
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer, com.google.android.exoplayer2.BaseRenderer
    public void onPositionReset(long j, boolean z) {
        super.onPositionReset(j, z);
        clearRenderedFirstFrame();
        this.frameReleaseHelper.onPositionReset();
        this.lastBufferPresentationTimeUs = C.TIME_UNSET;
        this.initialPositionUs = C.TIME_UNSET;
        this.consecutiveDroppedFrameCount = 0;
        if (z) {
            setJoiningDeadlineMs();
        } else {
            this.joiningDeadlineMs = C.TIME_UNSET;
        }
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    @CallSuper
    public void onProcessedOutputBuffer(long j) {
        super.onProcessedOutputBuffer(j);
        if (!this.tunneling) {
            this.buffersInCodecCount--;
        }
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public void onProcessedStreamChange() {
        super.onProcessedStreamChange();
        clearRenderedFirstFrame();
    }

    public void onProcessedTunneledBuffer(long j) {
        updateOutputFormatForTime(j);
        maybeNotifyVideoSizeChanged();
        this.decoderCounters.renderedOutputBufferCount++;
        maybeNotifyRenderedFirstFrame();
        onProcessedOutputBuffer(j);
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    @CallSuper
    public void onQueueInputBuffer(DecoderInputBuffer decoderInputBuffer) {
        boolean z = this.tunneling;
        if (!z) {
            this.buffersInCodecCount++;
        }
        if (Util.SDK_INT < 23 && z) {
            onProcessedTunneledBuffer(decoderInputBuffer.timeUs);
        }
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer, com.google.android.exoplayer2.BaseRenderer
    @TargetApi(17)
    public void onReset() {
        try {
            super.onReset();
            DummySurface dummySurface2 = this.dummySurface;
            if (dummySurface2 != null) {
                if (this.surface == dummySurface2) {
                    this.surface = null;
                }
                dummySurface2.release();
                this.dummySurface = null;
            }
        } catch (Throwable th) {
            if (this.dummySurface != null) {
                Surface surface2 = this.surface;
                DummySurface dummySurface3 = this.dummySurface;
                if (surface2 == dummySurface3) {
                    this.surface = null;
                }
                dummySurface3.release();
                this.dummySurface = null;
            }
            throw th;
        }
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer, com.google.android.exoplayer2.BaseRenderer
    public void onStarted() {
        super.onStarted();
        this.droppedFrames = 0;
        this.droppedFrameAccumulationStartTimeMs = SystemClock.elapsedRealtime();
        this.lastRenderRealtimeUs = SystemClock.elapsedRealtime() * 1000;
        this.totalVideoFrameProcessingOffsetUs = 0;
        this.videoFrameProcessingOffsetCount = 0;
        this.frameReleaseHelper.onStarted();
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer, com.google.android.exoplayer2.BaseRenderer
    public void onStopped() {
        this.joiningDeadlineMs = C.TIME_UNSET;
        maybeNotifyDroppedFrames();
        maybeNotifyVideoFrameProcessingOffset();
        this.frameReleaseHelper.onStopped();
        super.onStopped();
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public boolean processOutputBuffer(long j, long j2, @Nullable MediaCodecAdapter mediaCodecAdapter, @Nullable ByteBuffer byteBuffer, int i, int i2, int i3, long j3, boolean z, boolean z2, Format format) {
        long j4;
        boolean z3;
        Assertions.checkNotNull(mediaCodecAdapter);
        if (this.initialPositionUs == C.TIME_UNSET) {
            this.initialPositionUs = j;
        }
        if (j3 != this.lastBufferPresentationTimeUs) {
            this.frameReleaseHelper.onNextFrame(j3);
            this.lastBufferPresentationTimeUs = j3;
        }
        long outputStreamOffsetUs = getOutputStreamOffsetUs();
        long j5 = j3 - outputStreamOffsetUs;
        if (!z || z2) {
            double playbackSpeed = (double) getPlaybackSpeed();
            boolean z4 = getState() == 2;
            long elapsedRealtime = SystemClock.elapsedRealtime() * 1000;
            double d = (double) (j3 - j);
            Double.isNaN(d);
            Double.isNaN(playbackSpeed);
            long j6 = (long) (d / playbackSpeed);
            if (z4) {
                j6 -= elapsedRealtime - j2;
            }
            if (this.surface != this.dummySurface) {
                long j7 = elapsedRealtime - this.lastRenderRealtimeUs;
                if (this.renderedFirstFrameAfterEnable ? this.renderedFirstFrameAfterReset : !z4 && !this.mayRenderFirstFrameAfterEnableIfNotStarted) {
                    j4 = j7;
                    z3 = false;
                } else {
                    j4 = j7;
                    z3 = true;
                }
                if (this.joiningDeadlineMs == C.TIME_UNSET && j >= outputStreamOffsetUs && (z3 || (z4 && shouldForceRenderOutputBuffer(j6, j4)))) {
                    long nanoTime = System.nanoTime();
                    notifyFrameMetadataListener(j5, nanoTime, format);
                    if (Util.SDK_INT >= 21) {
                        renderOutputBufferV21(mediaCodecAdapter, i, j5, nanoTime);
                    } else {
                        renderOutputBuffer(mediaCodecAdapter, i, j5);
                    }
                    updateVideoFrameProcessingOffsetCounters(j6);
                    return true;
                }
                if (z4 && j != this.initialPositionUs) {
                    long nanoTime2 = System.nanoTime();
                    long adjustReleaseTime = this.frameReleaseHelper.adjustReleaseTime((j6 * 1000) + nanoTime2);
                    long j8 = (adjustReleaseTime - nanoTime2) / 1000;
                    boolean z5 = this.joiningDeadlineMs != C.TIME_UNSET;
                    if (shouldDropBuffersToKeyframe(j8, j2, z2) && maybeDropBuffersToKeyframe(j, z5)) {
                        return false;
                    }
                    if (shouldDropOutputBuffer(j8, j2, z2)) {
                        if (z5) {
                            skipOutputBuffer(mediaCodecAdapter, i, j5);
                        } else {
                            dropOutputBuffer(mediaCodecAdapter, i, j5);
                        }
                        updateVideoFrameProcessingOffsetCounters(j8);
                        return true;
                    } else if (Util.SDK_INT >= 21) {
                        if (j8 < 50000) {
                            notifyFrameMetadataListener(j5, adjustReleaseTime, format);
                            renderOutputBufferV21(mediaCodecAdapter, i, j5, adjustReleaseTime);
                            updateVideoFrameProcessingOffsetCounters(j8);
                            return true;
                        }
                    } else if (j8 < 30000) {
                        if (j8 > 11000) {
                            try {
                                Thread.sleep((j8 - 10000) / 1000);
                            } catch (InterruptedException unused) {
                                Thread.currentThread().interrupt();
                                return false;
                            }
                        }
                        notifyFrameMetadataListener(j5, adjustReleaseTime, format);
                        renderOutputBuffer(mediaCodecAdapter, i, j5);
                        updateVideoFrameProcessingOffsetCounters(j8);
                        return true;
                    }
                }
                return false;
            } else if (!isBufferLate(j6)) {
                return false;
            } else {
                skipOutputBuffer(mediaCodecAdapter, i, j5);
                updateVideoFrameProcessingOffsetCounters(j6);
                return true;
            }
        } else {
            skipOutputBuffer(mediaCodecAdapter, i, j5);
            return true;
        }
    }

    public void renderOutputBuffer(MediaCodecAdapter mediaCodecAdapter, int i, long j) {
        maybeNotifyVideoSizeChanged();
        TraceUtil.beginSection("releaseOutputBuffer");
        mediaCodecAdapter.releaseOutputBuffer(i, true);
        TraceUtil.endSection();
        this.lastRenderRealtimeUs = SystemClock.elapsedRealtime() * 1000;
        this.decoderCounters.renderedOutputBufferCount++;
        this.consecutiveDroppedFrameCount = 0;
        maybeNotifyRenderedFirstFrame();
    }

    @RequiresApi(21)
    public void renderOutputBufferV21(MediaCodecAdapter mediaCodecAdapter, int i, long j, long j2) {
        maybeNotifyVideoSizeChanged();
        TraceUtil.beginSection("releaseOutputBuffer");
        mediaCodecAdapter.releaseOutputBuffer(i, j2);
        TraceUtil.endSection();
        this.lastRenderRealtimeUs = SystemClock.elapsedRealtime() * 1000;
        this.decoderCounters.renderedOutputBufferCount++;
        this.consecutiveDroppedFrameCount = 0;
        maybeNotifyRenderedFirstFrame();
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    @CallSuper
    public void resetCodecStateForFlush() {
        super.resetCodecStateForFlush();
        this.buffersInCodecCount = 0;
    }

    @RequiresApi(23)
    public void setOutputSurfaceV23(MediaCodecAdapter mediaCodecAdapter, Surface surface2) {
        mediaCodecAdapter.setOutputSurface(surface2);
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer, com.google.android.exoplayer2.BaseRenderer, com.google.android.exoplayer2.Renderer
    public void setPlaybackSpeed(float f, float f2) {
        super.setPlaybackSpeed(f, f2);
        this.frameReleaseHelper.onPlaybackSpeed(f);
    }

    public boolean shouldDropBuffersToKeyframe(long j, long j2, boolean z) {
        return isBufferVeryLate(j) && !z;
    }

    public boolean shouldDropOutputBuffer(long j, long j2, boolean z) {
        return isBufferLate(j) && !z;
    }

    public boolean shouldForceRenderOutputBuffer(long j, long j2) {
        return isBufferLate(j) && j2 > IndexSeeker.MIN_TIME_BETWEEN_POINTS_US;
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public boolean shouldInitCodec(MediaCodecInfo mediaCodecInfo) {
        return this.surface != null || shouldUseDummySurface(mediaCodecInfo);
    }

    public void skipOutputBuffer(MediaCodecAdapter mediaCodecAdapter, int i, long j) {
        TraceUtil.beginSection("skipVideoBuffer");
        mediaCodecAdapter.releaseOutputBuffer(i, false);
        TraceUtil.endSection();
        this.decoderCounters.skippedOutputBufferCount++;
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public int supportsFormat(MediaCodecSelector mediaCodecSelector, Format format) {
        int i = 0;
        if (!MimeTypes.isVideo(format.sampleMimeType)) {
            return 0;
        }
        boolean z = format.drmInitData != null;
        List<MediaCodecInfo> decoderInfos = getDecoderInfos(mediaCodecSelector, format, z, false);
        if (z && decoderInfos.isEmpty()) {
            decoderInfos = getDecoderInfos(mediaCodecSelector, format, false, false);
        }
        if (decoderInfos.isEmpty()) {
            return 1;
        }
        if (!MediaCodecRenderer.supportsFormatDrm(format)) {
            return 2;
        }
        MediaCodecInfo mediaCodecInfo = decoderInfos.get(0);
        boolean isFormatSupported = mediaCodecInfo.isFormatSupported(format);
        int i2 = mediaCodecInfo.isSeamlessAdaptationSupported(format) ? 16 : 8;
        if (isFormatSupported) {
            List<MediaCodecInfo> decoderInfos2 = getDecoderInfos(mediaCodecSelector, format, z, true);
            if (!decoderInfos2.isEmpty()) {
                MediaCodecInfo mediaCodecInfo2 = decoderInfos2.get(0);
                if (mediaCodecInfo2.isFormatSupported(format) && mediaCodecInfo2.isSeamlessAdaptationSupported(format)) {
                    i = 32;
                }
            }
        }
        return (isFormatSupported ? 4 : 3) | i2 | i;
    }

    public void updateDroppedBufferCounters(int i) {
        DecoderCounters decoderCounters = this.decoderCounters;
        decoderCounters.droppedBufferCount += i;
        this.droppedFrames += i;
        int i2 = this.consecutiveDroppedFrameCount + i;
        this.consecutiveDroppedFrameCount = i2;
        decoderCounters.maxConsecutiveDroppedBufferCount = Math.max(i2, decoderCounters.maxConsecutiveDroppedBufferCount);
        int i3 = this.maxDroppedFramesToNotify;
        if (i3 > 0 && this.droppedFrames >= i3) {
            maybeNotifyDroppedFrames();
        }
    }

    public void updateVideoFrameProcessingOffsetCounters(long j) {
        this.decoderCounters.addVideoFrameProcessingOffset(j);
        this.totalVideoFrameProcessingOffsetUs += j;
        this.videoFrameProcessingOffsetCount++;
    }

    public MediaCodecVideoRenderer(Context context2, MediaCodecSelector mediaCodecSelector, long j) {
        this(context2, mediaCodecSelector, j, null, null, 0);
    }

    private static List<MediaCodecInfo> getDecoderInfos(MediaCodecSelector mediaCodecSelector, Format format, boolean z, boolean z2) {
        Pair<Integer, Integer> codecProfileAndLevel;
        String str = format.sampleMimeType;
        if (str == null) {
            return Collections.emptyList();
        }
        List<MediaCodecInfo> decoderInfosSortedByFormatSupport = MediaCodecUtil.getDecoderInfosSortedByFormatSupport(mediaCodecSelector.getDecoderInfos(str, z, z2), format);
        if (MimeTypes.VIDEO_DOLBY_VISION.equals(str) && (codecProfileAndLevel = MediaCodecUtil.getCodecProfileAndLevel(format)) != null) {
            int intValue = ((Integer) codecProfileAndLevel.first).intValue();
            if (intValue == 16 || intValue == 256) {
                decoderInfosSortedByFormatSupport.addAll(mediaCodecSelector.getDecoderInfos("video/hevc", z, z2));
            } else if (intValue == 512) {
                decoderInfosSortedByFormatSupport.addAll(mediaCodecSelector.getDecoderInfos("video/avc", z, z2));
            }
        }
        return Collections.unmodifiableList(decoderInfosSortedByFormatSupport);
    }

    public MediaCodecVideoRenderer(Context context2, MediaCodecSelector mediaCodecSelector, long j, @Nullable Handler handler, @Nullable VideoRendererEventListener videoRendererEventListener, int i) {
        this(context2, MediaCodecAdapter.Factory.DEFAULT, mediaCodecSelector, j, false, handler, videoRendererEventListener, i);
    }

    public MediaCodecVideoRenderer(Context context2, MediaCodecSelector mediaCodecSelector, long j, boolean z, @Nullable Handler handler, @Nullable VideoRendererEventListener videoRendererEventListener, int i) {
        this(context2, MediaCodecAdapter.Factory.DEFAULT, mediaCodecSelector, j, z, handler, videoRendererEventListener, i);
    }

    public MediaCodecVideoRenderer(Context context2, MediaCodecAdapter.Factory factory, MediaCodecSelector mediaCodecSelector, long j, boolean z, @Nullable Handler handler, @Nullable VideoRendererEventListener videoRendererEventListener, int i) {
        super(2, factory, mediaCodecSelector, z, 30.0f);
        this.allowedJoiningTimeMs = j;
        this.maxDroppedFramesToNotify = i;
        Context applicationContext = context2.getApplicationContext();
        this.context = applicationContext;
        this.frameReleaseHelper = new VideoFrameReleaseHelper(applicationContext);
        this.eventDispatcher = new VideoRendererEventListener.EventDispatcher(handler, videoRendererEventListener);
        this.deviceNeedsNoPostProcessWorkaround = deviceNeedsNoPostProcessWorkaround();
        this.joiningDeadlineMs = C.TIME_UNSET;
        this.currentWidth = -1;
        this.currentHeight = -1;
        this.currentPixelWidthHeightRatio = -1.0f;
        this.scalingMode = 1;
        this.tunnelingAudioSessionId = 0;
        clearReportedVideoSize();
    }
}
