package com.thoughtworks.xstream.core;

import com.thoughtworks.xstream.converters.ConversionException;
import com.thoughtworks.xstream.converters.Converter;
import com.thoughtworks.xstream.converters.ConverterLookup;
import com.thoughtworks.xstream.core.util.ObjectIdDictionary;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;
import com.thoughtworks.xstream.io.path.Path;
import com.thoughtworks.xstream.io.path.PathTracker;
import com.thoughtworks.xstream.io.path.PathTrackingWriter;
import com.thoughtworks.xstream.mapper.Mapper;
import java.util.Iterator;

public abstract class AbstractReferenceMarshaller extends TreeMarshaller {
    private ObjectIdDictionary implicitElements = new ObjectIdDictionary();
    private Path lastPath;
    private PathTracker pathTracker;
    private ObjectIdDictionary references = new ObjectIdDictionary();

    public static class Id {
        private Object item;
        private Path path;

        public Id(Object obj, Path path2) {
            this.item = obj;
            this.path = path2;
        }

        public Object getItem() {
            return this.item;
        }

        public Path getPath() {
            return this.path;
        }
    }

    public static class ReferencedImplicitElementException extends ConversionException {
        public ReferencedImplicitElementException(Object obj, Path path) {
            super("Cannot reference implicit element");
            add("implicit-element", obj.toString());
            add("referencing-element", path.toString());
        }
    }

    public AbstractReferenceMarshaller(HierarchicalStreamWriter hierarchicalStreamWriter, ConverterLookup converterLookup, Mapper mapper) {
        super(hierarchicalStreamWriter, converterLookup, mapper);
        PathTracker pathTracker2 = new PathTracker();
        this.pathTracker = pathTracker2;
        this.writer = new PathTrackingWriter(hierarchicalStreamWriter, pathTracker2);
    }

    @Override // com.thoughtworks.xstream.core.TreeMarshaller
    public void convert(Object obj, Converter converter) {
        final Object obj2;
        if (getMapper().isImmutableValueType(obj.getClass())) {
            converter.marshal(obj, this.writer, this);
            return;
        }
        final Path path = this.pathTracker.getPath();
        Id id = (Id) this.references.lookupId(obj);
        if (id == null || id.getPath() == path) {
            if (id == null) {
                obj2 = createReferenceKey(path, obj);
            } else {
                obj2 = id.getItem();
            }
            Path path2 = this.lastPath;
            if (path2 == null || !path.isAncestor(path2)) {
                fireValidReference(obj2);
                this.lastPath = path;
                this.references.associateId(obj, new Id(obj2, path));
            }
            converter.marshal(obj, this.writer, new ReferencingMarshallingContext() {
                /* class com.thoughtworks.xstream.core.AbstractReferenceMarshaller.AnonymousClass1 */

                @Override // com.thoughtworks.xstream.converters.MarshallingContext
                public void convertAnother(Object obj, Converter converter) {
                    AbstractReferenceMarshaller.this.convertAnother(obj, converter);
                }

                @Override // com.thoughtworks.xstream.core.ReferencingMarshallingContext
                public Path currentPath() {
                    return AbstractReferenceMarshaller.this.pathTracker.getPath();
                }

                @Override // com.thoughtworks.xstream.converters.DataHolder
                public Object get(Object obj) {
                    return AbstractReferenceMarshaller.this.get(obj);
                }

                @Override // com.thoughtworks.xstream.converters.DataHolder
                public Iterator keys() {
                    return AbstractReferenceMarshaller.this.keys();
                }

                @Override // com.thoughtworks.xstream.core.ReferencingMarshallingContext
                public Object lookupReference(Object obj) {
                    return ((Id) AbstractReferenceMarshaller.this.references.lookupId(obj)).getItem();
                }

                @Override // com.thoughtworks.xstream.converters.DataHolder
                public void put(Object obj, Object obj2) {
                    AbstractReferenceMarshaller.this.put(obj, obj2);
                }

                @Override // com.thoughtworks.xstream.core.ReferencingMarshallingContext
                public void registerImplicit(Object obj) {
                    if (!AbstractReferenceMarshaller.this.implicitElements.containsId(obj)) {
                        AbstractReferenceMarshaller.this.implicitElements.associateId(obj, obj2);
                        return;
                    }
                    throw new ReferencedImplicitElementException(obj, path);
                }

                @Override // com.thoughtworks.xstream.core.ReferencingMarshallingContext
                public void replace(Object obj, Object obj2) {
                    AbstractReferenceMarshaller.this.references.associateId(obj2, new Id(obj2, path));
                }

                @Override // com.thoughtworks.xstream.converters.MarshallingContext
                public void convertAnother(Object obj) {
                    AbstractReferenceMarshaller.this.convertAnother(obj);
                }
            });
            return;
        }
        String aliasForSystemAttribute = getMapper().aliasForSystemAttribute("reference");
        if (aliasForSystemAttribute != null) {
            this.writer.addAttribute(aliasForSystemAttribute, createReference(path, id.getItem()));
        }
    }

    public abstract String createReference(Path path, Object obj);

    public abstract Object createReferenceKey(Path path, Object obj);

    public abstract void fireValidReference(Object obj);
}
