package com.thoughtworks.xstream.io.binary;

import com.thoughtworks.xstream.io.StreamException;
import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import okhttp3.internal.ws.WebSocketProtocol;

public abstract class Token {
    private static final byte ID_EIGHT_BYTES = 32;
    private static final byte ID_FOUR_BYTES = 24;
    private static final byte ID_MASK = 56;
    private static final byte ID_ONE_BYTE = 8;
    private static final String ID_SPLITTED = "\u0000‡\u0000";
    private static final byte ID_TWO_BYTES = 16;
    private static final int MAX_UTF8_LENGTH = 65535;
    public static final byte TYPE_ATTRIBUTE = 5;
    public static final byte TYPE_END_NODE = 4;
    public static final byte TYPE_MAP_ID_TO_VALUE = 2;
    private static final byte TYPE_MASK = 7;
    public static final byte TYPE_START_NODE = 3;
    public static final byte TYPE_VALUE = 6;
    public static final byte TYPE_VERSION = 1;
    public long id = -1;
    private final byte type;
    public String value;

    public static class EndNode extends Token {
        public EndNode() {
            super((byte) 4);
        }

        @Override // com.thoughtworks.xstream.io.binary.Token
        public void readFrom(DataInput dataInput, byte b) {
        }

        @Override // com.thoughtworks.xstream.io.binary.Token
        public void writeTo(DataOutput dataOutput, byte b) {
        }
    }

    public static class Formatter {
        private Token contructToken(byte b) {
            if (b == 2) {
                return new MapIdToValue();
            }
            if (b == 3) {
                return new StartNode();
            }
            if (b == 4) {
                return new EndNode();
            }
            if (b == 5) {
                return new Attribute();
            }
            if (b == 6) {
                return new Value();
            }
            throw new StreamException("Unknown token type");
        }

        public Token read(DataInput dataInput) {
            byte readByte = dataInput.readByte();
            Token contructToken = contructToken((byte) (readByte & 7));
            contructToken.readFrom(dataInput, (byte) (readByte & Token.ID_MASK));
            return contructToken;
        }

        public void write(DataOutput dataOutput, Token token) {
            long id = token.getId();
            byte b = id <= 255 ? 8 : id <= WebSocketProtocol.PAYLOAD_SHORT_MAX ? Token.ID_TWO_BYTES : id <= 4294967295L ? Token.ID_FOUR_BYTES : 32;
            dataOutput.write(token.getType() + b);
            token.writeTo(dataOutput, b);
        }
    }

    public Token(byte b) {
        this.type = b;
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || getClass() != obj.getClass()) {
            return false;
        }
        Token token = (Token) obj;
        if (this.id != token.id || this.type != token.type) {
            return false;
        }
        String str = this.value;
        String str2 = token.value;
        if (str != null) {
            if (!str.equals(str2)) {
                return false;
            }
            return true;
        } else if (str2 == null) {
            return true;
        }
        return false;
    }

    public long getId() {
        return this.id;
    }

    public byte getType() {
        return this.type;
    }

    public String getValue() {
        return this.value;
    }

    public int hashCode() {
        long j = this.id;
        int i = ((this.type * 29) + ((int) (j ^ (j >>> 32)))) * 29;
        String str = this.value;
        return i + (str != null ? str.hashCode() : 0);
    }

    public abstract void readFrom(DataInput dataInput, byte b);

    public long readId(DataInput dataInput, byte b) {
        if (b == 8) {
            return (long) (dataInput.readByte() + 128);
        }
        if (b == 16) {
            return (long) (dataInput.readShort() - Short.MIN_VALUE);
        }
        if (b == 24) {
            return (long) (dataInput.readInt() - Integer.MIN_VALUE);
        }
        if (b == 32) {
            return dataInput.readLong() - Long.MIN_VALUE;
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Unknown idType ");
        stringBuffer.append((int) b);
        throw new Error(stringBuffer.toString());
    }

    public String readString(DataInput dataInput) {
        String readUTF = dataInput.readUTF();
        if (!ID_SPLITTED.equals(readUTF)) {
            return readUTF;
        }
        byte[] bArr = new byte[dataInput.readInt()];
        dataInput.readFully(bArr);
        return new String(bArr, "utf-8");
    }

    public String toString() {
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(getClass().getName());
        stringBuffer.append(" [id=");
        stringBuffer.append(this.id);
        stringBuffer.append(", value='");
        stringBuffer.append(this.value);
        stringBuffer.append("']");
        return stringBuffer.toString();
    }

    public void writeId(DataOutput dataOutput, long j, byte b) {
        if (j < 0) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("id must not be negative ");
            stringBuffer.append(j);
            throw new IOException(stringBuffer.toString());
        } else if (b == 8) {
            dataOutput.writeByte(((byte) ((int) j)) - 128);
        } else if (b == 16) {
            dataOutput.writeShort(((short) ((int) j)) - 32768);
        } else if (b == 24) {
            dataOutput.writeInt(((int) j) - 2147483648);
        } else if (b == 32) {
            dataOutput.writeLong(j - Long.MIN_VALUE);
        } else {
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append("Unknown idType ");
            stringBuffer2.append((int) b);
            throw new Error(stringBuffer2.toString());
        }
    }

    public void writeString(DataOutput dataOutput, String str) {
        byte[] bytes = str.length() > 16383 ? str.getBytes("utf-8") : new byte[0];
        if (bytes.length <= 65535) {
            dataOutput.writeUTF(str);
            return;
        }
        dataOutput.writeUTF(ID_SPLITTED);
        dataOutput.writeInt(bytes.length);
        dataOutput.write(bytes);
    }

    public abstract void writeTo(DataOutput dataOutput, byte b);

    public static class StartNode extends Token {
        public StartNode(long j) {
            super((byte) 3);
            this.id = j;
        }

        @Override // com.thoughtworks.xstream.io.binary.Token
        public void readFrom(DataInput dataInput, byte b) {
            this.id = readId(dataInput, b);
        }

        @Override // com.thoughtworks.xstream.io.binary.Token
        public void writeTo(DataOutput dataOutput, byte b) {
            writeId(dataOutput, this.id, b);
        }

        public StartNode() {
            super((byte) 3);
        }
    }

    public static class Value extends Token {
        public Value(String str) {
            super((byte) 6);
            this.value = str;
        }

        @Override // com.thoughtworks.xstream.io.binary.Token
        public void readFrom(DataInput dataInput, byte b) {
            this.value = readString(dataInput);
        }

        @Override // com.thoughtworks.xstream.io.binary.Token
        public void writeTo(DataOutput dataOutput, byte b) {
            writeString(dataOutput, this.value);
        }

        public Value() {
            super((byte) 6);
        }
    }

    public static class Attribute extends Token {
        public Attribute(long j, String str) {
            super((byte) 5);
            this.id = j;
            this.value = str;
        }

        @Override // com.thoughtworks.xstream.io.binary.Token
        public void readFrom(DataInput dataInput, byte b) {
            this.id = readId(dataInput, b);
            this.value = readString(dataInput);
        }

        @Override // com.thoughtworks.xstream.io.binary.Token
        public void writeTo(DataOutput dataOutput, byte b) {
            writeId(dataOutput, this.id, b);
            writeString(dataOutput, this.value);
        }

        public Attribute() {
            super((byte) 5);
        }
    }

    public static class MapIdToValue extends Token {
        public MapIdToValue(long j, String str) {
            super((byte) 2);
            this.id = j;
            this.value = str;
        }

        @Override // com.thoughtworks.xstream.io.binary.Token
        public void readFrom(DataInput dataInput, byte b) {
            this.id = readId(dataInput, b);
            this.value = readString(dataInput);
        }

        @Override // com.thoughtworks.xstream.io.binary.Token
        public void writeTo(DataOutput dataOutput, byte b) {
            writeId(dataOutput, this.id, b);
            writeString(dataOutput, this.value);
        }

        public MapIdToValue() {
            super((byte) 2);
        }
    }
}
