package com.thoughtworks.xstream.io.xml;

import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;
import com.thoughtworks.xstream.io.StreamException;
import com.thoughtworks.xstream.io.naming.NameCoder;
import java.io.File;
import java.io.FilterWriter;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.Reader;
import java.io.Writer;
import java.net.URL;
import java.nio.charset.Charset;
import org.dom4j.DocumentException;
import org.dom4j.DocumentFactory;
import org.dom4j.io.OutputFormat;
import org.dom4j.io.SAXReader;
import org.dom4j.io.XMLWriter;
import org.xml.sax.SAXException;

public class Dom4JDriver extends AbstractXmlDriver {
    private DocumentFactory documentFactory;
    private OutputFormat outputFormat;

    public Dom4JDriver() {
        this(new XmlFriendlyNameCoder());
    }

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamDriver
    public HierarchicalStreamReader createReader(Reader reader) {
        try {
            return new Dom4JReader(createReader().read(reader), getNameCoder());
        } catch (DocumentException e) {
            throw new StreamException((Throwable) e);
        }
    }

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamDriver
    public HierarchicalStreamWriter createWriter(Writer writer) {
        final HierarchicalStreamWriter[] hierarchicalStreamWriterArr = {new Dom4JXmlWriter(new XMLWriter(new FilterWriter(writer) {
            /* class com.thoughtworks.xstream.io.xml.Dom4JDriver.AnonymousClass1 */

            @Override // java.io.FilterWriter, java.io.Closeable, java.io.Writer, java.lang.AutoCloseable
            public void close() {
                hierarchicalStreamWriterArr[0].close();
            }
        }, this.outputFormat), getNameCoder())};
        return hierarchicalStreamWriterArr[0];
    }

    public DocumentFactory getDocumentFactory() {
        return this.documentFactory;
    }

    public OutputFormat getOutputFormat() {
        return this.outputFormat;
    }

    public void setDocumentFactory(DocumentFactory documentFactory2) {
        this.documentFactory = documentFactory2;
    }

    public void setOutputFormat(OutputFormat outputFormat2) {
        this.outputFormat = outputFormat2;
    }

    public Dom4JDriver(NameCoder nameCoder) {
        this(new DocumentFactory(), OutputFormat.createPrettyPrint(), nameCoder);
        this.outputFormat.setTrimText(false);
    }

    public Dom4JDriver(DocumentFactory documentFactory2, OutputFormat outputFormat2) {
        this(documentFactory2, outputFormat2, new XmlFriendlyNameCoder());
    }

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamDriver
    public HierarchicalStreamReader createReader(InputStream inputStream) {
        try {
            return new Dom4JReader(createReader().read(inputStream), getNameCoder());
        } catch (DocumentException e) {
            throw new StreamException((Throwable) e);
        }
    }

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamDriver
    public HierarchicalStreamWriter createWriter(OutputStream outputStream) {
        OutputStreamWriter outputStreamWriter;
        Charset charset = null;
        String encoding = getOutputFormat() != null ? getOutputFormat().getEncoding() : null;
        if (encoding != null && Charset.isSupported(encoding)) {
            charset = Charset.forName(encoding);
        }
        if (charset == null) {
            outputStreamWriter = new OutputStreamWriter(outputStream);
        }
        return createWriter(outputStreamWriter);
    }

    public Dom4JDriver(DocumentFactory documentFactory2, OutputFormat outputFormat2, NameCoder nameCoder) {
        super(nameCoder);
        this.documentFactory = documentFactory2;
        this.outputFormat = outputFormat2;
    }

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamDriver, com.thoughtworks.xstream.io.AbstractDriver
    public HierarchicalStreamReader createReader(URL url) {
        try {
            return new Dom4JReader(createReader().read(url), getNameCoder());
        } catch (DocumentException e) {
            throw new StreamException((Throwable) e);
        }
    }

    public Dom4JDriver(DocumentFactory documentFactory2, OutputFormat outputFormat2, XmlFriendlyReplacer xmlFriendlyReplacer) {
        this(documentFactory2, outputFormat2, (NameCoder) xmlFriendlyReplacer);
    }

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamDriver, com.thoughtworks.xstream.io.AbstractDriver
    public HierarchicalStreamReader createReader(File file) {
        try {
            return new Dom4JReader(createReader().read(file), getNameCoder());
        } catch (DocumentException e) {
            throw new StreamException((Throwable) e);
        }
    }

    public SAXReader createReader() {
        SAXReader sAXReader = new SAXReader();
        try {
            sAXReader.setFeature("http://apache.org/xml/features/disallow-doctype-decl", true);
            return sAXReader;
        } catch (SAXException e) {
            throw new DocumentException("Cannot disable DOCTYPE processing", e);
        }
    }
}
