package com.thoughtworks.xstream.mapper;

import androidx.base.b2;
import com.thoughtworks.xstream.InitializationException;
import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAliasType;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;
import com.thoughtworks.xstream.annotations.XStreamConverter;
import com.thoughtworks.xstream.annotations.XStreamConverters;
import com.thoughtworks.xstream.annotations.XStreamImplicit;
import com.thoughtworks.xstream.annotations.XStreamImplicitCollection;
import com.thoughtworks.xstream.annotations.XStreamInclude;
import com.thoughtworks.xstream.annotations.XStreamOmitField;
import com.thoughtworks.xstream.converters.Converter;
import com.thoughtworks.xstream.converters.ConverterLookup;
import com.thoughtworks.xstream.converters.ConverterMatcher;
import com.thoughtworks.xstream.converters.ConverterRegistry;
import com.thoughtworks.xstream.converters.SingleValueConverter;
import com.thoughtworks.xstream.converters.SingleValueConverterWrapper;
import com.thoughtworks.xstream.converters.reflection.ReflectionProvider;
import com.thoughtworks.xstream.core.ClassLoaderReference;
import com.thoughtworks.xstream.core.JVM;
import com.thoughtworks.xstream.core.util.DependencyInjectionFactory;
import com.thoughtworks.xstream.core.util.TypedNull;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.lang.reflect.Array;
import java.lang.reflect.Field;
import java.lang.reflect.GenericArrayType;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.lang.reflect.TypeVariable;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

public class AnnotationMapper extends MapperWrapper implements AnnotationConfiguration {
    private final Set<Class<?>> annotatedTypes;
    private transient Object[] arguments;
    private transient AttributeMapper attributeMapper;
    private transient ClassAliasingMapper classAliasingMapper;
    private final Map<Class<?>, Map<List<Object>, Converter>> converterCache;
    private final ConverterRegistry converterRegistry;
    private transient DefaultImplementationsMapper defaultImplementationsMapper;
    private transient ElementIgnoringMapper elementIgnoringMapper;
    private transient FieldAliasingMapper fieldAliasingMapper;
    private transient ImplicitCollectionMapper implicitCollectionMapper;
    private transient LocalConversionMapper localConversionMapper;
    private boolean locked;

    public final class UnprocessedTypesSet extends LinkedHashSet<Class<?>> {
        private UnprocessedTypesSet() {
        }

        public boolean add(Class<?> cls) {
            XStreamInclude xStreamInclude;
            Class<?>[] value;
            if (cls == null) {
                return false;
            }
            while (cls.isArray()) {
                cls = cls.getComponentType();
            }
            String name = cls.getName();
            if (name.startsWith("java.") || name.startsWith("javax.")) {
                return false;
            }
            boolean add = AnnotationMapper.this.annotatedTypes.contains(cls) ? false : super.add((Object) cls);
            if (!(!add || (xStreamInclude = (XStreamInclude) cls.getAnnotation(XStreamInclude.class)) == null || (value = xStreamInclude.value()) == null)) {
                for (Class<?> cls2 : value) {
                    add(cls2);
                }
            }
            return add;
        }
    }

    public AnnotationMapper(Mapper mapper, ConverterRegistry converterRegistry2, ConverterLookup converterLookup, ClassLoaderReference classLoaderReference, ReflectionProvider reflectionProvider) {
        super(mapper);
        this.converterCache = new HashMap();
        Set<Class<?>> synchronizedSet = Collections.synchronizedSet(new HashSet());
        this.annotatedTypes = synchronizedSet;
        this.converterRegistry = converterRegistry2;
        synchronizedSet.add(Object.class);
        setupMappers();
        this.locked = true;
        Object reference = classLoaderReference.getReference();
        Object[] objArr = new Object[6];
        objArr[0] = this;
        objArr[1] = classLoaderReference;
        objArr[2] = reflectionProvider;
        objArr[3] = converterLookup;
        objArr[4] = new JVM();
        objArr[5] = reference == null ? new TypedNull(ClassLoader.class) : reference;
        this.arguments = objArr;
    }

    private void addParametrizedTypes(Type type, final Set<Class<?>> set) {
        final HashSet hashSet = new HashSet();
        AnonymousClass1 r1 = new LinkedHashSet<Type>() {
            /* class com.thoughtworks.xstream.mapper.AnnotationMapper.AnonymousClass1 */

            public boolean add(Type type) {
                if (type instanceof Class) {
                    return set.add((Class) type);
                }
                if (type == null || hashSet.contains(type)) {
                    return false;
                }
                return super.add((Object) type);
            }
        };
        while (type != null) {
            hashSet.add(type);
            int i = 0;
            if (type instanceof Class) {
                Class<?> cls = (Class) type;
                set.add(cls);
                if (!cls.isPrimitive()) {
                    for (TypeVariable<Class<?>> typeVariable : cls.getTypeParameters()) {
                        r1.add((Object) typeVariable);
                    }
                    r1.add((Object) cls.getGenericSuperclass());
                    Type[] genericInterfaces = cls.getGenericInterfaces();
                    int length = genericInterfaces.length;
                    while (i < length) {
                        r1.add((Object) genericInterfaces[i]);
                        i++;
                    }
                }
            } else if (type instanceof TypeVariable) {
                Type[] bounds = ((TypeVariable) type).getBounds();
                int length2 = bounds.length;
                while (i < length2) {
                    r1.add((Object) bounds[i]);
                    i++;
                }
            } else if (type instanceof ParameterizedType) {
                ParameterizedType parameterizedType = (ParameterizedType) type;
                r1.add((Object) parameterizedType.getRawType());
                Type[] actualTypeArguments = parameterizedType.getActualTypeArguments();
                int length3 = actualTypeArguments.length;
                while (i < length3) {
                    r1.add((Object) actualTypeArguments[i]);
                    i++;
                }
            } else if (type instanceof GenericArrayType) {
                r1.add((Object) ((GenericArrayType) type).getGenericComponentType());
            }
            if (!r1.isEmpty()) {
                Iterator it = r1.iterator();
                it.remove();
                type = (Type) it.next();
            } else {
                type = null;
            }
        }
    }

    private Converter cacheConverter(XStreamConverter xStreamConverter, Class cls) {
        Object[] objArr;
        String str;
        ArrayList arrayList = new ArrayList();
        if (cls != null && xStreamConverter.useImplicitType()) {
            arrayList.add(cls);
        }
        ArrayList arrayList2 = new ArrayList();
        arrayList2.add(xStreamConverter.booleans());
        arrayList2.add(xStreamConverter.bytes());
        arrayList2.add(xStreamConverter.chars());
        arrayList2.add(xStreamConverter.doubles());
        arrayList2.add(xStreamConverter.floats());
        arrayList2.add(xStreamConverter.ints());
        arrayList2.add(xStreamConverter.longs());
        arrayList2.add(xStreamConverter.shorts());
        arrayList2.add(xStreamConverter.strings());
        arrayList2.add(xStreamConverter.types());
        Iterator it = arrayList2.iterator();
        while (true) {
            if (!it.hasNext()) {
                break;
            }
            Object next = it.next();
            if (next != null) {
                int length = Array.getLength(next);
                for (int i = 0; i < length; i++) {
                    arrayList.add(Array.get(next, i));
                }
            }
        }
        for (Class<?> cls2 : xStreamConverter.nulls()) {
            arrayList.add(new TypedNull(cls2));
        }
        Class<? extends ConverterMatcher> value = xStreamConverter.value();
        Map<List<Object>, Converter> map = this.converterCache.get(value);
        Converter converter = map != null ? map.get(arrayList) : null;
        if (converter == null) {
            int size = arrayList.size();
            if (size > 0) {
                Object[] objArr2 = this.arguments;
                objArr = new Object[(objArr2.length + size)];
                System.arraycopy(objArr2, 0, objArr, size, objArr2.length);
                System.arraycopy(arrayList.toArray(new Object[size]), 0, objArr, 0, size);
            } else {
                objArr = this.arguments;
            }
            try {
                if (!SingleValueConverter.class.isAssignableFrom(value) || Converter.class.isAssignableFrom(value)) {
                    converter = (Converter) DependencyInjectionFactory.newInstance(value, objArr);
                } else {
                    converter = new SingleValueConverterWrapper((SingleValueConverter) DependencyInjectionFactory.newInstance(value, objArr));
                }
                if (map == null) {
                    map = new HashMap<>();
                    this.converterCache.put(value, map);
                }
                map.put(arrayList, converter);
            } catch (Exception e) {
                StringBuilder j = b2.j("Cannot instantiate converter ");
                j.append(value.getName());
                if (cls != null) {
                    StringBuilder j2 = b2.j(" for type ");
                    j2.append(cls.getName());
                    str = j2.toString();
                } else {
                    str = "";
                }
                j.append(str);
                throw new InitializationException(j.toString(), e);
            }
        }
        return converter;
    }

    private Class<?> getClass(Type type) {
        if (type instanceof ParameterizedType) {
            return (Class) ((ParameterizedType) type).getRawType();
        }
        if (type instanceof Class) {
            return (Class) type;
        }
        return null;
    }

    private void processAliasAnnotation(Class<?> cls, Set<Class<?>> set) {
        XStreamAlias xStreamAlias = (XStreamAlias) cls.getAnnotation(XStreamAlias.class);
        if (xStreamAlias != null) {
            ClassAliasingMapper classAliasingMapper2 = this.classAliasingMapper;
            if (classAliasingMapper2 != null) {
                classAliasingMapper2.addClassAlias(xStreamAlias.value(), cls);
                if (xStreamAlias.impl() != Void.class) {
                    this.defaultImplementationsMapper.addDefaultImplementation(xStreamAlias.impl(), cls);
                    if (cls.isInterface()) {
                        set.add(xStreamAlias.impl());
                        return;
                    }
                    return;
                }
                return;
            }
            StringBuilder j = b2.j("No ");
            j.append(ClassAliasingMapper.class.getName());
            j.append(" available");
            throw new InitializationException(j.toString());
        }
    }

    private void processAliasTypeAnnotation(Class<?> cls) {
        XStreamAliasType xStreamAliasType = (XStreamAliasType) cls.getAnnotation(XStreamAliasType.class);
        if (xStreamAliasType != null) {
            ClassAliasingMapper classAliasingMapper2 = this.classAliasingMapper;
            if (classAliasingMapper2 != null) {
                classAliasingMapper2.addTypeAlias(xStreamAliasType.value(), cls);
                return;
            }
            StringBuilder j = b2.j("No ");
            j.append(ClassAliasingMapper.class.getName());
            j.append(" available");
            throw new InitializationException(j.toString());
        }
    }

    private void processAsAttributeAnnotation(Field field) {
        if (((XStreamAsAttribute) field.getAnnotation(XStreamAsAttribute.class)) != null) {
            AttributeMapper attributeMapper2 = this.attributeMapper;
            if (attributeMapper2 != null) {
                attributeMapper2.addAttributeFor(field);
                return;
            }
            StringBuilder j = b2.j("No ");
            j.append(AttributeMapper.class.getName());
            j.append(" available");
            throw new InitializationException(j.toString());
        }
    }

    private void processConverterAnnotations(Class<?> cls) {
        if (this.converterRegistry != null) {
            XStreamConverters xStreamConverters = (XStreamConverters) cls.getAnnotation(XStreamConverters.class);
            XStreamConverter xStreamConverter = (XStreamConverter) cls.getAnnotation(XStreamConverter.class);
            ArrayList<XStreamConverter> arrayList = xStreamConverters != null ? new ArrayList(Arrays.asList(xStreamConverters.value())) : new ArrayList();
            if (xStreamConverter != null) {
                arrayList.add(xStreamConverter);
            }
            for (XStreamConverter xStreamConverter2 : arrayList) {
                Converter cacheConverter = cacheConverter(xStreamConverter2, xStreamConverter != null ? cls : null);
                if (cacheConverter != null) {
                    if (xStreamConverter != null || cacheConverter.canConvert(cls)) {
                        this.converterRegistry.registerConverter(cacheConverter, xStreamConverter2.priority());
                    } else {
                        StringBuilder j = b2.j("Converter ");
                        j.append(xStreamConverter2.value().getName());
                        j.append(" cannot handle annotated class ");
                        j.append(cls.getName());
                        throw new InitializationException(j.toString());
                    }
                }
            }
        }
    }

    private void processFieldAliasAnnotation(Field field) {
        XStreamAlias xStreamAlias = (XStreamAlias) field.getAnnotation(XStreamAlias.class);
        if (xStreamAlias != null) {
            FieldAliasingMapper fieldAliasingMapper2 = this.fieldAliasingMapper;
            if (fieldAliasingMapper2 != null) {
                fieldAliasingMapper2.addFieldAlias(xStreamAlias.value(), field.getDeclaringClass(), field.getName());
                return;
            }
            StringBuilder j = b2.j("No ");
            j.append(FieldAliasingMapper.class.getName());
            j.append(" available");
            throw new InitializationException(j.toString());
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:12:0x004a  */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x006b  */
    private void processImplicitAnnotation(Field field) {
        Class<?> cls;
        XStreamImplicit xStreamImplicit = (XStreamImplicit) field.getAnnotation(XStreamImplicit.class);
        if (xStreamImplicit == null) {
            return;
        }
        if (this.implicitCollectionMapper != null) {
            String name = field.getName();
            String itemFieldName = xStreamImplicit.itemFieldName();
            String keyFieldName = xStreamImplicit.keyFieldName();
            boolean isAssignableFrom = Map.class.isAssignableFrom(field.getType());
            if (!field.getType().isArray()) {
                Type genericType = field.getGenericType();
                if (genericType instanceof ParameterizedType) {
                    cls = getClass(((ParameterizedType) genericType).getActualTypeArguments()[isAssignableFrom ? 1 : 0]);
                    if (!isAssignableFrom) {
                        ImplicitCollectionMapper implicitCollectionMapper2 = this.implicitCollectionMapper;
                        Class<?> declaringClass = field.getDeclaringClass();
                        if (itemFieldName == null || "".equals(itemFieldName)) {
                            itemFieldName = null;
                        }
                        implicitCollectionMapper2.add(declaringClass, name, itemFieldName, cls, (keyFieldName == null || "".equals(keyFieldName)) ? null : keyFieldName);
                        return;
                    } else if (itemFieldName == null || "".equals(itemFieldName)) {
                        this.implicitCollectionMapper.add(field.getDeclaringClass(), name, cls);
                        return;
                    } else {
                        this.implicitCollectionMapper.add(field.getDeclaringClass(), name, itemFieldName, cls);
                        return;
                    }
                }
            }
            cls = null;
            if (!isAssignableFrom) {
            }
        } else {
            StringBuilder j = b2.j("No ");
            j.append(ImplicitCollectionMapper.class.getName());
            j.append(" available");
            throw new InitializationException(j.toString());
        }
    }

    @Deprecated
    private void processImplicitCollectionAnnotation(Class<?> cls) {
        XStreamImplicitCollection xStreamImplicitCollection = (XStreamImplicitCollection) cls.getAnnotation(XStreamImplicitCollection.class);
        if (xStreamImplicitCollection == null) {
            return;
        }
        if (this.implicitCollectionMapper != null) {
            String value = xStreamImplicitCollection.value();
            String item = xStreamImplicitCollection.item();
            try {
                Type genericType = cls.getDeclaredField(value).getGenericType();
                Class<?> cls2 = genericType instanceof ParameterizedType ? getClass(((ParameterizedType) genericType).getActualTypeArguments()[0]) : null;
                if (cls2 == null) {
                    this.implicitCollectionMapper.add(cls, value, null, Object.class);
                } else if (item.equals("")) {
                    this.implicitCollectionMapper.add(cls, value, null, cls2);
                } else {
                    this.implicitCollectionMapper.add(cls, value, item, cls2);
                }
            } catch (NoSuchFieldException unused) {
                throw new InitializationException(cls.getName() + " does not have a field named '" + value + "' as required by " + XStreamImplicitCollection.class.getName());
            }
        } else {
            StringBuilder j = b2.j("No ");
            j.append(ImplicitCollectionMapper.class.getName());
            j.append(" available");
            throw new InitializationException(j.toString());
        }
    }

    private void processLocalConverterAnnotation(Field field) {
        Converter cacheConverter;
        XStreamConverter xStreamConverter = (XStreamConverter) field.getAnnotation(XStreamConverter.class);
        if (xStreamConverter != null && (cacheConverter = cacheConverter(xStreamConverter, field.getType())) != null) {
            LocalConversionMapper localConversionMapper2 = this.localConversionMapper;
            if (localConversionMapper2 != null) {
                localConversionMapper2.registerLocalConverter(field.getDeclaringClass(), field.getName(), cacheConverter);
                return;
            }
            StringBuilder j = b2.j("No ");
            j.append(LocalConversionMapper.class.getName());
            j.append(" available");
            throw new InitializationException(j.toString());
        }
    }

    private void processOmitFieldAnnotation(Field field) {
        if (((XStreamOmitField) field.getAnnotation(XStreamOmitField.class)) != null) {
            ElementIgnoringMapper elementIgnoringMapper2 = this.elementIgnoringMapper;
            if (elementIgnoringMapper2 != null) {
                elementIgnoringMapper2.omitField(field.getDeclaringClass(), field.getName());
                return;
            }
            StringBuilder j = b2.j("No ");
            j.append(ElementIgnoringMapper.class.getName());
            j.append(" available");
            throw new InitializationException(j.toString());
        }
    }

    private void processTypes(Set<Class<?>> set) {
        while (!set.isEmpty()) {
            Iterator<Class<?>> it = set.iterator();
            Class<?> next = it.next();
            it.remove();
            synchronized (next) {
                if (!this.annotatedTypes.contains(next)) {
                    try {
                        if (!next.isPrimitive()) {
                            addParametrizedTypes(next, set);
                            processConverterAnnotations(next);
                            processAliasAnnotation(next, set);
                            processAliasTypeAnnotation(next);
                            if (next.isInterface()) {
                                this.annotatedTypes.add(next);
                            } else {
                                processImplicitCollectionAnnotation(next);
                                Field[] declaredFields = next.getDeclaredFields();
                                for (Field field : declaredFields) {
                                    if (!field.isEnumConstant() && (field.getModifiers() & 136) <= 0) {
                                        addParametrizedTypes(field.getGenericType(), set);
                                        if (!field.isSynthetic()) {
                                            processFieldAliasAnnotation(field);
                                            processAsAttributeAnnotation(field);
                                            processImplicitAnnotation(field);
                                            processOmitFieldAnnotation(field);
                                            processLocalConverterAnnotation(field);
                                        }
                                    }
                                }
                                this.annotatedTypes.add(next);
                            }
                        }
                    } finally {
                        this.annotatedTypes.add(next);
                    }
                }
            }
        }
    }

    private void readObject(ObjectInputStream objectInputStream) {
        objectInputStream.defaultReadObject();
        setupMappers();
        int readInt = objectInputStream.readInt();
        this.arguments = new Object[(readInt + 2)];
        for (int i = 0; i < readInt; i++) {
            this.arguments[i] = objectInputStream.readObject();
            Object[] objArr = this.arguments;
            if (objArr[i] instanceof ClassLoaderReference) {
                objArr[readInt + 1] = ((ClassLoaderReference) objArr[i]).getReference();
            }
        }
        this.arguments[readInt] = new JVM();
    }

    private void setupMappers() {
        this.classAliasingMapper = (ClassAliasingMapper) lookupMapperOfType(ClassAliasingMapper.class);
        this.defaultImplementationsMapper = (DefaultImplementationsMapper) lookupMapperOfType(DefaultImplementationsMapper.class);
        this.implicitCollectionMapper = (ImplicitCollectionMapper) lookupMapperOfType(ImplicitCollectionMapper.class);
        this.fieldAliasingMapper = (FieldAliasingMapper) lookupMapperOfType(FieldAliasingMapper.class);
        this.elementIgnoringMapper = (ElementIgnoringMapper) lookupMapperOfType(ElementIgnoringMapper.class);
        this.attributeMapper = (AttributeMapper) lookupMapperOfType(AttributeMapper.class);
        this.localConversionMapper = (LocalConversionMapper) lookupMapperOfType(LocalConversionMapper.class);
    }

    private void writeObject(ObjectOutputStream objectOutputStream) {
        objectOutputStream.defaultWriteObject();
        int length = this.arguments.length - 2;
        objectOutputStream.writeInt(length);
        for (int i = 0; i < length; i++) {
            objectOutputStream.writeObject(this.arguments[i]);
        }
    }

    @Override // com.thoughtworks.xstream.mapper.AnnotationConfiguration
    public void autodetectAnnotations(boolean z) {
        this.locked = !z;
    }

    @Override // com.thoughtworks.xstream.mapper.MapperWrapper, com.thoughtworks.xstream.mapper.Mapper
    public Class defaultImplementationOf(Class cls) {
        if (!this.locked) {
            processAnnotations(cls);
        }
        Class defaultImplementationOf = super.defaultImplementationOf(cls);
        if (!this.locked) {
            processAnnotations(defaultImplementationOf);
        }
        return defaultImplementationOf;
    }

    @Override // com.thoughtworks.xstream.mapper.MapperWrapper, com.thoughtworks.xstream.mapper.Mapper
    public Converter getLocalConverter(Class cls, String str) {
        if (!this.locked) {
            processAnnotations(cls);
        }
        return super.getLocalConverter(cls, str);
    }

    @Override // com.thoughtworks.xstream.mapper.AnnotationConfiguration
    public void processAnnotations(Class[] clsArr) {
        if (!(clsArr == null || clsArr.length == 0)) {
            this.locked = true;
            Set<Class<?>> unprocessedTypesSet = new UnprocessedTypesSet();
            for (Class cls : clsArr) {
                unprocessedTypesSet.add(cls);
            }
            processTypes(unprocessedTypesSet);
        }
    }

    @Override // com.thoughtworks.xstream.mapper.MapperWrapper, com.thoughtworks.xstream.mapper.Mapper
    public String realMember(Class cls, String str) {
        if (!this.locked) {
            processAnnotations(cls);
        }
        return super.realMember(cls, str);
    }

    @Override // com.thoughtworks.xstream.mapper.MapperWrapper, com.thoughtworks.xstream.mapper.Mapper
    public String serializedClass(Class cls) {
        if (!this.locked) {
            processAnnotations(cls);
        }
        return super.serializedClass(cls);
    }

    private void processAnnotations(Class cls) {
        if (cls != null) {
            UnprocessedTypesSet unprocessedTypesSet = new UnprocessedTypesSet();
            unprocessedTypesSet.add((Object) cls);
            processTypes(unprocessedTypesSet);
        }
    }

    public AnnotationMapper(Mapper mapper, ConverterRegistry converterRegistry2, ConverterLookup converterLookup, ClassLoader classLoader, ReflectionProvider reflectionProvider, JVM jvm) {
        this(mapper, converterRegistry2, converterLookup, new ClassLoaderReference(classLoader), reflectionProvider);
    }
}
