package org.chromium.base;

import android.text.TextUtils;
import android.util.Log;
import androidx.base.b2;
import com.google.android.exoplayer2.C;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.concurrent.atomic.AtomicReference;
import org.chromium.base.annotations.MainDex;

@MainDex
public abstract class CommandLine {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final String SWITCH_PREFIX = "--";
    private static final String SWITCH_TERMINATOR = "--";
    private static final String SWITCH_VALUE_SEPARATOR = "=";
    private static final String TAG = "CommandLine";
    private static final AtomicReference<CommandLine> sCommandLine = new AtomicReference<>();
    private static final List<ResetListener> sResetListeners = new ArrayList();

    public static class JavaCommandLine extends CommandLine {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        private ArrayList<String> mArgs;
        private int mArgsBegin;
        private HashMap<String, String> mSwitches = new HashMap<>();

        public JavaCommandLine(String[] strArr) {
            super();
            ArrayList<String> arrayList = new ArrayList<>();
            this.mArgs = arrayList;
            this.mArgsBegin = 1;
            if (strArr == null || strArr.length == 0 || strArr[0] == null) {
                arrayList.add("");
                return;
            }
            arrayList.add(strArr[0]);
            appendSwitchesInternal(strArr, 1);
        }

        private void appendSwitchesInternal(String[] strArr, int i) {
            boolean z = true;
            for (String str : strArr) {
                if (i > 0) {
                    i--;
                } else {
                    if (str.equals("--")) {
                        z = false;
                    }
                    if (!z || !str.startsWith("--")) {
                        this.mArgs.add(str);
                    } else {
                        String[] split = str.split(CommandLine.SWITCH_VALUE_SEPARATOR, 2);
                        appendSwitchWithValue(split[0].substring(2), split.length > 1 ? split[1] : null);
                    }
                }
            }
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private String[] getCommandLineArguments() {
            ArrayList<String> arrayList = this.mArgs;
            return (String[]) arrayList.toArray(new String[arrayList.size()]);
        }

        @Override // org.chromium.base.CommandLine
        public void appendSwitch(String str) {
            appendSwitchWithValue(str, null);
        }

        @Override // org.chromium.base.CommandLine
        public void appendSwitchWithValue(String str, String str2) {
            this.mSwitches.put(str, str2 == null ? "" : str2);
            String str3 = "--" + str;
            if (str2 != null && !str2.isEmpty()) {
                str3 = b2.d(str3, CommandLine.SWITCH_VALUE_SEPARATOR, str2);
            }
            ArrayList<String> arrayList = this.mArgs;
            int i = this.mArgsBegin;
            this.mArgsBegin = i + 1;
            arrayList.add(i, str3);
        }

        @Override // org.chromium.base.CommandLine
        public void appendSwitchesAndArguments(String[] strArr) {
            appendSwitchesInternal(strArr, 0);
        }

        @Override // org.chromium.base.CommandLine
        public String getSwitchValue(String str) {
            String str2 = this.mSwitches.get(str);
            if (str2 == null || str2.isEmpty()) {
                return null;
            }
            return str2;
        }

        @Override // org.chromium.base.CommandLine
        public boolean hasSwitch(String str) {
            return this.mSwitches.containsKey(str);
        }
    }

    public static class NativeCommandLine extends CommandLine {
        private NativeCommandLine() {
            super();
        }

        @Override // org.chromium.base.CommandLine
        public void appendSwitch(String str) {
            CommandLine.nativeAppendSwitch(str);
        }

        @Override // org.chromium.base.CommandLine
        public void appendSwitchWithValue(String str, String str2) {
            CommandLine.nativeAppendSwitchWithValue(str, str2);
        }

        @Override // org.chromium.base.CommandLine
        public void appendSwitchesAndArguments(String[] strArr) {
            CommandLine.nativeAppendSwitchesAndArguments(strArr);
        }

        @Override // org.chromium.base.CommandLine
        public String getSwitchValue(String str) {
            return CommandLine.nativeGetSwitchValue(str);
        }

        @Override // org.chromium.base.CommandLine
        public boolean hasSwitch(String str) {
            return CommandLine.nativeHasSwitch(str);
        }

        @Override // org.chromium.base.CommandLine
        public boolean isNativeImplementation() {
            return true;
        }
    }

    public interface ResetListener {
        void onCommandLineReset();
    }

    public static void addResetListener(ResetListener resetListener) {
        sResetListeners.add(resetListener);
    }

    public static void enableNativeProxy() {
        sCommandLine.set(new NativeCommandLine());
    }

    @VisibleForTesting
    public static CommandLine getInstance() {
        return sCommandLine.get();
    }

    public static String[] getJavaSwitchesOrNull() {
        CommandLine commandLine = sCommandLine.get();
        if (commandLine != null) {
            return ((JavaCommandLine) commandLine).getCommandLineArguments();
        }
        return null;
    }

    public static void init(String[] strArr) {
        setInstance(new JavaCommandLine(strArr));
    }

    public static void initFromFile(String str) {
        String[] strArr;
        char[] readUtf8FileFully = readUtf8FileFully(str, 8192);
        if (readUtf8FileFully == null) {
            strArr = null;
        } else {
            strArr = tokenizeQuotedAruments(readUtf8FileFully);
        }
        init(strArr);
    }

    public static boolean isInitialized() {
        return sCommandLine.get() != null;
    }

    /* access modifiers changed from: private */
    public static native void nativeAppendSwitch(String str);

    /* access modifiers changed from: private */
    public static native void nativeAppendSwitchWithValue(String str, String str2);

    /* access modifiers changed from: private */
    public static native void nativeAppendSwitchesAndArguments(String[] strArr);

    /* access modifiers changed from: private */
    public static native String nativeGetSwitchValue(String str);

    /* access modifiers changed from: private */
    public static native boolean nativeHasSwitch(String str);

    private static native void nativeReset();

    /* JADX WARNING: Removed duplicated region for block: B:23:0x0068 A[SYNTHETIC, Splitter:B:23:0x0068] */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x0074 A[SYNTHETIC, Splitter:B:32:0x0074] */
    /* JADX WARNING: Removed duplicated region for block: B:41:0x0080 A[SYNTHETIC, Splitter:B:41:0x0080] */
    private static char[] readUtf8FileFully(String str, int i) {
        InputStreamReader inputStreamReader;
        Throwable th;
        File file = new File(str);
        long length = file.length();
        InputStreamReader inputStreamReader2 = null;
        if (length == 0) {
            return null;
        }
        if (length > ((long) i)) {
            Log.w(TAG, "File " + str + " length " + length + " exceeds limit " + i);
            return null;
        }
        int i2 = (int) length;
        try {
            char[] cArr = new char[i2];
            inputStreamReader = new InputStreamReader(new FileInputStream(file), C.UTF8_NAME);
            try {
                int read = inputStreamReader.read(cArr);
                if (read < i2) {
                    cArr = Arrays.copyOfRange(cArr, 0, read);
                }
                try {
                    inputStreamReader.close();
                } catch (IOException e) {
                    Log.e(TAG, "Unable to close file reader.", e);
                }
                return cArr;
            } catch (FileNotFoundException unused) {
                if (inputStreamReader != null) {
                }
                return null;
            } catch (IOException unused2) {
                if (inputStreamReader != null) {
                }
                return null;
            } catch (Throwable th2) {
                th = th2;
                inputStreamReader2 = inputStreamReader;
                if (inputStreamReader2 != null) {
                }
                throw th;
            }
        } catch (FileNotFoundException unused3) {
            inputStreamReader = null;
            if (inputStreamReader != null) {
                try {
                    inputStreamReader.close();
                } catch (IOException e2) {
                    Log.e(TAG, "Unable to close file reader.", e2);
                }
            }
            return null;
        } catch (IOException unused4) {
            inputStreamReader = null;
            if (inputStreamReader != null) {
                try {
                    inputStreamReader.close();
                } catch (IOException e3) {
                    Log.e(TAG, "Unable to close file reader.", e3);
                }
            }
            return null;
        } catch (Throwable th3) {
            th = th3;
            if (inputStreamReader2 != null) {
                try {
                    inputStreamReader2.close();
                } catch (IOException e4) {
                    Log.e(TAG, "Unable to close file reader.", e4);
                }
            }
            throw th;
        }
    }

    public static void removeResetListener(ResetListener resetListener) {
        sResetListeners.remove(resetListener);
    }

    @VisibleForTesting
    public static void reset() {
        setInstance(null);
        ThreadUtils.postOnUiThread(new Runnable() {
            /* class org.chromium.base.CommandLine.AnonymousClass1 */

            public void run() {
                for (ResetListener resetListener : CommandLine.sResetListeners) {
                    resetListener.onCommandLineReset();
                }
            }
        });
    }

    private static void setInstance(CommandLine commandLine) {
        CommandLine andSet = sCommandLine.getAndSet(commandLine);
        if (andSet != null && andSet.isNativeImplementation()) {
            nativeReset();
        }
    }

    public static String[] tokenizeQuotedAruments(char[] cArr) {
        ArrayList arrayList = new ArrayList();
        StringBuilder sb = null;
        char c = 0;
        for (char c2 : cArr) {
            if ((c == 0 && (c2 == '\'' || c2 == '\"')) || c2 == c) {
                if (sb == null || sb.length() <= 0 || sb.charAt(sb.length() - 1) != '\\') {
                    c = c == 0 ? c2 : 0;
                } else {
                    sb.setCharAt(sb.length() - 1, c2);
                }
            } else if (c != 0 || !Character.isWhitespace(c2)) {
                if (sb == null) {
                    sb = new StringBuilder();
                }
                sb.append(c2);
            } else if (sb != null) {
                arrayList.add(sb.toString());
                sb = null;
            }
        }
        if (sb != null) {
            if (c != 0) {
                Log.w(TAG, "Unterminated quoted string: " + ((Object) sb));
            }
            arrayList.add(sb.toString());
        }
        return (String[]) arrayList.toArray(new String[arrayList.size()]);
    }

    @VisibleForTesting
    public abstract void appendSwitch(String str);

    public abstract void appendSwitchWithValue(String str, String str2);

    public abstract void appendSwitchesAndArguments(String[] strArr);

    public abstract String getSwitchValue(String str);

    public String getSwitchValue(String str, String str2) {
        String switchValue = getSwitchValue(str);
        return TextUtils.isEmpty(switchValue) ? str2 : switchValue;
    }

    @VisibleForTesting
    public abstract boolean hasSwitch(String str);

    public boolean isNativeImplementation() {
        return false;
    }

    private CommandLine() {
    }
}
