package org.chromium.base;

import android.os.Debug;
import android.util.Log;
import androidx.base.b2;
import androidx.exifinterface.media.ExifInterface;
import com.google.android.exoplayer2.text.ttml.TtmlNode;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.PrintStream;
import java.util.LinkedList;
import java.util.List;
import org.chromium.base.annotations.SuppressFBWarnings;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

@SuppressFBWarnings({"CHROMIUM_SYNCHRONIZED_METHOD"})
public class PerfTraceEvent {
    private static final int MAX_NAME_LENGTH = 40;
    private static final String MEMORY_TRACE_NAME_SUFFIX = "_BZR_PSS";
    private static long sBeginNanoTime = 0;
    private static boolean sEnabled = false;
    private static List<String> sFilter = null;
    private static File sOutputFile = null;
    private static JSONArray sPerfTraceStrings = null;
    private static boolean sTrackMemory = false;
    private static boolean sTrackTiming = true;

    public enum EventType {
        START(ExifInterface.LATITUDE_SOUTH),
        FINISH("F"),
        INSTANT("I");
        
        private final String mTypeStr;

        private EventType(String str) {
            this.mTypeStr = str;
        }

        public String toString() {
            return this.mTypeStr;
        }
    }

    @VisibleForTesting
    public static synchronized void begin(String str) {
        synchronized (PerfTraceEvent.class) {
            long hashCode = (long) str.hashCode();
            TraceEvent.startAsync(str, hashCode);
            if (sEnabled && matchesFilter(str)) {
                if (sTrackMemory) {
                    savePerfString(makeMemoryTraceNameFromTimingName(str), hashCode, EventType.START, true);
                }
                if (sTrackTiming) {
                    savePerfString(str, hashCode, EventType.START, false);
                }
            }
        }
    }

    private static void dumpPerf() {
        String jSONArray = sPerfTraceStrings.toString();
        if (sOutputFile == null) {
            System.out.println(jSONArray);
            return;
        }
        try {
            PrintStream printStream = new PrintStream(new FileOutputStream(sOutputFile, true));
            try {
                printStream.print(jSONArray);
            } finally {
                try {
                    printStream.close();
                } catch (Exception unused) {
                    Log.e("PerfTraceEvent", "Unable to close perf trace output file.");
                }
            }
        } catch (FileNotFoundException unused2) {
            Log.e("PerfTraceEvent", "Unable to dump perf trace data to output file.");
        }
    }

    @VisibleForTesting
    public static synchronized boolean enabled() {
        boolean z;
        synchronized (PerfTraceEvent.class) {
            z = sEnabled;
        }
        return z;
    }

    @VisibleForTesting
    public static synchronized void end(String str) {
        synchronized (PerfTraceEvent.class) {
            long hashCode = (long) str.hashCode();
            TraceEvent.finishAsync(str, hashCode);
            if (sEnabled && matchesFilter(str)) {
                if (sTrackTiming) {
                    savePerfString(str, hashCode, EventType.FINISH, false);
                }
                if (sTrackMemory) {
                    savePerfString(makeMemoryTraceNameFromTimingName(str), hashCode, EventType.FINISH, true);
                }
            }
        }
    }

    public static synchronized void instant(String str) {
        synchronized (PerfTraceEvent.class) {
            long hashCode = (long) str.hashCode();
            TraceEvent.instant(str);
            if (sEnabled && matchesFilter(str)) {
                savePerfString(str, hashCode, EventType.INSTANT, false);
            }
        }
    }

    public static String makeMemoryTraceNameFromTimingName(String str) {
        return makeSafeTraceName(str, MEMORY_TRACE_NAME_SUFFIX);
    }

    public static String makeSafeTraceName(String str, String str2) {
        int length = str2.length();
        if (str.length() + length > 40) {
            str = str.substring(0, 40 - length);
        }
        return b2.c(str, str2);
    }

    private static boolean matchesFilter(String str) {
        List<String> list = sFilter;
        if (list != null) {
            return list.contains(str);
        }
        return false;
    }

    private static void savePerfString(String str, long j, EventType eventType, boolean z) {
        Debug.MemoryInfo memoryInfo;
        long nanoTime = (System.nanoTime() - sBeginNanoTime) / 1000;
        if (z) {
            memoryInfo = new Debug.MemoryInfo();
            Debug.getMemoryInfo(memoryInfo);
        } else {
            memoryInfo = null;
        }
        savePerfString(str, j, eventType, nanoTime, memoryInfo);
    }

    @VisibleForTesting
    public static synchronized void setEnabled(boolean z) {
        synchronized (PerfTraceEvent.class) {
            if (sEnabled != z) {
                if (z) {
                    sBeginNanoTime = System.nanoTime();
                    sPerfTraceStrings = new JSONArray();
                } else {
                    dumpPerf();
                    sPerfTraceStrings = null;
                    sFilter = null;
                }
                sEnabled = z;
            }
        }
    }

    @VisibleForTesting
    public static synchronized void setFilter(List<String> list) {
        synchronized (PerfTraceEvent.class) {
            sFilter = new LinkedList(list);
        }
    }

    @VisibleForTesting
    public static synchronized void setMemoryTrackingEnabled(boolean z) {
        synchronized (PerfTraceEvent.class) {
            sTrackMemory = z;
        }
    }

    @VisibleForTesting
    public static synchronized void setOutputFile(File file) {
        synchronized (PerfTraceEvent.class) {
            sOutputFile = file;
        }
    }

    @VisibleForTesting
    public static synchronized void setTimingTrackingEnabled(boolean z) {
        synchronized (PerfTraceEvent.class) {
            sTrackTiming = z;
        }
    }

    private static void savePerfString(String str, long j, EventType eventType, long j2, Debug.MemoryInfo memoryInfo) {
        try {
            JSONObject jSONObject = new JSONObject();
            jSONObject.put("cat", "Java");
            jSONObject.put("ts", j2);
            jSONObject.put("ph", eventType);
            jSONObject.put("name", str);
            jSONObject.put(TtmlNode.ATTR_ID, j);
            if (memoryInfo != null) {
                jSONObject.put("mem", memoryInfo.nativePss + memoryInfo.dalvikPss + memoryInfo.otherPss);
            }
            sPerfTraceStrings.put(jSONObject);
        } catch (JSONException e) {
            throw new RuntimeException(e);
        }
    }

    @VisibleForTesting
    public static synchronized void begin(String str, Debug.MemoryInfo memoryInfo) {
        synchronized (PerfTraceEvent.class) {
            long hashCode = (long) str.hashCode();
            TraceEvent.startAsync(str, hashCode);
            if (sEnabled && matchesFilter(str)) {
                long nanoTime = (System.nanoTime() - sBeginNanoTime) / 1000;
                String makeMemoryTraceNameFromTimingName = makeMemoryTraceNameFromTimingName(str);
                EventType eventType = EventType.START;
                savePerfString(makeMemoryTraceNameFromTimingName, hashCode, eventType, nanoTime, memoryInfo);
                if (sTrackTiming) {
                    savePerfString(str, hashCode, eventType, false);
                }
            }
        }
    }

    @VisibleForTesting
    public static synchronized void end(String str, Debug.MemoryInfo memoryInfo) {
        synchronized (PerfTraceEvent.class) {
            long hashCode = (long) str.hashCode();
            TraceEvent.finishAsync(str, hashCode);
            if (sEnabled && matchesFilter(str)) {
                if (sTrackTiming) {
                    savePerfString(str, hashCode, EventType.FINISH, false);
                }
                savePerfString(makeMemoryTraceNameFromTimingName(str), hashCode, EventType.FINISH, (System.nanoTime() - sBeginNanoTime) / 1000, memoryInfo);
            }
        }
    }
}
