package org.chromium.base;

import android.annotation.TargetApi;
import android.content.Context;
import android.content.SharedPreferences;
import android.content.pm.PackageManager;
import android.os.AsyncTask;
import android.os.Build;
import android.os.Handler;
import android.os.Looper;
import android.os.Trace;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.CancellationException;
import java.util.concurrent.ExecutionException;
import org.chromium.base.annotations.SuppressFBWarnings;

public class ResourceExtractor {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final String APP_VERSION_PREF = "org.chromium.base.ResourceExtractor.Version";
    private static final String ICU_DATA_FILENAME = "icudtl.dat";
    private static final String TAG = "cr.base";
    private static final String V8_NATIVES_DATA_FILENAME = "natives_blob.bin";
    private static final String V8_SNAPSHOT_DATA_FILENAME = "snapshot_blob.bin";
    private static ResourceExtractor sInstance;
    private static ResourceInterceptor sInterceptor;
    private static ResourceEntry[] sResourcesToExtract = new ResourceEntry[0];
    private final Context mContext;
    private ExtractTask mExtractTask;

    public class ExtractTask extends AsyncTask<Void, Void, Void> {
        private static final int BUFFER_SIZE = 16384;
        private final List<Runnable> mCompletionCallbacks;

        private ExtractTask() {
            this.mCompletionCallbacks = new ArrayList();
        }

        @TargetApi(18)
        private void beginTraceSection(String str) {
            if (Build.VERSION.SDK_INT >= 18) {
                Trace.beginSection(str);
            }
        }

        private void doInBackgroundImpl() {
            InputStream inputStream;
            File outputDir = ResourceExtractor.this.getOutputDir();
            File appDataDir = ResourceExtractor.this.getAppDataDir();
            if (outputDir.exists() || outputDir.mkdirs()) {
                beginTraceSection("checkPakTimeStamp");
                long apkVersion = getApkVersion();
                SharedPreferences appSharedPreferences = ContextUtils.getAppSharedPreferences();
                boolean z = apkVersion != appSharedPreferences.getLong(ResourceExtractor.APP_VERSION_PREF, 0);
                endTraceSection();
                if (z) {
                    ResourceExtractor.this.deleteFiles();
                    appSharedPreferences.edit().putLong(ResourceExtractor.APP_VERSION_PREF, apkVersion).apply();
                }
                beginTraceSection("WalkAssets");
                byte[] bArr = new byte[16384];
                try {
                    ResourceEntry[] resourceEntryArr = ResourceExtractor.sResourcesToExtract;
                    for (ResourceEntry resourceEntry : resourceEntryArr) {
                        File file = new File(ResourceExtractor.isAppDataFile(resourceEntry.extractedFileName) ? appDataDir : outputDir, resourceEntry.extractedFileName);
                        if (file.length() == 0) {
                            beginTraceSection("ExtractResource");
                            if (ResourceExtractor.sInterceptor == null || !ResourceExtractor.sInterceptor.shouldInterceptLoadRequest(resourceEntry.extractedFileName)) {
                                inputStream = ResourceExtractor.this.mContext.getResources().openRawResource(resourceEntry.resourceId);
                            } else {
                                inputStream = ResourceExtractor.sInterceptor.openRawResource(resourceEntry.extractedFileName);
                            }
                            try {
                                extractResourceHelper(inputStream, file, bArr);
                            } finally {
                                endTraceSection();
                            }
                        }
                    }
                    endTraceSection();
                } catch (IOException e) {
                    Log.w(ResourceExtractor.TAG, "Exception unpacking required pak resources: %s", e.getMessage());
                    ResourceExtractor.this.deleteFiles();
                } finally {
                    endTraceSection();
                }
            } else {
                Log.e(ResourceExtractor.TAG, "Unable to create pak resources directory!", new Object[0]);
            }
        }

        @TargetApi(18)
        private void endTraceSection() {
            if (Build.VERSION.SDK_INT >= 18) {
                Trace.endSection();
            }
        }

        /* JADX WARNING: Removed duplicated region for block: B:20:0x0032 A[SYNTHETIC, Splitter:B:20:0x0032] */
        /* JADX WARNING: Removed duplicated region for block: B:27:0x003f  */
        private void extractResourceHelper(InputStream inputStream, File file, byte[] bArr) {
            Throwable th;
            FileOutputStream fileOutputStream = null;
            try {
                FileOutputStream fileOutputStream2 = new FileOutputStream(file);
                try {
                    Log.i(ResourceExtractor.TAG, "Extracting resource %s", file);
                    while (true) {
                        int read = inputStream.read(bArr, 0, 16384);
                        if (read != -1) {
                            fileOutputStream2.write(bArr, 0, read);
                        } else {
                            try {
                                fileOutputStream2.close();
                                return;
                            } finally {
                                inputStream.close();
                            }
                        }
                    }
                } catch (Throwable th2) {
                    th = th2;
                    fileOutputStream = fileOutputStream2;
                    if (fileOutputStream != null) {
                        try {
                            fileOutputStream.close();
                        } catch (Throwable th3) {
                            if (inputStream != null) {
                                inputStream.close();
                            }
                            throw th3;
                        }
                    }
                    if (inputStream != null) {
                        inputStream.close();
                    }
                    throw th;
                }
            } catch (Throwable th4) {
                th = th4;
                if (fileOutputStream != null) {
                }
                if (inputStream != null) {
                }
                throw th;
            }
        }

        private long getApkVersion() {
            try {
                return ResourceExtractor.this.mContext.getPackageManager().getPackageInfo(ResourceExtractor.this.mContext.getPackageName(), 0).lastUpdateTime;
            } catch (PackageManager.NameNotFoundException e) {
                throw new RuntimeException(e);
            }
        }

        private void onPostExecuteImpl() {
            for (int i = 0; i < this.mCompletionCallbacks.size(); i++) {
                this.mCompletionCallbacks.get(i).run();
            }
            this.mCompletionCallbacks.clear();
        }

        /* JADX INFO: finally extract failed */
        public Void doInBackground(Void... voidArr) {
            beginTraceSection("ResourceExtractor.ExtractTask.doInBackground");
            try {
                doInBackgroundImpl();
                endTraceSection();
                return null;
            } catch (Throwable th) {
                endTraceSection();
                throw th;
            }
        }

        public void onPostExecute(Void r1) {
            beginTraceSection("ResourceExtractor.ExtractTask.onPostExecute");
            try {
                onPostExecuteImpl();
            } finally {
                endTraceSection();
            }
        }
    }

    public static final class ResourceEntry {
        public final String extractedFileName;
        public final String pathWithinApk;
        public final int resourceId;

        public ResourceEntry(int i, String str, String str2) {
            this.resourceId = i;
            this.pathWithinApk = str;
            this.extractedFileName = str2;
        }
    }

    public interface ResourceInterceptor {
        InputStream openRawResource(String str);

        boolean shouldInterceptLoadRequest(String str);
    }

    private ResourceExtractor(Context context) {
        this.mContext = context.getApplicationContext();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void deleteFiles() {
        File[] listFiles;
        File file = new File(getAppDataDir(), ICU_DATA_FILENAME);
        if (file.exists() && !file.delete()) {
            Log.e(TAG, "Unable to remove the icudata %s", file.getName());
        }
        File file2 = new File(getAppDataDir(), V8_NATIVES_DATA_FILENAME);
        if (file2.exists() && !file2.delete()) {
            Log.e(TAG, "Unable to remove the v8 data %s", file2.getName());
        }
        File file3 = new File(getAppDataDir(), V8_SNAPSHOT_DATA_FILENAME);
        if (file3.exists() && !file3.delete()) {
            Log.e(TAG, "Unable to remove the v8 data %s", file3.getName());
        }
        File outputDir = getOutputDir();
        if (outputDir.exists() && (listFiles = outputDir.listFiles()) != null) {
            for (File file4 : listFiles) {
                if (!file4.delete()) {
                    Log.e(TAG, "Unable to remove existing resource %s", file4.getName());
                }
            }
        }
    }

    public static ResourceExtractor get(Context context) {
        if (sInstance == null) {
            sInstance = new ResourceExtractor(context);
        }
        return sInstance;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private File getAppDataDir() {
        return new File(PathUtils.getDataDirectory(this.mContext));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private File getOutputDir() {
        return new File(getAppDataDir(), "paks");
    }

    /* access modifiers changed from: private */
    public static boolean isAppDataFile(String str) {
        return ICU_DATA_FILENAME.equals(str) || V8_NATIVES_DATA_FILENAME.equals(str) || V8_SNAPSHOT_DATA_FILENAME.equals(str);
    }

    public static void setResourceInterceptor(ResourceInterceptor resourceInterceptor) {
        sInterceptor = resourceInterceptor;
    }

    @SuppressFBWarnings({"EI_EXPOSE_STATIC_REP2"})
    public static void setResourcesToExtract(ResourceEntry[] resourceEntryArr) {
        sResourcesToExtract = resourceEntryArr;
    }

    private static boolean shouldSkipPakExtraction() {
        return sResourcesToExtract.length == 0;
    }

    public void addCompletionCallback(Runnable runnable) {
        ThreadUtils.assertOnUiThread();
        Handler handler = new Handler(Looper.getMainLooper());
        if (shouldSkipPakExtraction()) {
            handler.post(runnable);
        } else if (this.mExtractTask.getStatus() == AsyncTask.Status.FINISHED) {
            handler.post(runnable);
        } else {
            this.mExtractTask.mCompletionCallbacks.add(runnable);
        }
    }

    public void startExtractingResources() {
        if (this.mExtractTask == null && !shouldSkipPakExtraction()) {
            ExtractTask extractTask = new ExtractTask();
            this.mExtractTask = extractTask;
            extractTask.executeOnExecutor(AsyncTask.THREAD_POOL_EXECUTOR, new Void[0]);
        }
    }

    public void waitForCompletion() {
        if (!shouldSkipPakExtraction()) {
            try {
                this.mExtractTask.get();
                sInterceptor = null;
                sInstance = null;
            } catch (CancellationException unused) {
                deleteFiles();
            } catch (ExecutionException unused2) {
                deleteFiles();
            } catch (InterruptedException unused3) {
                deleteFiles();
            }
        }
    }
}
