package org.chromium.base.library_loader;

import android.content.Context;
import android.os.AsyncTask;
import android.os.SystemClock;
import androidx.base.b2;
import java.util.concurrent.atomic.AtomicBoolean;
import javax.annotation.Nullable;
import org.chromium.base.CommandLine;
import org.chromium.base.ContextUtils;
import org.chromium.base.Log;
import org.chromium.base.TraceEvent;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;
import org.chromium.base.metrics.RecordHistogram;

@JNINamespace("base::android")
public class LibraryLoader {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final boolean DEBUG = false;
    private static final String TAG = "LibraryLoader";
    private static volatile LibraryLoader sInstance;
    private static NativeLibraryPreloader sLibraryPreloader;
    private static final Object sLock = new Object();
    private boolean mCommandLineSwitched;
    private volatile boolean mInitialized;
    private boolean mIsUsingBrowserSharedRelros;
    private long mLibraryLoadTimeMs;
    private int mLibraryPreloaderStatus = -1;
    private final int mLibraryProcessType;
    private boolean mLibraryWasLoadedFromApk;
    private boolean mLoadAtFixedAddressFailed;
    private boolean mLoaded;
    private final AtomicBoolean mPrefetchLibraryHasBeenCalled;

    private LibraryLoader(int i) {
        this.mLibraryProcessType = i;
        this.mPrefetchLibraryHasBeenCalled = new AtomicBoolean();
    }

    private void ensureCommandLineSwitchedAlreadyLocked() {
        if (!this.mCommandLineSwitched) {
            nativeInitCommandLine(CommandLine.getJavaSwitchesOrNull());
            CommandLine.enableNativeProxy();
            this.mCommandLineSwitched = true;
            ContextUtils.initApplicationContextForNative();
        }
    }

    public static LibraryLoader get(int i) {
        synchronized (sLock) {
            if (sInstance == null) {
                sInstance = new LibraryLoader(i);
                return sInstance;
            } else if (sInstance.mLibraryProcessType == i) {
                return sInstance;
            } else {
                throw new ProcessInitException(2);
            }
        }
    }

    private int getLibraryLoadFromApkStatus(Context context) {
        return this.mLibraryWasLoadedFromApk ? 3 : 0;
    }

    @CalledByNative
    public static int getLibraryProcessType() {
        if (sInstance == null) {
            return 0;
        }
        return sInstance.mLibraryProcessType;
    }

    private void initializeAlreadyLocked() {
        if (!this.mInitialized) {
            ensureCommandLineSwitchedAlreadyLocked();
            if (nativeLibraryLoaded()) {
                TraceEvent.registerNativeEnabledObserver();
                this.mInitialized = true;
                return;
            }
            Log.e(TAG, "error calling nativeLibraryLoaded", new Object[0]);
            throw new ProcessInitException(1);
        }
    }

    private static boolean isAbiSplit(String str) {
        return str.startsWith("abi_");
    }

    public static boolean isInitialized() {
        return sInstance != null && sInstance.mInitialized;
    }

    private void loadAlreadyLocked(Context context) {
        String str;
        try {
            if (!this.mLoaded) {
                long uptimeMillis = SystemClock.uptimeMillis();
                if (Linker.isUsed()) {
                    Linker instance = Linker.getInstance();
                    instance.prepareLibraryLoad();
                    String[] strArr = NativeLibraries.LIBRARIES;
                    for (String str2 : strArr) {
                        if (!instance.isChromiumLinkerLibrary(str2)) {
                            String mapLibraryName = System.mapLibraryName(str2);
                            if (Linker.isInZipFile()) {
                                String str3 = context.getApplicationInfo().sourceDir;
                                Log.i(TAG, "Loading " + str2 + " from within " + str3, new Object[0]);
                                str = str3;
                            } else {
                                Log.i(TAG, "Loading " + str2, new Object[0]);
                                str = null;
                            }
                            loadLibrary(instance, str, mapLibraryName);
                        }
                    }
                    instance.finishLibraryLoad();
                } else {
                    NativeLibraryPreloader nativeLibraryPreloader = sLibraryPreloader;
                    if (nativeLibraryPreloader != null) {
                        this.mLibraryPreloaderStatus = nativeLibraryPreloader.loadLibrary(context);
                    }
                    for (String str4 : NativeLibraries.LIBRARIES) {
                        System.loadLibrary(str4);
                    }
                }
                long uptimeMillis2 = SystemClock.uptimeMillis();
                long j = uptimeMillis2 - uptimeMillis;
                this.mLibraryLoadTimeMs = j;
                Log.i(TAG, String.format("Time to load native libraries: %d ms (timestamps %d-%d)", Long.valueOf(j), Long.valueOf(uptimeMillis % 10000), Long.valueOf(uptimeMillis2 % 10000)), new Object[0]);
                this.mLoaded = true;
            }
            Log.i(TAG, String.format("Expected native library version number \"%s\", actual native library version number \"%s\"", NativeLibraries.sVersionNumber, nativeGetVersionNumber()), new Object[0]);
            if (!NativeLibraries.sVersionNumber.equals(nativeGetVersionNumber())) {
                throw new ProcessInitException(3);
            }
        } catch (UnsatisfiedLinkError e) {
            throw new ProcessInitException(2, e);
        }
    }

    private void loadLibrary(Linker linker, @Nullable String str, String str2) {
        if (linker.isUsingBrowserSharedRelros()) {
            this.mIsUsingBrowserSharedRelros = true;
            try {
                linker.loadLibrary(str, str2);
            } catch (UnsatisfiedLinkError unused) {
                Log.w(TAG, "Failed to load native library with shared RELRO, retrying without", new Object[0]);
                this.mLoadAtFixedAddressFailed = true;
                linker.loadLibraryNoFixedAddress(str, str2);
            }
        } else {
            linker.loadLibrary(str, str2);
        }
        if (str != null) {
            this.mLibraryWasLoadedFromApk = true;
        }
    }

    /* access modifiers changed from: private */
    public static native boolean nativeForkAndPrefetchNativeLibrary();

    private native String nativeGetVersionNumber();

    private native void nativeInitCommandLine(String[] strArr);

    private native boolean nativeLibraryLoaded();

    /* access modifiers changed from: private */
    public static native int nativePercentageOfResidentNativeLibraryCode();

    private native void nativeRecordChromiumAndroidLinkerBrowserHistogram(boolean z, boolean z2, int i, long j);

    private native void nativeRecordLibraryPreloaderBrowserHistogram(int i);

    private native void nativeRegisterChromiumAndroidLinkerRendererHistogram(boolean z, boolean z2, long j);

    private native void nativeRegisterLibraryPreloaderRendererHistogram(int i);

    private void recordBrowserProcessHistogram(Context context) {
        Linker.getInstance();
        if (Linker.isUsed()) {
            nativeRecordChromiumAndroidLinkerBrowserHistogram(this.mIsUsingBrowserSharedRelros, this.mLoadAtFixedAddressFailed, getLibraryLoadFromApkStatus(context), this.mLibraryLoadTimeMs);
        }
        if (sLibraryPreloader != null) {
            nativeRecordLibraryPreloaderBrowserHistogram(this.mLibraryPreloaderStatus);
        }
    }

    public static void setNativeLibraryPreloader(NativeLibraryPreloader nativeLibraryPreloader) {
        synchronized (sLock) {
            sLibraryPreloader = nativeLibraryPreloader;
        }
    }

    public void asyncPrefetchLibrariesToMemory() {
        final boolean compareAndSet = this.mPrefetchLibraryHasBeenCalled.compareAndSet(false, true);
        new AsyncTask<Void, Void, Void>() {
            /* class org.chromium.base.library_loader.LibraryLoader.AnonymousClass1 */

            public Void doInBackground(Void... voidArr) {
                TraceEvent.begin("LibraryLoader.asyncPrefetchLibrariesToMemory");
                int nativePercentageOfResidentNativeLibraryCode = LibraryLoader.nativePercentageOfResidentNativeLibraryCode();
                boolean z = false;
                if (compareAndSet) {
                    boolean nativeForkAndPrefetchNativeLibrary = LibraryLoader.nativeForkAndPrefetchNativeLibrary();
                    if (!nativeForkAndPrefetchNativeLibrary) {
                        Log.w(LibraryLoader.TAG, "Forking a process to prefetch the native library failed.", new Object[0]);
                    }
                    z = nativeForkAndPrefetchNativeLibrary;
                }
                RecordHistogram.initialize();
                if (compareAndSet) {
                    RecordHistogram.recordBooleanHistogram("LibraryLoader.PrefetchStatus", z);
                }
                if (nativePercentageOfResidentNativeLibraryCode != -1) {
                    StringBuilder j = b2.j("LibraryLoader.PercentageOfResidentCodeBeforePrefetch");
                    j.append(compareAndSet ? ".ColdStartup" : ".WarmStartup");
                    RecordHistogram.recordPercentageHistogram(j.toString(), nativePercentageOfResidentNativeLibraryCode);
                }
                TraceEvent.end("LibraryLoader.asyncPrefetchLibrariesToMemory");
                return null;
            }
        }.executeOnExecutor(AsyncTask.THREAD_POOL_EXECUTOR, new Void[0]);
    }

    public void ensureInitialized(Context context) {
        ContextUtils.initApplicationContext(context.getApplicationContext());
        synchronized (sLock) {
            if (!this.mInitialized) {
                loadAlreadyLocked(context);
                initializeAlreadyLocked();
            }
        }
    }

    public void initialize() {
        synchronized (sLock) {
            initializeAlreadyLocked();
        }
    }

    public void loadNow(Context context) {
        synchronized (sLock) {
            loadAlreadyLocked(context);
        }
    }

    public void onNativeInitializationComplete(Context context) {
        recordBrowserProcessHistogram(context);
    }

    public void registerRendererProcessHistogram(boolean z, boolean z2) {
        Linker.getInstance();
        if (Linker.isUsed()) {
            nativeRegisterChromiumAndroidLinkerRendererHistogram(z, z2, this.mLibraryLoadTimeMs);
        }
        if (sLibraryPreloader != null) {
            nativeRegisterLibraryPreloaderRendererHistogram(this.mLibraryPreloaderStatus);
        }
    }

    public void switchCommandLineForWebView() {
        synchronized (sLock) {
            ensureCommandLineSwitchedAlreadyLocked();
        }
    }
}
