package org.chromium.content.app;

import android.content.Context;
import android.content.Intent;
import android.graphics.SurfaceTexture;
import android.os.Bundle;
import android.os.Debug;
import android.os.IBinder;
import android.os.Parcelable;
import android.os.Process;
import android.os.RemoteException;
import android.view.Surface;
import java.util.concurrent.Semaphore;
import java.util.concurrent.atomic.AtomicReference;
import org.chromium.base.BaseSwitches;
import org.chromium.base.CommandLine;
import org.chromium.base.ContextUtils;
import org.chromium.base.Log;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;
import org.chromium.base.annotations.SuppressFBWarnings;
import org.chromium.base.library_loader.LibraryLoader;
import org.chromium.base.library_loader.Linker;
import org.chromium.base.library_loader.ProcessInitException;
import org.chromium.content.browser.ChildProcessConstants;
import org.chromium.content.browser.ChildProcessCreationParams;
import org.chromium.content.browser.FileDescriptorInfo;
import org.chromium.content.common.ContentSwitches;
import org.chromium.content.common.IChildProcessCallback;
import org.chromium.content.common.IChildProcessService;
import org.chromium.content.common.SurfaceWrapper;

@JNINamespace("content")
public class ChildProcessServiceImpl {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final FileDescriptorInfo[] EMPTY_FILE_DESCRIPTOR_INFO = new FileDescriptorInfo[0];
    private static final String MAIN_THREAD_NAME = "ChildProcessMain";
    private static final String TAG = "ChildProcessService";
    private static AtomicReference<Context> sContext = new AtomicReference<>(null);
    private final Semaphore mActivitySemaphore = new Semaphore(1);
    private final IChildProcessService.Stub mBinder = new IChildProcessService.Stub() {
        /* class org.chromium.content.app.ChildProcessServiceImpl.AnonymousClass1 */

        @Override // org.chromium.content.common.IChildProcessService
        public void crashIntentionallyForTesting() {
            Process.killProcess(Process.myPid());
        }

        @Override // org.chromium.content.common.IChildProcessService
        public int setupConnection(Bundle bundle, IChildProcessCallback iChildProcessCallback) {
            ChildProcessServiceImpl.this.mCallback = iChildProcessCallback;
            ChildProcessServiceImpl.this.getServiceInfo(bundle);
            return Process.myPid();
        }
    };
    private IChildProcessCallback mCallback;
    private String[] mCommandLineParams;
    private int mCpuCount;
    private long mCpuFeatures;
    private FileDescriptorInfo[] mFdInfos;
    private ClassLoader mHostClassLoader;
    private boolean mIsBound = false;
    private boolean mLibraryInitialized = false;
    private int mLibraryProcessType;
    private ChromiumLinkerParams mLinkerParams;
    private Thread mMainThread;

    @CalledByNative
    private void createSurfaceTextureSurface(int i, int i2, SurfaceTexture surfaceTexture) {
        if (this.mCallback == null) {
            Log.e(TAG, "No callback interface has been provided.", new Object[0]);
            return;
        }
        Surface surface = new Surface(surfaceTexture);
        try {
            this.mCallback.registerSurfaceTextureSurface(i, i2, surface);
        } catch (RemoteException e) {
            Log.e(TAG, "Unable to call registerSurfaceTextureSurface: %s", e);
        }
        surface.release();
    }

    @CalledByNative
    private void destroySurfaceTextureSurface(int i, int i2) {
        IChildProcessCallback iChildProcessCallback = this.mCallback;
        if (iChildProcessCallback == null) {
            Log.e(TAG, "No callback interface has been provided.", new Object[0]);
            return;
        }
        try {
            iChildProcessCallback.unregisterSurfaceTextureSurface(i, i2);
        } catch (RemoteException e) {
            Log.e(TAG, "Unable to call unregisterSurfaceTextureSurface: %s", e);
        }
    }

    @CalledByNative
    private void establishSurfaceTexturePeer(int i, Object obj, int i2, int i3) {
        Surface surface;
        boolean z;
        if (this.mCallback == null) {
            Log.e(TAG, "No callback interface has been provided.", new Object[0]);
            return;
        }
        if (obj instanceof Surface) {
            surface = (Surface) obj;
            z = false;
        } else if (obj instanceof SurfaceTexture) {
            surface = new Surface((SurfaceTexture) obj);
            z = true;
        } else {
            Log.e(TAG, "Not a valid surfaceObject: %s", obj);
            return;
        }
        try {
            this.mCallback.establishSurfacePeer(i, surface, i2, i3);
            if (z) {
                surface.release();
            }
        } catch (RemoteException e) {
            Log.e(TAG, "Unable to call establishSurfaceTexturePeer: %s", e);
            if (z) {
                surface.release();
            }
        } catch (Throwable th) {
            if (z) {
                surface.release();
            }
            throw th;
        }
    }

    public static Context getContext() {
        return sContext.get();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Linker getLinker() {
        if (Linker.areTestsEnabled()) {
            ChromiumLinkerParams chromiumLinkerParams = this.mLinkerParams;
            Linker.setupForTesting(chromiumLinkerParams.mLinkerImplementationForTesting, chromiumLinkerParams.mTestRunnerClassNameForTesting);
        }
        return Linker.getInstance();
    }

    @CalledByNative
    private Surface getSurfaceTextureSurface(int i) {
        IChildProcessCallback iChildProcessCallback = this.mCallback;
        if (iChildProcessCallback == null) {
            Log.e(TAG, "No callback interface has been provided.", new Object[0]);
            return null;
        }
        try {
            return iChildProcessCallback.getSurfaceTextureSurface(i).getSurface();
        } catch (RemoteException e) {
            Log.e(TAG, "Unable to call getSurfaceTextureSurface: %s", e);
            return null;
        }
    }

    @CalledByNative
    private Surface getViewSurface(int i) {
        IChildProcessCallback iChildProcessCallback = this.mCallback;
        if (iChildProcessCallback == null) {
            Log.e(TAG, "No callback interface has been provided.", new Object[0]);
            return null;
        }
        try {
            SurfaceWrapper viewSurface = iChildProcessCallback.getViewSurface(i);
            if (viewSurface != null) {
                return viewSurface.getSurface();
            }
            return null;
        } catch (RemoteException e) {
            Log.e(TAG, "Unable to call getViewSurface: %s", e);
            return null;
        }
    }

    /* access modifiers changed from: private */
    public static native void nativeExitChildProcess();

    /* access modifiers changed from: private */
    public static native void nativeInitChildProcessImpl(ChildProcessServiceImpl childProcessServiceImpl, int i, long j);

    /* access modifiers changed from: private */
    public static native void nativeRegisterGlobalFileDescriptor(int i, int i2, long j, long j2);

    private native void nativeShutdownMainThread();

    public IBinder bind(Intent intent) {
        initializeParams(intent);
        return this.mBinder;
    }

    public void create(Context context, final Context context2) {
        this.mHostClassLoader = context2.getClassLoader();
        Log.i(TAG, "Creating new ChildProcessService pid=%d", Integer.valueOf(Process.myPid()));
        if (sContext.get() == null) {
            sContext.set(context);
            ContextUtils.initApplicationContext(context);
            Thread thread = new Thread(new Runnable() {
                /* class org.chromium.content.app.ChildProcessServiceImpl.AnonymousClass2 */

                /* JADX WARNING: Code restructure failed: missing block: B:33:0x008d, code lost:
                    r5 = move-exception;
                 */
                /* JADX WARNING: Code restructure failed: missing block: B:34:0x008e, code lost:
                    if (r4 != false) goto L_0x0090;
                 */
                /* JADX WARNING: Code restructure failed: missing block: B:35:0x0090, code lost:
                    org.chromium.base.Log.w(org.chromium.content.app.ChildProcessServiceImpl.TAG, "Failed to load native library with shared RELRO, retrying without", new java.lang.Object[0]);
                    r5 = false;
                    r6 = true;
                 */
                /* JADX WARNING: Code restructure failed: missing block: B:36:0x009c, code lost:
                    org.chromium.base.Log.e(org.chromium.content.app.ChildProcessServiceImpl.TAG, "Failed to load native library", r5);
                    r5 = false;
                 */
                /* JADX WARNING: Code restructure failed: missing block: B:67:0x015b, code lost:
                    r3 = move-exception;
                 */
                /* JADX WARNING: Code restructure failed: missing block: B:68:0x015c, code lost:
                    org.chromium.base.Log.w(org.chromium.content.app.ChildProcessServiceImpl.TAG, "%s startup failed: %s", org.chromium.content.app.ChildProcessServiceImpl.MAIN_THREAD_NAME, r3);
                 */
                /* JADX WARNING: Code restructure failed: missing block: B:69:0x016c, code lost:
                    r3 = move-exception;
                 */
                /* JADX WARNING: Code restructure failed: missing block: B:70:0x016d, code lost:
                    org.chromium.base.Log.w(org.chromium.content.app.ChildProcessServiceImpl.TAG, "%s startup failed: %s", org.chromium.content.app.ChildProcessServiceImpl.MAIN_THREAD_NAME, r3);
                 */
                /* JADX WARNING: Code restructure failed: missing block: B:75:?, code lost:
                    return;
                 */
                /* JADX WARNING: Code restructure failed: missing block: B:78:?, code lost:
                    return;
                 */
                /* JADX WARNING: Failed to process nested try/catch */
                /* JADX WARNING: Removed duplicated region for block: B:28:0x0078  */
                /* JADX WARNING: Removed duplicated region for block: B:46:0x00cf  */
                /* JADX WARNING: Removed duplicated region for block: B:49:0x00f4 A[SYNTHETIC] */
                /* JADX WARNING: Removed duplicated region for block: B:69:0x016c A[ExcHandler: InterruptedException (r3v0 'e' java.lang.InterruptedException A[CUSTOM_DECLARE]), Splitter:B:1:0x0003] */
                @SuppressFBWarnings({"DM_EXIT"})
                public void run() {
                    boolean z;
                    boolean z2;
                    try {
                        synchronized (ChildProcessServiceImpl.this.mMainThread) {
                            while (ChildProcessServiceImpl.this.mCommandLineParams == null) {
                                ChildProcessServiceImpl.this.mMainThread.wait();
                            }
                        }
                        CommandLine.init(ChildProcessServiceImpl.this.mCommandLineParams);
                        Linker linker = null;
                        if (Linker.isUsed()) {
                            synchronized (ChildProcessServiceImpl.this.mMainThread) {
                                while (!ChildProcessServiceImpl.this.mIsBound) {
                                    ChildProcessServiceImpl.this.mMainThread.wait();
                                }
                            }
                            linker = ChildProcessServiceImpl.this.getLinker();
                            if (ChildProcessServiceImpl.this.mLinkerParams.mWaitForSharedRelro) {
                                linker.initServiceProcess(ChildProcessServiceImpl.this.mLinkerParams.mBaseLoadAddress);
                                z = true;
                                if (CommandLine.getInstance().hasSwitch(BaseSwitches.RENDERER_WAIT_FOR_JAVA_DEBUGGER)) {
                                    Debug.waitForDebugger();
                                }
                                LibraryLoader.get(ChildProcessServiceImpl.this.mLibraryProcessType).loadNow(context2);
                                z2 = true;
                                boolean z3 = false;
                                if (!z2 && z) {
                                    linker.disableSharedRelros();
                                    LibraryLoader.get(ChildProcessServiceImpl.this.mLibraryProcessType).loadNow(context2);
                                    z2 = true;
                                }
                                if (!z2) {
                                    System.exit(-1);
                                }
                                LibraryLoader.get(ChildProcessServiceImpl.this.mLibraryProcessType).registerRendererProcessHistogram(z, z3);
                                LibraryLoader.get(ChildProcessServiceImpl.this.mLibraryProcessType).initialize();
                                synchronized (ChildProcessServiceImpl.this.mMainThread) {
                                    ChildProcessServiceImpl.this.mLibraryInitialized = true;
                                    ChildProcessServiceImpl.this.mMainThread.notifyAll();
                                    while (ChildProcessServiceImpl.this.mFdInfos == null) {
                                        ChildProcessServiceImpl.this.mMainThread.wait();
                                    }
                                }
                                FileDescriptorInfo[] fileDescriptorInfoArr = ChildProcessServiceImpl.this.mFdInfos;
                                for (FileDescriptorInfo fileDescriptorInfo : fileDescriptorInfoArr) {
                                    ChildProcessServiceImpl.nativeRegisterGlobalFileDescriptor(fileDescriptorInfo.mId, fileDescriptorInfo.mFd.detachFd(), fileDescriptorInfo.mOffset, fileDescriptorInfo.mSize);
                                }
                                ChildProcessServiceImpl childProcessServiceImpl = ChildProcessServiceImpl.this;
                                ChildProcessServiceImpl.nativeInitChildProcessImpl(childProcessServiceImpl, childProcessServiceImpl.mCpuCount, ChildProcessServiceImpl.this.mCpuFeatures);
                                if (ChildProcessServiceImpl.this.mActivitySemaphore.tryAcquire()) {
                                    ContentMain.start();
                                    ChildProcessServiceImpl.nativeExitChildProcess();
                                    return;
                                }
                                return;
                            }
                            linker.disableSharedRelros();
                        }
                        z = false;
                        if (CommandLine.getInstance().hasSwitch(BaseSwitches.RENDERER_WAIT_FOR_JAVA_DEBUGGER)) {
                        }
                        LibraryLoader.get(ChildProcessServiceImpl.this.mLibraryProcessType).loadNow(context2);
                        z2 = true;
                        boolean z32 = false;
                        linker.disableSharedRelros();
                        LibraryLoader.get(ChildProcessServiceImpl.this.mLibraryProcessType).loadNow(context2);
                        z2 = true;
                    } catch (ProcessInitException e) {
                        Log.e(ChildProcessServiceImpl.TAG, "Failed to load native library on retry", e);
                    } catch (InterruptedException e2) {
                    }
                    if (!z2) {
                    }
                    LibraryLoader.get(ChildProcessServiceImpl.this.mLibraryProcessType).registerRendererProcessHistogram(z, z32);
                    LibraryLoader.get(ChildProcessServiceImpl.this.mLibraryProcessType).initialize();
                    synchronized (ChildProcessServiceImpl.this.mMainThread) {
                    }
                }
            }, MAIN_THREAD_NAME);
            this.mMainThread = thread;
            thread.start();
            return;
        }
        throw new RuntimeException("Illegal child process reuse.");
    }

    /* JADX WARNING: Exception block dominator not found, dom blocks: [] */
    /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x0030 */
    @SuppressFBWarnings({"DM_EXIT"})
    public void destroy() {
        Log.i(TAG, "Destroying ChildProcessService pid=%d", Integer.valueOf(Process.myPid()));
        if (this.mActivitySemaphore.tryAcquire()) {
            System.exit(0);
            return;
        }
        synchronized (this.mMainThread) {
            while (true) {
                if (!this.mLibraryInitialized) {
                    this.mMainThread.wait();
                }
            }
        }
        nativeShutdownMainThread();
    }

    public void getServiceInfo(Bundle bundle) {
        bundle.setClassLoader(this.mHostClassLoader);
        synchronized (this.mMainThread) {
            if (this.mCommandLineParams == null) {
                this.mCommandLineParams = bundle.getStringArray(ChildProcessConstants.EXTRA_COMMAND_LINE);
            }
            this.mCpuCount = bundle.getInt(ChildProcessConstants.EXTRA_CPU_COUNT);
            this.mCpuFeatures = bundle.getLong(ChildProcessConstants.EXTRA_CPU_FEATURES);
            Parcelable[] parcelableArray = bundle.getParcelableArray(ChildProcessConstants.EXTRA_FILES);
            if (parcelableArray != null) {
                FileDescriptorInfo[] fileDescriptorInfoArr = new FileDescriptorInfo[parcelableArray.length];
                this.mFdInfos = fileDescriptorInfoArr;
                System.arraycopy(parcelableArray, 0, fileDescriptorInfoArr, 0, parcelableArray.length);
            } else {
                ContentSwitches.getSwitchValue(this.mCommandLineParams, "type");
                this.mFdInfos = EMPTY_FILE_DESCRIPTOR_INFO;
            }
            Bundle bundle2 = bundle.getBundle(Linker.EXTRA_LINKER_SHARED_RELROS);
            if (bundle2 != null) {
                getLinker().useSharedRelros(bundle2);
            }
            this.mMainThread.notifyAll();
        }
    }

    public void initializeParams(Intent intent) {
        synchronized (this.mMainThread) {
            this.mCommandLineParams = intent.getStringArrayExtra(ChildProcessConstants.EXTRA_COMMAND_LINE);
            this.mLinkerParams = new ChromiumLinkerParams(intent);
            this.mLibraryProcessType = ChildProcessCreationParams.getLibraryProcessType(intent);
            this.mIsBound = true;
            this.mMainThread.notifyAll();
        }
    }
}
