package org.chromium.content.browser;

import android.annotation.TargetApi;
import android.content.ComponentCallbacks2;
import android.content.Context;
import android.content.res.Configuration;
import android.os.Build;
import android.os.Handler;
import android.util.LruCache;
import android.util.SparseArray;
import java.util.Map;
import org.chromium.base.Log;
import org.chromium.base.SysUtils;
import org.chromium.base.ThreadUtils;
import org.chromium.base.VisibleForTesting;

public class BindingManagerImpl implements BindingManager {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final long DETACH_AS_ACTIVE_HIGH_END_DELAY_MILLIS = 1000;
    private static final float MODERATE_BINDING_HIGH_REDUCE_RATIO = 0.5f;
    private static final float MODERATE_BINDING_LOW_REDUCE_RATIO = 0.25f;
    private static final long MODERATE_BINDING_POOL_CLEARER_DELAY_MILLIS = 10000;
    private static final String TAG = "cr.BindingManager";
    private ManagedConnection mBoundForBackgroundPeriod;
    private final boolean mIsLowMemoryDevice;
    private ManagedConnection mLastInForeground;
    private final Object mLastInForegroundLock = new Object();
    private final SparseArray<ManagedConnection> mManagedConnections = new SparseArray<>();
    private ModerateBindingPool mModerateBindingPool;
    private final Object mModerateBindingPoolLock = new Object();
    private boolean mModerateBindingTillBackgrounded;
    private final boolean mOnTesting;

    public class ManagedConnection {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        private boolean mBoundForBackgroundPeriod;
        private ChildProcessConnection mConnection;
        private boolean mInForeground;
        private boolean mWasOomProtected;

        public ManagedConnection(ChildProcessConnection childProcessConnection) {
            this.mConnection = childProcessConnection;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void addConnectionToModerateBindingPool(ChildProcessConnection childProcessConnection) {
            ModerateBindingPool moderateBindingPool;
            synchronized (BindingManagerImpl.this.mModerateBindingPoolLock) {
                moderateBindingPool = BindingManagerImpl.this.mModerateBindingPool;
            }
            if (moderateBindingPool != null && !childProcessConnection.isStrongBindingBound()) {
                moderateBindingPool.addConnection(this);
            }
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void addModerateBinding() {
            ChildProcessConnection childProcessConnection = this.mConnection;
            if (childProcessConnection != null) {
                childProcessConnection.addModerateBinding();
            }
        }

        private void addStrongBinding() {
            ModerateBindingPool moderateBindingPool;
            ChildProcessConnection childProcessConnection = this.mConnection;
            if (childProcessConnection != null) {
                childProcessConnection.addStrongBinding();
                synchronized (BindingManagerImpl.this.mModerateBindingPoolLock) {
                    moderateBindingPool = BindingManagerImpl.this.mModerateBindingPool;
                }
                if (moderateBindingPool != null) {
                    moderateBindingPool.removeConnection(this);
                }
            }
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void dropBindings() {
            ChildProcessConnection childProcessConnection = this.mConnection;
            if (childProcessConnection != null) {
                childProcessConnection.dropOomBindings();
            }
        }

        private boolean removeInitialBinding() {
            ChildProcessConnection childProcessConnection = this.mConnection;
            if (childProcessConnection == null || !childProcessConnection.isInitialBindingBound()) {
                return false;
            }
            this.mConnection.removeInitialBinding();
            return true;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void removeModerateBinding() {
            ChildProcessConnection childProcessConnection = this.mConnection;
            if (childProcessConnection != null && childProcessConnection.isModerateBindingBound()) {
                this.mConnection.removeModerateBinding();
            }
        }

        private void removeStrongBinding(final boolean z) {
            final ChildProcessConnection childProcessConnection = this.mConnection;
            if (childProcessConnection != null && childProcessConnection.isStrongBindingBound()) {
                AnonymousClass1 r1 = new Runnable() {
                    /* class org.chromium.content.browser.BindingManagerImpl.ManagedConnection.AnonymousClass1 */

                    public void run() {
                        if (childProcessConnection.isStrongBindingBound()) {
                            childProcessConnection.removeStrongBinding();
                            if (z) {
                                ManagedConnection.this.addConnectionToModerateBindingPool(childProcessConnection);
                            }
                        }
                    }
                };
                if (BindingManagerImpl.this.mIsLowMemoryDevice) {
                    r1.run();
                } else {
                    ThreadUtils.postOnUiThreadDelayed(r1, 1000);
                }
            }
        }

        public void clearConnection() {
            ModerateBindingPool moderateBindingPool;
            this.mWasOomProtected = this.mConnection.isOomProtectedOrWasWhenDied();
            synchronized (BindingManagerImpl.this.mModerateBindingPoolLock) {
                moderateBindingPool = BindingManagerImpl.this.mModerateBindingPool;
            }
            if (moderateBindingPool != null) {
                moderateBindingPool.removeConnection(this);
            }
            this.mConnection = null;
        }

        public void determinedVisibility() {
            if (removeInitialBinding() && BindingManagerImpl.this.mModerateBindingTillBackgrounded) {
                addConnectionToModerateBindingPool(this.mConnection);
            }
        }

        @VisibleForTesting
        public boolean isConnectionCleared() {
            return this.mConnection == null;
        }

        public boolean isOomProtected() {
            ChildProcessConnection childProcessConnection = this.mConnection;
            return childProcessConnection != null ? childProcessConnection.isOomProtectedOrWasWhenDied() : this.mWasOomProtected;
        }

        public void setBoundForBackgroundPeriod(boolean z) {
            boolean z2 = this.mBoundForBackgroundPeriod;
            if (!z2 && z) {
                addStrongBinding();
            } else if (z2 && !z) {
                removeStrongBinding(false);
            }
            this.mBoundForBackgroundPeriod = z;
        }

        public void setInForeground(boolean z) {
            boolean z2 = this.mInForeground;
            if (!z2 && z) {
                addStrongBinding();
            } else if (z2 && !z) {
                removeStrongBinding(true);
            }
            this.mInForeground = z;
        }
    }

    public static class ModerateBindingPool extends LruCache<Integer, ManagedConnection> implements ComponentCallbacks2 {
        private Runnable mDelayedClearer;
        private final Object mDelayedClearerLock = new Object();
        private final Handler mHandler = new Handler(ThreadUtils.getUiThreadLooper());

        public ModerateBindingPool(int i) {
            super(i);
        }

        @TargetApi(17)
        private void reduce(float f) {
            int size = size();
            int i = (int) ((1.0f - f) * ((float) size));
            int i2 = 0;
            Log.i(BindingManagerImpl.TAG, "Reduce connections from %d to %d", Integer.valueOf(size), Integer.valueOf(i));
            if (i == 0) {
                evictAll();
            } else if (Build.VERSION.SDK_INT >= 17) {
                trimToSize(i);
            } else {
                for (Map.Entry entry : snapshot().entrySet()) {
                    remove(entry.getKey());
                    i2++;
                    if (i2 == size - i) {
                        return;
                    }
                }
            }
        }

        public void addConnection(ManagedConnection managedConnection) {
            ChildProcessConnection childProcessConnection = managedConnection.mConnection;
            if (childProcessConnection != null && childProcessConnection.isInSandbox()) {
                managedConnection.addModerateBinding();
                if (childProcessConnection.isModerateBindingBound()) {
                    put(Integer.valueOf(childProcessConnection.getServiceNumber()), managedConnection);
                } else {
                    remove(Integer.valueOf(childProcessConnection.getServiceNumber()));
                }
            }
        }

        public void onBroughtToForeground() {
            synchronized (this.mDelayedClearerLock) {
                Runnable runnable = this.mDelayedClearer;
                if (runnable != null) {
                    this.mHandler.removeCallbacks(runnable);
                    this.mDelayedClearer = null;
                }
            }
        }

        public void onConfigurationChanged(Configuration configuration) {
        }

        public void onLowMemory() {
            Log.i(BindingManagerImpl.TAG, "onLowMemory: evict %d bindings", Integer.valueOf(size()));
            evictAll();
        }

        public void onSentToBackground(final boolean z) {
            if (size() != 0) {
                synchronized (this.mDelayedClearerLock) {
                    AnonymousClass1 r1 = new Runnable() {
                        /* class org.chromium.content.browser.BindingManagerImpl.ModerateBindingPool.AnonymousClass1 */

                        /* JADX WARNING: Code restructure failed: missing block: B:10:0x0031, code lost:
                            if (r5 != false) goto L_0x003e;
                         */
                        /* JADX WARNING: Code restructure failed: missing block: B:11:0x0033, code lost:
                            org.chromium.base.metrics.RecordHistogram.recordCountHistogram("Android.ModerateBindingCount", r5.this$0.size());
                         */
                        /* JADX WARNING: Code restructure failed: missing block: B:12:0x003e, code lost:
                            r5.this$0.evictAll();
                         */
                        /* JADX WARNING: Code restructure failed: missing block: B:13:0x0043, code lost:
                            return;
                         */
                        /* JADX WARNING: Code restructure failed: missing block: B:9:0x0018, code lost:
                            org.chromium.base.Log.i(org.chromium.content.browser.BindingManagerImpl.TAG, "Release moderate connections: %d", java.lang.Integer.valueOf(r5.this$0.size()));
                         */
                        public void run() {
                            synchronized (ModerateBindingPool.this.mDelayedClearerLock) {
                                if (ModerateBindingPool.this.mDelayedClearer != null) {
                                    ModerateBindingPool.this.mDelayedClearer = null;
                                }
                            }
                        }
                    };
                    this.mDelayedClearer = r1;
                    this.mHandler.postDelayed(r1, BindingManagerImpl.MODERATE_BINDING_POOL_CLEARER_DELAY_MILLIS);
                }
            }
        }

        public void onTrimMemory(int i) {
            Log.i(BindingManagerImpl.TAG, "onTrimMemory: level=%d, size=%d", Integer.valueOf(i), Integer.valueOf(size()));
            if (size() <= 0) {
                return;
            }
            if (i <= 5) {
                reduce(BindingManagerImpl.MODERATE_BINDING_LOW_REDUCE_RATIO);
            } else if (i <= 10) {
                reduce(0.5f);
            } else if (i != 20) {
                evictAll();
            }
        }

        public void removeConnection(ManagedConnection managedConnection) {
            ChildProcessConnection childProcessConnection = managedConnection.mConnection;
            if (childProcessConnection != null && childProcessConnection.isInSandbox()) {
                remove(Integer.valueOf(childProcessConnection.getServiceNumber()));
            }
        }

        public void entryRemoved(boolean z, Integer num, ManagedConnection managedConnection, ManagedConnection managedConnection2) {
            if (managedConnection != managedConnection2) {
                managedConnection.removeModerateBinding();
            }
        }
    }

    private BindingManagerImpl(boolean z, boolean z2) {
        this.mIsLowMemoryDevice = z;
        this.mOnTesting = z2;
    }

    public static BindingManagerImpl createBindingManager() {
        return new BindingManagerImpl(SysUtils.isLowEndDevice(), false);
    }

    public static BindingManagerImpl createBindingManagerForTesting(boolean z) {
        return new BindingManagerImpl(z, true);
    }

    @Override // org.chromium.content.browser.BindingManager
    public void addNewConnection(int i, ChildProcessConnection childProcessConnection) {
        synchronized (this.mManagedConnections) {
            this.mManagedConnections.put(i, new ManagedConnection(childProcessConnection));
        }
    }

    @Override // org.chromium.content.browser.BindingManager
    public void clearConnection(int i) {
        ManagedConnection managedConnection;
        synchronized (this.mManagedConnections) {
            managedConnection = this.mManagedConnections.get(i);
        }
        if (managedConnection != null) {
            managedConnection.clearConnection();
        }
    }

    @Override // org.chromium.content.browser.BindingManager
    public void determinedVisibility(int i) {
        ManagedConnection managedConnection;
        synchronized (this.mManagedConnections) {
            managedConnection = this.mManagedConnections.get(i);
        }
        if (managedConnection == null) {
            Log.w(TAG, "Cannot call determinedVisibility() - never saw a connection for the pid: %d", Integer.valueOf(i));
            return;
        }
        managedConnection.determinedVisibility();
    }

    @VisibleForTesting
    public boolean isConnectionCleared(int i) {
        boolean isConnectionCleared;
        synchronized (this.mManagedConnections) {
            isConnectionCleared = this.mManagedConnections.get(i).isConnectionCleared();
        }
        return isConnectionCleared;
    }

    @Override // org.chromium.content.browser.BindingManager
    public boolean isOomProtected(int i) {
        ManagedConnection managedConnection;
        synchronized (this.mManagedConnections) {
            managedConnection = this.mManagedConnections.get(i);
        }
        if (managedConnection != null) {
            return managedConnection.isOomProtected();
        }
        return false;
    }

    @Override // org.chromium.content.browser.BindingManager
    public void onBroughtToForeground() {
        ModerateBindingPool moderateBindingPool;
        ManagedConnection managedConnection = this.mBoundForBackgroundPeriod;
        if (managedConnection != null) {
            managedConnection.setBoundForBackgroundPeriod(false);
            this.mBoundForBackgroundPeriod = null;
        }
        synchronized (this.mModerateBindingPoolLock) {
            moderateBindingPool = this.mModerateBindingPool;
        }
        if (moderateBindingPool != null) {
            moderateBindingPool.onBroughtToForeground();
        }
    }

    @Override // org.chromium.content.browser.BindingManager
    public void onSentToBackground() {
        ModerateBindingPool moderateBindingPool;
        synchronized (this.mLastInForegroundLock) {
            ManagedConnection managedConnection = this.mLastInForeground;
            if (managedConnection != null) {
                managedConnection.setBoundForBackgroundPeriod(true);
                this.mBoundForBackgroundPeriod = this.mLastInForeground;
            }
        }
        synchronized (this.mModerateBindingPoolLock) {
            moderateBindingPool = this.mModerateBindingPool;
        }
        if (moderateBindingPool != null) {
            moderateBindingPool.onSentToBackground(this.mOnTesting);
        }
    }

    @Override // org.chromium.content.browser.BindingManager
    public void releaseAllModerateBindings() {
        ModerateBindingPool moderateBindingPool;
        synchronized (this.mModerateBindingPoolLock) {
            moderateBindingPool = this.mModerateBindingPool;
        }
        if (moderateBindingPool != null) {
            Log.i(TAG, "Release all moderate bindings: %d", Integer.valueOf(moderateBindingPool.size()));
            moderateBindingPool.evictAll();
        }
    }

    @Override // org.chromium.content.browser.BindingManager
    public void setInForeground(int i, boolean z) {
        ManagedConnection managedConnection;
        ManagedConnection managedConnection2;
        synchronized (this.mManagedConnections) {
            managedConnection = this.mManagedConnections.get(i);
        }
        if (managedConnection == null) {
            Log.w(TAG, "Cannot setInForeground() - never saw a connection for the pid: %d", Integer.valueOf(i));
            return;
        }
        synchronized (this.mLastInForegroundLock) {
            if (z) {
                if (!(!this.mIsLowMemoryDevice || (managedConnection2 = this.mLastInForeground) == null || managedConnection2 == managedConnection)) {
                    managedConnection2.dropBindings();
                }
            }
            managedConnection.setInForeground(z);
            if (z) {
                this.mLastInForeground = managedConnection;
            }
        }
    }

    @Override // org.chromium.content.browser.BindingManager
    public void startModerateBindingManagement(Context context, int i, boolean z) {
        synchronized (this.mModerateBindingPoolLock) {
            if (!this.mIsLowMemoryDevice) {
                if (this.mModerateBindingPool == null) {
                    this.mModerateBindingTillBackgrounded = z;
                    Log.i(TAG, "Moderate binding enabled: maxSize=%d", Integer.valueOf(i));
                    ModerateBindingPool moderateBindingPool = new ModerateBindingPool(i);
                    this.mModerateBindingPool = moderateBindingPool;
                    if (context != null) {
                        context.registerComponentCallbacks(moderateBindingPool);
                    }
                }
            }
        }
    }
}
