package org.chromium.content.browser;

import android.annotation.SuppressLint;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.graphics.SurfaceTexture;
import android.os.Bundle;
import android.os.ParcelFileDescriptor;
import android.os.RemoteException;
import android.text.TextUtils;
import android.util.Pair;
import android.view.Surface;
import androidx.base.b2;
import com.google.android.exoplayer2.source.rtsp.SessionDescription;
import java.io.IOException;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.Map;
import java.util.Queue;
import java.util.concurrent.ConcurrentHashMap;
import org.chromium.base.CommandLine;
import org.chromium.base.CpuFeatures;
import org.chromium.base.Log;
import org.chromium.base.ThreadUtils;
import org.chromium.base.TraceEvent;
import org.chromium.base.VisibleForTesting;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;
import org.chromium.base.library_loader.Linker;
import org.chromium.content.app.ChromiumLinkerParams;
import org.chromium.content.app.DownloadProcessService;
import org.chromium.content.app.PrivilegedProcessService;
import org.chromium.content.app.SandboxedProcessService;
import org.chromium.content.browser.ChildProcessConnection;
import org.chromium.content.common.ContentSwitches;
import org.chromium.content.common.IChildProcessCallback;
import org.chromium.content.common.SurfaceWrapper;

@JNINamespace("content")
public class ChildProcessLauncher {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final int CALLBACK_FOR_DOWNLOAD_PROCESS = 4;
    public static final int CALLBACK_FOR_GPU_PROCESS = 1;
    public static final int CALLBACK_FOR_RENDERER_PROCESS = 2;
    public static final int CALLBACK_FOR_UNKNOWN_PROCESS = 0;
    public static final int CALLBACK_FOR_UTILITY_PROCESS = 3;
    private static final long FREE_CONNECTION_DELAY_MILLIS = 1;
    private static final int NULL_PROCESS_HANDLE = 0;
    private static final String NUM_PRIVILEGED_SERVICES_KEY = "org.chromium.content.browser.NUM_PRIVILEGED_SERVICES";
    private static final String NUM_SANDBOXED_SERVICES_KEY = "org.chromium.content.browser.NUM_SANDBOXED_SERVICES";
    private static final String SANDBOXED_SERVICES_NAME_KEY = "org.chromium.content.browser.SANDBOXED_SERVICES_NAME";
    @VisibleForTesting
    public static final String SWITCH_NUM_SANDBOXED_SERVICES_FOR_TESTING = "num-sandboxed-services";
    public static final String SWITCH_SANDBOXED_SERVICES_NAME_FOR_TESTING = "sandboxed-services-name";
    private static final String TAG = "ChildProcLauncher";
    private static boolean sApplicationInForeground = true;
    private static BindingManager sBindingManager = BindingManagerImpl.createBindingManager();
    private static boolean sLinkerInitialized = false;
    private static long sLinkerLoadAddress;
    private static ChildConnectionAllocator sPrivilegedChildConnectionAllocator;
    private static Map<String, ChildConnectionAllocator> sSandboxedChildConnectionAllocatorMap;
    private static Map<Integer, ChildProcessConnection> sServiceMap = new ConcurrentHashMap();
    private static ChildProcessConnection sSpareSandboxedConnection = null;
    private static Map<Pair<Integer, Integer>, Surface> sSurfaceTextureSurfaceMap = new ConcurrentHashMap();
    private static Map<Integer, Surface> sViewSurfaceMap = new ConcurrentHashMap();

    public static class ChildConnectionAllocator {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        private final String mChildClassName;
        private final ChildProcessConnection[] mChildProcessConnections;
        private final Object mConnectionLock = new Object();
        private final ArrayList<Integer> mFreeConnectionIndices;
        private final boolean mInSandbox;
        private final PendingSpawnQueue mPendingSpawnQueue = new PendingSpawnQueue();

        public ChildConnectionAllocator(boolean z, int i, String str) {
            this.mChildProcessConnections = new ChildProcessConnectionImpl[i];
            this.mFreeConnectionIndices = new ArrayList<>(i);
            for (int i2 = 0; i2 < i; i2++) {
                this.mFreeConnectionIndices.add(Integer.valueOf(i2));
            }
            this.mChildClassName = str;
            this.mInSandbox = z;
        }

        public ChildProcessConnection allocate(Context context, ChildProcessConnection.DeathCallback deathCallback, ChromiumLinkerParams chromiumLinkerParams, boolean z, ChildProcessCreationParams childProcessCreationParams) {
            synchronized (this.mConnectionLock) {
                if (this.mFreeConnectionIndices.isEmpty()) {
                    Log.d(ChildProcessLauncher.TAG, "Ran out of services to allocate.");
                    return null;
                }
                int intValue = this.mFreeConnectionIndices.remove(0).intValue();
                this.mChildProcessConnections[intValue] = new ChildProcessConnectionImpl(context, intValue, this.mInSandbox, deathCallback, this.mChildClassName, chromiumLinkerParams, z, childProcessCreationParams);
                Log.d(ChildProcessLauncher.TAG, "Allocator allocated a connection, sandbox: %b, slot: %d", Boolean.valueOf(this.mInSandbox), Integer.valueOf(intValue));
                return this.mChildProcessConnections[intValue];
            }
        }

        @VisibleForTesting
        public int allocatedConnectionsCountForTesting() {
            return this.mChildProcessConnections.length - this.mFreeConnectionIndices.size();
        }

        public void free(ChildProcessConnection childProcessConnection) {
            synchronized (this.mConnectionLock) {
                int serviceNumber = childProcessConnection.getServiceNumber();
                ChildProcessConnection[] childProcessConnectionArr = this.mChildProcessConnections;
                if (childProcessConnectionArr[serviceNumber] != childProcessConnection) {
                    Log.e(ChildProcessLauncher.TAG, "Unable to find connection to free in slot: %d already occupied by service: %d", Integer.valueOf(serviceNumber), Integer.valueOf(childProcessConnectionArr[serviceNumber] == null ? -1 : childProcessConnectionArr[serviceNumber].getServiceNumber()));
                } else {
                    childProcessConnectionArr[serviceNumber] = null;
                    this.mFreeConnectionIndices.add(Integer.valueOf(serviceNumber));
                    Log.d(ChildProcessLauncher.TAG, "Allocator freed a connection, sandbox: %b, slot: %d", Boolean.valueOf(this.mInSandbox), Integer.valueOf(serviceNumber));
                }
            }
        }

        public PendingSpawnQueue getPendingSpawnQueue() {
            return this.mPendingSpawnQueue;
        }

        public boolean isFreeConnectionAvailable() {
            boolean z;
            synchronized (this.mConnectionLock) {
                z = !this.mFreeConnectionIndices.isEmpty();
            }
            return z;
        }
    }

    public static class PendingSpawnData {
        private final int mCallbackType;
        private final int mChildProcessId;
        private final long mClientContext;
        private final String[] mCommandLine;
        private final Context mContext;
        private final ChildProcessCreationParams mCreationParams;
        private final FileDescriptorInfo[] mFilesToBeMapped;
        private final boolean mInSandbox;

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private int callbackType() {
            return this.mCallbackType;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private int childProcessId() {
            return this.mChildProcessId;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private long clientContext() {
            return this.mClientContext;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private String[] commandLine() {
            return this.mCommandLine;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private Context context() {
            return this.mContext;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private FileDescriptorInfo[] filesToBeMapped() {
            return this.mFilesToBeMapped;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private ChildProcessCreationParams getCreationParams() {
            return this.mCreationParams;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private boolean inSandbox() {
            return this.mInSandbox;
        }

        private PendingSpawnData(Context context, String[] strArr, int i, FileDescriptorInfo[] fileDescriptorInfoArr, long j, int i2, boolean z, ChildProcessCreationParams childProcessCreationParams) {
            this.mContext = context;
            this.mCommandLine = strArr;
            this.mChildProcessId = i;
            this.mFilesToBeMapped = fileDescriptorInfoArr;
            this.mClientContext = j;
            this.mCallbackType = i2;
            this.mInSandbox = z;
            this.mCreationParams = childProcessCreationParams;
        }
    }

    public static class PendingSpawnQueue {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        private Queue<PendingSpawnData> mPendingSpawns;
        public final Object mPendingSpawnsLock;

        private PendingSpawnQueue() {
            this.mPendingSpawns = new LinkedList();
            this.mPendingSpawnsLock = new Object();
        }

        public PendingSpawnData dequeueLocked() {
            return this.mPendingSpawns.poll();
        }

        public void enqueueLocked(PendingSpawnData pendingSpawnData) {
            this.mPendingSpawns.add(pendingSpawnData);
        }

        public int sizeLocked() {
            return this.mPendingSpawns.size();
        }
    }

    private static ChildProcessConnection allocateBoundConnection(Context context, String[] strArr, boolean z, boolean z2, ChildProcessCreationParams childProcessCreationParams) {
        ChildProcessConnection allocateConnection = allocateConnection(context, z, getLinkerParamsForNewConnection(), z2, childProcessCreationParams);
        if (allocateConnection != null) {
            allocateConnection.start(strArr);
            String packageName = childProcessCreationParams != null ? childProcessCreationParams.getPackageName() : context.getPackageName();
            if (z && !getConnectionAllocator(packageName, z).isFreeConnectionAvailable()) {
                sBindingManager.releaseAllModerateBindings();
            }
        }
        return allocateConnection;
    }

    @VisibleForTesting
    public static ChildProcessConnection allocateBoundConnectionForTesting(Context context, ChildProcessCreationParams childProcessCreationParams) {
        return allocateBoundConnection(context, null, true, false, childProcessCreationParams);
    }

    private static ChildProcessConnection allocateConnection(Context context, boolean z, ChromiumLinkerParams chromiumLinkerParams, boolean z2, ChildProcessCreationParams childProcessCreationParams) {
        AnonymousClass1 r2 = new ChildProcessConnection.DeathCallback() {
            /* class org.chromium.content.browser.ChildProcessLauncher.AnonymousClass1 */

            @Override // org.chromium.content.browser.ChildProcessConnection.DeathCallback
            public void onChildProcessDied(ChildProcessConnection childProcessConnection) {
                if (childProcessConnection.getPid() != 0) {
                    ChildProcessLauncher.stop(childProcessConnection.getPid());
                } else {
                    ChildProcessLauncher.freeConnection(childProcessConnection);
                }
            }
        };
        String packageName = childProcessCreationParams != null ? childProcessCreationParams.getPackageName() : context.getPackageName();
        initConnectionAllocatorsIfNecessary(context, z, packageName);
        return getConnectionAllocator(packageName, z).allocate(context, r2, chromiumLinkerParams, z2, childProcessCreationParams);
    }

    @VisibleForTesting
    public static ChildProcessConnection allocateConnectionForTesting(Context context, ChildProcessCreationParams childProcessCreationParams) {
        return allocateConnection(context, true, getLinkerParamsForNewConnection(), false, childProcessCreationParams);
    }

    @VisibleForTesting
    public static int allocatedSandboxedConnectionsCountForTesting(Context context, String str) {
        initConnectionAllocatorsIfNecessary(context, true, str);
        return sSandboxedChildConnectionAllocatorMap.get(str).allocatedConnectionsCountForTesting();
    }

    @VisibleForTesting
    public static int connectedServicesCountForTesting() {
        return sServiceMap.size();
    }

    @VisibleForTesting
    public static boolean crashProcessForTesting(int i) {
        if (sServiceMap.get(Integer.valueOf(i)) == null) {
            return false;
        }
        try {
            ((ChildProcessConnectionImpl) sServiceMap.get(Integer.valueOf(i))).crashServiceForTesting();
            return true;
        } catch (RemoteException unused) {
            return false;
        }
    }

    private static IChildProcessCallback createCallback(final int i, final int i2) {
        return new IChildProcessCallback.Stub() {
            /* class org.chromium.content.browser.ChildProcessLauncher.AnonymousClass4 */

            @Override // org.chromium.content.common.IChildProcessCallback
            public void establishSurfacePeer(int i, Surface surface, int i2, int i3) {
                if (i2 != 1) {
                    Log.e(ChildProcessLauncher.TAG, "Illegal callback for non-GPU process.", new Object[0]);
                } else {
                    ChildProcessLauncher.nativeEstablishSurfacePeer(i, surface, i2, i3);
                }
            }

            @Override // org.chromium.content.common.IChildProcessCallback
            public SurfaceWrapper getSurfaceTextureSurface(int i) {
                if (i2 == 2) {
                    return ChildProcessLauncher.getSurfaceTextureSurface(i, i);
                }
                Log.e(ChildProcessLauncher.TAG, "Illegal callback for non-renderer process.", new Object[0]);
                return null;
            }

            @Override // org.chromium.content.common.IChildProcessCallback
            public SurfaceWrapper getViewSurface(int i) {
                if (i2 != 1) {
                    Log.e(ChildProcessLauncher.TAG, "Illegal callback for non-GPU process.", new Object[0]);
                    return null;
                }
                Surface viewSurface = ChildProcessLauncher.getViewSurface(i);
                if (viewSurface == null) {
                    return null;
                }
                return new SurfaceWrapper(viewSurface);
            }

            @Override // org.chromium.content.common.IChildProcessCallback
            public void onDownloadStarted(boolean z, int i) {
                if (i2 != 4) {
                    Log.e(ChildProcessLauncher.TAG, "Illegal callback for non-download process.", new Object[0]);
                }
            }

            @Override // org.chromium.content.common.IChildProcessCallback
            public void registerSurfaceTextureSurface(int i, int i2, Surface surface) {
                if (i2 != 1) {
                    Log.e(ChildProcessLauncher.TAG, "Illegal callback for non-GPU process.", new Object[0]);
                } else {
                    ChildProcessLauncher.registerSurfaceTextureSurface(i, i2, surface);
                }
            }

            @Override // org.chromium.content.common.IChildProcessCallback
            public void unregisterSurfaceTextureSurface(int i, int i2) {
                if (i2 != 1) {
                    Log.e(ChildProcessLauncher.TAG, "Illegal callback for non-GPU process.", new Object[0]);
                } else {
                    ChildProcessLauncher.unregisterSurfaceTextureSurface(i, i2);
                }
            }
        };
    }

    @CalledByNative
    private static void createSurfaceTextureSurface(int i, int i2, SurfaceTexture surfaceTexture) {
        registerSurfaceTextureSurface(i, i2, new Surface(surfaceTexture));
    }

    public static Bundle createsServiceBundle(String[] strArr, FileDescriptorInfo[] fileDescriptorInfoArr, Bundle bundle) {
        Bundle bundle2 = new Bundle();
        bundle2.putStringArray(ChildProcessConstants.EXTRA_COMMAND_LINE, strArr);
        bundle2.putParcelableArray(ChildProcessConstants.EXTRA_FILES, fileDescriptorInfoArr);
        bundle2.putInt(ChildProcessConstants.EXTRA_CPU_COUNT, CpuFeatures.getCount());
        bundle2.putLong(ChildProcessConstants.EXTRA_CPU_FEATURES, CpuFeatures.getMask());
        bundle2.putBundle(Linker.EXTRA_LINKER_SHARED_RELROS, bundle);
        return bundle2;
    }

    @CalledByNative
    private static void destroySurfaceTextureSurface(int i, int i2) {
        unregisterSurfaceTextureSurface(i, i2);
    }

    public static void determinedVisibility(int i) {
        sBindingManager.determinedVisibility(i);
    }

    @VisibleForTesting
    public static void enqueuePendingSpawnForTesting(Context context, String[] strArr, ChildProcessCreationParams childProcessCreationParams, boolean z) {
        PendingSpawnQueue pendingSpawnQueue = getPendingSpawnQueue(context, childProcessCreationParams != null ? childProcessCreationParams.getPackageName() : context.getPackageName(), z);
        synchronized (pendingSpawnQueue.mPendingSpawnsLock) {
            pendingSpawnQueue.enqueueLocked(new PendingSpawnData(context, strArr, 1, new FileDescriptorInfo[0], 0, 2, true, childProcessCreationParams));
        }
    }

    /* access modifiers changed from: private */
    public static void freeConnection(final ChildProcessConnection childProcessConnection) {
        synchronized (ChildProcessLauncher.class) {
            if (childProcessConnection.equals(sSpareSandboxedConnection)) {
                sSpareSandboxedConnection = null;
            }
        }
        ThreadUtils.postOnUiThreadDelayed(new Runnable() {
            /* class org.chromium.content.browser.ChildProcessLauncher.AnonymousClass2 */

            public void run() {
                final PendingSpawnData freeConnectionAndDequeuePending = ChildProcessLauncher.freeConnectionAndDequeuePending(childProcessConnection);
                if (freeConnectionAndDequeuePending != null) {
                    new Thread(new Runnable() {
                        /* class org.chromium.content.browser.ChildProcessLauncher.AnonymousClass2.AnonymousClass1 */

                        public void run() {
                            ChildProcessLauncher.startInternal(freeConnectionAndDequeuePending.context(), freeConnectionAndDequeuePending.commandLine(), freeConnectionAndDequeuePending.childProcessId(), freeConnectionAndDequeuePending.filesToBeMapped(), freeConnectionAndDequeuePending.clientContext(), freeConnectionAndDequeuePending.callbackType(), freeConnectionAndDequeuePending.inSandbox(), freeConnectionAndDequeuePending.getCreationParams());
                        }
                    }).start();
                }
            }
        }, 1);
    }

    /* access modifiers changed from: private */
    public static PendingSpawnData freeConnectionAndDequeuePending(ChildProcessConnection childProcessConnection) {
        PendingSpawnData dequeueLocked;
        ChildConnectionAllocator connectionAllocator = getConnectionAllocator(childProcessConnection.getPackageName(), childProcessConnection.isInSandbox());
        PendingSpawnQueue pendingSpawnQueue = connectionAllocator.getPendingSpawnQueue();
        synchronized (pendingSpawnQueue.mPendingSpawnsLock) {
            connectionAllocator.free(childProcessConnection);
            dequeueLocked = pendingSpawnQueue.dequeueLocked();
        }
        return dequeueLocked;
    }

    private static String getClassNameOfService(Context context, boolean z, String str) {
        if (!z) {
            return PrivilegedProcessService.class.getName();
        }
        if (CommandLine.getInstance().hasSwitch(SWITCH_SANDBOXED_SERVICES_NAME_FOR_TESTING)) {
            return CommandLine.getInstance().getSwitchValue(SWITCH_SANDBOXED_SERVICES_NAME_FOR_TESTING);
        }
        String str2 = null;
        try {
            Bundle bundle = context.getPackageManager().getApplicationInfo(str, 128).metaData;
            if (bundle != null) {
                str2 = bundle.getString(SANDBOXED_SERVICES_NAME_KEY);
            }
            if (str2 == null) {
                return SandboxedProcessService.class.getName();
            }
            try {
                PackageManager packageManager = context.getPackageManager();
                packageManager.getServiceInfo(new ComponentName(str, str2 + SessionDescription.SUPPORTED_SDP_VERSION), 0);
                return str2;
            } catch (PackageManager.NameNotFoundException unused) {
                throw new RuntimeException("Illegal meta data value: the child service doesn't exist");
            }
        } catch (PackageManager.NameNotFoundException unused2) {
            throw new RuntimeException("Could not get application info.");
        }
    }

    private static ChildConnectionAllocator getConnectionAllocator(String str, boolean z) {
        if (!z) {
            return sPrivilegedChildConnectionAllocator;
        }
        return sSandboxedChildConnectionAllocatorMap.get(str);
    }

    private static ChromiumLinkerParams getLinkerParamsForNewConnection() {
        if (!sLinkerInitialized) {
            if (Linker.isUsed()) {
                long baseLoadAddress = Linker.getInstance().getBaseLoadAddress();
                sLinkerLoadAddress = baseLoadAddress;
                if (baseLoadAddress == 0) {
                    Log.i(TAG, "Shared RELRO support disabled!", new Object[0]);
                }
            }
            sLinkerInitialized = true;
        }
        if (sLinkerLoadAddress == 0) {
            return null;
        }
        if (!Linker.areTestsEnabled()) {
            return new ChromiumLinkerParams(sLinkerLoadAddress, true);
        }
        Linker instance = Linker.getInstance();
        return new ChromiumLinkerParams(sLinkerLoadAddress, true, instance.getTestRunnerClassNameForTesting(), instance.getImplementationForTesting());
    }

    private static int getNumberOfServices(Context context, boolean z, String str) {
        int i = -1;
        if (!z || !CommandLine.getInstance().hasSwitch(SWITCH_NUM_SANDBOXED_SERVICES_FOR_TESTING)) {
            try {
                Bundle bundle = context.getPackageManager().getApplicationInfo(str, 128).metaData;
                if (bundle != null) {
                    i = bundle.getInt(z ? NUM_SANDBOXED_SERVICES_KEY : NUM_PRIVILEGED_SERVICES_KEY, -1);
                }
            } catch (PackageManager.NameNotFoundException unused) {
                throw new RuntimeException("Could not get application info");
            }
        } else {
            String switchValue = CommandLine.getInstance().getSwitchValue(SWITCH_NUM_SANDBOXED_SERVICES_FOR_TESTING);
            if (!TextUtils.isEmpty(switchValue)) {
                try {
                    i = Integer.parseInt(switchValue);
                } catch (NumberFormatException unused2) {
                    Log.w(TAG, b2.c("The value of --num-sandboxed-services is formatted wrongly: ", switchValue), new Object[0]);
                }
            }
        }
        if (i >= 0) {
            return i;
        }
        throw new RuntimeException("Illegal meta data value for number of child services");
    }

    private static PendingSpawnQueue getPendingSpawnQueue(Context context, String str, boolean z) {
        initConnectionAllocatorsIfNecessary(context, z, str);
        return getConnectionAllocator(str, z).getPendingSpawnQueue();
    }

    /* access modifiers changed from: private */
    @CalledByNative
    public static SurfaceWrapper getSurfaceTextureSurface(int i, int i2) {
        Surface surface = sSurfaceTextureSurfaceMap.get(new Pair(Integer.valueOf(i), Integer.valueOf(i2)));
        if (surface != null) {
            return new SurfaceWrapper(surface);
        }
        Log.e(TAG, "Invalid Id for surface texture.", new Object[0]);
        return null;
    }

    /* access modifiers changed from: private */
    @CalledByNative
    public static Surface getViewSurface(int i) {
        Surface surface = sViewSurfaceMap.get(Integer.valueOf(i));
        if (surface == null) {
            Log.e(TAG, "Invalid surfaceId.", new Object[0]);
            return null;
        } else if (surface.isValid()) {
            return surface;
        } else {
            Log.e(TAG, "Requested surface is not valid.", new Object[0]);
            return null;
        }
    }

    private static void initConnectionAllocatorsIfNecessary(Context context, boolean z, String str) {
        synchronized (ChildProcessLauncher.class) {
            if (z) {
                if (sSandboxedChildConnectionAllocatorMap == null) {
                    sSandboxedChildConnectionAllocatorMap = new ConcurrentHashMap();
                }
                if (!sSandboxedChildConnectionAllocatorMap.containsKey(str)) {
                    Log.w(TAG, "Create a new ChildConnectionAllocator with package name = %s, inSandbox = true", str);
                    sSandboxedChildConnectionAllocatorMap.put(str, new ChildConnectionAllocator(true, getNumberOfServices(context, true, str), getClassNameOfService(context, true, str)));
                }
            } else if (sPrivilegedChildConnectionAllocator == null) {
                sPrivilegedChildConnectionAllocator = new ChildConnectionAllocator(false, getNumberOfServices(context, false, str), getClassNameOfService(context, false, str));
            }
        }
    }

    public static boolean isApplicationInForeground() {
        return sApplicationInForeground;
    }

    @CalledByNative
    private static boolean isOomProtected(int i) {
        return sBindingManager.isOomProtected(i);
    }

    public static void logPidWarning(int i, String str) {
        if (i > 0 && !nativeIsSingleProcess()) {
            Log.w(TAG, "%s, pid=%d", str, Integer.valueOf(i));
        }
    }

    @CalledByNative
    private static FileDescriptorInfo makeFdInfo(int i, int i2, boolean z, long j, long j2) {
        ParcelFileDescriptor fromFd;
        if (z) {
            fromFd = ParcelFileDescriptor.adoptFd(i2);
        } else {
            try {
                fromFd = ParcelFileDescriptor.fromFd(i2);
            } catch (IOException e) {
                Log.e(TAG, "Invalid FD provided for process connection, aborting connection.", e);
                return null;
            }
        }
        return new FileDescriptorInfo(i, fromFd, j, j2);
    }

    /* access modifiers changed from: private */
    public static native void nativeEstablishSurfacePeer(int i, Surface surface, int i2, int i3);

    private static native boolean nativeIsSingleProcess();

    /* access modifiers changed from: private */
    public static native void nativeOnChildProcessStarted(long j, int i);

    public static void onBroughtToForeground() {
        sApplicationInForeground = true;
        sBindingManager.onBroughtToForeground();
    }

    public static void onSentToBackground() {
        sApplicationInForeground = false;
        sBindingManager.onSentToBackground();
    }

    @VisibleForTesting
    public static int pendingSpawnsCountForTesting(Context context, String str, boolean z) {
        int sizeLocked;
        PendingSpawnQueue pendingSpawnQueue = getPendingSpawnQueue(context, str, z);
        synchronized (pendingSpawnQueue.mPendingSpawnsLock) {
            sizeLocked = pendingSpawnQueue.sizeLocked();
        }
        return sizeLocked;
    }

    /* access modifiers changed from: private */
    public static void registerSurfaceTextureSurface(int i, int i2, Surface surface) {
        sSurfaceTextureSurfaceMap.put(new Pair<>(Integer.valueOf(i), Integer.valueOf(i2)), surface);
    }

    @CalledByNative
    private static void registerViewSurface(int i, Surface surface) {
        if (surface.isValid()) {
            sViewSurfaceMap.put(Integer.valueOf(i), surface);
            return;
        }
        throw new RuntimeException("Attempting to register invalid Surface.");
    }

    @VisibleForTesting
    public static void setBindingManagerForTesting(BindingManager bindingManager) {
        sBindingManager = bindingManager;
    }

    @CalledByNative
    public static void setInForeground(int i, boolean z) {
        sBindingManager.setInForeground(i, z);
    }

    @CalledByNative
    private static void start(Context context, String[] strArr, int i, FileDescriptorInfo[] fileDescriptorInfoArr, long j) {
        ChildProcessCreationParams childProcessCreationParams;
        boolean z;
        int i2;
        String switchValue = ContentSwitches.getSwitchValue(strArr, "type");
        ChildProcessCreationParams childProcessCreationParams2 = ChildProcessCreationParams.get();
        if (childProcessCreationParams2 != null) {
            childProcessCreationParams2 = childProcessCreationParams2.copy();
        }
        if (ContentSwitches.SWITCH_RENDERER_PROCESS.equals(switchValue)) {
            childProcessCreationParams = childProcessCreationParams2;
            i2 = 2;
        } else {
            if (childProcessCreationParams2 != null && !childProcessCreationParams2.getPackageName().equals(context.getPackageName())) {
                childProcessCreationParams2 = new ChildProcessCreationParams(context.getPackageName(), childProcessCreationParams2.getExtraBindFlags(), childProcessCreationParams2.getLibraryProcessType());
            }
            if (ContentSwitches.SWITCH_GPU_PROCESS.equals(switchValue)) {
                childProcessCreationParams = childProcessCreationParams2;
                i2 = 1;
                z = false;
                startInternal(context, strArr, i, fileDescriptorInfoArr, j, i2, z, childProcessCreationParams);
            } else if (ContentSwitches.SWITCH_UTILITY_PROCESS.equals(switchValue)) {
                childProcessCreationParams = childProcessCreationParams2;
                i2 = 3;
            } else {
                childProcessCreationParams = childProcessCreationParams2;
                i2 = 0;
            }
        }
        z = true;
        startInternal(context, strArr, i, fileDescriptorInfoArr, j, i2, z, childProcessCreationParams);
    }

    @SuppressLint({"NewApi"})
    @CalledByNative
    private static void startDownloadProcessIfNecessary(Context context, String[] strArr) {
        ContentSwitches.getSwitchValue(strArr, "type");
        Intent intent = new Intent();
        intent.setClass(context, DownloadProcessService.class);
        intent.setPackage(context.getPackageName());
        intent.putExtra(ChildProcessConstants.EXTRA_COMMAND_LINE, strArr);
        Bundle createsServiceBundle = createsServiceBundle(strArr, null, Linker.getInstance().getSharedRelros());
        createsServiceBundle.putBinder(ChildProcessConstants.EXTRA_CHILD_PROCESS_CALLBACK, createCallback(0, 4).asBinder());
        intent.putExtras(createsServiceBundle);
        ChromiumLinkerParams linkerParamsForNewConnection = getLinkerParamsForNewConnection();
        if (linkerParamsForNewConnection != null) {
            linkerParamsForNewConnection.addIntentExtras(intent);
        }
        context.startService(intent);
    }

    /* access modifiers changed from: private */
    public static void startInternal(Context context, String[] strArr, int i, FileDescriptorInfo[] fileDescriptorInfoArr, long j, int i2, boolean z, ChildProcessCreationParams childProcessCreationParams) {
        ChildProcessConnection childProcessConnection;
        try {
            TraceEvent.begin("ChildProcessLauncher.startInternal");
            String packageName = childProcessCreationParams != null ? childProcessCreationParams.getPackageName() : context.getPackageName();
            synchronized (ChildProcessLauncher.class) {
                childProcessConnection = null;
                if (z) {
                    ChildProcessConnection childProcessConnection2 = sSpareSandboxedConnection;
                    if (childProcessConnection2 != null && childProcessConnection2.getPackageName().equals(packageName)) {
                        ChildProcessConnection childProcessConnection3 = sSpareSandboxedConnection;
                        sSpareSandboxedConnection = null;
                        childProcessConnection = childProcessConnection3;
                    }
                }
            }
            if (childProcessConnection == null) {
                boolean z2 = false;
                if (i2 == 1) {
                    z2 = true;
                }
                PendingSpawnQueue pendingSpawnQueue = getPendingSpawnQueue(context, packageName, z);
                synchronized (pendingSpawnQueue.mPendingSpawnsLock) {
                    childProcessConnection = allocateBoundConnection(context, strArr, z, z2, childProcessCreationParams);
                    if (childProcessConnection == null) {
                        Log.d(TAG, "Allocation of new service failed. Queuing up pending spawn.");
                        pendingSpawnQueue.enqueueLocked(new PendingSpawnData(context, strArr, i, fileDescriptorInfoArr, j, i2, z, childProcessCreationParams));
                        return;
                    }
                }
            }
            Log.d(TAG, "Setting up connection to process: slot=%d", Integer.valueOf(childProcessConnection.getServiceNumber()));
            triggerConnectionSetup(childProcessConnection, strArr, i, fileDescriptorInfoArr, i2, j);
            TraceEvent.end("ChildProcessLauncher.startInternal");
        } finally {
            TraceEvent.end("ChildProcessLauncher.startInternal");
        }
    }

    public static void startModerateBindingManagement(Context context, boolean z) {
        sBindingManager.startModerateBindingManagement(context, getNumberOfServices(context, true, context.getPackageName()), z);
    }

    @CalledByNative
    public static void stop(int i) {
        Log.d(TAG, "stopping child connection: pid=%d", Integer.valueOf(i));
        ChildProcessConnection remove = sServiceMap.remove(Integer.valueOf(i));
        if (remove == null) {
            logPidWarning(i, "Tried to stop non-existent connection");
            return;
        }
        sBindingManager.clearConnection(i);
        remove.stop();
        freeConnection(remove);
    }

    @VisibleForTesting
    public static void triggerConnectionSetup(final ChildProcessConnection childProcessConnection, String[] strArr, int i, FileDescriptorInfo[] fileDescriptorInfoArr, final int i2, final long j) {
        childProcessConnection.setupConnection(strArr, fileDescriptorInfoArr, createCallback(i, i2), new ChildProcessConnection.ConnectionCallback() {
            /* class org.chromium.content.browser.ChildProcessLauncher.AnonymousClass3 */

            @Override // org.chromium.content.browser.ChildProcessConnection.ConnectionCallback
            public void onConnected(int i) {
                Log.d(ChildProcessLauncher.TAG, "on connect callback, pid=%d context=%d callbackType=%d", Integer.valueOf(i), Long.valueOf(j), Integer.valueOf(i2));
                if (i != 0) {
                    ChildProcessLauncher.sBindingManager.addNewConnection(i, childProcessConnection);
                    ChildProcessLauncher.sServiceMap.put(Integer.valueOf(i), childProcessConnection);
                }
                long j = j;
                if (j != 0) {
                    ChildProcessLauncher.nativeOnChildProcessStarted(j, i);
                }
            }
        }, Linker.getInstance().getSharedRelros());
    }

    /* access modifiers changed from: private */
    public static void unregisterSurfaceTextureSurface(int i, int i2) {
        Surface remove = sSurfaceTextureSurfaceMap.remove(new Pair(Integer.valueOf(i), Integer.valueOf(i2)));
        if (remove != null) {
            remove.release();
        }
    }

    @CalledByNative
    private static void unregisterViewSurface(int i) {
        sViewSurfaceMap.remove(Integer.valueOf(i));
    }

    public static void warmUp(Context context) {
        synchronized (ChildProcessLauncher.class) {
            if (sSpareSandboxedConnection == null) {
                ChildProcessCreationParams childProcessCreationParams = ChildProcessCreationParams.get();
                if (childProcessCreationParams != null) {
                    childProcessCreationParams = childProcessCreationParams.copy();
                }
                sSpareSandboxedConnection = allocateBoundConnection(context, null, true, false, childProcessCreationParams);
            }
        }
    }
}
