package org.chromium.content.browser;

import android.content.Context;
import android.location.Criteria;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.os.Bundle;
import java.util.List;
import org.chromium.base.Log;
import org.chromium.base.ThreadUtils;
import org.chromium.base.VisibleForTesting;

public class LocationProviderFactory {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static LocationProvider sProviderImpl;

    public interface LocationProvider {
        boolean isRunning();

        void start(boolean z);

        void stop();
    }

    public static class LocationProviderImpl implements LocationListener, LocationProvider {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        private static final String TAG = "cr.LocationProvider";
        private Context mContext;
        private boolean mIsRunning;
        private LocationManager mLocationManager;

        public LocationProviderImpl(Context context) {
            this.mContext = context;
        }

        private void ensureLocationManagerCreated() {
            if (this.mLocationManager == null) {
                LocationManager locationManager = (LocationManager) this.mContext.getSystemService("location");
                this.mLocationManager = locationManager;
                if (locationManager == null) {
                    Log.e(TAG, "Could not get location manager.", new Object[0]);
                }
            }
        }

        private boolean isOnlyPassiveLocationProviderEnabled() {
            List<String> providers = this.mLocationManager.getProviders(true);
            if (providers == null || providers.size() != 1 || !providers.get(0).equals("passive")) {
                return false;
            }
            return true;
        }

        private void registerForLocationUpdates(boolean z) {
            ensureLocationManagerCreated();
            if (!usePassiveOneShotLocation()) {
                this.mIsRunning = true;
                try {
                    Criteria criteria = new Criteria();
                    if (z) {
                        criteria.setAccuracy(1);
                    }
                    this.mLocationManager.requestLocationUpdates(0, 0.0f, criteria, this, ThreadUtils.getUiThreadLooper());
                } catch (SecurityException unused) {
                    Log.e(TAG, "Caught security exception while registering for location updates from the system. The application does not have sufficient geolocation permissions.", new Object[0]);
                    unregisterFromLocationUpdates();
                    LocationProviderAdapter.newErrorAvailable("application does not have sufficient geolocation permissions.");
                } catch (IllegalArgumentException unused2) {
                    Log.e(TAG, "Caught IllegalArgumentException registering for location updates.", new Object[0]);
                    unregisterFromLocationUpdates();
                }
            }
        }

        private void unregisterFromLocationUpdates() {
            if (this.mIsRunning) {
                this.mIsRunning = false;
                this.mLocationManager.removeUpdates(this);
            }
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void updateNewLocation(Location location) {
            double latitude = location.getLatitude();
            double longitude = location.getLongitude();
            double time = (double) location.getTime();
            Double.isNaN(time);
            LocationProviderAdapter.newLocationAvailable(latitude, longitude, time / 1000.0d, location.hasAltitude(), location.getAltitude(), location.hasAccuracy(), (double) location.getAccuracy(), location.hasBearing(), (double) location.getBearing(), location.hasSpeed(), (double) location.getSpeed());
        }

        private boolean usePassiveOneShotLocation() {
            if (!isOnlyPassiveLocationProviderEnabled()) {
                return false;
            }
            final Location lastKnownLocation = this.mLocationManager.getLastKnownLocation("passive");
            if (lastKnownLocation == null) {
                return true;
            }
            ThreadUtils.runOnUiThread(new Runnable() {
                /* class org.chromium.content.browser.LocationProviderFactory.LocationProviderImpl.AnonymousClass1 */

                public void run() {
                    LocationProviderImpl.this.updateNewLocation(lastKnownLocation);
                }
            });
            return true;
        }

        @Override // org.chromium.content.browser.LocationProviderFactory.LocationProvider
        public boolean isRunning() {
            return this.mIsRunning;
        }

        public void onLocationChanged(Location location) {
            if (this.mIsRunning) {
                updateNewLocation(location);
            }
        }

        public void onProviderDisabled(String str) {
        }

        public void onProviderEnabled(String str) {
        }

        public void onStatusChanged(String str, int i, Bundle bundle) {
        }

        @Override // org.chromium.content.browser.LocationProviderFactory.LocationProvider
        public void start(boolean z) {
            unregisterFromLocationUpdates();
            registerForLocationUpdates(z);
        }

        @Override // org.chromium.content.browser.LocationProviderFactory.LocationProvider
        public void stop() {
            unregisterFromLocationUpdates();
        }
    }

    private LocationProviderFactory() {
    }

    public static LocationProvider get(Context context) {
        if (sProviderImpl == null) {
            sProviderImpl = new LocationProviderImpl(context);
        }
        return sProviderImpl;
    }

    @VisibleForTesting
    public static void setLocationProviderImpl(LocationProvider locationProvider) {
        sProviderImpl = locationProvider;
    }
}
