package org.chromium.content.browser;

import android.content.Context;
import android.media.MediaPlayer;
import android.os.AsyncTask;
import android.os.Handler;
import android.os.Looper;
import android.os.SystemClock;
import com.google.android.exoplayer2.DefaultRenderersFactory;
import org.chromium.base.Log;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;
import org.chromium.base.metrics.RecordHistogram;
import org.chromium.content.R;

@JNINamespace("content")
public class MediaThrottler implements MediaPlayer.OnErrorListener {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final int RELEASE_WATCH_DOG_PLAYER_DELAY_IN_MILLIS = 5000;
    private static final int SERVER_CRASH_COUNT_THRESHOLD_FOR_THROTTLING = 4;
    private static final long SERVER_CRASH_INTERVAL_THRESHOLD_IN_MILLIS = 60000;
    private static final String TAG = "cr_MediaThrottler";
    private static final long UNKNOWN_LAST_SERVER_CRASH_TIME = -1;
    private final Context mContext;
    private final Runnable mDelayedReleaseRunnable = new Runnable() {
        /* class org.chromium.content.browser.MediaThrottler.AnonymousClass1 */

        public void run() {
            new ReleaseWatchDogTask().execute(new Void[0]);
        }
    };
    private Handler mHandler;
    private long mLastCrashTime = -1;
    private final Object mLock = new Object();
    private MediaPlayer mPlayer;
    private int mRequestCount;
    private int mServerCrashCount;

    public class ReleaseWatchDogTask extends AsyncTask<Void, Void, Void> {
        private ReleaseWatchDogTask() {
        }

        public Void doInBackground(Void... voidArr) {
            synchronized (MediaThrottler.this.mLock) {
                if (MediaThrottler.this.mRequestCount == 0 && MediaThrottler.this.mPlayer != null) {
                    MediaThrottler.this.mPlayer.release();
                    MediaThrottler.this.mPlayer = null;
                }
            }
            return null;
        }
    }

    public class StartWatchDogTask extends AsyncTask<Void, Void, Void> {
        private StartWatchDogTask() {
        }

        public Void doInBackground(Void... voidArr) {
            synchronized (MediaThrottler.this.mLock) {
                if (MediaThrottler.this.mPlayer != null || MediaThrottler.this.mRequestCount == 0) {
                    return null;
                }
                try {
                    MediaThrottler mediaThrottler = MediaThrottler.this;
                    mediaThrottler.mPlayer = MediaPlayer.create(mediaThrottler.mContext, R.raw.empty);
                } catch (IllegalStateException e) {
                    Log.e(MediaThrottler.TAG, "Exception happens while creating the watch dog player.", e);
                } catch (RuntimeException e2) {
                    Log.e(MediaThrottler.TAG, "Exception happens while creating the watch dog player.", e2);
                }
                if (MediaThrottler.this.mPlayer == null) {
                    Log.e(MediaThrottler.TAG, "Unable to create watch dog player, treat it as server crash.", new Object[0]);
                    MediaThrottler.this.onMediaServerCrash();
                } else {
                    MediaThrottler.this.mPlayer.setOnErrorListener(MediaThrottler.this);
                }
                return null;
            }
        }
    }

    private MediaThrottler(Context context) {
        this.mContext = context;
        this.mHandler = new Handler(Looper.getMainLooper());
    }

    @CalledByNative
    private static MediaThrottler create(Context context) {
        return new MediaThrottler(context);
    }

    @CalledByNative
    private void onDecodeRequestFinished() {
        synchronized (this.mLock) {
            int i = this.mRequestCount - 1;
            this.mRequestCount = i;
            if (i == 0) {
                prepareToStopWatchDog();
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onMediaServerCrash() {
        long elapsedRealtime = SystemClock.elapsedRealtime();
        long j = this.mLastCrashTime;
        if (j == -1 || elapsedRealtime - j >= 60000) {
            recordNumMediaServerCrashes();
            this.mServerCrashCount = 1;
        } else {
            this.mServerCrashCount++;
        }
        this.mLastCrashTime = elapsedRealtime;
    }

    private void prepareToStopWatchDog() {
        this.mHandler.postDelayed(this.mDelayedReleaseRunnable, DefaultRenderersFactory.DEFAULT_ALLOWED_VIDEO_JOINING_TIME_MS);
    }

    private void recordNumMediaServerCrashes() {
        int i = this.mServerCrashCount;
        if (i > 0) {
            RecordHistogram.recordCountHistogram("Media.Android.NumMediaServerCrashes", i);
        }
    }

    @CalledByNative
    private boolean requestDecoderResources() {
        synchronized (this.mLock) {
            long elapsedRealtime = SystemClock.elapsedRealtime();
            long j = this.mLastCrashTime;
            if (j == -1 || elapsedRealtime - j >= 60000 || this.mServerCrashCount < 4) {
                int i = this.mRequestCount + 1;
                this.mRequestCount = i;
                if (i == 1 || this.mPlayer == null) {
                    this.mHandler.removeCallbacks(this.mDelayedReleaseRunnable);
                    this.mHandler.post(new Runnable() {
                        /* class org.chromium.content.browser.MediaThrottler.AnonymousClass2 */

                        public void run() {
                            new StartWatchDogTask().execute(new Void[0]);
                        }
                    });
                }
                return true;
            }
            Log.e(TAG, "Request to decode media data denied due to throttling.", new Object[0]);
            return false;
        }
    }

    @CalledByNative
    private void reset() {
        synchronized (this.mLock) {
            recordNumMediaServerCrashes();
            this.mServerCrashCount = 0;
            this.mLastCrashTime = -1;
        }
    }

    public boolean onError(MediaPlayer mediaPlayer, int i, int i2) {
        if (i != 100) {
            return true;
        }
        synchronized (this.mLock) {
            onMediaServerCrash();
        }
        return true;
    }
}
