package org.chromium.content.browser;

import org.chromium.base.VisibleForTesting;

public class RenderCoordinates {
    private float mContentHeightCss;
    private float mContentOffsetYPix;
    private float mContentWidthCss;
    private float mDeviceScaleFactor;
    private boolean mHasFrameInfo;
    private float mLastFrameViewportHeightCss;
    private float mLastFrameViewportWidthCss;
    private float mMaxPageScaleFactor = 1.0f;
    private float mMinPageScaleFactor = 1.0f;
    private float mPageScaleFactor = 1.0f;
    private float mScrollXCss;
    private float mScrollYCss;

    public class NormalizedPoint {
        private float mXAbsoluteCss;
        private float mYAbsoluteCss;

        public float getXAbsoluteCss() {
            return this.mXAbsoluteCss;
        }

        public float getXLocalDip() {
            return RenderCoordinates.this.mPageScaleFactor * (this.mXAbsoluteCss - RenderCoordinates.this.mScrollXCss);
        }

        public float getXPix() {
            return RenderCoordinates.this.mDeviceScaleFactor * getXLocalDip();
        }

        public float getYAbsoluteCss() {
            return this.mYAbsoluteCss;
        }

        public float getYLocalDip() {
            return RenderCoordinates.this.mPageScaleFactor * (this.mYAbsoluteCss - RenderCoordinates.this.mScrollYCss);
        }

        public float getYPix() {
            return RenderCoordinates.this.mContentOffsetYPix + (RenderCoordinates.this.mDeviceScaleFactor * getYLocalDip());
        }

        public void setAbsoluteCss(float f, float f2) {
            this.mXAbsoluteCss = f;
            this.mYAbsoluteCss = f2;
        }

        public void setLocalDip(float f, float f2) {
            setAbsoluteCss(RenderCoordinates.this.mScrollXCss + (f / RenderCoordinates.this.mPageScaleFactor), RenderCoordinates.this.mScrollYCss + (f2 / RenderCoordinates.this.mPageScaleFactor));
        }

        public void setScreen(float f, float f2) {
            setLocalDip(f / RenderCoordinates.this.mDeviceScaleFactor, f2 / RenderCoordinates.this.mDeviceScaleFactor);
        }

        private NormalizedPoint() {
        }
    }

    public NormalizedPoint createNormalizedPoint() {
        return new NormalizedPoint();
    }

    public float fromDipToPix(float f) {
        return f * this.mDeviceScaleFactor;
    }

    public float fromLocalCssToPix(float f) {
        return f * this.mPageScaleFactor * this.mDeviceScaleFactor;
    }

    public float fromPixToDip(float f) {
        return f / this.mDeviceScaleFactor;
    }

    public float fromPixToLocalCss(float f) {
        return f / (this.mDeviceScaleFactor * this.mPageScaleFactor);
    }

    public float getContentHeightCss() {
        return this.mContentHeightCss;
    }

    public float getContentHeightPix() {
        return fromLocalCssToPix(this.mContentHeightCss);
    }

    public int getContentHeightPixInt() {
        return (int) Math.ceil((double) getContentHeightPix());
    }

    public float getContentOffsetYPix() {
        return this.mContentOffsetYPix;
    }

    public float getContentWidthCss() {
        return this.mContentWidthCss;
    }

    public float getContentWidthPix() {
        return fromLocalCssToPix(this.mContentWidthCss);
    }

    public int getContentWidthPixInt() {
        return (int) Math.ceil((double) getContentWidthPix());
    }

    public float getDeviceScaleFactor() {
        return this.mDeviceScaleFactor;
    }

    public float getLastFrameViewportHeightCss() {
        return this.mLastFrameViewportHeightCss;
    }

    public float getLastFrameViewportHeightPix() {
        return fromLocalCssToPix(this.mLastFrameViewportHeightCss);
    }

    public int getLastFrameViewportHeightPixInt() {
        return (int) Math.ceil((double) getLastFrameViewportHeightPix());
    }

    public float getLastFrameViewportWidthCss() {
        return this.mLastFrameViewportWidthCss;
    }

    public float getLastFrameViewportWidthPix() {
        return fromLocalCssToPix(this.mLastFrameViewportWidthCss);
    }

    public int getLastFrameViewportWidthPixInt() {
        return (int) Math.ceil((double) getLastFrameViewportWidthPix());
    }

    public float getMaxHorizontalScrollPix() {
        return getContentWidthPix() - getLastFrameViewportWidthPix();
    }

    public int getMaxHorizontalScrollPixInt() {
        return (int) Math.floor((double) getMaxHorizontalScrollPix());
    }

    public float getMaxPageScaleFactor() {
        return this.mMaxPageScaleFactor;
    }

    public float getMaxVerticalScrollPix() {
        return getContentHeightPix() - getLastFrameViewportHeightPix();
    }

    public int getMaxVerticalScrollPixInt() {
        return (int) Math.floor((double) getMaxVerticalScrollPix());
    }

    public float getMinPageScaleFactor() {
        return this.mMinPageScaleFactor;
    }

    public float getPageScaleFactor() {
        return this.mPageScaleFactor;
    }

    public float getScrollX() {
        return this.mScrollXCss;
    }

    public float getScrollXPix() {
        return fromLocalCssToPix(this.mScrollXCss);
    }

    public int getScrollXPixInt() {
        return (int) Math.floor((double) getScrollXPix());
    }

    public float getScrollY() {
        return this.mScrollYCss;
    }

    public float getScrollYPix() {
        return fromLocalCssToPix(this.mScrollYCss);
    }

    public int getScrollYPixInt() {
        return (int) Math.floor((double) getScrollYPix());
    }

    public boolean hasFrameInfo() {
        return this.mHasFrameInfo;
    }

    public void reset() {
        this.mScrollYCss = 0.0f;
        this.mScrollXCss = 0.0f;
        this.mPageScaleFactor = 1.0f;
        this.mHasFrameInfo = false;
    }

    public void setDeviceScaleFactor(float f) {
        this.mDeviceScaleFactor = f;
    }

    @VisibleForTesting
    public void setFrameInfoForTest(float f, float f2) {
        reset();
        this.mDeviceScaleFactor = f;
        this.mContentOffsetYPix = f2;
    }

    public void updateContentSizeCss(float f, float f2) {
        this.mContentWidthCss = f;
        this.mContentHeightCss = f2;
    }

    public void updateFrameInfo(float f, float f2, float f3, float f4, float f5, float f6, float f7, float f8, float f9, float f10) {
        this.mScrollXCss = f;
        this.mScrollYCss = f2;
        this.mPageScaleFactor = f7;
        this.mMinPageScaleFactor = f8;
        this.mMaxPageScaleFactor = f9;
        this.mContentOffsetYPix = f10;
        updateContentSizeCss(f3, f4);
        this.mLastFrameViewportWidthCss = f5;
        this.mLastFrameViewportHeightCss = f6;
        this.mHasFrameInfo = true;
    }
}
