package org.chromium.content.browser;

import android.annotation.SuppressLint;
import android.content.ComponentCallbacks;
import android.content.Context;
import android.content.res.Configuration;
import android.hardware.display.DisplayManager;
import android.os.Build;
import android.view.WindowManager;
import java.util.Iterator;
import org.chromium.base.Log;
import org.chromium.base.ObserverList;
import org.chromium.base.ThreadUtils;
import org.chromium.base.VisibleForTesting;
import org.chromium.ui.gfx.DeviceDisplayInfo;

@VisibleForTesting
public class ScreenOrientationListener {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final String TAG = "cr.ScreenOrientation";
    private static ScreenOrientationListener sInstance;
    private Context mAppContext;
    private ScreenOrientationListenerBackend mBackend;
    private final ObserverList<ScreenOrientationObserver> mObservers = new ObserverList<>();
    private int mOrientation;

    public class ScreenOrientationConfigurationListener implements ScreenOrientationListenerBackend, ComponentCallbacks {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        private static final long POLLING_DELAY = 500;
        private int mAccurateCount;

        private ScreenOrientationConfigurationListener() {
            this.mAccurateCount = 0;
        }

        public void onConfigurationChanged(Configuration configuration) {
            ScreenOrientationListener.this.notifyObservers();
        }

        public void onLowMemory() {
        }

        @Override // org.chromium.content.browser.ScreenOrientationListener.ScreenOrientationListenerBackend
        public void startAccurateListening() {
            int i = this.mAccurateCount + 1;
            this.mAccurateCount = i;
            if (i <= 1) {
                ThreadUtils.postOnUiThreadDelayed(new Runnable() {
                    /* class org.chromium.content.browser.ScreenOrientationListener.ScreenOrientationConfigurationListener.AnonymousClass1 */

                    public void run() {
                        this.onConfigurationChanged(null);
                        if (this.mAccurateCount >= 1) {
                            ThreadUtils.postOnUiThreadDelayed(this, 500);
                        }
                    }
                }, 500);
            }
        }

        @Override // org.chromium.content.browser.ScreenOrientationListener.ScreenOrientationListenerBackend
        public void startListening() {
            ScreenOrientationListener.this.mAppContext.registerComponentCallbacks(this);
        }

        @Override // org.chromium.content.browser.ScreenOrientationListener.ScreenOrientationListenerBackend
        public void stopAccurateListening() {
            this.mAccurateCount--;
        }

        @Override // org.chromium.content.browser.ScreenOrientationListener.ScreenOrientationListenerBackend
        public void stopListening() {
            ScreenOrientationListener.this.mAppContext.unregisterComponentCallbacks(this);
        }
    }

    @SuppressLint({"NewApi"})
    public class ScreenOrientationDisplayListener implements ScreenOrientationListenerBackend, DisplayManager.DisplayListener {
        private ScreenOrientationDisplayListener() {
        }

        public void onDisplayAdded(int i) {
        }

        public void onDisplayChanged(int i) {
            ScreenOrientationListener.this.notifyObservers();
        }

        public void onDisplayRemoved(int i) {
        }

        @Override // org.chromium.content.browser.ScreenOrientationListener.ScreenOrientationListenerBackend
        public void startAccurateListening() {
        }

        @Override // org.chromium.content.browser.ScreenOrientationListener.ScreenOrientationListenerBackend
        public void startListening() {
            ((DisplayManager) ScreenOrientationListener.this.mAppContext.getSystemService("display")).registerDisplayListener(this, null);
        }

        @Override // org.chromium.content.browser.ScreenOrientationListener.ScreenOrientationListenerBackend
        public void stopAccurateListening() {
        }

        @Override // org.chromium.content.browser.ScreenOrientationListener.ScreenOrientationListenerBackend
        public void stopListening() {
            ((DisplayManager) ScreenOrientationListener.this.mAppContext.getSystemService("display")).unregisterDisplayListener(this);
        }
    }

    public interface ScreenOrientationListenerBackend {
        void startAccurateListening();

        void startListening();

        void stopAccurateListening();

        void stopListening();
    }

    public interface ScreenOrientationObserver {
        void onScreenOrientationChanged(int i);
    }

    private ScreenOrientationListener() {
        this.mBackend = Build.VERSION.SDK_INT >= 17 ? new ScreenOrientationDisplayListener() : new ScreenOrientationConfigurationListener();
    }

    public static ScreenOrientationListener getInstance() {
        ThreadUtils.assertOnUiThread();
        if (sInstance == null) {
            sInstance = new ScreenOrientationListener();
        }
        return sInstance;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void notifyObservers() {
        int i = this.mOrientation;
        updateOrientation();
        if (this.mOrientation != i) {
            DeviceDisplayInfo.create(this.mAppContext).updateNativeSharedDisplayInfo();
            Iterator<ScreenOrientationObserver> it = this.mObservers.iterator();
            while (it.hasNext()) {
                it.next().onScreenOrientationChanged(this.mOrientation);
            }
        }
    }

    private void updateOrientation() {
        int rotation = ((WindowManager) this.mAppContext.getSystemService("window")).getDefaultDisplay().getRotation();
        if (rotation == 0) {
            this.mOrientation = 0;
        } else if (rotation == 1) {
            this.mOrientation = 90;
        } else if (rotation == 2) {
            this.mOrientation = 180;
        } else if (rotation == 3) {
            this.mOrientation = -90;
        } else {
            throw new IllegalStateException("Display.getRotation() shouldn't return that value");
        }
    }

    public void addObserver(final ScreenOrientationObserver screenOrientationObserver, Context context) {
        if (this.mAppContext == null) {
            this.mAppContext = context.getApplicationContext();
        }
        if (!this.mObservers.addObserver(screenOrientationObserver)) {
            Log.w(TAG, "Adding an observer that is already present!", new Object[0]);
            return;
        }
        if (this.mObservers.size() == 1) {
            updateOrientation();
            this.mBackend.startListening();
        }
        ThreadUtils.assertOnUiThread();
        ThreadUtils.postOnUiThread(new Runnable() {
            /* class org.chromium.content.browser.ScreenOrientationListener.AnonymousClass1 */

            public void run() {
                screenOrientationObserver.onScreenOrientationChanged(ScreenOrientationListener.this.mOrientation);
            }
        });
    }

    public void removeObserver(ScreenOrientationObserver screenOrientationObserver) {
        if (!this.mObservers.removeObserver(screenOrientationObserver)) {
            Log.w(TAG, "Removing an inexistent observer!", new Object[0]);
        } else if (this.mObservers.isEmpty()) {
            this.mBackend.stopListening();
        }
    }

    public void startAccurateListening() {
        this.mBackend.startAccurateListening();
    }

    public void stopAccurateListening() {
        this.mBackend.stopAccurateListening();
    }
}
