package org.chromium.content.browser;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Environment;
import android.text.TextUtils;
import androidx.base.b2;
import java.io.File;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;
import java.util.TimeZone;
import org.chromium.base.Log;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;
import org.chromium.content.R;
import org.chromium.ui.widget.Toast;

@JNINamespace("content")
public class TracingControllerAndroid {
    private static final String ACTION_LIST_CATEGORIES = "GPU_PROFILER_LIST_CATEGORIES";
    private static final String ACTION_START = "GPU_PROFILER_START";
    private static final String ACTION_STOP = "GPU_PROFILER_STOP";
    private static final String CATEGORIES_EXTRA = "categories";
    private static final String DEFAULT_CHROME_CATEGORIES_PLACE_HOLDER = "_DEFAULT_CHROME_CATEGORIES";
    private static final String FILE_EXTRA = "file";
    private static final String PROFILER_FINISHED_FMT = "Profiler finished. Results are in %s.";
    private static final String PROFILER_STARTED_FMT = "Profiler started: %s";
    private static final String RECORD_CONTINUOUSLY_EXTRA = "continuous";
    private static final String TAG = "cr.TracingController";
    private final TracingBroadcastReceiver mBroadcastReceiver;
    private final Context mContext;
    private String mFilename;
    private final TracingIntentFilter mIntentFilter;
    private boolean mIsTracing;
    private long mNativeTracingControllerAndroid;
    private boolean mShowToasts = true;

    public class TracingBroadcastReceiver extends BroadcastReceiver {
        public TracingBroadcastReceiver() {
        }

        public void onReceive(Context context, Intent intent) {
            String str;
            if (intent.getAction().endsWith(TracingControllerAndroid.ACTION_START)) {
                String stringExtra = intent.getStringExtra(TracingControllerAndroid.CATEGORIES_EXTRA);
                if (TextUtils.isEmpty(stringExtra)) {
                    str = TracingControllerAndroid.this.nativeGetDefaultCategories();
                } else {
                    str = stringExtra.replaceFirst(TracingControllerAndroid.DEFAULT_CHROME_CATEGORIES_PLACE_HOLDER, TracingControllerAndroid.this.nativeGetDefaultCategories());
                }
                String str2 = intent.getStringExtra(TracingControllerAndroid.RECORD_CONTINUOUSLY_EXTRA) == null ? "record-until-full" : "record-continuously";
                String stringExtra2 = intent.getStringExtra(TracingControllerAndroid.FILE_EXTRA);
                if (stringExtra2 != null) {
                    TracingControllerAndroid.this.startTracing(stringExtra2, true, str, str2);
                } else {
                    TracingControllerAndroid.this.startTracing(true, str, str2);
                }
            } else if (intent.getAction().endsWith(TracingControllerAndroid.ACTION_STOP)) {
                TracingControllerAndroid.this.stopTracing();
            } else if (intent.getAction().endsWith(TracingControllerAndroid.ACTION_LIST_CATEGORIES)) {
                TracingControllerAndroid.this.getCategoryGroups();
            } else {
                Log.e(TracingControllerAndroid.TAG, "Unexpected intent: %s", intent);
            }
        }
    }

    public static class TracingIntentFilter extends IntentFilter {
        public TracingIntentFilter(Context context) {
            addAction(context.getPackageName() + "." + TracingControllerAndroid.ACTION_START);
            addAction(context.getPackageName() + "." + TracingControllerAndroid.ACTION_STOP);
            addAction(context.getPackageName() + "." + TracingControllerAndroid.ACTION_LIST_CATEGORIES);
        }
    }

    public TracingControllerAndroid(Context context) {
        this.mContext = context;
        this.mBroadcastReceiver = new TracingBroadcastReceiver();
        this.mIntentFilter = new TracingIntentFilter(context);
    }

    @CalledByNative
    private static String generateTracingFilePath() {
        if (!"mounted".equals(Environment.getExternalStorageState())) {
            return null;
        }
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd-HHmmss", Locale.US);
        simpleDateFormat.setTimeZone(TimeZone.getTimeZone("UTC"));
        File externalStoragePublicDirectory = Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_DOWNLOADS);
        StringBuilder j = b2.j("chrome-profile-results-");
        j.append(simpleDateFormat.format(new Date()));
        return new File(externalStoragePublicDirectory, j.toString()).getPath();
    }

    private void initializeNativeControllerIfNeeded() {
        if (this.mNativeTracingControllerAndroid == 0) {
            this.mNativeTracingControllerAndroid = nativeInit();
        }
    }

    private void logAndToastError(String str) {
        Log.e(TAG, str, new Object[0]);
        if (this.mShowToasts) {
            Toast.makeText(this.mContext, str, 0).show();
        }
    }

    private void logForProfiler(String str) {
        Log.i(TAG, str, new Object[0]);
    }

    private native void nativeDestroy(long j);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native String nativeGetDefaultCategories();

    private native boolean nativeGetKnownCategoryGroupsAsync(long j);

    private native long nativeInit();

    private native boolean nativeStartTracing(long j, String str, String str2);

    private native void nativeStopTracing(long j, String str);

    private void showToast(String str) {
        if (this.mShowToasts) {
            Toast.makeText(this.mContext, str, 0).show();
        }
    }

    public void destroy() {
        long j = this.mNativeTracingControllerAndroid;
        if (j != 0) {
            nativeDestroy(j);
            this.mNativeTracingControllerAndroid = 0;
        }
    }

    public BroadcastReceiver getBroadcastReceiver() {
        return this.mBroadcastReceiver;
    }

    public void getCategoryGroups() {
        initializeNativeControllerIfNeeded();
        if (!nativeGetKnownCategoryGroupsAsync(this.mNativeTracingControllerAndroid)) {
            Log.e(TAG, "Unable to fetch tracing record groups list.", new Object[0]);
        }
    }

    public IntentFilter getIntentFilter() {
        return this.mIntentFilter;
    }

    public String getOutputPath() {
        return this.mFilename;
    }

    public boolean isTracing() {
        return this.mIsTracing;
    }

    @CalledByNative
    public void onTracingStopped() {
        if (!isTracing()) {
            Log.e(TAG, "Received onTracingStopped, but we aren't tracing", new Object[0]);
            return;
        }
        logForProfiler(String.format(PROFILER_FINISHED_FMT, this.mFilename));
        showToast(this.mContext.getString(R.string.profiler_stopped_toast, this.mFilename));
        this.mIsTracing = false;
        this.mFilename = null;
    }

    public void registerReceiver(Context context) {
        context.registerReceiver(getBroadcastReceiver(), getIntentFilter());
    }

    public boolean startTracing(boolean z, String str, String str2) {
        this.mShowToasts = z;
        String generateTracingFilePath = generateTracingFilePath();
        if (generateTracingFilePath == null) {
            logAndToastError(this.mContext.getString(R.string.profiler_no_storage_toast));
        }
        return startTracing(generateTracingFilePath, z, str, str2);
    }

    public void stopTracing() {
        if (isTracing()) {
            nativeStopTracing(this.mNativeTracingControllerAndroid, this.mFilename);
        }
    }

    public void unregisterReceiver(Context context) {
        context.unregisterReceiver(getBroadcastReceiver());
    }

    public boolean startTracing(String str, boolean z, String str2, String str3) {
        this.mShowToasts = z;
        if (isTracing()) {
            Log.e(TAG, "Received startTracing, but we're already tracing", new Object[0]);
            return false;
        }
        initializeNativeControllerIfNeeded();
        if (!nativeStartTracing(this.mNativeTracingControllerAndroid, str2, str3.toString())) {
            logAndToastError(this.mContext.getString(R.string.profiler_error_toast));
            return false;
        }
        logForProfiler(String.format(PROFILER_STARTED_FMT, str2));
        showToast(this.mContext.getString(R.string.profiler_started_toast) + ": " + str2);
        this.mFilename = str;
        this.mIsTracing = true;
        return true;
    }
}
