package org.chromium.content.browser.accessibility;

import android.annotation.SuppressLint;
import android.graphics.Rect;
import android.os.Build;
import android.os.Bundle;
import android.provider.Settings;
import android.text.SpannableString;
import android.text.style.URLSpan;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewParent;
import android.view.accessibility.AccessibilityEvent;
import android.view.accessibility.AccessibilityManager;
import android.view.accessibility.AccessibilityNodeInfo;
import android.view.accessibility.AccessibilityNodeProvider;
import androidx.core.view.accessibility.AccessibilityNodeInfoCompat;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;
import org.chromium.content.browser.ContentViewCore;
import org.chromium.content.browser.RenderCoordinates;

@JNINamespace("content")
public class BrowserAccessibilityManager {
    private static final String ACTION_ARGUMENT_SET_TEXT_CHARSEQUENCE = "ACTION_ARGUMENT_SET_TEXT_CHARSEQUENCE";
    private static final int ACTION_SET_TEXT = 2097152;
    private static final String TAG = "BrowserAccessibilityManager";
    private static final int WINDOW_CONTENT_CHANGED_DELAY_MS = 500;
    public int mAccessibilityFocusId;
    private Rect mAccessibilityFocusRect;
    private final AccessibilityManager mAccessibilityManager;
    private final AccessibilityNodeProvider mAccessibilityNodeProvider;
    private ContentViewCore mContentViewCore;
    public int mCurrentRootId;
    private boolean mIsHovering;
    private int mLastHoverId = -1;
    private long mNativeObj;
    private boolean mNotifyFrameInfoInitializedCalled;
    private boolean mPendingScrollToMakeNodeVisible;
    private final RenderCoordinates mRenderCoordinates;
    private int mSelectionEndIndex;
    private int mSelectionGranularity;
    private int mSelectionStartIndex;
    private Runnable mSendWindowContentChangedRunnable;
    private final int[] mTempLocation = new int[2];
    private boolean mUserHasTouchExplored;
    private final ViewGroup mView;

    public BrowserAccessibilityManager(long j, ContentViewCore contentViewCore) {
        this.mNativeObj = j;
        this.mContentViewCore = contentViewCore;
        this.mAccessibilityFocusId = -1;
        this.mIsHovering = false;
        this.mCurrentRootId = -1;
        this.mView = contentViewCore.getContainerView();
        this.mRenderCoordinates = this.mContentViewCore.getRenderCoordinates();
        this.mAccessibilityManager = (AccessibilityManager) this.mContentViewCore.getContext().getSystemService("accessibility");
        this.mAccessibilityNodeProvider = new AccessibilityNodeProvider() {
            /* class org.chromium.content.browser.accessibility.BrowserAccessibilityManager.AnonymousClass1 */

            public AccessibilityNodeInfo createAccessibilityNodeInfo(int i) {
                return this.createAccessibilityNodeInfo(i);
            }

            @Override // android.view.accessibility.AccessibilityNodeProvider
            public List<AccessibilityNodeInfo> findAccessibilityNodeInfosByText(String str, int i) {
                return this.findAccessibilityNodeInfosByText(str, i);
            }

            public boolean performAction(int i, int i2, Bundle bundle) {
                return this.performAction(i, i2, bundle);
            }
        };
        this.mContentViewCore.setBrowserAccessibilityManager(this);
    }

    @CalledByNative
    private void addAccessibilityNodeInfoChild(AccessibilityNodeInfo accessibilityNodeInfo, int i) {
        accessibilityNodeInfo.addChild(this.mView, i);
    }

    @CalledByNative
    private void announceLiveRegionText(String str) {
        this.mView.announceForAccessibility(str);
    }

    private AccessibilityEvent buildAccessibilityEvent(int i, int i2) {
        if (!this.mAccessibilityManager.isEnabled() || this.mNativeObj == 0 || !isFrameInfoInitialized()) {
            return null;
        }
        this.mView.postInvalidate();
        AccessibilityEvent obtain = AccessibilityEvent.obtain(i2);
        obtain.setPackageName(this.mContentViewCore.getContext().getPackageName());
        obtain.setSource(this.mView, i);
        if (nativePopulateAccessibilityEvent(this.mNativeObj, obtain, i, i2)) {
            return obtain;
        }
        obtain.recycle();
        return null;
    }

    @CalledByNative
    private static BrowserAccessibilityManager create(long j, ContentViewCore contentViewCore) {
        int i = Build.VERSION.SDK_INT;
        if (i >= 21) {
            return new LollipopBrowserAccessibilityManager(j, contentViewCore);
        }
        if (i >= 19) {
            return new KitKatBrowserAccessibilityManager(j, contentViewCore);
        }
        return new BrowserAccessibilityManager(j, contentViewCore);
    }

    private AccessibilityNodeInfo createNodeForHost(int i) {
        AccessibilityNodeInfo obtain = AccessibilityNodeInfo.obtain(this.mView);
        AccessibilityNodeInfo obtain2 = AccessibilityNodeInfo.obtain(this.mView);
        this.mView.onInitializeAccessibilityNodeInfo(obtain2);
        Rect rect = new Rect();
        obtain2.getBoundsInParent(rect);
        obtain.setBoundsInParent(rect);
        obtain2.getBoundsInScreen(rect);
        obtain.setBoundsInScreen(rect);
        ViewParent parentForAccessibility = this.mView.getParentForAccessibility();
        if (parentForAccessibility instanceof View) {
            obtain.setParent((View) parentForAccessibility);
        }
        obtain.setVisibleToUser(obtain2.isVisibleToUser());
        obtain.setEnabled(obtain2.isEnabled());
        obtain.setPackageName(obtain2.getPackageName());
        obtain.setClassName(obtain2.getClassName());
        if (isFrameInfoInitialized()) {
            obtain.addChild(this.mView, i);
        }
        return obtain;
    }

    @CalledByNative
    private void finishGranularityMove(String str, boolean z, int i, int i2, boolean z2) {
        AccessibilityEvent buildAccessibilityEvent;
        if (this.mNativeObj != 0 && (buildAccessibilityEvent = buildAccessibilityEvent(this.mAccessibilityFocusId, 8192)) != null) {
            AccessibilityEvent buildAccessibilityEvent2 = buildAccessibilityEvent(this.mAccessibilityFocusId, 131072);
            if (buildAccessibilityEvent2 == null) {
                buildAccessibilityEvent.recycle();
                return;
            }
            if (z2) {
                this.mSelectionEndIndex = i2;
            } else {
                this.mSelectionEndIndex = i;
            }
            if (!z) {
                this.mSelectionStartIndex = this.mSelectionEndIndex;
            }
            if (nativeIsEditableText(this.mNativeObj, this.mAccessibilityFocusId)) {
                nativeSetSelection(this.mNativeObj, this.mAccessibilityFocusId, this.mSelectionStartIndex, this.mSelectionEndIndex);
            }
            buildAccessibilityEvent.setFromIndex(this.mSelectionStartIndex);
            buildAccessibilityEvent.setToIndex(this.mSelectionStartIndex);
            buildAccessibilityEvent.setItemCount(str.length());
            buildAccessibilityEvent2.setFromIndex(i);
            buildAccessibilityEvent2.setToIndex(i2);
            buildAccessibilityEvent2.setItemCount(str.length());
            buildAccessibilityEvent2.setMovementGranularity(this.mSelectionGranularity);
            buildAccessibilityEvent2.setContentDescription(str);
            if (z2) {
                buildAccessibilityEvent2.setAction(256);
            } else {
                buildAccessibilityEvent2.setAction(512);
            }
            ViewGroup viewGroup = this.mView;
            viewGroup.requestSendAccessibilityEvent(viewGroup, buildAccessibilityEvent);
            ViewGroup viewGroup2 = this.mView;
            viewGroup2.requestSendAccessibilityEvent(viewGroup2, buildAccessibilityEvent2);
        }
    }

    private Bundle getOrCreateBundleForAccessibilityEvent(AccessibilityEvent accessibilityEvent) {
        Bundle bundle = (Bundle) accessibilityEvent.getParcelableData();
        if (bundle != null) {
            return bundle;
        }
        Bundle bundle2 = new Bundle();
        accessibilityEvent.setParcelableData(bundle2);
        return bundle2;
    }

    @CalledByNative
    private void handleCheckStateChanged(int i) {
        if (this.mNativeObj != 0) {
            sendAccessibilityEvent(i, 1);
        }
    }

    @CalledByNative
    private void handleClicked(int i) {
        if (this.mNativeObj != 0) {
            sendAccessibilityEvent(i, 1);
        }
    }

    @CalledByNative
    private void handleContentChanged(int i) {
        long j = this.mNativeObj;
        if (j != 0) {
            int nativeGetRootId = nativeGetRootId(j);
            if (nativeGetRootId != this.mCurrentRootId) {
                this.mCurrentRootId = nativeGetRootId;
                sendWindowContentChangedOnView();
                return;
            }
            sendWindowContentChangedOnVirtualView(i);
        }
    }

    @CalledByNative
    private void handleEditableTextChanged(int i) {
        if (this.mNativeObj != 0) {
            sendAccessibilityEvent(i, 16);
        }
    }

    @CalledByNative
    private void handleFocusChanged(int i) {
        if (this.mNativeObj != 0) {
            sendAccessibilityEvent(i, 8);
            moveAccessibilityFocusToId(i);
        }
    }

    @CalledByNative
    private void handleHover(int i) {
        if (this.mNativeObj != 0 && this.mLastHoverId != i && this.mIsHovering) {
            sendAccessibilityEvent(i, 128);
            int i2 = this.mLastHoverId;
            if (i2 != -1) {
                sendAccessibilityEvent(i2, 256);
            }
            this.mLastHoverId = i;
        }
    }

    @CalledByNative
    private void handleNavigate() {
        if (this.mNativeObj != 0) {
            this.mAccessibilityFocusId = -1;
            this.mAccessibilityFocusRect = null;
            this.mUserHasTouchExplored = false;
            sendWindowContentChangedOnView();
        }
    }

    @CalledByNative
    private void handlePageLoaded(int i) {
        if (this.mNativeObj != 0 && !this.mUserHasTouchExplored && this.mContentViewCore.shouldSetAccessibilityFocusOnPageLoad()) {
            moveAccessibilityFocusToIdAndRefocusIfNeeded(i);
        }
    }

    @CalledByNative
    private void handleScrollPositionChanged(int i) {
        if (this.mNativeObj != 0) {
            sendAccessibilityEvent(i, 4096);
        }
    }

    @CalledByNative
    private void handleScrolledToAnchor(int i) {
        if (this.mNativeObj != 0) {
            moveAccessibilityFocusToId(i);
        }
    }

    @CalledByNative
    private void handleSliderChanged(int i) {
        if (this.mNativeObj != 0) {
            sendAccessibilityEvent(i, 4096);
        }
    }

    @CalledByNative
    private void handleTextSelectionChanged(int i) {
        if (this.mNativeObj != 0) {
            sendAccessibilityEvent(i, 8192);
        }
    }

    private boolean isFrameInfoInitialized() {
        return (((double) this.mRenderCoordinates.getContentWidthCss()) == 0.0d && ((double) this.mRenderCoordinates.getContentHeightCss()) == 0.0d) ? false : true;
    }

    public static boolean isValidMovementGranularity(int i) {
        return i == 1 || i == 2 || i == 4;
    }

    private boolean jumpToElementType(String str, boolean z) {
        int nativeFindElementType = nativeFindElementType(this.mNativeObj, this.mAccessibilityFocusId, str, z);
        if (nativeFindElementType == 0) {
            return false;
        }
        moveAccessibilityFocusToId(nativeFindElementType);
        nativeScrollToMakeNodeVisible(this.mNativeObj, this.mAccessibilityFocusId);
        return true;
    }

    private boolean moveAccessibilityFocusToId(int i) {
        if (i == this.mAccessibilityFocusId) {
            return false;
        }
        this.mAccessibilityFocusId = i;
        this.mAccessibilityFocusRect = null;
        this.mSelectionGranularity = 0;
        this.mSelectionStartIndex = 0;
        this.mSelectionEndIndex = 0;
        if (i == this.mCurrentRootId) {
            nativeSetAccessibilityFocus(this.mNativeObj, -1);
        } else {
            nativeSetAccessibilityFocus(this.mNativeObj, i);
        }
        sendAccessibilityEvent(this.mAccessibilityFocusId, 32768);
        return true;
    }

    private void moveAccessibilityFocusToIdAndRefocusIfNeeded(int i) {
        if (i == this.mAccessibilityFocusId) {
            sendAccessibilityEvent(i, 65536);
            this.mAccessibilityFocusId = -1;
        }
        moveAccessibilityFocusToId(i);
    }

    private native boolean nativeAdjustSlider(long j, int i, boolean z);

    private native void nativeBlur(long j);

    private native void nativeClick(long j, int i);

    private native int nativeFindElementType(long j, int i, String str, boolean z);

    private native void nativeFocus(long j, int i);

    private native int nativeGetEditableTextSelectionEnd(long j, int i);

    private native int nativeGetEditableTextSelectionStart(long j, int i);

    private native int nativeGetRootId(long j);

    private native void nativeHitTest(long j, int i, int i2);

    private native boolean nativeIsEditableText(long j, int i);

    private native boolean nativeIsNodeValid(long j, int i);

    private native boolean nativeIsSlider(long j, int i);

    private native boolean nativeNextAtGranularity(long j, int i, boolean z, int i2, int i3);

    private native boolean nativePopulateAccessibilityEvent(long j, AccessibilityEvent accessibilityEvent, int i, int i2);

    private native boolean nativePopulateAccessibilityNodeInfo(long j, AccessibilityNodeInfo accessibilityNodeInfo, int i);

    private native boolean nativePreviousAtGranularity(long j, int i, boolean z, int i2, int i3);

    private native boolean nativeScroll(long j, int i, int i2);

    private native void nativeScrollToMakeNodeVisible(long j, int i);

    private native void nativeSetAccessibilityFocus(long j, int i);

    private native void nativeSetSelection(long j, int i, int i2, int i3);

    private native void nativeSetTextFieldValue(long j, int i, String str);

    private boolean nextAtGranularity(int i, boolean z) {
        setGranularityAndUpdateSelection(i);
        return nativeNextAtGranularity(this.mNativeObj, this.mSelectionGranularity, z, this.mAccessibilityFocusId, this.mSelectionEndIndex);
    }

    @CalledByNative
    private void onNativeObjectDestroyed(long j) {
        if (j == this.mNativeObj) {
            ContentViewCore contentViewCore = this.mContentViewCore;
            if (contentViewCore != null && contentViewCore.getBrowserAccessibilityManager() == this) {
                this.mContentViewCore.setBrowserAccessibilityManager(null);
            }
            this.mNativeObj = 0;
            this.mContentViewCore = null;
        }
    }

    private boolean previousAtGranularity(int i, boolean z) {
        setGranularityAndUpdateSelection(i);
        return nativePreviousAtGranularity(this.mNativeObj, this.mSelectionGranularity, z, this.mAccessibilityFocusId, this.mSelectionEndIndex);
    }

    private boolean scrollBackward(int i) {
        if (nativeIsSlider(this.mNativeObj, i)) {
            return nativeAdjustSlider(this.mNativeObj, i, false);
        }
        return nativeScroll(this.mNativeObj, i, 1);
    }

    private boolean scrollForward(int i) {
        if (nativeIsSlider(this.mNativeObj, i)) {
            return nativeAdjustSlider(this.mNativeObj, i, true);
        }
        return nativeScroll(this.mNativeObj, i, 0);
    }

    private void sendAccessibilityEvent(int i, int i2) {
        if (i == -1) {
            this.mView.sendAccessibilityEvent(i2);
            return;
        }
        AccessibilityEvent buildAccessibilityEvent = buildAccessibilityEvent(i, i2);
        if (buildAccessibilityEvent != null) {
            ViewGroup viewGroup = this.mView;
            viewGroup.requestSendAccessibilityEvent(viewGroup, buildAccessibilityEvent);
        }
    }

    @CalledByNative
    private void sendDelayedWindowContentChangedEvent() {
        if (this.mNativeObj != 0 && this.mSendWindowContentChangedRunnable == null) {
            AnonymousClass2 r0 = new Runnable() {
                /* class org.chromium.content.browser.accessibility.BrowserAccessibilityManager.AnonymousClass2 */

                public void run() {
                    BrowserAccessibilityManager.this.sendWindowContentChangedOnView();
                }
            };
            this.mSendWindowContentChangedRunnable = r0;
            this.mView.postDelayed(r0, 500);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void sendWindowContentChangedOnView() {
        ViewGroup viewGroup;
        if (this.mNativeObj != 0 && this.mContentViewCore != null && (viewGroup = this.mView) != null) {
            Runnable runnable = this.mSendWindowContentChangedRunnable;
            if (runnable != null) {
                viewGroup.removeCallbacks(runnable);
                this.mSendWindowContentChangedRunnable = null;
            }
            this.mView.sendAccessibilityEvent(2048);
        }
    }

    private void sendWindowContentChangedOnVirtualView(int i) {
        sendAccessibilityEvent(i, 2048);
    }

    @CalledByNative
    private void setAccessibilityEventBooleanAttributes(AccessibilityEvent accessibilityEvent, boolean z, boolean z2, boolean z3, boolean z4) {
        accessibilityEvent.setChecked(z);
        accessibilityEvent.setEnabled(z2);
        accessibilityEvent.setPassword(z3);
        accessibilityEvent.setScrollable(z4);
    }

    @CalledByNative
    private void setAccessibilityEventClassName(AccessibilityEvent accessibilityEvent, String str) {
        accessibilityEvent.setClassName(str);
    }

    @CalledByNative
    private void setAccessibilityEventListAttributes(AccessibilityEvent accessibilityEvent, int i, int i2) {
        accessibilityEvent.setCurrentItemIndex(i);
        accessibilityEvent.setItemCount(i2);
    }

    @CalledByNative
    private void setAccessibilityEventScrollAttributes(AccessibilityEvent accessibilityEvent, int i, int i2, int i3, int i4) {
        accessibilityEvent.setScrollX(i);
        accessibilityEvent.setScrollY(i2);
        accessibilityEvent.setMaxScrollX(i3);
        accessibilityEvent.setMaxScrollY(i4);
    }

    @CalledByNative
    private void setAccessibilityEventSelectionAttrs(AccessibilityEvent accessibilityEvent, int i, int i2, int i3, String str) {
        accessibilityEvent.setFromIndex(i);
        accessibilityEvent.setToIndex(i2);
        accessibilityEvent.setItemCount(i3);
        accessibilityEvent.getText().add(str);
    }

    @CalledByNative
    private void setAccessibilityEventTextChangedAttrs(AccessibilityEvent accessibilityEvent, int i, int i2, int i3, String str, String str2) {
        accessibilityEvent.setFromIndex(i);
        accessibilityEvent.setAddedCount(i2);
        accessibilityEvent.setRemovedCount(i3);
        accessibilityEvent.setBeforeText(str);
        accessibilityEvent.getText().add(str2);
    }

    @CalledByNative
    private void setAccessibilityNodeInfoBooleanAttributes(AccessibilityNodeInfo accessibilityNodeInfo, int i, boolean z, boolean z2, boolean z3, boolean z4, boolean z5, boolean z6, boolean z7, boolean z8, boolean z9, boolean z10) {
        accessibilityNodeInfo.setCheckable(z);
        accessibilityNodeInfo.setChecked(z2);
        accessibilityNodeInfo.setClickable(z3);
        accessibilityNodeInfo.setEnabled(z4);
        accessibilityNodeInfo.setFocusable(z5);
        accessibilityNodeInfo.setFocused(z6);
        accessibilityNodeInfo.setPassword(z7);
        accessibilityNodeInfo.setScrollable(z8);
        accessibilityNodeInfo.setSelected(z9);
        accessibilityNodeInfo.setVisibleToUser(z10);
        accessibilityNodeInfo.setMovementGranularities(7);
        if (this.mAccessibilityFocusId == i) {
            accessibilityNodeInfo.setAccessibilityFocused(true);
        } else {
            accessibilityNodeInfo.setAccessibilityFocused(false);
        }
    }

    @CalledByNative
    private void setAccessibilityNodeInfoClassName(AccessibilityNodeInfo accessibilityNodeInfo, String str) {
        accessibilityNodeInfo.setClassName(str);
    }

    @CalledByNative
    private void setAccessibilityNodeInfoLocation(AccessibilityNodeInfo accessibilityNodeInfo, int i, int i2, int i3, int i4, int i5, int i6, int i7, boolean z) {
        Rect rect = new Rect(i4, i5, i4 + i6, i5 + i7);
        if (z) {
            rect.offset(0, (int) this.mRenderCoordinates.getContentOffsetYPix());
        }
        accessibilityNodeInfo.setBoundsInParent(rect);
        Rect rect2 = new Rect(i2, i3, i6 + i2, i7 + i3);
        rect2.offset(-((int) this.mRenderCoordinates.getScrollX()), -((int) this.mRenderCoordinates.getScrollY()));
        rect2.left = (int) this.mRenderCoordinates.fromLocalCssToPix((float) rect2.left);
        rect2.top = (int) this.mRenderCoordinates.fromLocalCssToPix((float) rect2.top);
        rect2.bottom = (int) this.mRenderCoordinates.fromLocalCssToPix((float) rect2.bottom);
        rect2.right = (int) this.mRenderCoordinates.fromLocalCssToPix((float) rect2.right);
        rect2.offset(0, (int) this.mRenderCoordinates.getContentOffsetYPix());
        int[] iArr = new int[2];
        this.mView.getLocationOnScreen(iArr);
        rect2.offset(iArr[0], iArr[1]);
        int contentOffsetYPix = iArr[1] + ((int) this.mRenderCoordinates.getContentOffsetYPix());
        int viewportHeightPix = this.mContentViewCore.getViewportHeightPix() + contentOffsetYPix;
        if (rect2.top < contentOffsetYPix) {
            rect2.top = contentOffsetYPix;
        }
        if (rect2.bottom > viewportHeightPix) {
            rect2.bottom = viewportHeightPix;
        }
        accessibilityNodeInfo.setBoundsInScreen(rect2);
        if (i == this.mAccessibilityFocusId && i != this.mCurrentRootId) {
            Rect rect3 = this.mAccessibilityFocusRect;
            if (rect3 == null) {
                this.mAccessibilityFocusRect = rect2;
            } else if (!rect3.equals(rect2)) {
                this.mAccessibilityFocusRect = rect2;
                moveAccessibilityFocusToIdAndRefocusIfNeeded(i);
            }
        }
    }

    @CalledByNative
    private void setAccessibilityNodeInfoParent(AccessibilityNodeInfo accessibilityNodeInfo, int i) {
        accessibilityNodeInfo.setParent(this.mView, i);
    }

    /* JADX DEBUG: Multi-variable search result rejected for r5v1, resolved type: android.text.SpannableString */
    /* JADX WARN: Multi-variable type inference failed */
    @SuppressLint({"NewApi"})
    @CalledByNative
    private void setAccessibilityNodeInfoText(AccessibilityNodeInfo accessibilityNodeInfo, String str, boolean z, boolean z2) {
        if (z) {
            SpannableString spannableString = new SpannableString(str);
            spannableString.setSpan(new URLSpan(""), 0, spannableString.length(), 0);
            str = spannableString;
        }
        if (z2) {
            accessibilityNodeInfo.setText(str);
        } else {
            accessibilityNodeInfo.setContentDescription(str);
        }
    }

    private void setGranularityAndUpdateSelection(int i) {
        if (this.mSelectionGranularity == 0) {
            this.mSelectionStartIndex = -1;
            this.mSelectionEndIndex = -1;
        }
        this.mSelectionGranularity = i;
        if (nativeIsEditableText(this.mNativeObj, this.mAccessibilityFocusId)) {
            this.mSelectionStartIndex = nativeGetEditableTextSelectionStart(this.mNativeObj, this.mAccessibilityFocusId);
            this.mSelectionEndIndex = nativeGetEditableTextSelectionEnd(this.mNativeObj, this.mAccessibilityFocusId);
        }
    }

    @CalledByNative
    public void addAccessibilityNodeInfoActions(AccessibilityNodeInfo accessibilityNodeInfo, int i, boolean z, boolean z2, boolean z3, boolean z4, boolean z5, boolean z6, boolean z7, boolean z8, boolean z9, boolean z10, boolean z11) {
        accessibilityNodeInfo.addAction(1024);
        accessibilityNodeInfo.addAction(2048);
        accessibilityNodeInfo.addAction(256);
        accessibilityNodeInfo.addAction(512);
        if (z8 && z9) {
            accessibilityNodeInfo.addAction(2097152);
            accessibilityNodeInfo.addAction(131072);
        }
        if (z) {
            accessibilityNodeInfo.addAction(4096);
        }
        if (z2) {
            accessibilityNodeInfo.addAction(8192);
        }
        if (z10) {
            if (z11) {
                accessibilityNodeInfo.addAction(2);
            } else {
                accessibilityNodeInfo.addAction(1);
            }
        }
        if (this.mAccessibilityFocusId == i) {
            accessibilityNodeInfo.addAction(128);
        } else {
            accessibilityNodeInfo.addAction(64);
        }
        if (z7) {
            accessibilityNodeInfo.addAction(16);
        }
    }

    public AccessibilityNodeInfo createAccessibilityNodeInfo(int i) {
        if (this.mAccessibilityManager.isEnabled()) {
            long j = this.mNativeObj;
            if (j != 0) {
                int nativeGetRootId = nativeGetRootId(j);
                if (i == -1) {
                    return createNodeForHost(nativeGetRootId);
                }
                if (!isFrameInfoInitialized()) {
                    return null;
                }
                AccessibilityNodeInfo obtain = AccessibilityNodeInfo.obtain(this.mView);
                obtain.setPackageName(this.mContentViewCore.getContext().getPackageName());
                obtain.setSource(this.mView, i);
                if (i == nativeGetRootId) {
                    obtain.setParent(this.mView);
                }
                if (nativePopulateAccessibilityNodeInfo(this.mNativeObj, obtain, i)) {
                    return obtain;
                }
                obtain.recycle();
            }
        }
        return null;
    }

    public List<AccessibilityNodeInfo> findAccessibilityNodeInfosByText(String str, int i) {
        return new ArrayList();
    }

    public AccessibilityNodeProvider getAccessibilityNodeProvider() {
        return this.mAccessibilityNodeProvider;
    }

    public native String nativeGetSupportedHtmlElementTypes(long j);

    public void notifyFrameInfoInitialized() {
        if (!this.mNotifyFrameInfoInitializedCalled) {
            this.mNotifyFrameInfoInitializedCalled = true;
            sendWindowContentChangedOnView();
            int i = this.mAccessibilityFocusId;
            if (i != -1) {
                moveAccessibilityFocusToIdAndRefocusIfNeeded(i);
            }
        }
    }

    public boolean onHoverEvent(MotionEvent motionEvent) {
        if (!this.mAccessibilityManager.isEnabled() || this.mNativeObj == 0) {
            return false;
        }
        if (motionEvent.getAction() == 10) {
            this.mIsHovering = false;
            int i = this.mLastHoverId;
            if (i != -1) {
                sendAccessibilityEvent(i, 256);
                this.mLastHoverId = -1;
            }
            if (this.mPendingScrollToMakeNodeVisible) {
                nativeScrollToMakeNodeVisible(this.mNativeObj, this.mAccessibilityFocusId);
            }
            this.mPendingScrollToMakeNodeVisible = false;
            return true;
        }
        this.mIsHovering = true;
        this.mUserHasTouchExplored = true;
        float x = motionEvent.getX();
        float y = motionEvent.getY();
        nativeHitTest(this.mNativeObj, (int) this.mRenderCoordinates.fromPixToLocalCss(x), (int) this.mRenderCoordinates.fromPixToLocalCss(y));
        return true;
    }

    public boolean performAction(int i, int i2, Bundle bundle) {
        String string;
        String string2;
        int i3;
        int i4;
        String string3;
        if (this.mAccessibilityManager.isEnabled()) {
            long j = this.mNativeObj;
            if (j != 0 && nativeIsNodeValid(j, i)) {
                if (i2 == 1) {
                    nativeFocus(this.mNativeObj, i);
                    return true;
                } else if (i2 != 2) {
                    switch (i2) {
                        case 16:
                            nativeClick(this.mNativeObj, i);
                            return true;
                        case 64:
                            if (!moveAccessibilityFocusToId(i)) {
                                return true;
                            }
                            if (!this.mIsHovering) {
                                nativeScrollToMakeNodeVisible(this.mNativeObj, this.mAccessibilityFocusId);
                            } else {
                                this.mPendingScrollToMakeNodeVisible = true;
                            }
                            return true;
                        case 128:
                            sendAccessibilityEvent(i, 65536);
                            if (this.mAccessibilityFocusId == i) {
                                this.mAccessibilityFocusId = -1;
                                this.mAccessibilityFocusRect = null;
                            }
                            return true;
                        case 256:
                            if (bundle == null) {
                                return false;
                            }
                            int i5 = bundle.getInt(AccessibilityNodeInfoCompat.ACTION_ARGUMENT_MOVEMENT_GRANULARITY_INT);
                            boolean z = bundle.getBoolean(AccessibilityNodeInfoCompat.ACTION_ARGUMENT_EXTEND_SELECTION_BOOLEAN);
                            if (!isValidMovementGranularity(i5)) {
                                return false;
                            }
                            return nextAtGranularity(i5, z);
                        case 512:
                            if (bundle == null) {
                                return false;
                            }
                            int i6 = bundle.getInt(AccessibilityNodeInfoCompat.ACTION_ARGUMENT_MOVEMENT_GRANULARITY_INT);
                            boolean z2 = bundle.getBoolean(AccessibilityNodeInfoCompat.ACTION_ARGUMENT_EXTEND_SELECTION_BOOLEAN);
                            if (!isValidMovementGranularity(i6)) {
                                return false;
                            }
                            return previousAtGranularity(i6, z2);
                        case 1024:
                            if (bundle == null || (string = bundle.getString(AccessibilityNodeInfoCompat.ACTION_ARGUMENT_HTML_ELEMENT_STRING)) == null) {
                                return false;
                            }
                            return jumpToElementType(string.toUpperCase(Locale.US), true);
                        case 2048:
                            if (bundle == null || (string2 = bundle.getString(AccessibilityNodeInfoCompat.ACTION_ARGUMENT_HTML_ELEMENT_STRING)) == null) {
                                return false;
                            }
                            return jumpToElementType(string2.toUpperCase(Locale.US), false);
                        case 4096:
                            return scrollForward(i);
                        case 8192:
                            return scrollBackward(i);
                        case 131072:
                            if (!nativeIsEditableText(this.mNativeObj, i)) {
                                return false;
                            }
                            if (bundle != null) {
                                int i7 = bundle.getInt(AccessibilityNodeInfoCompat.ACTION_ARGUMENT_SELECTION_START_INT);
                                i3 = bundle.getInt(AccessibilityNodeInfoCompat.ACTION_ARGUMENT_SELECTION_END_INT);
                                i4 = i7;
                            } else {
                                i4 = 0;
                                i3 = 0;
                            }
                            nativeSetSelection(this.mNativeObj, i, i4, i3);
                            return true;
                        case 2097152:
                            if (!nativeIsEditableText(this.mNativeObj, i) || bundle == null || (string3 = bundle.getString("ACTION_ARGUMENT_SET_TEXT_CHARSEQUENCE")) == null) {
                                return false;
                            }
                            nativeSetTextFieldValue(this.mNativeObj, i, string3);
                            nativeSetSelection(this.mNativeObj, i, string3.length(), string3.length());
                            return true;
                        default:
                            return false;
                    }
                } else {
                    nativeBlur(this.mNativeObj);
                    return true;
                }
            }
        }
        return false;
    }

    @CalledByNative
    public void setAccessibilityEventCollectionInfo(AccessibilityEvent accessibilityEvent, int i, int i2, boolean z) {
        Bundle orCreateBundleForAccessibilityEvent = getOrCreateBundleForAccessibilityEvent(accessibilityEvent);
        orCreateBundleForAccessibilityEvent.putInt("AccessibilityNodeInfo.CollectionInfo.rowCount", i);
        orCreateBundleForAccessibilityEvent.putInt("AccessibilityNodeInfo.CollectionInfo.columnCount", i2);
        orCreateBundleForAccessibilityEvent.putBoolean("AccessibilityNodeInfo.CollectionInfo.hierarchical", z);
    }

    @CalledByNative
    public void setAccessibilityEventCollectionItemInfo(AccessibilityEvent accessibilityEvent, int i, int i2, int i3, int i4) {
        Bundle orCreateBundleForAccessibilityEvent = getOrCreateBundleForAccessibilityEvent(accessibilityEvent);
        orCreateBundleForAccessibilityEvent.putInt("AccessibilityNodeInfo.CollectionItemInfo.rowIndex", i);
        orCreateBundleForAccessibilityEvent.putInt("AccessibilityNodeInfo.CollectionItemInfo.rowSpan", i2);
        orCreateBundleForAccessibilityEvent.putInt("AccessibilityNodeInfo.CollectionItemInfo.columnIndex", i3);
        orCreateBundleForAccessibilityEvent.putInt("AccessibilityNodeInfo.CollectionItemInfo.columnSpan", i4);
    }

    @CalledByNative
    public void setAccessibilityEventHeadingFlag(AccessibilityEvent accessibilityEvent, boolean z) {
        getOrCreateBundleForAccessibilityEvent(accessibilityEvent).putBoolean("AccessibilityNodeInfo.CollectionItemInfo.heading", z);
    }

    @CalledByNative
    public void setAccessibilityEventLollipopAttributes(AccessibilityEvent accessibilityEvent, boolean z, boolean z2, boolean z3, boolean z4, int i, int i2) {
        Bundle orCreateBundleForAccessibilityEvent = getOrCreateBundleForAccessibilityEvent(accessibilityEvent);
        orCreateBundleForAccessibilityEvent.putBoolean("AccessibilityNodeInfo.canOpenPopup", z);
        orCreateBundleForAccessibilityEvent.putBoolean("AccessibilityNodeInfo.contentInvalid", z2);
        orCreateBundleForAccessibilityEvent.putBoolean("AccessibilityNodeInfo.dismissable", z3);
        orCreateBundleForAccessibilityEvent.putBoolean("AccessibilityNodeInfo.multiLine", z4);
        orCreateBundleForAccessibilityEvent.putInt("AccessibilityNodeInfo.inputType", i);
        orCreateBundleForAccessibilityEvent.putInt("AccessibilityNodeInfo.liveRegion", i2);
    }

    @CalledByNative
    public void setAccessibilityEventRangeInfo(AccessibilityEvent accessibilityEvent, int i, float f, float f2, float f3) {
        Bundle orCreateBundleForAccessibilityEvent = getOrCreateBundleForAccessibilityEvent(accessibilityEvent);
        orCreateBundleForAccessibilityEvent.putInt("AccessibilityNodeInfo.RangeInfo.type", i);
        orCreateBundleForAccessibilityEvent.putFloat("AccessibilityNodeInfo.RangeInfo.min", f);
        orCreateBundleForAccessibilityEvent.putFloat("AccessibilityNodeInfo.RangeInfo.max", f2);
        orCreateBundleForAccessibilityEvent.putFloat("AccessibilityNodeInfo.RangeInfo.current", f3);
    }

    @CalledByNative
    public void setAccessibilityNodeInfoCollectionInfo(AccessibilityNodeInfo accessibilityNodeInfo, int i, int i2, boolean z) {
    }

    @CalledByNative
    public void setAccessibilityNodeInfoCollectionItemInfo(AccessibilityNodeInfo accessibilityNodeInfo, int i, int i2, int i3, int i4, boolean z) {
    }

    @CalledByNative
    public void setAccessibilityNodeInfoKitKatAttributes(AccessibilityNodeInfo accessibilityNodeInfo, boolean z, boolean z2, String str) {
    }

    @CalledByNative
    public void setAccessibilityNodeInfoLollipopAttributes(AccessibilityNodeInfo accessibilityNodeInfo, boolean z, boolean z2, boolean z3, boolean z4, int i, int i2) {
    }

    @CalledByNative
    public void setAccessibilityNodeInfoRangeInfo(AccessibilityNodeInfo accessibilityNodeInfo, int i, float f, float f2, float f3) {
    }

    @CalledByNative
    public void setAccessibilityNodeInfoViewIdResourceName(AccessibilityNodeInfo accessibilityNodeInfo, String str) {
    }

    @CalledByNative
    public boolean shouldExposePasswordText() {
        return Settings.Secure.getInt(this.mContentViewCore.getContext().getContentResolver(), "speak_password", 0) == 1;
    }
}
