package org.chromium.content.browser.crypto;

import android.annotation.SuppressLint;
import android.os.AsyncTask;
import android.os.Bundle;
import java.io.IOException;
import java.security.GeneralSecurityException;
import java.security.Key;
import java.security.SecureRandom;
import java.util.Arrays;
import java.util.Iterator;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.FutureTask;
import javax.annotation.concurrent.ThreadSafe;
import javax.crypto.Cipher;
import javax.crypto.KeyGenerator;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import org.chromium.base.Log;
import org.chromium.base.ObserverList;
import org.chromium.base.SecureRandomInitializer;
import org.chromium.base.ThreadUtils;

@ThreadSafe
public class CipherFactory {
    public static final String BUNDLE_IV = "org.chromium.content.browser.crypto.CipherFactory.IV";
    public static final String BUNDLE_KEY = "org.chromium.content.browser.crypto.CipherFactory.KEY";
    public static final int NUM_BYTES = 16;
    private static final String TAG = "cr.CipherFactory";
    private CipherData mData;
    private FutureTask<CipherData> mDataGenerator;
    private final Object mDataLock;
    private final ObserverList<CipherDataObserver> mObservers;
    private ByteArrayGenerator mRandomNumberProvider;

    public static class CipherData {
        public final byte[] iv;
        public final Key key;

        public CipherData(Key key2, byte[] bArr) {
            this.key = key2;
            this.iv = bArr;
        }
    }

    public interface CipherDataObserver {
        void onCipherDataGenerated();
    }

    public static class LazyHolder {
        private static CipherFactory sInstance = new CipherFactory();

        private LazyHolder() {
        }
    }

    private Callable<CipherData> createGeneratorCallable() {
        return new Callable<CipherData>() {
            /* class org.chromium.content.browser.crypto.CipherFactory.AnonymousClass2 */

            @Override // java.util.concurrent.Callable
            @SuppressLint({"TrulyRandom"})
            public CipherData call() {
                try {
                    byte[] bytes = CipherFactory.this.mRandomNumberProvider.getBytes(16);
                    try {
                        SecureRandom instance = SecureRandom.getInstance("SHA1PRNG");
                        SecureRandomInitializer.initialize(instance);
                        KeyGenerator instance2 = KeyGenerator.getInstance("AES");
                        instance2.init(128, instance);
                        return new CipherData(instance2.generateKey(), bytes);
                    } catch (IOException unused) {
                        Log.e(CipherFactory.TAG, "Couldn't get generator data.", new Object[0]);
                        return null;
                    } catch (GeneralSecurityException unused2) {
                        Log.e(CipherFactory.TAG, "Couldn't get generator instances.", new Object[0]);
                        return null;
                    }
                } catch (IOException unused3) {
                    Log.e(CipherFactory.TAG, "Couldn't get generator data.", new Object[0]);
                    return null;
                } catch (GeneralSecurityException unused4) {
                    Log.e(CipherFactory.TAG, "Couldn't get generator data.", new Object[0]);
                    return null;
                }
            }
        };
    }

    public static CipherFactory getInstance() {
        return LazyHolder.sInstance;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void notifyCipherDataGenerated() {
        Iterator<CipherDataObserver> it = this.mObservers.iterator();
        while (it.hasNext()) {
            it.next().onCipherDataGenerated();
        }
    }

    public void addCipherDataObserver(CipherDataObserver cipherDataObserver) {
        this.mObservers.addObserver(cipherDataObserver);
    }

    public Cipher getCipher(int i) {
        CipherData cipherData = getCipherData(true);
        if (cipherData != null) {
            try {
                Cipher instance = Cipher.getInstance("AES/CBC/PKCS5Padding");
                instance.init(i, cipherData.key, new IvParameterSpec(cipherData.iv));
                return instance;
            } catch (GeneralSecurityException unused) {
            }
        }
        Log.e(TAG, "Error in creating cipher instance.", new Object[0]);
        return null;
    }

    public CipherData getCipherData(boolean z) {
        if (this.mData == null && z) {
            triggerKeyGeneration();
            try {
                CipherData cipherData = this.mDataGenerator.get();
                synchronized (this.mDataLock) {
                    if (this.mData == null) {
                        this.mData = cipherData;
                        ThreadUtils.postOnUiThread(new Runnable() {
                            /* class org.chromium.content.browser.crypto.CipherFactory.AnonymousClass1 */

                            public void run() {
                                CipherFactory.this.notifyCipherDataGenerated();
                            }
                        });
                    }
                }
            } catch (InterruptedException e) {
                throw new RuntimeException(e);
            } catch (ExecutionException e2) {
                throw new RuntimeException(e2);
            }
        }
        return this.mData;
    }

    public boolean hasCipher() {
        boolean z;
        synchronized (this.mDataLock) {
            z = this.mData != null;
        }
        return z;
    }

    public void removeCipherDataObserver(CipherDataObserver cipherDataObserver) {
        this.mObservers.removeObserver(cipherDataObserver);
    }

    public boolean restoreFromBundle(Bundle bundle) {
        if (bundle == null) {
            return false;
        }
        byte[] byteArray = bundle.getByteArray(BUNDLE_KEY);
        byte[] byteArray2 = bundle.getByteArray(BUNDLE_IV);
        if (!(byteArray == null || byteArray2 == null)) {
            try {
                SecretKeySpec secretKeySpec = new SecretKeySpec(byteArray, "AES");
                synchronized (this.mDataLock) {
                    CipherData cipherData = this.mData;
                    if (cipherData == null) {
                        this.mData = new CipherData(secretKeySpec, byteArray2);
                        return true;
                    } else if (cipherData.key.equals(secretKeySpec) && Arrays.equals(this.mData.iv, byteArray2)) {
                        return true;
                    } else {
                        Log.e(TAG, "Attempted to restore different cipher data.", new Object[0]);
                    }
                }
            } catch (IllegalArgumentException unused) {
                Log.e(TAG, "Error in restoring the key from the bundle.", new Object[0]);
            }
        }
        return false;
    }

    public void saveToBundle(Bundle bundle) {
        byte[] encoded;
        CipherData cipherData = getCipherData(false);
        if (cipherData != null && (encoded = cipherData.key.getEncoded()) != null && cipherData.iv != null) {
            bundle.putByteArray(BUNDLE_KEY, encoded);
            bundle.putByteArray(BUNDLE_IV, cipherData.iv);
        }
    }

    public void setRandomNumberProviderForTests(ByteArrayGenerator byteArrayGenerator) {
        this.mRandomNumberProvider = byteArrayGenerator;
    }

    public void triggerKeyGeneration() {
        if (this.mData == null) {
            synchronized (this.mDataLock) {
                if (this.mDataGenerator == null) {
                    FutureTask<CipherData> futureTask = new FutureTask<>(createGeneratorCallable());
                    this.mDataGenerator = futureTask;
                    AsyncTask.THREAD_POOL_EXECUTOR.execute(futureTask);
                }
            }
        }
    }

    private CipherFactory() {
        this.mDataLock = new Object();
        this.mRandomNumberProvider = new ByteArrayGenerator();
        this.mObservers = new ObserverList<>();
    }
}
