package org.chromium.content.browser.input;

import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.view.KeyEvent;
import android.view.View;
import android.view.inputmethod.BaseInputConnection;
import android.view.inputmethod.CompletionInfo;
import android.view.inputmethod.CorrectionInfo;
import android.view.inputmethod.ExtractedText;
import android.view.inputmethod.ExtractedTextRequest;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.LinkedBlockingQueue;
import org.chromium.base.Log;
import org.chromium.base.ThreadUtils;
import org.chromium.base.VisibleForTesting;

public class ThreadedInputConnection extends BaseInputConnection implements ChromiumBaseInputConnection {
    private static final boolean DEBUG_LOGS = false;
    private static final String TAG = "cr_Ime";
    private static final TextInputState UNBLOCKER = new TextInputState("", new Range(0, 0), new Range(-1, -1), false, false) {
        /* class org.chromium.content.browser.input.ThreadedInputConnection.AnonymousClass1 */

        @Override // org.chromium.content.browser.input.TextInputState
        public boolean shouldUnblock() {
            return true;
        }
    };
    private final Runnable mFinishComposingTextRunnable = new Runnable() {
        /* class org.chromium.content.browser.input.ThreadedInputConnection.AnonymousClass6 */

        public void run() {
            ThreadedInputConnection.this.mImeAdapter.finishComposingText();
        }
    };
    private final Handler mHandler;
    private final ImeAdapter mImeAdapter;
    private final Runnable mMoveCursorSelectionEndRunnable = new Runnable() {
        /* class org.chromium.content.browser.input.ThreadedInputConnection.AnonymousClass3 */

        public void run() {
            TextInputState requestAndWaitForTextInputState = ThreadedInputConnection.this.requestAndWaitForTextInputState();
            if (requestAndWaitForTextInputState != null) {
                Range selection = requestAndWaitForTextInputState.selection();
                ThreadedInputConnection.this.setSelection(selection.end(), selection.end());
            }
        }
    };
    private final Runnable mNotifyUserActionRunnable = new Runnable() {
        /* class org.chromium.content.browser.input.ThreadedInputConnection.AnonymousClass5 */

        public void run() {
            ThreadedInputConnection.this.mImeAdapter.notifyUserAction();
        }
    };
    private int mNumNestedBatchEdits;
    private int mPendingAccent;
    private final Runnable mProcessPendingInputStatesRunnable = new Runnable() {
        /* class org.chromium.content.browser.input.ThreadedInputConnection.AnonymousClass2 */

        public void run() {
            ThreadedInputConnection.this.processPendingInputStates();
        }
    };
    private final BlockingQueue<TextInputState> mQueue = new LinkedBlockingQueue();
    private final Runnable mRequestTextInputStateUpdate = new Runnable() {
        /* class org.chromium.content.browser.input.ThreadedInputConnection.AnonymousClass4 */

        public void run() {
            if (!ThreadedInputConnection.this.mImeAdapter.requestTextInputStateUpdate()) {
                ThreadedInputConnection.this.unblockOnUiThread();
            }
        }
    };

    public ThreadedInputConnection(View view, ImeAdapter imeAdapter, Handler handler) {
        super(view, true);
        ImeUtils.checkOnUiThread();
        this.mImeAdapter = imeAdapter;
        this.mHandler = handler;
    }

    private void addToQueueOnUiThread(TextInputState textInputState) {
        ImeUtils.checkOnUiThread();
        try {
            this.mQueue.put(textInputState);
        } catch (InterruptedException e) {
            Log.e(TAG, "addToQueueOnUiThread interrupted", e);
        }
    }

    private void assertOnImeThread() {
        ImeUtils.checkCondition(this.mHandler.getLooper() == Looper.myLooper());
    }

    private TextInputState blockAndGetStateUpdate() {
        assertOnImeThread();
        boolean z = false;
        while (true) {
            try {
                TextInputState take = this.mQueue.take();
                if (take.shouldUnblock()) {
                    return null;
                }
                if (take.fromIme()) {
                    if (z) {
                        updateSelection(take);
                    }
                    return take;
                }
                z = true;
            } catch (InterruptedException e) {
                e.printStackTrace();
                ImeUtils.checkCondition(false);
                return null;
            }
        }
    }

    private void cancelCombiningAccent() {
        this.mPendingAccent = 0;
    }

    private boolean handleCombiningAccent(KeyEvent keyEvent) {
        int action = keyEvent.getAction();
        int unicodeChar = keyEvent.getUnicodeChar();
        if (action != 0) {
            return false;
        }
        if ((Integer.MIN_VALUE & unicodeChar) != 0) {
            int i = unicodeChar & Integer.MAX_VALUE;
            StringBuilder sb = new StringBuilder();
            sb.appendCodePoint(i);
            updateComposingText(sb.toString(), 1, true);
            setCombiningAccent(i);
            return true;
        }
        int i2 = this.mPendingAccent;
        if (!(i2 == 0 || unicodeChar == 0)) {
            int deadChar = KeyEvent.getDeadChar(i2, unicodeChar);
            if (deadChar != 0) {
                StringBuilder sb2 = new StringBuilder();
                sb2.appendCodePoint(deadChar);
                commitText(sb2.toString(), 1);
                return true;
            }
            finishComposingText();
        }
        return false;
    }

    private void notifyUserAction() {
        ThreadUtils.postOnUiThread(this.mNotifyUserActionRunnable);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void processPendingInputStates() {
        assertOnImeThread();
        while (true) {
            TextInputState poll = this.mQueue.poll();
            if (poll != null) {
                if (!poll.shouldUnblock()) {
                    updateSelection(poll);
                }
            } else {
                return;
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private TextInputState requestAndWaitForTextInputState() {
        ThreadUtils.postOnUiThread(this.mRequestTextInputStateUpdate);
        return blockAndGetStateUpdate();
    }

    private void updateSelection(TextInputState textInputState) {
        if (textInputState != null) {
            assertOnImeThread();
            if (this.mNumNestedBatchEdits == 0) {
                Range selection = textInputState.selection();
                Range composition = textInputState.composition();
                this.mImeAdapter.updateSelection(selection.start(), selection.end(), composition.start(), composition.end());
            }
        }
    }

    public boolean beginBatchEdit() {
        assertOnImeThread();
        this.mNumNestedBatchEdits++;
        return true;
    }

    public boolean clearMetaKeyStates(int i) {
        assertOnImeThread();
        return false;
    }

    public void closeConnection() {
    }

    public boolean commitCompletion(CompletionInfo completionInfo) {
        assertOnImeThread();
        return false;
    }

    public boolean commitCorrection(CorrectionInfo correctionInfo) {
        assertOnImeThread();
        return false;
    }

    public boolean commitText(final CharSequence charSequence, final int i) {
        assertOnImeThread();
        cancelCombiningAccent();
        ThreadUtils.postOnUiThread(new Runnable() {
            /* class org.chromium.content.browser.input.ThreadedInputConnection.AnonymousClass9 */

            public void run() {
                ImeAdapter imeAdapter = ThreadedInputConnection.this.mImeAdapter;
                CharSequence charSequence = charSequence;
                imeAdapter.sendCompositionToNative(charSequence, i, charSequence.length() > 0, 0);
            }
        });
        notifyUserAction();
        return true;
    }

    public boolean deleteSurroundingText(final int i, final int i2) {
        assertOnImeThread();
        if (this.mPendingAccent != 0) {
            finishComposingText();
        }
        ThreadUtils.postOnUiThread(new Runnable() {
            /* class org.chromium.content.browser.input.ThreadedInputConnection.AnonymousClass12 */

            public void run() {
                ThreadedInputConnection.this.mImeAdapter.deleteSurroundingText(i, i2);
            }
        });
        return true;
    }

    public boolean deleteSurroundingTextInCodePoints(int i, int i2) {
        return false;
    }

    public boolean endBatchEdit() {
        assertOnImeThread();
        int i = this.mNumNestedBatchEdits;
        if (i == 0) {
            return false;
        }
        int i2 = i - 1;
        this.mNumNestedBatchEdits = i2;
        if (i2 == 0) {
            updateSelection(requestAndWaitForTextInputState());
        }
        if (this.mNumNestedBatchEdits != 0) {
            return true;
        }
        return false;
    }

    public boolean finishComposingText() {
        cancelCombiningAccent();
        ThreadUtils.postOnUiThread(this.mFinishComposingTextRunnable);
        return true;
    }

    public int getCursorCapsMode(int i) {
        assertOnImeThread();
        return 0;
    }

    public ExtractedText getExtractedText(ExtractedTextRequest extractedTextRequest, int i) {
        assertOnImeThread();
        TextInputState requestAndWaitForTextInputState = requestAndWaitForTextInputState();
        if (requestAndWaitForTextInputState == null) {
            return null;
        }
        ExtractedText extractedText = new ExtractedText();
        extractedText.text = requestAndWaitForTextInputState.text();
        extractedText.partialEndOffset = requestAndWaitForTextInputState.text().length();
        extractedText.selectionStart = requestAndWaitForTextInputState.selection().start();
        extractedText.selectionEnd = requestAndWaitForTextInputState.selection().end();
        extractedText.flags = requestAndWaitForTextInputState.singleLine() ? 1 : 0;
        return extractedText;
    }

    @Override // org.chromium.content.browser.input.ChromiumBaseInputConnection
    public Handler getHandler() {
        return this.mHandler;
    }

    public BlockingQueue<TextInputState> getQueueForTest() {
        return this.mQueue;
    }

    public CharSequence getSelectedText(int i) {
        assertOnImeThread();
        TextInputState requestAndWaitForTextInputState = requestAndWaitForTextInputState();
        if (requestAndWaitForTextInputState == null) {
            return null;
        }
        return requestAndWaitForTextInputState.getSelectedText();
    }

    public CharSequence getTextAfterCursor(int i, int i2) {
        assertOnImeThread();
        TextInputState requestAndWaitForTextInputState = requestAndWaitForTextInputState();
        if (requestAndWaitForTextInputState == null) {
            return null;
        }
        return requestAndWaitForTextInputState.getTextAfterSelection(i);
    }

    public CharSequence getTextBeforeCursor(int i, int i2) {
        assertOnImeThread();
        TextInputState requestAndWaitForTextInputState = requestAndWaitForTextInputState();
        if (requestAndWaitForTextInputState == null) {
            return null;
        }
        return requestAndWaitForTextInputState.getTextBeforeSelection(i);
    }

    @Override // org.chromium.content.browser.input.ChromiumBaseInputConnection
    public void moveCursorToSelectionEndOnUiThread() {
        this.mHandler.post(this.mMoveCursorSelectionEndRunnable);
    }

    @Override // org.chromium.content.browser.input.ChromiumBaseInputConnection
    public void onRestartInputOnUiThread() {
    }

    public boolean performContextMenuAction(final int i) {
        assertOnImeThread();
        ThreadUtils.postOnUiThread(new Runnable() {
            /* class org.chromium.content.browser.input.ThreadedInputConnection.AnonymousClass11 */

            public void run() {
                ThreadedInputConnection.this.mImeAdapter.performContextMenuAction(i);
            }
        });
        return true;
    }

    public boolean performEditorAction(final int i) {
        assertOnImeThread();
        ThreadUtils.postOnUiThread(new Runnable() {
            /* class org.chromium.content.browser.input.ThreadedInputConnection.AnonymousClass10 */

            public void run() {
                ThreadedInputConnection.this.mImeAdapter.performEditorAction(i);
            }
        });
        return true;
    }

    public boolean performPrivateCommand(String str, Bundle bundle) {
        assertOnImeThread();
        return false;
    }

    public boolean reportFullscreenMode(boolean z) {
        return false;
    }

    public boolean requestCursorUpdates(final int i) {
        assertOnImeThread();
        ThreadUtils.postOnUiThread(new Runnable() {
            /* class org.chromium.content.browser.input.ThreadedInputConnection.AnonymousClass16 */

            public void run() {
                ThreadedInputConnection.this.mImeAdapter.onRequestCursorUpdates(i);
            }
        });
        return true;
    }

    public void resetOnUiThread() {
        ImeUtils.checkOnUiThread();
        this.mNumNestedBatchEdits = 0;
        this.mPendingAccent = 0;
    }

    public boolean sendKeyEvent(final KeyEvent keyEvent) {
        assertOnImeThread();
        if (handleCombiningAccent(keyEvent)) {
            return true;
        }
        ThreadUtils.postOnUiThread(new Runnable() {
            /* class org.chromium.content.browser.input.ThreadedInputConnection.AnonymousClass13 */

            public void run() {
                ThreadedInputConnection.this.mImeAdapter.sendKeyEvent(keyEvent);
            }
        });
        notifyUserAction();
        return true;
    }

    @Override // org.chromium.content.browser.input.ChromiumBaseInputConnection
    public boolean sendKeyEventOnUiThread(final KeyEvent keyEvent) {
        ImeUtils.checkOnUiThread();
        this.mHandler.post(new Runnable() {
            /* class org.chromium.content.browser.input.ThreadedInputConnection.AnonymousClass7 */

            public void run() {
                ThreadedInputConnection.this.sendKeyEvent(keyEvent);
            }
        });
        return true;
    }

    @VisibleForTesting
    public void setCombiningAccent(int i) {
        this.mPendingAccent = i;
    }

    public boolean setComposingRegion(final int i, final int i2) {
        assertOnImeThread();
        ThreadUtils.postOnUiThread(new Runnable() {
            /* class org.chromium.content.browser.input.ThreadedInputConnection.AnonymousClass15 */

            public void run() {
                ThreadedInputConnection.this.mImeAdapter.setComposingRegion(i, i2);
            }
        });
        return true;
    }

    public boolean setComposingText(CharSequence charSequence, int i) {
        return updateComposingText(charSequence, i, false);
    }

    public boolean setSelection(final int i, final int i2) {
        assertOnImeThread();
        ThreadUtils.postOnUiThread(new Runnable() {
            /* class org.chromium.content.browser.input.ThreadedInputConnection.AnonymousClass14 */

            public void run() {
                ThreadedInputConnection.this.mImeAdapter.setEditableSelectionOffsets(i, i2);
            }
        });
        return true;
    }

    @Override // org.chromium.content.browser.input.ChromiumBaseInputConnection
    @VisibleForTesting
    public void unblockOnUiThread() {
        ImeUtils.checkOnUiThread();
        addToQueueOnUiThread(UNBLOCKER);
        this.mHandler.post(this.mProcessPendingInputStatesRunnable);
    }

    @VisibleForTesting
    public boolean updateComposingText(final CharSequence charSequence, final int i, boolean z) {
        final int i2 = z ? this.mPendingAccent | Integer.MIN_VALUE : 0;
        assertOnImeThread();
        cancelCombiningAccent();
        ThreadUtils.postOnUiThread(new Runnable() {
            /* class org.chromium.content.browser.input.ThreadedInputConnection.AnonymousClass8 */

            public void run() {
                ThreadedInputConnection.this.mImeAdapter.sendCompositionToNative(charSequence, i, false, i2);
            }
        });
        notifyUserAction();
        return true;
    }

    @Override // org.chromium.content.browser.input.ChromiumBaseInputConnection
    public void updateStateOnUiThread(String str, int i, int i2, int i3, int i4, boolean z, boolean z2) {
        ImeUtils.checkOnUiThread();
        addToQueueOnUiThread(new TextInputState(str, new Range(i, i2), new Range(i3, i4), z, !z2));
        if (z2) {
            this.mHandler.post(this.mProcessPendingInputStatesRunnable);
        }
    }
}
