package org.chromium.content.browser.input;

import android.os.Handler;
import android.os.HandlerThread;
import android.view.View;
import android.view.inputmethod.EditorInfo;
import org.chromium.base.VisibleForTesting;
import org.chromium.content.browser.input.ChromiumBaseInputConnection;

public class ThreadedInputConnectionFactory implements ChromiumBaseInputConnection.Factory {
    private static final int CHECK_REGISTER_RETRY = 1;
    private static final boolean DEBUG_LOGS = false;
    private static final String TAG = "cr_Ime";
    private CheckInvalidator mCheckInvalidator;
    private final Handler mHandler = createHandler();
    private final InputMethodManagerWrapper mInputMethodManagerWrapper;
    private final InputMethodUma mInputMethodUma = createInputMethodUma();
    private ThreadedInputConnectionProxyView mProxyView;
    private boolean mReentrantTriggering;
    private ThreadedInputConnection mThreadedInputConnection;

    public static class CheckInvalidator {
        private boolean mInvalid;

        private CheckInvalidator() {
        }

        public void invalidate() {
            ImeUtils.checkOnUiThread();
            this.mInvalid = true;
        }

        public boolean isInvalid() {
            ImeUtils.checkOnUiThread();
            return this.mInvalid;
        }
    }

    public ThreadedInputConnectionFactory(InputMethodManagerWrapper inputMethodManagerWrapper) {
        this.mInputMethodManagerWrapper = inputMethodManagerWrapper;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void checkRegisterResult(View view, CheckInvalidator checkInvalidator, int i) {
        if (this.mInputMethodManagerWrapper.isActive(this.mProxyView)) {
            this.mInputMethodUma.recordProxyViewSuccess();
        } else if (!checkInvalidator.isInvalid()) {
            if (i > 0) {
                postCheckRegisterResultOnUiThread(view, checkInvalidator, i - 1);
            } else {
                onRegisterProxyViewFailed();
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void postCheckRegisterResultOnUiThread(final View view, final CheckInvalidator checkInvalidator, final int i) {
        Handler handler = view.getHandler();
        if (handler != null) {
            handler.post(new Runnable() {
                /* class org.chromium.content.browser.input.ThreadedInputConnectionFactory.AnonymousClass2 */

                public void run() {
                    ThreadedInputConnectionFactory.this.checkRegisterResult(view, checkInvalidator, i);
                }
            });
        }
    }

    private boolean shouldTriggerDelayedOnCreateInputConnection() {
        for (StackTraceElement stackTraceElement : Thread.currentThread().getStackTrace()) {
            String className = stackTraceElement.getClassName();
            if (className != null && (className.contains(ThreadedInputConnectionProxyView.class.getName()) || className.contains("TestInputMethodManagerWrapper"))) {
                return false;
            }
        }
        return true;
    }

    private void triggerDelayedOnCreateInputConnection(final View view) {
        if (!this.mReentrantTriggering && view.hasFocus() && view.hasWindowFocus()) {
            this.mCheckInvalidator = new CheckInvalidator();
            if (this.mProxyView == null) {
                this.mProxyView = createProxyView(this.mHandler, view);
            }
            this.mReentrantTriggering = true;
            this.mProxyView.requestFocus();
            this.mReentrantTriggering = false;
            view.getHandler().post(new Runnable() {
                /* class org.chromium.content.browser.input.ThreadedInputConnectionFactory.AnonymousClass1 */

                public void run() {
                    if (!ThreadedInputConnectionFactory.this.mCheckInvalidator.isInvalid()) {
                        ThreadedInputConnectionFactory.this.mProxyView.onWindowFocusChanged(true);
                        ThreadedInputConnectionFactory.this.mInputMethodManagerWrapper.isActive(view);
                        ThreadedInputConnectionFactory.this.mHandler.post(new Runnable() {
                            /* class org.chromium.content.browser.input.ThreadedInputConnectionFactory.AnonymousClass1.AnonymousClass1 */

                            public void run() {
                                AnonymousClass1 r0 = AnonymousClass1.this;
                                ThreadedInputConnectionFactory threadedInputConnectionFactory = ThreadedInputConnectionFactory.this;
                                threadedInputConnectionFactory.postCheckRegisterResultOnUiThread(view, threadedInputConnectionFactory.mCheckInvalidator, 1);
                            }
                        });
                    }
                }
            });
        }
    }

    @VisibleForTesting
    public Handler createHandler() {
        HandlerThread handlerThread = new HandlerThread("InputConnectionHandlerThread", 5);
        handlerThread.start();
        return new Handler(handlerThread.getLooper());
    }

    @VisibleForTesting
    public InputMethodUma createInputMethodUma() {
        return new InputMethodUma();
    }

    @VisibleForTesting
    public ThreadedInputConnectionProxyView createProxyView(Handler handler, View view) {
        return new ThreadedInputConnectionProxyView(view.getContext(), handler, view);
    }

    @Override // org.chromium.content.browser.input.ChromiumBaseInputConnection.Factory
    public Handler getHandler() {
        return this.mHandler;
    }

    @VisibleForTesting
    public void onRegisterProxyViewFailed() {
        this.mInputMethodUma.recordProxyViewFailure();
        throw new AssertionError("Failed to register proxy view");
    }

    @Override // org.chromium.content.browser.input.ChromiumBaseInputConnection.Factory
    public void onViewAttachedToWindow() {
        ThreadedInputConnectionProxyView threadedInputConnectionProxyView = this.mProxyView;
        if (threadedInputConnectionProxyView != null) {
            threadedInputConnectionProxyView.onOriginalViewAttachedToWindow();
        }
    }

    @Override // org.chromium.content.browser.input.ChromiumBaseInputConnection.Factory
    public void onViewDetachedFromWindow() {
        CheckInvalidator checkInvalidator = this.mCheckInvalidator;
        if (checkInvalidator != null) {
            checkInvalidator.invalidate();
        }
        ThreadedInputConnectionProxyView threadedInputConnectionProxyView = this.mProxyView;
        if (threadedInputConnectionProxyView != null) {
            threadedInputConnectionProxyView.onOriginalViewDetachedFromWindow();
        }
    }

    @Override // org.chromium.content.browser.input.ChromiumBaseInputConnection.Factory
    public void onViewFocusChanged(boolean z) {
        CheckInvalidator checkInvalidator;
        if (!z && (checkInvalidator = this.mCheckInvalidator) != null) {
            checkInvalidator.invalidate();
        }
        ThreadedInputConnectionProxyView threadedInputConnectionProxyView = this.mProxyView;
        if (threadedInputConnectionProxyView != null) {
            threadedInputConnectionProxyView.onOriginalViewFocusChanged(z);
        }
    }

    @Override // org.chromium.content.browser.input.ChromiumBaseInputConnection.Factory
    public void onWindowFocusChanged(boolean z) {
        CheckInvalidator checkInvalidator;
        if (!z && (checkInvalidator = this.mCheckInvalidator) != null) {
            checkInvalidator.invalidate();
        }
        ThreadedInputConnectionProxyView threadedInputConnectionProxyView = this.mProxyView;
        if (threadedInputConnectionProxyView != null) {
            threadedInputConnectionProxyView.onOriginalViewWindowFocusChanged(z);
        }
    }

    @Override // org.chromium.content.browser.input.ChromiumBaseInputConnection.Factory
    public ThreadedInputConnection initializeAndGet(View view, ImeAdapter imeAdapter, int i, int i2, int i3, int i4, EditorInfo editorInfo) {
        ImeUtils.checkOnUiThread();
        ImeUtils.computeEditorInfo(i, i2, i3, i4, editorInfo);
        CheckInvalidator checkInvalidator = this.mCheckInvalidator;
        if (checkInvalidator != null) {
            checkInvalidator.invalidate();
        }
        if (shouldTriggerDelayedOnCreateInputConnection()) {
            triggerDelayedOnCreateInputConnection(view);
            return null;
        }
        ThreadedInputConnection threadedInputConnection = this.mThreadedInputConnection;
        if (threadedInputConnection == null) {
            this.mThreadedInputConnection = new ThreadedInputConnection(view, imeAdapter, this.mHandler);
        } else {
            threadedInputConnection.resetOnUiThread();
        }
        return this.mThreadedInputConnection;
    }
}
