package org.chromium.device.vibration;

import android.content.Context;
import android.media.AudioManager;
import android.os.Vibrator;
import android.util.Log;
import org.chromium.base.VisibleForTesting;
import org.chromium.mojo.system.MojoException;
import org.chromium.mojom.device.VibrationManager;

public class VibrationManagerImpl implements VibrationManager {
    private static final long MAXIMUM_VIBRATION_DURATION_MS = 10000;
    private static final long MINIMUM_VIBRATION_DURATION_MS = 1;
    private static final String TAG = "VibrationManagerImpl";
    private static AndroidVibratorWrapper sVibratorWrapper;
    private final AudioManager mAudioManager;
    private final boolean mHasVibratePermission;
    private final Vibrator mVibrator;

    @VisibleForTesting
    public static class AndroidVibratorWrapper {
        public void cancel(Vibrator vibrator) {
            vibrator.cancel();
        }

        public void vibrate(Vibrator vibrator, long j) {
            vibrator.vibrate(j);
        }
    }

    public VibrationManagerImpl(Context context) {
        this.mAudioManager = (AudioManager) context.getSystemService("audio");
        this.mVibrator = (Vibrator) context.getSystemService("vibrator");
        if (sVibratorWrapper == null) {
            sVibratorWrapper = new AndroidVibratorWrapper();
        }
        boolean z = context.checkCallingOrSelfPermission("android.permission.VIBRATE") == 0;
        this.mHasVibratePermission = z;
        if (!z) {
            Log.w(TAG, "Failed to use vibrate API, requires VIBRATE permission.");
        }
    }

    public static void setVibratorWrapperForTesting(AndroidVibratorWrapper androidVibratorWrapper) {
        sVibratorWrapper = androidVibratorWrapper;
    }

    @Override // org.chromium.mojom.device.VibrationManager
    public void cancel(VibrationManager.CancelResponse cancelResponse) {
        if (this.mHasVibratePermission) {
            sVibratorWrapper.cancel(this.mVibrator);
        }
        cancelResponse.call();
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable, org.chromium.mojo.bindings.Interface
    public void close() {
    }

    @Override // org.chromium.mojo.bindings.ConnectionErrorHandler
    public void onConnectionError(MojoException mojoException) {
    }

    @Override // org.chromium.mojom.device.VibrationManager
    public void vibrate(long j, VibrationManager.VibrateResponse vibrateResponse) {
        long max = Math.max(1L, Math.min(j, (long) MAXIMUM_VIBRATION_DURATION_MS));
        if (this.mAudioManager.getRingerMode() != 0 && this.mHasVibratePermission) {
            sVibratorWrapper.vibrate(this.mVibrator, max);
        }
        vibrateResponse.call();
    }
}
