package org.chromium.media;

import android.annotation.TargetApi;
import android.media.MediaCodec;
import android.media.MediaCodecInfo;
import android.media.MediaCodecList;
import android.os.Build;
import java.util.Locale;
import org.chromium.base.Log;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;
import org.chromium.base.annotations.MainDex;

@JNINamespace("media")
public class MediaCodecUtil {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final int MEDIA_CODEC_DECODER = 0;
    public static final int MEDIA_CODEC_ENCODER = 1;
    private static final String TAG = "MediaCodecUtil";

    @MainDex
    public static class CodecCreationInfo {
        public MediaCodec mediaCodec = null;
        public boolean supportsAdaptivePlayback = false;
    }

    @MainDex
    public static class MediaCodecListHelper {
        private MediaCodecInfo[] mCodecList;

        @TargetApi(21)
        public MediaCodecListHelper() {
            if (hasNewMediaCodecList()) {
                this.mCodecList = new MediaCodecList(1).getCodecInfos();
            }
        }

        private boolean hasNewMediaCodecList() {
            return Build.VERSION.SDK_INT >= 21;
        }

        public int getCodecCount() {
            if (hasNewMediaCodecList()) {
                return this.mCodecList.length;
            }
            return MediaCodecList.getCodecCount();
        }

        public MediaCodecInfo getCodecInfoAt(int i) {
            if (hasNewMediaCodecList()) {
                return this.mCodecList[i];
            }
            return MediaCodecList.getCodecInfoAt(i);
        }
    }

    @MainDex
    public static final class MimeTypes {
        public static final String VIDEO_H264 = "video/avc";
        public static final String VIDEO_H265 = "video/hevc";
        public static final String VIDEO_MP4 = "video/mp4";
        public static final String VIDEO_VP8 = "video/x-vnd.on2.vp8";
        public static final String VIDEO_VP9 = "video/x-vnd.on2.vp9";
        public static final String VIDEO_WEBM = "video/webm";
    }

    @CalledByNative
    private static boolean canDecode(String str, boolean z) {
        MediaCodec mediaCodec = createDecoder(str, z, false).mediaCodec;
        if (mediaCodec == null) {
            return false;
        }
        try {
            mediaCodec.release();
        } catch (IllegalStateException e) {
            Log.e(TAG, "Cannot release media codec", e);
        }
        return true;
    }

    @TargetApi(19)
    private static boolean codecSupportsAdaptivePlayback(MediaCodec mediaCodec, String str) {
        MediaCodecInfo.CodecCapabilities capabilitiesForType;
        if (Build.VERSION.SDK_INT >= 19 && mediaCodec != null) {
            try {
                MediaCodecInfo codecInfo = mediaCodec.getCodecInfo();
                if (!codecInfo.isEncoder() && !isAdaptivePlaybackBlacklisted(str) && (capabilitiesForType = codecInfo.getCapabilitiesForType(str)) != null && capabilitiesForType.isFeatureSupported("adaptive-playback")) {
                    return true;
                }
                return false;
            } catch (IllegalArgumentException e) {
                Log.e(TAG, "Cannot retrieve codec information", e);
            }
        }
        return false;
    }

    public static CodecCreationInfo createDecoder(String str, boolean z, boolean z2) {
        CodecCreationInfo codecCreationInfo = new CodecCreationInfo();
        if (z && Build.VERSION.SDK_INT < 18) {
            return codecCreationInfo;
        }
        if (!isDecoderSupportedForDevice(str)) {
            Log.e(TAG, "Decoder for type %s is not supported on this device", str);
            return codecCreationInfo;
        }
        try {
            if (!str.startsWith("video") || !z) {
                if (z2) {
                    codecCreationInfo.mediaCodec = MediaCodec.createByCodecName(getDefaultCodecName(str, 0, z2));
                } else {
                    codecCreationInfo.mediaCodec = MediaCodec.createDecoderByType(str);
                }
                codecCreationInfo.supportsAdaptivePlayback = codecSupportsAdaptivePlayback(codecCreationInfo.mediaCodec, str);
                return codecCreationInfo;
            }
            String defaultCodecName = getDefaultCodecName(str, 0, z2);
            if (defaultCodecName.equals("")) {
                return null;
            }
            if (Build.VERSION.SDK_INT >= 19) {
                MediaCodec createByCodecName = MediaCodec.createByCodecName(defaultCodecName);
                codecCreationInfo.supportsAdaptivePlayback = codecSupportsAdaptivePlayback(createByCodecName, str);
                createByCodecName.release();
            }
            codecCreationInfo.mediaCodec = MediaCodec.createByCodecName(defaultCodecName + ".secure");
            return codecCreationInfo;
        } catch (Exception e) {
            Object[] objArr = new Object[4];
            objArr[0] = str;
            objArr[1] = Boolean.valueOf(z);
            objArr[2] = z2 ? "yes" : "no";
            objArr[3] = e;
            Log.e(TAG, "Failed to create MediaCodec: %s, isSecure: %s, requireSoftwareCodec: %s", objArr);
            codecCreationInfo.mediaCodec = null;
        }
    }

    @CalledByNative
    private static String getDefaultCodecName(String str, int i, boolean z) {
        String[] supportedTypes;
        MediaCodecListHelper mediaCodecListHelper = new MediaCodecListHelper();
        int codecCount = mediaCodecListHelper.getCodecCount();
        for (int i2 = 0; i2 < codecCount; i2++) {
            MediaCodecInfo codecInfoAt = mediaCodecListHelper.getCodecInfoAt(i2);
            if (codecInfoAt.isEncoder() == i && (!z || isSoftwareCodec(codecInfoAt.getName()))) {
                for (String str2 : codecInfoAt.getSupportedTypes()) {
                    if (str2.equalsIgnoreCase(str)) {
                        return codecInfoAt.getName();
                    }
                }
                continue;
            }
        }
        Log.e(TAG, "Decoder for type %s is not supported on this device", str);
        return "";
    }

    @CalledByNative
    private static int[] getEncoderColorFormatsForMime(String str) {
        MediaCodecListHelper mediaCodecListHelper = new MediaCodecListHelper();
        int codecCount = mediaCodecListHelper.getCodecCount();
        for (int i = 0; i < codecCount; i++) {
            MediaCodecInfo codecInfoAt = mediaCodecListHelper.getCodecInfoAt(i);
            if (codecInfoAt.isEncoder()) {
                String[] supportedTypes = codecInfoAt.getSupportedTypes();
                for (int i2 = 0; i2 < supportedTypes.length; i2++) {
                    if (supportedTypes[i2].equalsIgnoreCase(str)) {
                        return codecInfoAt.getCapabilitiesForType(supportedTypes[i2]).colorFormats;
                    }
                }
                continue;
            }
        }
        return null;
    }

    private static boolean isAdaptivePlaybackBlacklisted(String str) {
        if ((!str.equals("video/avc") && !str.equals("video/avc1")) || !Build.VERSION.RELEASE.equals("4.4.2") || !Build.MANUFACTURER.toLowerCase(Locale.getDefault()).equals("samsung")) {
            return false;
        }
        String str2 = Build.MODEL;
        if (str2.startsWith("GT-I9300") || str2.startsWith("SCH-I535")) {
            return true;
        }
        return false;
    }

    @CalledByNative
    public static boolean isDecoderSupportedForDevice(String str) {
        if (str.equals("video/x-vnd.on2.vp8")) {
            if (Build.MANUFACTURER.toLowerCase(Locale.getDefault()).equals("samsung")) {
                int i = Build.VERSION.SDK_INT;
                if (i < 21) {
                    String str2 = Build.MODEL;
                    if (str2.startsWith("GT-I9505") || str2.startsWith("GT-I9500")) {
                        return false;
                    }
                }
                String str3 = Build.MODEL;
                if (str3.startsWith("GT-I9190") || str3.startsWith("GT-I9195") || (i < 19 && (str3.startsWith("GT-") || str3.startsWith("SCH-") || str3.startsWith("SM-T")))) {
                    return false;
                }
            }
            if (Build.HARDWARE.startsWith("mt")) {
                return false;
            }
            return true;
        } else if (str.equals("video/x-vnd.on2.vp9")) {
            int i2 = Build.VERSION.SDK_INT;
            if (i2 < 19) {
                return false;
            }
            if (i2 >= 21 || !Build.HARDWARE.startsWith("mt")) {
                return true;
            }
            return false;
        } else if (!str.equals(com.google.android.exoplayer2.util.MimeTypes.AUDIO_OPUS) || Build.VERSION.SDK_INT >= 21) {
            return true;
        } else {
            return false;
        }
    }

    public static boolean isSoftwareCodec(String str) {
        if (!str.startsWith("OMX.google.") && str.startsWith("OMX.")) {
            return false;
        }
        return true;
    }
}
