package org.chromium.media;

import android.content.Context;
import android.os.Build;
import org.chromium.base.Log;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;

@JNINamespace("media")
public class VideoCaptureFactory {

    public static class ChromiumCameraInfo {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        private static final String[][] SPECIAL_DEVICE_LIST = {new String[]{"Peanut", "peanut"}};
        private static final String TAG = "cr.media";
        private static int sNumberOfSystemCameras = -1;

        /* access modifiers changed from: private */
        public static int getNumberOfCameras(Context context) {
            if (sNumberOfSystemCameras == -1) {
                if (Build.VERSION.SDK_INT < 23 && context.getPackageManager().checkPermission("android.permission.CAMERA", context.getPackageName()) != 0) {
                    sNumberOfSystemCameras = 0;
                    Log.w(TAG, "Missing android.permission.CAMERA permission, no system camera available.", new Object[0]);
                } else if (VideoCaptureFactory.isLReleaseOrLater()) {
                    sNumberOfSystemCameras = VideoCaptureCamera2.getNumberOfCameras(context);
                } else {
                    sNumberOfSystemCameras = VideoCaptureAndroid.getNumberOfCameras();
                    if (isSpecialDevice()) {
                        Log.d(TAG, "Special device: %s", Build.MODEL);
                        sNumberOfSystemCameras = VideoCaptureTango.numberOfCameras() + sNumberOfSystemCameras;
                    }
                }
            }
            return sNumberOfSystemCameras;
        }

        /* access modifiers changed from: private */
        public static boolean isSpecialCamera(int i) {
            return i >= sNumberOfSystemCameras;
        }

        private static boolean isSpecialDevice() {
            String[][] strArr = SPECIAL_DEVICE_LIST;
            for (String[] strArr2 : strArr) {
                if (strArr2[0].contentEquals(Build.MODEL) && strArr2[1].contentEquals(Build.DEVICE)) {
                    return true;
                }
            }
            return false;
        }

        /* access modifiers changed from: private */
        public static int toSpecialCameraId(int i) {
            return i - sNumberOfSystemCameras;
        }
    }

    @CalledByNative
    public static VideoCapture createVideoCapture(Context context, int i, long j) {
        if (isLReleaseOrLater() && !VideoCaptureCamera2.isLegacyDevice(context, i)) {
            return new VideoCaptureCamera2(context, i, j);
        }
        if (!ChromiumCameraInfo.isSpecialCamera(i)) {
            return new VideoCaptureAndroid(context, i, j);
        }
        return new VideoCaptureTango(context, ChromiumCameraInfo.toSpecialCameraId(i), j);
    }

    @CalledByNative
    public static int getCaptureApiType(int i, Context context) {
        if (isLReleaseOrLater()) {
            return VideoCaptureCamera2.getCaptureApiType(i, context);
        }
        if (ChromiumCameraInfo.isSpecialCamera(i)) {
            return VideoCaptureTango.getCaptureApiType(ChromiumCameraInfo.toSpecialCameraId(i));
        }
        return VideoCaptureAndroid.getCaptureApiType(i);
    }

    @CalledByNative
    public static int getCaptureFormatFramerate(VideoCaptureFormat videoCaptureFormat) {
        return videoCaptureFormat.getFramerate();
    }

    @CalledByNative
    public static int getCaptureFormatHeight(VideoCaptureFormat videoCaptureFormat) {
        return videoCaptureFormat.getHeight();
    }

    @CalledByNative
    public static int getCaptureFormatPixelFormat(VideoCaptureFormat videoCaptureFormat) {
        return videoCaptureFormat.getPixelFormat();
    }

    @CalledByNative
    public static int getCaptureFormatWidth(VideoCaptureFormat videoCaptureFormat) {
        return videoCaptureFormat.getWidth();
    }

    @CalledByNative
    public static String getDeviceName(int i, Context context) {
        if (!isLReleaseOrLater() || VideoCaptureCamera2.isLegacyDevice(context, i)) {
            return ChromiumCameraInfo.isSpecialCamera(i) ? VideoCaptureTango.getName(ChromiumCameraInfo.toSpecialCameraId(i)) : VideoCaptureAndroid.getName(i);
        }
        return VideoCaptureCamera2.getName(i, context);
    }

    @CalledByNative
    public static VideoCaptureFormat[] getDeviceSupportedFormats(Context context, int i) {
        if (!isLReleaseOrLater() || VideoCaptureCamera2.isLegacyDevice(context, i)) {
            return ChromiumCameraInfo.isSpecialCamera(i) ? VideoCaptureTango.getDeviceSupportedFormats(ChromiumCameraInfo.toSpecialCameraId(i)) : VideoCaptureAndroid.getDeviceSupportedFormats(i);
        }
        return VideoCaptureCamera2.getDeviceSupportedFormats(context, i);
    }

    @CalledByNative
    public static int getNumberOfCameras(Context context) {
        return ChromiumCameraInfo.getNumberOfCameras(context);
    }

    /* access modifiers changed from: private */
    public static boolean isLReleaseOrLater() {
        return Build.VERSION.SDK_INT >= 21;
    }
}
