package org.chromium.media.midi;

import android.annotation.TargetApi;
import android.hardware.usb.UsbDevice;
import android.hardware.usb.UsbDeviceConnection;
import android.hardware.usb.UsbEndpoint;
import android.hardware.usb.UsbInterface;
import android.hardware.usb.UsbManager;
import android.hardware.usb.UsbRequest;
import android.os.Handler;
import android.util.SparseArray;
import java.nio.ByteBuffer;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;

@JNINamespace("media::midi")
public class UsbMidiDeviceAndroid {
    public static final int MIDI_SUBCLASS = 3;
    public static final int REQUEST_GET_DESCRIPTOR = 6;
    public static final int STRING_DESCRIPTOR_TYPE = 3;
    private final UsbDeviceConnection mConnection;
    private final SparseArray<UsbEndpoint> mEndpointMap = new SparseArray<>();
    private final Handler mHandler = new Handler();
    private boolean mHasInputThread;
    private boolean mIsClosed;
    private long mNativePointer;
    private final Map<UsbEndpoint, UsbRequest> mRequestMap = new HashMap();
    private UsbDevice mUsbDevice;

    public UsbMidiDeviceAndroid(UsbManager usbManager, UsbDevice usbDevice) {
        this.mConnection = usbManager.openDevice(usbDevice);
        this.mUsbDevice = usbDevice;
        this.mIsClosed = false;
        this.mHasInputThread = false;
        this.mNativePointer = 0;
        for (int i = 0; i < usbDevice.getInterfaceCount(); i++) {
            UsbInterface usbInterface = usbDevice.getInterface(i);
            if (usbInterface.getInterfaceClass() == 1 && usbInterface.getInterfaceSubclass() == 3) {
                this.mConnection.claimInterface(usbInterface, true);
                for (int i2 = 0; i2 < usbInterface.getEndpointCount(); i2++) {
                    UsbEndpoint endpoint = usbInterface.getEndpoint(i2);
                    if (endpoint.getDirection() == 0) {
                        this.mEndpointMap.put(endpoint.getEndpointNumber(), endpoint);
                    }
                }
            }
        }
        startListen(usbDevice);
    }

    /* access modifiers changed from: private */
    public static int getInputDataLength(ByteBuffer byteBuffer) {
        int position = byteBuffer.position();
        for (int i = 0; i < position; i += 4) {
            if (byteBuffer.get(i) == 0) {
                return i;
            }
        }
        return position;
    }

    /* access modifiers changed from: private */
    public static native void nativeOnData(long j, int i, byte[] bArr);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void postOnDataEvent(final int i, final byte[] bArr) {
        this.mHandler.post(new Runnable() {
            /* class org.chromium.media.midi.UsbMidiDeviceAndroid.AnonymousClass2 */

            public void run() {
                if (!UsbMidiDeviceAndroid.this.mIsClosed) {
                    UsbMidiDeviceAndroid.nativeOnData(UsbMidiDeviceAndroid.this.mNativePointer, i, bArr);
                }
            }
        });
    }

    private boolean shouldUseBulkTransfer() {
        return this.mHasInputThread;
    }

    private void startListen(UsbDevice usbDevice) {
        final HashMap hashMap = new HashMap();
        for (int i = 0; i < usbDevice.getInterfaceCount(); i++) {
            UsbInterface usbInterface = usbDevice.getInterface(i);
            if (usbInterface.getInterfaceClass() == 1 && usbInterface.getInterfaceSubclass() == 3) {
                for (int i2 = 0; i2 < usbInterface.getEndpointCount(); i2++) {
                    UsbEndpoint endpoint = usbInterface.getEndpoint(i2);
                    if (endpoint.getDirection() == 128) {
                        ByteBuffer allocate = ByteBuffer.allocate(endpoint.getMaxPacketSize());
                        UsbRequest usbRequest = new UsbRequest();
                        usbRequest.initialize(this.mConnection, endpoint);
                        usbRequest.queue(allocate, allocate.remaining());
                        hashMap.put(endpoint, allocate);
                    }
                }
            }
        }
        if (!hashMap.isEmpty()) {
            this.mHasInputThread = true;
            new Thread() {
                /* class org.chromium.media.midi.UsbMidiDeviceAndroid.AnonymousClass1 */

                public void run() {
                    while (true) {
                        UsbRequest requestWait = UsbMidiDeviceAndroid.this.mConnection.requestWait();
                        if (requestWait != null) {
                            UsbEndpoint endpoint = requestWait.getEndpoint();
                            if (endpoint.getDirection() == 128) {
                                ByteBuffer byteBuffer = (ByteBuffer) hashMap.get(endpoint);
                                int inputDataLength = UsbMidiDeviceAndroid.getInputDataLength(byteBuffer);
                                if (inputDataLength > 0) {
                                    byteBuffer.rewind();
                                    byte[] bArr = new byte[inputDataLength];
                                    byteBuffer.get(bArr, 0, inputDataLength);
                                    UsbMidiDeviceAndroid.this.postOnDataEvent(endpoint.getEndpointNumber(), bArr);
                                }
                                byteBuffer.rewind();
                                requestWait.queue(byteBuffer, byteBuffer.capacity());
                            }
                        } else {
                            return;
                        }
                    }
                }
            }.start();
        }
    }

    @CalledByNative
    public void close() {
        this.mEndpointMap.clear();
        for (UsbRequest usbRequest : this.mRequestMap.values()) {
            usbRequest.close();
        }
        this.mRequestMap.clear();
        this.mConnection.close();
        this.mNativePointer = 0;
        this.mIsClosed = true;
    }

    @CalledByNative
    public byte[] getDescriptors() {
        UsbDeviceConnection usbDeviceConnection = this.mConnection;
        if (usbDeviceConnection == null) {
            return new byte[0];
        }
        return usbDeviceConnection.getRawDescriptors();
    }

    @CalledByNative
    public byte[] getStringDescriptor(int i) {
        UsbDeviceConnection usbDeviceConnection = this.mConnection;
        if (usbDeviceConnection == null) {
            return new byte[0];
        }
        byte[] bArr = new byte[255];
        int controlTransfer = usbDeviceConnection.controlTransfer(128, 6, i | 768, 0, bArr, 255, 0);
        if (controlTransfer < 0) {
            return new byte[0];
        }
        return Arrays.copyOf(bArr, controlTransfer);
    }

    public UsbDevice getUsbDevice() {
        return this.mUsbDevice;
    }

    public boolean isClosed() {
        return this.mIsClosed;
    }

    @CalledByNative
    public void registerSelf(long j) {
        this.mNativePointer = j;
    }

    @TargetApi(18)
    @CalledByNative
    public void send(int i, byte[] bArr) {
        UsbEndpoint usbEndpoint;
        if (this.mIsClosed || (usbEndpoint = this.mEndpointMap.get(i)) == null) {
            return;
        }
        if (shouldUseBulkTransfer()) {
            this.mConnection.bulkTransfer(usbEndpoint, bArr, bArr.length, 100);
            return;
        }
        UsbRequest usbRequest = this.mRequestMap.get(usbEndpoint);
        if (usbRequest == null) {
            usbRequest = new UsbRequest();
            usbRequest.initialize(this.mConnection, usbEndpoint);
            this.mRequestMap.put(usbEndpoint, usbRequest);
        }
        usbRequest.queue(ByteBuffer.wrap(bArr), bArr.length);
    }
}
