package org.chromium.mojo.bindings;

import androidx.base.b2;
import java.nio.ByteOrder;
import java.nio.charset.Charset;
import org.chromium.mojo.bindings.Interface;
import org.chromium.mojo.system.DataPipe;
import org.chromium.mojo.system.Handle;
import org.chromium.mojo.system.InvalidHandle;
import org.chromium.mojo.system.MessagePipeHandle;
import org.chromium.mojo.system.SharedBufferHandle;
import org.chromium.mojo.system.UntypedHandle;

public class Decoder {
    private final int mBaseOffset;
    private final Message mMessage;
    private final Validator mValidator;

    public static final class Validator {
        private final long mMaxMemory;
        private int mMinNextClaimedHandle = 0;
        private long mMinNextMemory = 0;
        private final long mNumberOfHandles;

        public Validator(long j, int i) {
            this.mMaxMemory = j;
            this.mNumberOfHandles = (long) i;
        }

        public void claimHandle(int i) {
            if (i < this.mMinNextClaimedHandle) {
                throw new DeserializationException("Trying to access handle out of order.");
            } else if (((long) i) < this.mNumberOfHandles) {
                this.mMinNextClaimedHandle = i + 1;
            } else {
                throw new DeserializationException("Trying to access non present handle.");
            }
        }

        public void claimMemory(long j, long j2) {
            if (j % 8 != 0) {
                throw new DeserializationException("Incorrect starting alignment: " + j + ".");
            } else if (j < this.mMinNextMemory) {
                throw new DeserializationException("Trying to access memory out of order.");
            } else if (j2 < j) {
                throw new DeserializationException("Incorrect memory range.");
            } else if (j2 <= this.mMaxMemory) {
                this.mMinNextMemory = BindingsHelper.align(j2);
            } else {
                throw new DeserializationException("Trying to access out of range memory.");
            }
        }
    }

    public Decoder(Message message) {
        this(message, new Validator((long) message.getData().limit(), message.getHandles().size()), 0);
    }

    private Decoder getDecoderAtPosition(int i) {
        return new Decoder(this.mMessage, this.mValidator, i);
    }

    private DataHeader readDataHeaderAtOffset(int i, boolean z) {
        int readInt = readInt(i + 0);
        int readInt2 = readInt(i + 4);
        if (readInt < 0) {
            throw new DeserializationException("Negative size. Unsigned integers are not valid for java.");
        } else if (readInt2 >= 0 || (z && readInt2 == -1)) {
            return new DataHeader(readInt, readInt2);
        } else {
            throw new DeserializationException("Negative elements or version. Unsigned integers are not valid for java.");
        }
    }

    private DataHeader readDataHeaderForArray(long j, int i) {
        DataHeader readDataHeader = readDataHeader();
        int i2 = readDataHeader.elementsOrVersion;
        if (((long) readDataHeader.size) < (j * ((long) i2)) + 8) {
            throw new DeserializationException("Array header is incorrect.");
        } else if (i == -1 || i2 == i) {
            return readDataHeader;
        } else {
            throw new DeserializationException(b2.e(b2.k("Incorrect array length. Expected: ", i, ", but got: "), readDataHeader.elementsOrVersion, "."));
        }
    }

    private DataHeader readDataHeaderForBooleanArray(int i) {
        DataHeader readDataHeader = readDataHeader();
        int i2 = readDataHeader.size;
        int i3 = readDataHeader.elementsOrVersion;
        if (i2 < ((i3 + 7) / 8) + 8) {
            throw new DeserializationException("Array header is incorrect.");
        } else if (i == -1 || i3 == i) {
            return readDataHeader;
        } else {
            throw new DeserializationException(b2.e(b2.k("Incorrect array length. Expected: ", i, ", but got: "), readDataHeader.elementsOrVersion, "."));
        }
    }

    private void validateBufferSize(int i, int i2) {
        if (this.mMessage.getData().limit() < i + i2) {
            throw new DeserializationException("Buffer is smaller than expected.");
        }
    }

    public Decoder decoderForSerializedUnion() {
        this.mValidator.claimMemory(0, 16);
        return this;
    }

    public DataHeader readAndValidateDataHeader(DataHeader[] dataHeaderArr) {
        DataHeader readDataHeader = readDataHeader();
        int length = dataHeaderArr.length - 1;
        if (readDataHeader.elementsOrVersion <= dataHeaderArr[length].elementsOrVersion) {
            DataHeader dataHeader = null;
            while (true) {
                if (length < 0) {
                    break;
                }
                DataHeader dataHeader2 = dataHeaderArr[length];
                if (readDataHeader.elementsOrVersion >= dataHeader2.elementsOrVersion) {
                    dataHeader = dataHeader2;
                    break;
                }
                length--;
            }
            if (dataHeader == null || dataHeader.size != readDataHeader.size) {
                throw new DeserializationException("Header doesn't correspond to any known version.");
            }
        } else if (readDataHeader.size < dataHeaderArr[length].size) {
            throw new DeserializationException("Message newer than the last known version cannot be shorter than required by the last known version.");
        }
        return readDataHeader;
    }

    public AssociatedInterfaceRequestNotSupported readAssociatedInterfaceRequestNotSupported(int i, boolean z) {
        return null;
    }

    public AssociatedInterfaceRequestNotSupported[] readAssociatedInterfaceRequestNotSupporteds(int i, int i2, int i3) {
        return null;
    }

    public AssociatedInterfaceNotSupported readAssociatedServiceInterfaceNotSupported(int i, boolean z) {
        return null;
    }

    public AssociatedInterfaceNotSupported[] readAssociatedServiceInterfaceNotSupporteds(int i, int i2, int i3) {
        return null;
    }

    public boolean readBoolean(int i, int i2) {
        validateBufferSize(i, 1);
        if ((readByte(i) & (1 << i2)) != 0) {
            return true;
        }
        return false;
    }

    public boolean[] readBooleans(int i, int i2, int i3) {
        Decoder readPointer = readPointer(i, BindingsHelper.isArrayNullable(i2));
        if (readPointer == null) {
            return null;
        }
        DataHeader readDataHeaderForBooleanArray = readPointer.readDataHeaderForBooleanArray(i3);
        int i4 = (readDataHeaderForBooleanArray.elementsOrVersion + 7) / 8;
        byte[] bArr = new byte[i4];
        readPointer.mMessage.getData().position(readPointer.mBaseOffset + 8);
        readPointer.mMessage.getData().get(bArr);
        int i5 = readDataHeaderForBooleanArray.elementsOrVersion;
        boolean[] zArr = new boolean[i5];
        for (int i6 = 0; i6 < i4; i6++) {
            for (int i7 = 0; i7 < 8; i7++) {
                int i8 = (i6 * 8) + i7;
                if (i8 < i5) {
                    boolean z = true;
                    if ((bArr[i6] & (1 << i7)) == 0) {
                        z = false;
                    }
                    zArr[i8] = z;
                }
            }
        }
        return zArr;
    }

    public byte readByte(int i) {
        validateBufferSize(i, 1);
        return this.mMessage.getData().get(this.mBaseOffset + i);
    }

    public byte[] readBytes(int i, int i2, int i3) {
        Decoder readPointer = readPointer(i, BindingsHelper.isArrayNullable(i2));
        if (readPointer == null) {
            return null;
        }
        byte[] bArr = new byte[readPointer.readDataHeaderForArray(1, i3).elementsOrVersion];
        readPointer.mMessage.getData().position(readPointer.mBaseOffset + 8);
        readPointer.mMessage.getData().get(bArr);
        return bArr;
    }

    public DataPipe.ConsumerHandle readConsumerHandle(int i, boolean z) {
        return readUntypedHandle(i, z).toDataPipeConsumerHandle();
    }

    public DataPipe.ConsumerHandle[] readConsumerHandles(int i, int i2, int i3) {
        Decoder readPointer = readPointer(i, BindingsHelper.isArrayNullable(i2));
        if (readPointer == null) {
            return null;
        }
        int i4 = readPointer.readDataHeaderForArray(4, i3).elementsOrVersion;
        DataPipe.ConsumerHandle[] consumerHandleArr = new DataPipe.ConsumerHandle[i4];
        for (int i5 = 0; i5 < i4; i5++) {
            consumerHandleArr[i5] = readPointer.readConsumerHandle((i5 * 4) + 8, BindingsHelper.isElementNullable(i2));
        }
        return consumerHandleArr;
    }

    public DataHeader readDataHeader() {
        Validator validator = this.mValidator;
        int i = this.mBaseOffset;
        validator.claimMemory((long) i, (long) (i + 8));
        DataHeader readDataHeaderAtOffset = readDataHeaderAtOffset(0, false);
        Validator validator2 = this.mValidator;
        int i2 = this.mBaseOffset;
        validator2.claimMemory((long) (i2 + 8), (long) (i2 + readDataHeaderAtOffset.size));
        return readDataHeaderAtOffset;
    }

    public void readDataHeaderForMap() {
        DataHeader readDataHeader = readDataHeader();
        int i = readDataHeader.size;
        DataHeader dataHeader = BindingsHelper.MAP_STRUCT_HEADER;
        if (i != dataHeader.size) {
            throw new DeserializationException("Incorrect header for map. The size is incorrect.");
        } else if (readDataHeader.elementsOrVersion != dataHeader.elementsOrVersion) {
            throw new DeserializationException("Incorrect header for map. The version is incorrect.");
        }
    }

    public DataHeader readDataHeaderForPointerArray(int i) {
        return readDataHeaderForArray(8, i);
    }

    public DataHeader readDataHeaderForUnion(int i) {
        DataHeader readDataHeaderAtOffset = readDataHeaderAtOffset(i, true);
        int i2 = readDataHeaderAtOffset.size;
        if (i2 == 0) {
            if (readDataHeaderAtOffset.elementsOrVersion != 0) {
                StringBuilder j = b2.j("Unexpected version tag for a null union. Expecting 0, found: ");
                j.append(readDataHeaderAtOffset.elementsOrVersion);
                throw new DeserializationException(j.toString());
            }
        } else if (i2 != 16) {
            throw new DeserializationException("Unexpected size of an union. The size must be 0 for a null union, or 16 for a non-null union.");
        }
        return readDataHeaderAtOffset;
    }

    public DataHeader readDataHeaderForUnionArray(int i) {
        return readDataHeaderForArray(16, i);
    }

    public double readDouble(int i) {
        validateBufferSize(i, 8);
        return this.mMessage.getData().getDouble(this.mBaseOffset + i);
    }

    public double[] readDoubles(int i, int i2, int i3) {
        Decoder readPointer = readPointer(i, BindingsHelper.isArrayNullable(i2));
        if (readPointer == null) {
            return null;
        }
        double[] dArr = new double[readPointer.readDataHeaderForArray(8, i3).elementsOrVersion];
        readPointer.mMessage.getData().position(readPointer.mBaseOffset + 8);
        readPointer.mMessage.getData().asDoubleBuffer().get(dArr);
        return dArr;
    }

    public float readFloat(int i) {
        validateBufferSize(i, 4);
        return this.mMessage.getData().getFloat(this.mBaseOffset + i);
    }

    public float[] readFloats(int i, int i2, int i3) {
        Decoder readPointer = readPointer(i, BindingsHelper.isArrayNullable(i2));
        if (readPointer == null) {
            return null;
        }
        float[] fArr = new float[readPointer.readDataHeaderForArray(4, i3).elementsOrVersion];
        readPointer.mMessage.getData().position(readPointer.mBaseOffset + 8);
        readPointer.mMessage.getData().asFloatBuffer().get(fArr);
        return fArr;
    }

    public Handle readHandle(int i, boolean z) {
        int readInt = readInt(i);
        if (readInt != -1) {
            this.mValidator.claimHandle(readInt);
            return (Handle) this.mMessage.getHandles().get(readInt);
        } else if (z) {
            return InvalidHandle.INSTANCE;
        } else {
            throw new DeserializationException("Trying to decode an invalid handle for a non-nullable type.");
        }
    }

    public Handle[] readHandles(int i, int i2, int i3) {
        Decoder readPointer = readPointer(i, BindingsHelper.isArrayNullable(i2));
        if (readPointer == null) {
            return null;
        }
        int i4 = readPointer.readDataHeaderForArray(4, i3).elementsOrVersion;
        Handle[] handleArr = new Handle[i4];
        for (int i5 = 0; i5 < i4; i5++) {
            handleArr[i5] = readPointer.readHandle((i5 * 4) + 8, BindingsHelper.isElementNullable(i2));
        }
        return handleArr;
    }

    public int readInt(int i) {
        validateBufferSize(i, 4);
        return this.mMessage.getData().getInt(this.mBaseOffset + i);
    }

    public <I extends Interface> InterfaceRequest<I> readInterfaceRequest(int i, boolean z) {
        MessagePipeHandle readMessagePipeHandle = readMessagePipeHandle(i, z);
        if (readMessagePipeHandle == null) {
            return null;
        }
        return new InterfaceRequest<>(readMessagePipeHandle);
    }

    public <I extends Interface> InterfaceRequest<I>[] readInterfaceRequests(int i, int i2, int i3) {
        Decoder readPointer = readPointer(i, BindingsHelper.isArrayNullable(i2));
        if (readPointer == null) {
            return null;
        }
        int i4 = readPointer.readDataHeaderForArray(4, i3).elementsOrVersion;
        InterfaceRequest<I>[] interfaceRequestArr = new InterfaceRequest[i4];
        for (int i5 = 0; i5 < i4; i5++) {
            interfaceRequestArr[i5] = readPointer.readInterfaceRequest((i5 * 4) + 8, BindingsHelper.isElementNullable(i2));
        }
        return interfaceRequestArr;
    }

    public int[] readInts(int i, int i2, int i3) {
        Decoder readPointer = readPointer(i, BindingsHelper.isArrayNullable(i2));
        if (readPointer == null) {
            return null;
        }
        int[] iArr = new int[readPointer.readDataHeaderForArray(4, i3).elementsOrVersion];
        readPointer.mMessage.getData().position(readPointer.mBaseOffset + 8);
        readPointer.mMessage.getData().asIntBuffer().get(iArr);
        return iArr;
    }

    public long readLong(int i) {
        validateBufferSize(i, 8);
        return this.mMessage.getData().getLong(this.mBaseOffset + i);
    }

    public long[] readLongs(int i, int i2, int i3) {
        Decoder readPointer = readPointer(i, BindingsHelper.isArrayNullable(i2));
        if (readPointer == null) {
            return null;
        }
        long[] jArr = new long[readPointer.readDataHeaderForArray(8, i3).elementsOrVersion];
        readPointer.mMessage.getData().position(readPointer.mBaseOffset + 8);
        readPointer.mMessage.getData().asLongBuffer().get(jArr);
        return jArr;
    }

    public MessagePipeHandle readMessagePipeHandle(int i, boolean z) {
        return readUntypedHandle(i, z).toMessagePipeHandle();
    }

    public MessagePipeHandle[] readMessagePipeHandles(int i, int i2, int i3) {
        Decoder readPointer = readPointer(i, BindingsHelper.isArrayNullable(i2));
        if (readPointer == null) {
            return null;
        }
        int i4 = readPointer.readDataHeaderForArray(4, i3).elementsOrVersion;
        MessagePipeHandle[] messagePipeHandleArr = new MessagePipeHandle[i4];
        for (int i5 = 0; i5 < i4; i5++) {
            messagePipeHandleArr[i5] = readPointer.readMessagePipeHandle((i5 * 4) + 8, BindingsHelper.isElementNullable(i2));
        }
        return messagePipeHandleArr;
    }

    public Decoder readPointer(int i, boolean z) {
        int i2 = this.mBaseOffset + i;
        long readLong = readLong(i);
        if (readLong != 0) {
            return getDecoderAtPosition((int) (((long) i2) + readLong));
        }
        if (z) {
            return null;
        }
        throw new DeserializationException("Trying to decode null pointer for a non-nullable type.");
    }

    public DataPipe.ProducerHandle readProducerHandle(int i, boolean z) {
        return readUntypedHandle(i, z).toDataPipeProducerHandle();
    }

    public DataPipe.ProducerHandle[] readProducerHandles(int i, int i2, int i3) {
        Decoder readPointer = readPointer(i, BindingsHelper.isArrayNullable(i2));
        if (readPointer == null) {
            return null;
        }
        int i4 = readPointer.readDataHeaderForArray(4, i3).elementsOrVersion;
        DataPipe.ProducerHandle[] producerHandleArr = new DataPipe.ProducerHandle[i4];
        for (int i5 = 0; i5 < i4; i5++) {
            producerHandleArr[i5] = readPointer.readProducerHandle((i5 * 4) + 8, BindingsHelper.isElementNullable(i2));
        }
        return producerHandleArr;
    }

    public <P extends Interface.Proxy> P readServiceInterface(int i, boolean z, Interface.Manager<?, P> manager) {
        MessagePipeHandle readMessagePipeHandle = readMessagePipeHandle(i, z);
        if (!readMessagePipeHandle.isValid()) {
            return null;
        }
        return manager.attachProxy(readMessagePipeHandle, readInt(i + 4));
    }

    public <S extends Interface, P extends Interface.Proxy> S[] readServiceInterfaces(int i, int i2, int i3, Interface.Manager<S, P> manager) {
        Decoder readPointer = readPointer(i, BindingsHelper.isArrayNullable(i2));
        if (readPointer == null) {
            return null;
        }
        S[] buildArray = manager.buildArray(readPointer.readDataHeaderForArray(8, i3).elementsOrVersion);
        for (int i4 = 0; i4 < buildArray.length; i4++) {
            buildArray[i4] = readPointer.readServiceInterface((i4 * 8) + 8, BindingsHelper.isElementNullable(i2), manager);
        }
        return buildArray;
    }

    public SharedBufferHandle readSharedBufferHandle(int i, boolean z) {
        return readUntypedHandle(i, z).toSharedBufferHandle();
    }

    public SharedBufferHandle[] readSharedBufferHandles(int i, int i2, int i3) {
        Decoder readPointer = readPointer(i, BindingsHelper.isArrayNullable(i2));
        if (readPointer == null) {
            return null;
        }
        int i4 = readPointer.readDataHeaderForArray(4, i3).elementsOrVersion;
        SharedBufferHandle[] sharedBufferHandleArr = new SharedBufferHandle[i4];
        for (int i5 = 0; i5 < i4; i5++) {
            sharedBufferHandleArr[i5] = readPointer.readSharedBufferHandle((i5 * 4) + 8, BindingsHelper.isElementNullable(i2));
        }
        return sharedBufferHandleArr;
    }

    public short readShort(int i) {
        validateBufferSize(i, 2);
        return this.mMessage.getData().getShort(this.mBaseOffset + i);
    }

    public short[] readShorts(int i, int i2, int i3) {
        Decoder readPointer = readPointer(i, BindingsHelper.isArrayNullable(i2));
        if (readPointer == null) {
            return null;
        }
        short[] sArr = new short[readPointer.readDataHeaderForArray(2, i3).elementsOrVersion];
        readPointer.mMessage.getData().position(readPointer.mBaseOffset + 8);
        readPointer.mMessage.getData().asShortBuffer().get(sArr);
        return sArr;
    }

    public String readString(int i, boolean z) {
        byte[] readBytes = readBytes(i, z ? 1 : 0, -1);
        if (readBytes == null) {
            return null;
        }
        return new String(readBytes, Charset.forName("utf8"));
    }

    public UntypedHandle readUntypedHandle(int i, boolean z) {
        return readHandle(i, z).toUntypedHandle();
    }

    public UntypedHandle[] readUntypedHandles(int i, int i2, int i3) {
        Decoder readPointer = readPointer(i, BindingsHelper.isArrayNullable(i2));
        if (readPointer == null) {
            return null;
        }
        int i4 = readPointer.readDataHeaderForArray(4, i3).elementsOrVersion;
        UntypedHandle[] untypedHandleArr = new UntypedHandle[i4];
        for (int i5 = 0; i5 < i4; i5++) {
            untypedHandleArr[i5] = readPointer.readUntypedHandle((i5 * 4) + 8, BindingsHelper.isElementNullable(i2));
        }
        return untypedHandleArr;
    }

    private Decoder(Message message, Validator validator, int i) {
        this.mMessage = message;
        message.getData().order(ByteOrder.LITTLE_ENDIAN);
        this.mBaseOffset = i;
        this.mValidator = validator;
    }
}
