package org.chromium.ui.base;

import android.app.Activity;
import android.app.PendingIntent;
import android.content.ActivityNotFoundException;
import android.content.Context;
import android.content.Intent;
import android.content.IntentSender;
import android.content.SharedPreferences;
import android.content.pm.PackageManager;
import android.content.pm.PermissionInfo;
import android.os.Build;
import android.os.Handler;
import android.os.Process;
import android.text.TextUtils;
import android.util.SparseArray;
import android.view.View;
import androidx.base.b2;
import java.lang.ref.WeakReference;
import org.chromium.base.ApiCompatibilityUtils;
import org.chromium.base.ApplicationStatus;
import org.chromium.base.Callback;
import org.chromium.base.ContextUtils;
import org.chromium.ui.UiUtils;
import org.chromium.ui.base.WindowAndroid;

public class ActivityWindowAndroid extends WindowAndroid implements ApplicationStatus.ActivityStateListener, View.OnLayoutChangeListener {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final String PERMISSION_QUERIED_KEY_PREFIX = "HasRequestedAndroidPermission::";
    private static final int REQUEST_CODE_PREFIX = 1000;
    private static final int REQUEST_CODE_RANGE_SIZE = 100;
    private final Handler mHandler;
    private int mNextRequestCode;
    private final SparseArray<WindowAndroid.PermissionCallback> mOutstandingPermissionRequests;

    public class ActivityAndroidPermissionDelegate implements AndroidPermissionDelegate {
        private ActivityAndroidPermissionDelegate() {
        }

        private boolean requestPermissionsInternal(String[] strArr, WindowAndroid.PermissionCallback permissionCallback) {
            Activity activity;
            if (Build.VERSION.SDK_INT < 23 || (activity = ActivityWindowAndroid.this.getActivity().get()) == null) {
                return false;
            }
            int generateNextRequestCode = ActivityWindowAndroid.this.generateNextRequestCode();
            ActivityWindowAndroid.this.mOutstandingPermissionRequests.put(generateNextRequestCode, permissionCallback);
            activity.requestPermissions(strArr, generateNextRequestCode);
            return true;
        }

        @Override // org.chromium.ui.base.AndroidPermissionDelegate
        public boolean canRequestPermission(String str) {
            Activity activity;
            if (Build.VERSION.SDK_INT < 23 || (activity = ActivityWindowAndroid.this.getActivity().get()) == null || isPermissionRevokedByPolicy(str)) {
                return false;
            }
            if (activity.shouldShowRequestPermissionRationale(str)) {
                return true;
            }
            if (!ContextUtils.getAppSharedPreferences().getBoolean(ActivityWindowAndroid.this.getHasRequestedPermissionKey(str), false)) {
                return true;
            }
            return false;
        }

        @Override // org.chromium.ui.base.AndroidPermissionDelegate
        public boolean hasPermission(String str) {
            return ApiCompatibilityUtils.checkPermission(ActivityWindowAndroid.this.mApplicationContext, str, Process.myPid(), Process.myUid()) == 0;
        }

        @Override // org.chromium.ui.base.AndroidPermissionDelegate
        public boolean isPermissionRevokedByPolicy(String str) {
            Activity activity;
            if (Build.VERSION.SDK_INT >= 23 && (activity = ActivityWindowAndroid.this.getActivity().get()) != null) {
                return activity.getPackageManager().isPermissionRevokedByPolicy(str, activity.getPackageName());
            }
            return false;
        }

        @Override // org.chromium.ui.base.AndroidPermissionDelegate
        public void requestPermissions(final String[] strArr, final WindowAndroid.PermissionCallback permissionCallback) {
            if (!requestPermissionsInternal(strArr, permissionCallback)) {
                ActivityWindowAndroid.this.mHandler.post(new Runnable() {
                    /* class org.chromium.ui.base.ActivityWindowAndroid.ActivityAndroidPermissionDelegate.AnonymousClass1 */

                    public void run() {
                        int[] iArr = new int[strArr.length];
                        int i = 0;
                        while (true) {
                            String[] strArr = strArr;
                            if (i < strArr.length) {
                                iArr[i] = ActivityAndroidPermissionDelegate.this.hasPermission(strArr[i]) ? 0 : -1;
                                i++;
                            } else {
                                permissionCallback.onRequestPermissionsResult(strArr, iArr);
                                return;
                            }
                        }
                    }
                });
            }
        }
    }

    public ActivityWindowAndroid(Context context) {
        this(context, true);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private int generateNextRequestCode() {
        int i = this.mNextRequestCode;
        int i2 = i + 1000;
        this.mNextRequestCode = (i + 1) % 100;
        return i2;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String getHasRequestedPermissionKey(String str) {
        try {
            PermissionInfo permissionInfo = getApplicationContext().getPackageManager().getPermissionInfo(str, 128);
            if (!TextUtils.isEmpty(permissionInfo.group)) {
                str = permissionInfo.group;
            }
        } catch (PackageManager.NameNotFoundException unused) {
        }
        return b2.c(PERMISSION_QUERIED_KEY_PREFIX, str);
    }

    private void storeCallbackData(int i, WindowAndroid.IntentCallback intentCallback, Integer num) {
        this.mOutstandingIntents.put(i, intentCallback);
        this.mIntentErrors.put(Integer.valueOf(i), num == null ? null : this.mApplicationContext.getString(num.intValue()));
    }

    @Override // org.chromium.ui.base.WindowAndroid
    public void cancelIntent(int i) {
        Activity activity = getActivity().get();
        if (activity != null) {
            activity.finishActivity(i);
        }
    }

    @Override // org.chromium.ui.base.WindowAndroid
    public WeakReference<Activity> getActivity() {
        return new WeakReference<>(WindowAndroid.activityFromContext(getContext().get()));
    }

    public boolean onActivityResult(int i, int i2, Intent intent) {
        WindowAndroid.IntentCallback intentCallback = this.mOutstandingIntents.get(i);
        this.mOutstandingIntents.delete(i);
        String remove = this.mIntentErrors.remove(Integer.valueOf(i));
        if (intentCallback != null) {
            intentCallback.onIntentCompleted(this, i2, this.mApplicationContext.getContentResolver(), intent);
            return true;
        } else if (remove == null) {
            return false;
        } else {
            showCallbackNonExistentError(remove);
            return true;
        }
    }

    @Override // org.chromium.base.ApplicationStatus.ActivityStateListener
    public void onActivityStateChange(Activity activity, int i) {
        if (i == 5) {
            onActivityStopped();
        } else if (i == 2) {
            onActivityStarted();
        }
    }

    public void onLayoutChange(View view, int i, int i2, int i3, int i4, int i5, int i6, int i7, int i8) {
        keyboardVisibilityPossiblyChanged(UiUtils.isKeyboardShowing(getActivity().get(), view));
    }

    public boolean onRequestPermissionsResult(int i, String[] strArr, int[] iArr) {
        getActivity().get();
        SharedPreferences.Editor edit = ContextUtils.getAppSharedPreferences().edit();
        for (String str : strArr) {
            edit.putBoolean(getHasRequestedPermissionKey(str), true);
        }
        edit.apply();
        WindowAndroid.PermissionCallback permissionCallback = this.mOutstandingPermissionRequests.get(i);
        this.mOutstandingPermissionRequests.delete(i);
        if (permissionCallback == null) {
            return false;
        }
        permissionCallback.onRequestPermissionsResult(strArr, iArr);
        return true;
    }

    @Override // org.chromium.ui.base.WindowAndroid
    public void registerKeyboardVisibilityCallbacks() {
        Activity activity = getActivity().get();
        if (activity != null) {
            View findViewById = activity.findViewById(16908290);
            this.mIsKeyboardShowing = UiUtils.isKeyboardShowing(getActivity().get(), findViewById);
            findViewById.addOnLayoutChangeListener(this);
        }
    }

    @Override // org.chromium.ui.base.WindowAndroid
    public int showCancelableIntent(PendingIntent pendingIntent, WindowAndroid.IntentCallback intentCallback, Integer num) {
        Activity activity = getActivity().get();
        if (activity == null) {
            return -1;
        }
        int generateNextRequestCode = generateNextRequestCode();
        try {
            activity.startIntentSenderForResult(pendingIntent.getIntentSender(), generateNextRequestCode, new Intent(), 0, 0, 0);
            storeCallbackData(generateNextRequestCode, intentCallback, num);
            return generateNextRequestCode;
        } catch (IntentSender.SendIntentException unused) {
            return -1;
        }
    }

    @Override // org.chromium.ui.base.WindowAndroid
    public void unregisterKeyboardVisibilityCallbacks() {
        Activity activity = getActivity().get();
        if (activity != null) {
            activity.findViewById(16908290).removeOnLayoutChangeListener(this);
        }
    }

    public ActivityWindowAndroid(Context context, boolean z) {
        super(context);
        this.mNextRequestCode = 0;
        Activity activityFromContext = WindowAndroid.activityFromContext(context);
        if (activityFromContext != null) {
            this.mHandler = new Handler();
            this.mOutstandingPermissionRequests = new SparseArray<>();
            if (z) {
                ApplicationStatus.registerStateListenerForActivity(this, activityFromContext);
            }
            setAndroidPermissionDelegate(new ActivityAndroidPermissionDelegate());
            return;
        }
        throw new IllegalArgumentException("Context is not and does not wrap an Activity");
    }

    @Override // org.chromium.ui.base.WindowAndroid
    public int showCancelableIntent(Intent intent, WindowAndroid.IntentCallback intentCallback, Integer num) {
        Activity activity = getActivity().get();
        if (activity == null) {
            return -1;
        }
        int generateNextRequestCode = generateNextRequestCode();
        try {
            activity.startActivityForResult(intent, generateNextRequestCode);
            storeCallbackData(generateNextRequestCode, intentCallback, num);
            return generateNextRequestCode;
        } catch (ActivityNotFoundException unused) {
            return -1;
        }
    }

    @Override // org.chromium.ui.base.WindowAndroid
    public int showCancelableIntent(Callback<Integer> callback, WindowAndroid.IntentCallback intentCallback, Integer num) {
        if (getActivity().get() == null) {
            return -1;
        }
        int generateNextRequestCode = generateNextRequestCode();
        callback.onResult(Integer.valueOf(generateNextRequestCode));
        storeCallbackData(generateNextRequestCode, intentCallback, num);
        return generateNextRequestCode;
    }
}
