package org.chromium.ui.resources.dynamics;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewTreeObserver;

public class ViewResourceInflater {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final int INVALID_ID = -1;
    private ViewGroup mContainer;
    private Context mContext;
    private boolean mIsAttached;
    private boolean mIsInvalidated;
    private int mLayoutId;
    private boolean mNeedsLayoutUpdate;
    private ViewInflaterOnDrawListener mOnDrawListener;
    private ViewResourceAdapter mResourceAdapter;
    private DynamicResourceLoader mResourceLoader;
    private View mView;
    private int mViewId;

    public class ViewInflaterAdapter extends ViewResourceAdapter {
        public ViewInflaterAdapter(View view) {
            super(view);
        }

        @Override // org.chromium.ui.resources.dynamics.ViewResourceAdapter
        public void onCaptureEnd() {
            ViewResourceInflater.this.onCaptureEnd();
        }
    }

    public class ViewInflaterOnDrawListener implements ViewTreeObserver.OnDrawListener {
        private ViewInflaterOnDrawListener() {
        }

        public void onDraw() {
            ViewResourceInflater.this.invalidateResource();
        }
    }

    public ViewResourceInflater(int i, int i2, Context context, ViewGroup viewGroup, DynamicResourceLoader dynamicResourceLoader) {
        this.mLayoutId = i;
        this.mViewId = i2;
        this.mContext = context;
        this.mContainer = viewGroup;
        this.mResourceLoader = dynamicResourceLoader;
    }

    private void attachView() {
        if (!this.mIsAttached) {
            this.mContainer.addView(this.mView);
            this.mIsAttached = true;
            if (this.mOnDrawListener == null) {
                this.mOnDrawListener = new ViewInflaterOnDrawListener();
                this.mView.getViewTreeObserver().addOnDrawListener(this.mOnDrawListener);
            }
        }
    }

    private void detachView() {
        if (this.mIsAttached) {
            if (this.mOnDrawListener != null) {
                this.mView.getViewTreeObserver().removeOnDrawListener(this.mOnDrawListener);
                this.mOnDrawListener = null;
            }
            this.mContainer.removeView(this.mView);
            this.mIsAttached = false;
        }
    }

    private int getUnspecifiedMeasureSpec() {
        return View.MeasureSpec.makeMeasureSpec(0, 0);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void invalidateResource() {
        ViewResourceAdapter viewResourceAdapter;
        if (this.mIsInvalidated && this.mView != null && (viewResourceAdapter = this.mResourceAdapter) != null) {
            this.mIsInvalidated = false;
            viewResourceAdapter.invalidate(null);
        }
    }

    private void registerResource() {
        if (this.mResourceAdapter == null) {
            this.mResourceAdapter = new ViewInflaterAdapter(this.mView.findViewById(this.mViewId));
        }
        DynamicResourceLoader dynamicResourceLoader = this.mResourceLoader;
        if (dynamicResourceLoader != null) {
            dynamicResourceLoader.registerResource(this.mViewId, this.mResourceAdapter);
        }
    }

    private void unregisterResource() {
        DynamicResourceLoader dynamicResourceLoader = this.mResourceLoader;
        if (dynamicResourceLoader != null) {
            dynamicResourceLoader.unregisterResource(this.mViewId);
        }
        this.mResourceAdapter = null;
    }

    private void updateLayoutParams() {
        int widthMeasureSpec = getWidthMeasureSpec();
        int i = -2;
        int size = View.MeasureSpec.getMode(widthMeasureSpec) == 1073741824 ? View.MeasureSpec.getSize(widthMeasureSpec) : -2;
        int heightMeasureSpec = getHeightMeasureSpec();
        if (View.MeasureSpec.getMode(heightMeasureSpec) == 1073741824) {
            i = View.MeasureSpec.getSize(heightMeasureSpec);
        }
        ViewGroup.LayoutParams layoutParams = this.mView.getLayoutParams();
        layoutParams.width = size;
        layoutParams.height = i;
        this.mView.setLayoutParams(layoutParams);
    }

    public void destroy() {
        if (this.mView != null) {
            unregisterResource();
            detachView();
            this.mView = null;
            this.mLayoutId = -1;
            this.mViewId = -1;
            this.mContext = null;
            this.mContainer = null;
            this.mResourceLoader = null;
        }
    }

    public Context getContext() {
        return this.mContext;
    }

    public int getHeightMeasureSpec() {
        return getUnspecifiedMeasureSpec();
    }

    public int getMeasuredHeight() {
        return this.mView.getMeasuredHeight();
    }

    public int getMeasuredWidth() {
        return this.mView.getMeasuredWidth();
    }

    public View getView() {
        return this.mView;
    }

    public int getViewId() {
        return this.mViewId;
    }

    public int getWidthMeasureSpec() {
        return getUnspecifiedMeasureSpec();
    }

    public void inflate() {
        if (this.mView == null) {
            this.mView = LayoutInflater.from(this.mContext).inflate(this.mLayoutId, this.mContainer, false);
            onFinishInflate();
            registerResource();
            this.mNeedsLayoutUpdate = true;
        }
    }

    public void invalidate() {
        invalidate(false);
    }

    public void layout() {
        this.mView.measure(getWidthMeasureSpec(), getHeightMeasureSpec());
        this.mView.layout(0, 0, getMeasuredWidth(), getMeasuredHeight());
    }

    public void onCaptureEnd() {
        if (shouldDetachViewAfterCapturing()) {
            detachView();
        }
    }

    public void onFinishInflate() {
    }

    public boolean shouldAttachView() {
        return true;
    }

    public boolean shouldDetachViewAfterCapturing() {
        return true;
    }

    public void invalidate(boolean z) {
        if (this.mView == null) {
            inflate();
        }
        this.mIsInvalidated = true;
        if (!this.mIsAttached && shouldAttachView()) {
            attachView();
        }
        if (!this.mIsAttached) {
            layout();
            invalidateResource();
        } else if (z || this.mNeedsLayoutUpdate) {
            updateLayoutParams();
        }
        this.mNeedsLayoutUpdate = false;
    }
}
