package org.chromium.ui.widget;

import android.annotation.SuppressLint;
import android.content.Context;
import android.os.Bundle;
import android.text.Layout;
import android.text.SpannableString;
import android.text.style.ClickableSpan;
import android.util.AttributeSet;
import android.view.Menu;
import android.view.MenuItem;
import android.view.MotionEvent;
import android.view.View;
import android.view.accessibility.AccessibilityManager;
import android.widget.PopupMenu;
import android.widget.TextView;
import org.chromium.base.VisibleForTesting;

public class TextViewWithClickableSpans extends TextView {
    private AccessibilityManager mAccessibilityManager;

    public TextViewWithClickableSpans(Context context) {
        super(context);
        init();
    }

    private void handleAccessibilityClick() {
        ClickableSpan[] clickableSpans = getClickableSpans();
        if (clickableSpans != null && clickableSpans.length != 0) {
            if (clickableSpans.length == 1) {
                clickableSpans[0].onClick(this);
            } else {
                openDisambiguationMenu();
            }
        }
    }

    private void init() {
        setSaveEnabled(false);
        this.mAccessibilityManager = (AccessibilityManager) getContext().getSystemService("accessibility");
        setOnLongClickListener(new View.OnLongClickListener() {
            /* class org.chromium.ui.widget.TextViewWithClickableSpans.AnonymousClass1 */

            public boolean onLongClick(View view) {
                if (!TextViewWithClickableSpans.this.mAccessibilityManager.isTouchExplorationEnabled()) {
                    return false;
                }
                TextViewWithClickableSpans.this.openDisambiguationMenu();
                return true;
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void openDisambiguationMenu() {
        ClickableSpan[] clickableSpans = getClickableSpans();
        if (!(clickableSpans == null || clickableSpans.length == 0)) {
            SpannableString spannableString = (SpannableString) getText();
            PopupMenu popupMenu = new PopupMenu(getContext(), this);
            Menu menu = popupMenu.getMenu();
            for (final ClickableSpan clickableSpan : clickableSpans) {
                menu.add(spannableString.subSequence(spannableString.getSpanStart(clickableSpan), spannableString.getSpanEnd(clickableSpan))).setOnMenuItemClickListener(new MenuItem.OnMenuItemClickListener() {
                    /* class org.chromium.ui.widget.TextViewWithClickableSpans.AnonymousClass2 */

                    public boolean onMenuItemClick(MenuItem menuItem) {
                        clickableSpan.onClick(TextViewWithClickableSpans.this);
                        return true;
                    }
                });
            }
            popupMenu.show();
        }
    }

    private boolean touchIntersectsAnyClickableSpans(MotionEvent motionEvent) {
        CharSequence text = getText();
        if (!(text instanceof SpannableString)) {
            return false;
        }
        int x = ((int) motionEvent.getX()) - getTotalPaddingLeft();
        int y = ((int) motionEvent.getY()) - getTotalPaddingTop();
        int scrollX = getScrollX() + x;
        int scrollY = getScrollY() + y;
        Layout layout = getLayout();
        int offsetForHorizontal = layout.getOffsetForHorizontal(layout.getLineForVertical(scrollY), (float) scrollX);
        if (((ClickableSpan[]) ((SpannableString) text).getSpans(offsetForHorizontal, offsetForHorizontal, ClickableSpan.class)).length > 0) {
            return true;
        }
        return false;
    }

    @VisibleForTesting
    public ClickableSpan[] getClickableSpans() {
        CharSequence text = getText();
        if (!(text instanceof SpannableString)) {
            return null;
        }
        SpannableString spannableString = (SpannableString) text;
        return (ClickableSpan[]) spannableString.getSpans(0, spannableString.length(), ClickableSpan.class);
    }

    @SuppressLint({"ClickableViewAccessibility"})
    public boolean onTouchEvent(MotionEvent motionEvent) {
        boolean onTouchEvent = super.onTouchEvent(motionEvent);
        if (motionEvent.getAction() == 1 || !this.mAccessibilityManager.isTouchExplorationEnabled() || touchIntersectsAnyClickableSpans(motionEvent)) {
            return onTouchEvent;
        }
        handleAccessibilityClick();
        return true;
    }

    public boolean performAccessibilityAction(int i, Bundle bundle) {
        if (i != 16) {
            return super.performAccessibilityAction(i, bundle);
        }
        handleAccessibilityClick();
        return true;
    }

    public TextViewWithClickableSpans(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        init();
    }

    public TextViewWithClickableSpans(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        init();
    }
}
