package org.xwalk.core;

import android.content.Context;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.os.Build;
import android.util.Log;
import androidx.base.b2;
import dalvik.system.DexClassLoader;
import java.io.File;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import junit.framework.Assert;

public class XWalkCoreWrapper {
    private static final String BRIDGE_PACKAGE = "org.xwalk.core.internal";
    private static final String TAG = "XWalkLib";
    private static final String WRAPPER_PACKAGE = "org.xwalk.core";
    private static final String XWALK_CORE_CLASSES_DEX = "classes.dex";
    private static XWalkCoreWrapper sInstance;
    private static XWalkCoreWrapper sProvisionalInstance;
    private static HashMap<String, LinkedList<ReservedAction>> sReservedActions = new HashMap<>();
    private static LinkedList<String> sReservedActivities = new LinkedList<>();
    private int mApiVersion = 8;
    private Context mBridgeContext;
    private ClassLoader mBridgeLoader;
    private int mCoreStatus;
    private int mMinApiVersion;
    private Context mWrapperContext;

    private XWalkCoreWrapper(Context context, int i) {
        this.mMinApiVersion = (i <= 0 || i > 8) ? 8 : i;
        this.mCoreStatus = 0;
        this.mWrapperContext = context;
    }

    public static int attachXWalkCore() {
        Assert.assertFalse(sReservedActivities.isEmpty());
        Assert.assertNull(sInstance);
        Log.d(TAG, "Attach xwalk core");
        XWalkCoreWrapper xWalkCoreWrapper = new XWalkCoreWrapper(XWalkEnvironment.getApplicationContext(), 1);
        sProvisionalInstance = xWalkCoreWrapper;
        if (xWalkCoreWrapper.findEmbeddedCore()) {
            return sProvisionalInstance.mCoreStatus;
        }
        if (XWalkEnvironment.isDownloadMode()) {
            sProvisionalInstance.findDownloadedCore();
            return sProvisionalInstance.mCoreStatus;
        }
        if (XWalkEnvironment.is64bitDevice()) {
            if (!sProvisionalInstance.findSharedCore("org.xwalk.core") && !sProvisionalInstance.findSharedCore(XWalkLibraryInterface.XWALK_CORE64_PACKAGE) && XWalkEnvironment.isIaDevice()) {
                sProvisionalInstance.findSharedCore(XWalkLibraryInterface.XWALK_CORE64_IA_PACKAGE);
            }
        } else if (!sProvisionalInstance.findSharedCore("org.xwalk.core") && XWalkEnvironment.isIaDevice()) {
            sProvisionalInstance.findSharedCore(XWalkLibraryInterface.XWALK_CORE_IA_PACKAGE);
        }
        return sProvisionalInstance.mCoreStatus;
    }

    private boolean checkCoreArchitecture() {
        boolean z;
        try {
            ReflectMethod reflectMethod = new ReflectMethod(getBridgeClass("XWalkViewDelegate"), "loadXWalkLibrary", (Class<?>[]) new Class[]{Context.class, String.class});
            String str = null;
            Context context = this.mBridgeContext;
            if (context != null) {
                if (Build.VERSION.SDK_INT < 17) {
                    str = "/data/data/" + this.mBridgeContext.getPackageName() + "/lib";
                }
                z = ((Boolean) reflectMethod.invoke(this.mBridgeContext, str)).booleanValue();
            } else {
                try {
                    z = ((Boolean) reflectMethod.invoke(context, null)).booleanValue();
                } catch (RuntimeException e) {
                    Log.d(TAG, e.getLocalizedMessage());
                    z = false;
                }
                if (!z && this.mWrapperContext != null) {
                    z = ((Boolean) reflectMethod.invoke(this.mBridgeContext, XWalkEnvironment.getPrivateDataDir())).booleanValue();
                }
            }
            if (!z) {
                Log.d(TAG, "Mismatch of CPU architecture");
                this.mCoreStatus = 6;
                return false;
            }
            Log.d(TAG, "XWalk core architecture matched");
            return true;
        } catch (RuntimeException e2) {
            Log.d(TAG, e2.getLocalizedMessage());
            if (e2.getCause() instanceof UnsatisfiedLinkError) {
                this.mCoreStatus = 6;
                return false;
            }
            this.mCoreStatus = 5;
            return false;
        }
    }

    private boolean checkCorePackage(String str) {
        try {
            if (!verifyPackageInfo(this.mWrapperContext.getPackageManager().getPackageInfo(str, 64), XWalkAppVersion.XWALK_APK_HASH_ALGORITHM, XWalkAppVersion.XWALK_APK_HASH_CODE)) {
                Log.d(TAG, str + " signature verification failed");
                this.mCoreStatus = 7;
                return false;
            }
            try {
                this.mBridgeContext = this.mWrapperContext.createPackageContext(str, 3);
                Log.d(TAG, "Created package context for " + str);
                return true;
            } catch (PackageManager.NameNotFoundException unused) {
                Log.d(TAG, str + " not found");
                return false;
            }
        } catch (PackageManager.NameNotFoundException unused2) {
            Log.d(TAG, str + " not found");
            return false;
        }
    }

    private boolean checkCoreVersion() {
        StringBuilder j = b2.j("[Environment] SDK:");
        j.append(Build.VERSION.SDK_INT);
        Log.d(TAG, j.toString());
        Log.d(TAG, "[App Version] build:23.53.589.4, api:" + this.mApiVersion + ", min_api:" + this.mMinApiVersion);
        try {
            Class<?> bridgeClass = getBridgeClass("XWalkCoreVersion");
            String str = "";
            try {
                str = (String) new ReflectField(bridgeClass, "XWALK_BUILD_VERSION").get();
            } catch (RuntimeException unused) {
            }
            int intValue = ((Integer) new ReflectField(bridgeClass, "API_VERSION").get()).intValue();
            int intValue2 = ((Integer) new ReflectField(bridgeClass, "MIN_API_VERSION").get()).intValue();
            Log.d(TAG, "[Lib Version] build:" + str + ", api:" + intValue + ", min_api:" + intValue2);
            if (XWalkEnvironment.isDownloadMode() && XWalkEnvironment.isDownloadModeUpdate() && !str.isEmpty() && !str.equals(XWalkAppVersion.XWALK_BUILD_VERSION)) {
                this.mCoreStatus = 8;
                return false;
            } else if (this.mMinApiVersion > intValue) {
                this.mCoreStatus = 3;
                return false;
            } else if (this.mApiVersion < intValue2) {
                this.mCoreStatus = 4;
                return false;
            } else {
                Log.d(TAG, "XWalk core version matched");
                return true;
            }
        } catch (RuntimeException unused2) {
            Log.d(TAG, "XWalk core not found");
            this.mCoreStatus = 2;
            return false;
        }
    }

    public static void dockXWalkCore() {
        Assert.assertNotNull(sProvisionalInstance);
        Assert.assertNull(sInstance);
        Log.d(TAG, "Dock xwalk core");
        XWalkCoreWrapper xWalkCoreWrapper = sProvisionalInstance;
        sInstance = xWalkCoreWrapper;
        sProvisionalInstance = null;
        xWalkCoreWrapper.initCoreBridge();
        sInstance.initXWalkView();
    }

    private boolean findDownloadedCore() {
        String extractedCoreDir = XWalkEnvironment.getExtractedCoreDir();
        this.mBridgeLoader = new DexClassLoader(b2.f(b2.j(extractedCoreDir), File.separator, XWALK_CORE_CLASSES_DEX), XWalkEnvironment.getOptimizedDexDir(), extractedCoreDir, ClassLoader.getSystemClassLoader());
        if (!checkCoreVersion() || !checkCoreArchitecture()) {
            this.mBridgeLoader = null;
            return false;
        }
        Log.d(TAG, "Running in downloaded mode");
        this.mCoreStatus = 1;
        return true;
    }

    private boolean findEmbeddedCore() {
        this.mBridgeContext = null;
        this.mBridgeLoader = XWalkCoreWrapper.class.getClassLoader();
        if (!checkCoreVersion() || !checkCoreArchitecture()) {
            this.mBridgeLoader = null;
            return false;
        }
        Log.d(TAG, "Running in embedded mode");
        this.mCoreStatus = 1;
        return true;
    }

    private boolean findSharedCore(String str) {
        if (!checkCorePackage(str)) {
            return false;
        }
        this.mBridgeLoader = this.mBridgeContext.getClassLoader();
        if (!checkCoreVersion() || !checkCoreArchitecture()) {
            this.mBridgeContext = null;
            this.mBridgeLoader = null;
            return false;
        }
        Log.d(TAG, "Running in shared mode");
        this.mCoreStatus = 1;
        return true;
    }

    public static int getCoreStatus() {
        XWalkCoreWrapper xWalkCoreWrapper = sInstance;
        if (xWalkCoreWrapper != null) {
            return xWalkCoreWrapper.mCoreStatus;
        }
        XWalkCoreWrapper xWalkCoreWrapper2 = sProvisionalInstance;
        if (xWalkCoreWrapper2 == null) {
            return 0;
        }
        return xWalkCoreWrapper2.mCoreStatus;
    }

    public static XWalkCoreWrapper getInstance() {
        return sInstance;
    }

    public static void handlePostInit(String str) {
        Log.d(TAG, "Post init xwalk core in " + str);
        if (sReservedActions.containsKey(str)) {
            Iterator<ReservedAction> it = sReservedActions.get(str).iterator();
            while (it.hasNext()) {
                ReservedAction next = it.next();
                if (next.mObject != null) {
                    StringBuilder j = b2.j("Init reserved object: ");
                    j.append(next.mObject.getClass());
                    Log.d(TAG, j.toString());
                    new ReflectMethod(next.mObject, "reflectionInit", new Class[0]).invoke(new Object[0]);
                } else if (next.mClass != null) {
                    StringBuilder j2 = b2.j("Init reserved class: ");
                    j2.append(next.mClass.toString());
                    Log.d(TAG, j2.toString());
                    new ReflectMethod(next.mClass, "reflectionInit", (Class<?>[]) new Class[0]).invoke(new Object[0]);
                } else {
                    StringBuilder j3 = b2.j("Call reserved method: ");
                    j3.append(next.mMethod.toString());
                    Log.d(TAG, j3.toString());
                    Object[] objArr = next.mArguments;
                    if (objArr != null) {
                        for (int i = 0; i < objArr.length; i++) {
                            if (objArr[i] instanceof ReflectMethod) {
                                objArr[i] = ((ReflectMethod) objArr[i]).invokeWithArguments();
                            }
                        }
                    }
                    next.mMethod.invoke(objArr);
                }
            }
            sReservedActions.remove(str);
            sReservedActivities.remove(str);
        }
    }

    public static void handlePreInit(String str) {
        if (sInstance == null) {
            Log.d(TAG, "Pre init xwalk core in " + str);
            if (sReservedActions.containsKey(str)) {
                sReservedActions.remove(str);
            } else {
                sReservedActivities.add(str);
            }
            sReservedActions.put(str, new LinkedList<>());
        }
    }

    public static void handleRuntimeError(RuntimeException runtimeException) {
        Log.e(TAG, "This API is incompatible with the Crosswalk runtime library");
        runtimeException.printStackTrace();
    }

    private byte[] hexStringToByteArray(String str) {
        if (str == null || str.isEmpty() || str.length() % 2 != 0) {
            return null;
        }
        byte[] bArr = new byte[(str.length() / 2)];
        for (int i = 0; i < str.length(); i += 2) {
            bArr[i / 2] = (byte) (Character.digit(str.charAt(i + 1), 16) + (Character.digit(str.charAt(i), 16) << 4));
        }
        return bArr;
    }

    private void initCoreBridge() {
        Log.d(TAG, "Init core bridge");
        new ReflectMethod(getBridgeClass("XWalkCoreBridge"), "init", (Class<?>[]) new Class[]{Context.class, Object.class}).invoke(this.mBridgeContext, this);
    }

    public static void initEmbeddedMode() {
        if (sInstance == null && sReservedActivities.isEmpty()) {
            Log.d(TAG, "Init embedded mode");
            XWalkCoreWrapper xWalkCoreWrapper = new XWalkCoreWrapper(null, -1);
            if (xWalkCoreWrapper.findEmbeddedCore()) {
                sInstance = xWalkCoreWrapper;
                xWalkCoreWrapper.initCoreBridge();
                return;
            }
            throw new RuntimeException("Please have your activity extend XWalkActivity for shared mode");
        }
    }

    private void initXWalkView() {
        Log.d(TAG, "Init xwalk view");
        new ReflectMethod(getBridgeClass("XWalkViewDelegate"), "init", (Class<?>[]) new Class[]{Context.class, Context.class}).invoke(this.mBridgeContext, this.mWrapperContext);
    }

    public static void reserveReflectClass(Class<?> cls) {
        String last = sReservedActivities.getLast();
        StringBuilder j = b2.j("Reserve class ");
        j.append(cls.toString());
        j.append(" to ");
        j.append(last);
        Log.d(TAG, j.toString());
        sReservedActions.get(last).add(new ReservedAction(cls));
    }

    public static void reserveReflectMethod(ReflectMethod reflectMethod) {
        String last = sReservedActivities.getLast();
        StringBuilder j = b2.j("Reserve method ");
        j.append(reflectMethod.toString());
        j.append(" to ");
        j.append(last);
        Log.d(TAG, j.toString());
        sReservedActions.get(last).add(new ReservedAction(reflectMethod));
    }

    public static void reserveReflectObject(Object obj) {
        String last = sReservedActivities.getLast();
        StringBuilder j = b2.j("Reserve object ");
        j.append(obj.getClass());
        j.append(" to ");
        j.append(last);
        Log.d(TAG, j.toString());
        sReservedActions.get(last).add(new ReservedAction(obj));
    }

    private boolean verifyPackageInfo(PackageInfo packageInfo, String str, String str2) {
        if (packageInfo.signatures == null) {
            Log.e(TAG, "No signature in package info");
            return false;
        }
        try {
            MessageDigest instance = MessageDigest.getInstance(str);
            byte[] hexStringToByteArray = hexStringToByteArray(str2);
            if (hexStringToByteArray != null) {
                for (int i = 0; i < packageInfo.signatures.length; i++) {
                    Log.d(TAG, "Checking signature " + i);
                    if (!MessageDigest.isEqual(instance.digest(packageInfo.signatures[i].toByteArray()), hexStringToByteArray)) {
                        Log.e(TAG, "Hash code does not match");
                    } else {
                        Log.d(TAG, "Signature passed verification");
                        return true;
                    }
                }
                return false;
            }
            throw new IllegalArgumentException("Invalid hash code");
        } catch (NullPointerException | NoSuchAlgorithmException unused) {
            throw new IllegalArgumentException("Invalid hash algorithm");
        }
    }

    public Class<?> getBridgeClass(String str) {
        try {
            ClassLoader classLoader = this.mBridgeLoader;
            return classLoader.loadClass("org.xwalk.core.internal." + str);
        } catch (ClassNotFoundException unused) {
            return null;
        }
    }

    public Object getBridgeObject(Object obj) {
        try {
            return new ReflectMethod(obj, "getBridge", new Class[0]).invoke(new Object[0]);
        } catch (RuntimeException unused) {
            return null;
        }
    }

    public Object getWrapperObject(Object obj) {
        try {
            return new ReflectMethod(obj, "getWrapper", new Class[0]).invoke(new Object[0]);
        } catch (RuntimeException unused) {
            return null;
        }
    }

    public boolean isSharedMode() {
        return this.mBridgeContext != null;
    }

    public static class ReservedAction {
        public Object[] mArguments;
        public Class<?> mClass;
        public ReflectMethod mMethod;
        public Object mObject;

        public ReservedAction(Object obj) {
            this.mObject = obj;
        }

        public ReservedAction(Class<?> cls) {
            this.mClass = cls;
        }

        public ReservedAction(ReflectMethod reflectMethod) {
            this.mMethod = reflectMethod;
            if (reflectMethod.getArguments() != null) {
                this.mArguments = Arrays.copyOf(reflectMethod.getArguments(), reflectMethod.getArguments().length);
            }
        }
    }
}
