package org.xwalk.core;

import android.app.DownloadManager;
import android.content.Context;
import android.content.pm.PackageManager;
import android.database.Cursor;
import android.net.Uri;
import android.os.AsyncTask;
import android.os.Environment;
import android.os.SystemClock;
import android.util.Log;
import androidx.base.b2;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.Arrays;
import org.chromium.content.common.ContentSwitches;

public class XWalkLibraryLoader {
    private static final String DEFAULT_DOWNLOAD_FILE_NAME = "xwalk_download.tmp";
    private static final String DOWNLOAD_WITHOUT_NOTIFICATION = "android.permission.DOWNLOAD_WITHOUT_NOTIFICATION";
    private static final String TAG = "XWalkLib";
    private static AsyncTask<Void, Integer, Integer> sActiveTask;

    public interface ActivateListener {
        void onActivateCompleted();

        void onActivateFailed();

        void onActivateStarted();
    }

    public static class ActivateTask extends AsyncTask<Void, Integer, Integer> {
        public ActivateListener mListener;

        public ActivateTask(ActivateListener activateListener) {
            this.mListener = activateListener;
        }

        public void onPreExecute() {
            Log.d(XWalkLibraryLoader.TAG, "ActivateTask started");
            AsyncTask unused = XWalkLibraryLoader.sActiveTask = this;
            this.mListener.onActivateStarted();
        }

        public Integer doInBackground(Void... voidArr) {
            if (XWalkCoreWrapper.getInstance() != null) {
                return -1;
            }
            return Integer.valueOf(XWalkCoreWrapper.attachXWalkCore());
        }

        public void onPostExecute(Integer num) {
            if (num.intValue() == 1) {
                XWalkCoreWrapper.dockXWalkCore();
            }
            Log.d(XWalkLibraryLoader.TAG, "ActivateTask finished, " + num);
            AsyncTask unused = XWalkLibraryLoader.sActiveTask = null;
            if (num.intValue() > 1) {
                this.mListener.onActivateFailed();
            } else {
                this.mListener.onActivateCompleted();
            }
        }
    }

    public interface DecompressListener {
        void onDecompressCancelled();

        void onDecompressCompleted();

        void onDecompressStarted();
    }

    public static class DecompressTask extends AsyncTask<Void, Integer, Integer> {
        public boolean mIsCompressed;
        public boolean mIsDecompressed;
        public DecompressListener mListener;

        public DecompressTask(DecompressListener decompressListener) {
            this.mListener = decompressListener;
        }

        public void onPreExecute() {
            Log.d(XWalkLibraryLoader.TAG, "DecompressTask started");
            AsyncTask unused = XWalkLibraryLoader.sActiveTask = this;
            boolean isLibraryCompressed = XWalkDecompressor.isLibraryCompressed();
            this.mIsCompressed = isLibraryCompressed;
            if (isLibraryCompressed) {
                boolean z = false;
                int i = XWalkEnvironment.getSharedPreferences().getInt("version", 0);
                if (i > 0 && i == 8) {
                    z = true;
                }
                this.mIsDecompressed = z;
            }
            if (this.mIsCompressed && !this.mIsDecompressed) {
                this.mListener.onDecompressStarted();
            }
        }

        public Integer doInBackground(Void... voidArr) {
            if (this.mIsCompressed && !this.mIsDecompressed) {
                if (!XWalkDecompressor.decompressLibrary()) {
                    return 1;
                }
                XWalkEnvironment.getSharedPreferences().edit().putInt("version", 8).apply();
            }
            return 0;
        }

        public void onCancelled(Integer num) {
            Log.d(XWalkLibraryLoader.TAG, "DecompressTask cancelled");
            AsyncTask unused = XWalkLibraryLoader.sActiveTask = null;
            this.mListener.onDecompressCancelled();
        }

        public void onPostExecute(Integer num) {
            Log.d(XWalkLibraryLoader.TAG, "DecompressTask finished, " + num);
            if (num.intValue() == 0) {
                AsyncTask unused = XWalkLibraryLoader.sActiveTask = null;
                this.mListener.onDecompressCompleted();
                return;
            }
            throw new RuntimeException("Decompression Failed");
        }
    }

    public interface DownloadListener {
        void onDownloadCancelled();

        void onDownloadCompleted(Uri uri);

        void onDownloadFailed(int i, int i2);

        void onDownloadStarted();

        void onDownloadUpdated(int i);
    }

    public static class DownloadManagerTask extends AsyncTask<Void, Integer, Integer> {
        private static final int MAX_PAUSED_COUNT = 6000;
        private static final int QUERY_INTERVAL_MS = 100;
        private Context mContext;
        private long mDownloadId;
        private DownloadManager mDownloadManager;
        private String mDownloadUrl;
        private DownloadListener mListener;

        public DownloadManagerTask(DownloadListener downloadListener, Context context, String str) {
            this.mListener = downloadListener;
            this.mContext = context;
            this.mDownloadUrl = str;
            this.mDownloadManager = (DownloadManager) context.getSystemService(ContentSwitches.SWITCH_DOWNLOAD_PROCESS);
        }

        private boolean isSilentDownload() {
            try {
                return Arrays.asList(this.mContext.getPackageManager().getPackageInfo(this.mContext.getPackageName(), 4096).requestedPermissions).contains(XWalkLibraryLoader.DOWNLOAD_WITHOUT_NOTIFICATION);
            } catch (PackageManager.NameNotFoundException | NullPointerException unused) {
                return false;
            }
        }

        public void onPreExecute() {
            StringBuilder j = b2.j("DownloadManagerTask started, ");
            j.append(this.mDownloadUrl);
            Log.d(XWalkLibraryLoader.TAG, j.toString());
            AsyncTask unused = XWalkLibraryLoader.sActiveTask = this;
            try {
                String name = new File(new URL(this.mDownloadUrl).getPath()).getName();
                if (name.isEmpty()) {
                    name = XWalkLibraryLoader.DEFAULT_DOWNLOAD_FILE_NAME;
                }
                File file = new File(this.mContext.getExternalFilesDir(Environment.DIRECTORY_DOWNLOADS), name);
                if (file.isFile()) {
                    file.delete();
                }
                DownloadManager.Request request = new DownloadManager.Request(Uri.parse(this.mDownloadUrl));
                request.setDestinationInExternalFilesDir(this.mContext, Environment.DIRECTORY_DOWNLOADS, name);
                if (isSilentDownload()) {
                    request.setNotificationVisibility(2);
                }
                this.mDownloadId = this.mDownloadManager.enqueue(request);
                this.mListener.onDownloadStarted();
            } catch (NullPointerException | MalformedURLException unused2) {
                StringBuilder j2 = b2.j("Invalid download URL ");
                j2.append(this.mDownloadUrl);
                Log.e(XWalkLibraryLoader.TAG, j2.toString());
                this.mDownloadUrl = null;
            }
        }

        public Integer doInBackground(Void... voidArr) {
            if (this.mDownloadUrl == null) {
                return 16;
            }
            DownloadManager.Query filterById = new DownloadManager.Query().setFilterById(this.mDownloadId);
            int i = 0;
            while (!isCancelled()) {
                try {
                    Thread.sleep(100);
                    Cursor query = this.mDownloadManager.query(filterById);
                    if (query != null && query.moveToFirst()) {
                        int columnIndex = query.getColumnIndex("total_size");
                        int columnIndex2 = query.getColumnIndex("bytes_so_far");
                        int i2 = query.getInt(columnIndex);
                        int i3 = query.getInt(columnIndex2);
                        if (i2 > 0) {
                            publishProgress(Integer.valueOf(i3), Integer.valueOf(i2));
                        }
                        int i4 = query.getInt(query.getColumnIndex("status"));
                        if (i4 == 16 || i4 == 8) {
                            return Integer.valueOf(i4);
                        }
                        if (i4 == 4 && (i = i + 1) == MAX_PAUSED_COUNT) {
                            return Integer.valueOf(i4);
                        }
                    }
                } catch (InterruptedException unused) {
                }
            }
            return 2;
        }

        public void onCancelled(Integer num) {
            this.mDownloadManager.remove(this.mDownloadId);
            Log.d(XWalkLibraryLoader.TAG, "DownloadManagerTask cancelled");
            AsyncTask unused = XWalkLibraryLoader.sActiveTask = null;
            this.mListener.onDownloadCancelled();
        }

        public void onPostExecute(Integer num) {
            Cursor query;
            Cursor query2;
            Log.d(XWalkLibraryLoader.TAG, "DownloadManagerTask finished, " + num);
            AsyncTask unused = XWalkLibraryLoader.sActiveTask = null;
            if (num.intValue() == 8) {
                Uri uriForDownloadedFile = this.mDownloadManager.getUriForDownloadedFile(this.mDownloadId);
                StringBuilder j = b2.j("Uri for downloaded file:");
                j.append(uriForDownloadedFile.toString());
                Log.d(XWalkLibraryLoader.TAG, j.toString());
                if (uriForDownloadedFile.getScheme().equals("content") && (query2 = this.mDownloadManager.query(new DownloadManager.Query().setFilterById(this.mDownloadId))) != null && query2.moveToFirst()) {
                    int columnIndex = query2.getColumnIndex("local_filename");
                    StringBuilder j2 = b2.j("file://");
                    j2.append(query2.getString(columnIndex));
                    uriForDownloadedFile = Uri.parse(j2.toString());
                }
                this.mListener.onDownloadCompleted(uriForDownloadedFile);
                return;
            }
            int i = 1000;
            if (num.intValue() == 16 && (query = this.mDownloadManager.query(new DownloadManager.Query().setFilterById(this.mDownloadId))) != null && query.moveToFirst()) {
                i = query.getInt(query.getColumnIndex("reason"));
            }
            this.mListener.onDownloadFailed(num.intValue(), i);
        }

        public void onProgressUpdate(Integer... numArr) {
            StringBuilder j = b2.j("DownloadManagerTask updated: ");
            int i = 0;
            j.append(numArr[0]);
            j.append("/");
            j.append(numArr[1]);
            Log.d(XWalkLibraryLoader.TAG, j.toString());
            if (numArr[1].intValue() > 0) {
                double intValue = (double) numArr[0].intValue();
                Double.isNaN(intValue);
                double intValue2 = (double) numArr[1].intValue();
                Double.isNaN(intValue2);
                i = (int) ((intValue * 100.0d) / intValue2);
            }
            this.mListener.onDownloadUpdated(i);
        }
    }

    public static class HttpDownloadTask extends AsyncTask<Void, Integer, Integer> {
        private static final int DOWNLOAD_FAILED = -1;
        private static final int DOWNLOAD_SUCCESS = 0;
        private static final int UPDATE_INTERVAL_MS = 500;
        private static final String XWALK_DOWNLOAD_DIR = "xwalk_download";
        private Context mContext;
        private String mDownloadUrl;
        private File mDownloadedFile;
        private DownloadListener mListener;
        private long mProgressUpdateTime;

        public HttpDownloadTask(DownloadListener downloadListener, Context context, String str) {
            this.mListener = downloadListener;
            this.mContext = context;
            this.mDownloadUrl = str;
        }

        public void onPreExecute() {
            StringBuilder j = b2.j("HttpDownloadTask started, ");
            j.append(this.mDownloadUrl);
            Log.d(XWalkLibraryLoader.TAG, j.toString());
            AsyncTask unused = XWalkLibraryLoader.sActiveTask = this;
            try {
                String name = new File(new URL(this.mDownloadUrl).getPath()).getName();
                if (name.isEmpty()) {
                    name = XWalkLibraryLoader.DEFAULT_DOWNLOAD_FILE_NAME;
                }
                this.mDownloadedFile = new File(this.mContext.getDir(XWALK_DOWNLOAD_DIR, 0), name);
                this.mListener.onDownloadStarted();
            } catch (NullPointerException | MalformedURLException unused2) {
                StringBuilder j2 = b2.j("Invalid download URL ");
                j2.append(this.mDownloadUrl);
                Log.e(XWalkLibraryLoader.TAG, j2.toString());
                this.mDownloadUrl = null;
            }
        }

        /* JADX WARNING: Removed duplicated region for block: B:51:0x00d5 A[SYNTHETIC, Splitter:B:51:0x00d5] */
        /* JADX WARNING: Removed duplicated region for block: B:56:0x00dd A[Catch:{ IOException -> 0x00d9 }] */
        /* JADX WARNING: Removed duplicated region for block: B:58:0x00e2  */
        /* JADX WARNING: Removed duplicated region for block: B:64:0x00ea A[SYNTHETIC, Splitter:B:64:0x00ea] */
        /* JADX WARNING: Removed duplicated region for block: B:69:0x00f2 A[Catch:{ IOException -> 0x00ee }] */
        /* JADX WARNING: Removed duplicated region for block: B:71:0x00f7  */
        public Integer doInBackground(Void... voidArr) {
            InputStream inputStream;
            HttpURLConnection httpURLConnection;
            Throwable th;
            if (this.mDownloadUrl == null) {
                return -1;
            }
            if (this.mDownloadedFile.exists()) {
                this.mDownloadedFile.delete();
            }
            FileOutputStream fileOutputStream = null;
            try {
                httpURLConnection = (HttpURLConnection) new URL(this.mDownloadUrl).openConnection();
                try {
                    httpURLConnection.connect();
                    if (httpURLConnection.getResponseCode() != 200) {
                        Log.e(XWalkLibraryLoader.TAG, "Server returned HTTP " + httpURLConnection.getResponseCode() + " " + httpURLConnection.getResponseMessage());
                        httpURLConnection.disconnect();
                        return -1;
                    }
                    int contentLength = httpURLConnection.getContentLength();
                    inputStream = httpURLConnection.getInputStream();
                    try {
                        FileOutputStream fileOutputStream2 = new FileOutputStream(this.mDownloadedFile);
                        try {
                            byte[] bArr = new byte[4096];
                            long j = 0;
                            while (true) {
                                int read = inputStream.read(bArr);
                                if (read == -1) {
                                    fileOutputStream2.flush();
                                    try {
                                        fileOutputStream2.close();
                                        inputStream.close();
                                    } catch (IOException unused) {
                                    }
                                    httpURLConnection.disconnect();
                                    return 0;
                                } else if (isCancelled()) {
                                    try {
                                        fileOutputStream2.close();
                                        inputStream.close();
                                    } catch (IOException unused2) {
                                    }
                                    httpURLConnection.disconnect();
                                    return -1;
                                } else {
                                    j += (long) read;
                                    fileOutputStream2.write(bArr, 0, read);
                                    long uptimeMillis = SystemClock.uptimeMillis();
                                    if (uptimeMillis - this.mProgressUpdateTime > 500) {
                                        this.mProgressUpdateTime = uptimeMillis;
                                        publishProgress(Integer.valueOf((int) j), Integer.valueOf(contentLength));
                                    }
                                }
                            }
                        } catch (Exception unused3) {
                            fileOutputStream = fileOutputStream2;
                            if (fileOutputStream != null) {
                            }
                            if (inputStream != null) {
                            }
                            if (httpURLConnection != null) {
                            }
                            return -1;
                        } catch (Throwable th2) {
                            th = th2;
                            fileOutputStream = fileOutputStream2;
                            if (fileOutputStream != null) {
                            }
                            if (inputStream != null) {
                            }
                            if (httpURLConnection != null) {
                            }
                            throw th;
                        }
                    } catch (Exception unused4) {
                        if (fileOutputStream != null) {
                        }
                        if (inputStream != null) {
                        }
                        if (httpURLConnection != null) {
                        }
                        return -1;
                    } catch (Throwable th3) {
                        th = th3;
                        if (fileOutputStream != null) {
                        }
                        if (inputStream != null) {
                        }
                        if (httpURLConnection != null) {
                        }
                        throw th;
                    }
                } catch (Exception unused5) {
                    inputStream = null;
                    if (fileOutputStream != null) {
                    }
                    if (inputStream != null) {
                    }
                    if (httpURLConnection != null) {
                    }
                    return -1;
                } catch (Throwable th4) {
                    th = th4;
                    inputStream = null;
                    if (fileOutputStream != null) {
                    }
                    if (inputStream != null) {
                    }
                    if (httpURLConnection != null) {
                    }
                    throw th;
                }
            } catch (Exception unused6) {
                httpURLConnection = null;
                inputStream = null;
                if (fileOutputStream != null) {
                    try {
                        fileOutputStream.close();
                    } catch (IOException unused7) {
                        if (httpURLConnection != null) {
                        }
                        return -1;
                    }
                }
                if (inputStream != null) {
                    inputStream.close();
                }
                if (httpURLConnection != null) {
                    httpURLConnection.disconnect();
                }
                return -1;
            } catch (Throwable th5) {
                th = th5;
                httpURLConnection = null;
                inputStream = null;
                if (fileOutputStream != null) {
                    try {
                        fileOutputStream.close();
                    } catch (IOException unused8) {
                        if (httpURLConnection != null) {
                            httpURLConnection.disconnect();
                        }
                        throw th;
                    }
                }
                if (inputStream != null) {
                    inputStream.close();
                }
                if (httpURLConnection != null) {
                }
                throw th;
            }
        }

        public void onCancelled(Integer num) {
            Log.d(XWalkLibraryLoader.TAG, "HttpDownloadTask cancelled");
            AsyncTask unused = XWalkLibraryLoader.sActiveTask = null;
            this.mListener.onDownloadCancelled();
        }

        public void onPostExecute(Integer num) {
            Log.d(XWalkLibraryLoader.TAG, "HttpDownloadTask finished, " + num);
            AsyncTask unused = XWalkLibraryLoader.sActiveTask = null;
            if (num.intValue() == 0) {
                this.mListener.onDownloadCompleted(Uri.fromFile(this.mDownloadedFile));
            } else {
                this.mListener.onDownloadFailed(-1, 0);
            }
        }

        public void onProgressUpdate(Integer... numArr) {
            StringBuilder j = b2.j("HttpDownloadTask updated: ");
            int i = 0;
            j.append(numArr[0]);
            j.append("/");
            j.append(numArr[1]);
            Log.d(XWalkLibraryLoader.TAG, j.toString());
            if (numArr[1].intValue() > 0) {
                double intValue = (double) numArr[0].intValue();
                Double.isNaN(intValue);
                double intValue2 = (double) numArr[1].intValue();
                Double.isNaN(intValue2);
                i = (int) ((intValue * 100.0d) / intValue2);
            }
            this.mListener.onDownloadUpdated(i);
        }
    }

    public static boolean cancelDecompress() {
        AsyncTask<Void, Integer, Integer> asyncTask = sActiveTask;
        return asyncTask != null && (asyncTask instanceof DecompressTask) && asyncTask.cancel(true);
    }

    public static boolean cancelDownloadManager() {
        AsyncTask<Void, Integer, Integer> asyncTask = sActiveTask;
        return asyncTask != null && (asyncTask instanceof DownloadManagerTask) && asyncTask.cancel(true);
    }

    public static boolean cancelHttpDownload() {
        AsyncTask<Void, Integer, Integer> asyncTask = sActiveTask;
        return asyncTask != null && (asyncTask instanceof HttpDownloadTask) && asyncTask.cancel(true);
    }

    public static void finishInit(Context context) {
        XWalkCoreWrapper.handlePostInit(context.getClass().getName());
    }

    public static int getLibraryStatus() {
        return XWalkCoreWrapper.getCoreStatus();
    }

    public static boolean isDownloading() {
        AsyncTask<Void, Integer, Integer> asyncTask = sActiveTask;
        return asyncTask != null && ((asyncTask instanceof DownloadManagerTask) || (asyncTask instanceof HttpDownloadTask));
    }

    public static boolean isInitializing() {
        AsyncTask<Void, Integer, Integer> asyncTask = sActiveTask;
        return asyncTask != null && ((asyncTask instanceof DecompressTask) || (asyncTask instanceof ActivateTask));
    }

    public static boolean isLibraryReady() {
        return XWalkCoreWrapper.getInstance() != null;
    }

    public static boolean isSharedLibrary() {
        return XWalkCoreWrapper.getInstance().isSharedMode();
    }

    public static void prepareToInit(Context context) {
        XWalkEnvironment.init(context);
        XWalkCoreWrapper.handlePreInit(context.getClass().getName());
    }

    public static void startActivate(ActivateListener activateListener) {
        new ActivateTask(activateListener).execute(new Void[0]);
    }

    public static void startDecompress(DecompressListener decompressListener) {
        new DecompressTask(decompressListener).execute(new Void[0]);
    }

    public static void startDownloadManager(DownloadListener downloadListener, Context context, String str) {
        new DownloadManagerTask(downloadListener, context, str).execute(new Void[0]);
    }

    public static void startHttpDownload(DownloadListener downloadListener, Context context, String str) {
        new HttpDownloadTask(downloadListener, context, str).execute(new Void[0]);
    }
}
