package org.xwalk.core.extension;

import android.util.Log;
import androidx.base.b2;
import java.lang.reflect.AccessibleObject;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Member;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import org.json.JSONArray;
import org.json.JSONObject;

public class ReflectionHelper {
    private static final String TAG = "JsStubReflectHelper";
    public static Set<Class<?>> primitives = new HashSet();
    private Map<String, String> bindingClasses = new HashMap();
    private Map<String, ReflectionHelper> constructorReflections = new HashMap();
    private MemberInfo entryPoint = null;
    private String[] eventList = null;
    private Map<String, MemberInfo> members = new HashMap();
    private Class<?> myClass;

    public class MemberInfo {
        public AccessibleObject accesser;
        public boolean isEntryPoint;
        public boolean isStatic;
        public boolean isWritable;
        public String javaName;
        public String jsName;
        public Class<?> mainClass;
        public MemberType type;
        public boolean withPromise;
        public String wrapArgs = "";
        public String wrapReturns = "";

        public MemberInfo() {
        }
    }

    public enum MemberType {
        JS_METHOD,
        JS_PROPERTY,
        JS_CONSTRUCTOR
    }

    public ReflectionHelper(Class<?> cls) {
        this.myClass = cls;
        init();
    }

    public static boolean isSerializable(Object obj) {
        Class<?> cls = obj.getClass();
        return cls.isPrimitive() || primitives.contains(cls) || (obj instanceof String) || (obj instanceof Map) || (obj instanceof JSONArray) || (obj instanceof JSONObject);
    }

    public static String objToJSON(Object obj) {
        if (obj == null) {
            return "null";
        }
        Object serializableObject = toSerializableObject(obj);
        boolean z = serializableObject instanceof String;
        String obj2 = serializableObject.toString();
        return z ? JSONObject.quote(obj2) : obj2;
    }

    public static void registerHandlers(ReflectionHelper reflectionHelper, MessageHandler messageHandler, Object obj) {
        if (!(reflectionHelper == null || messageHandler == null)) {
            for (String str : reflectionHelper.getMembers().keySet()) {
                MemberInfo memberInfo = reflectionHelper.getMembers().get(str);
                messageHandler.register(memberInfo.jsName, memberInfo.javaName, memberInfo.type, obj, reflectionHelper);
            }
        }
    }

    public static Object toSerializableObject(Object obj) {
        int i = 0;
        if (obj.getClass().isArray()) {
            JSONArray jSONArray = new JSONArray();
            Object[] objArr = (Object[]) obj;
            while (i < objArr.length) {
                try {
                    jSONArray.put(i, toSerializableObject(objArr[i]));
                } catch (Exception e) {
                    e.printStackTrace();
                }
                i++;
            }
            return jSONArray;
        } else if (isSerializable(obj)) {
            return obj;
        } else {
            try {
                String str = (String) obj.getClass().getMethod("toJSONString", new Class[0]).invoke(obj, new Object[0]);
                if (str.trim().charAt(0) == '[') {
                    return new JSONArray(str);
                }
                return new JSONObject(str);
            } catch (Exception unused) {
                Log.w(TAG, "No serialization method: \"toJSONString\", or errors happened.");
                try {
                    Class<?> cls = obj.getClass();
                    JSONObject jSONObject = new JSONObject();
                    Field[] fields = cls.getFields();
                    int length = fields.length;
                    while (i < length) {
                        Field field = fields[i];
                        jSONObject.put(field.getName(), field.get(obj));
                        i++;
                    }
                    return jSONObject;
                } catch (Exception e2) {
                    Log.e(TAG, "Field to serialize object to JSON.");
                    e2.printStackTrace();
                    return null;
                }
            }
        }
    }

    public Object[] getArgsFromJson(XWalkExternalExtension xWalkExternalExtension, int i, Method method, JSONArray jSONArray) {
        int i2;
        Exception e;
        Class<?>[] parameterTypes = method.getParameterTypes();
        Object[] objArr = new Object[parameterTypes.length];
        boolean isStatic = Modifier.isStatic(method.getModifiers());
        int i3 = 0;
        while (i3 < parameterTypes.length) {
            try {
                Class<?> cls = parameterTypes[i3];
                if (!isStatic || !cls.equals(JsContextInfo.class)) {
                    objArr[i3] = jSONArray.get(i3);
                    i3++;
                } else {
                    i2 = i3 + 1;
                    try {
                        objArr[i3] = new JsContextInfo(i, xWalkExternalExtension, method.getClass(), Integer.toString(0));
                    } catch (Exception e2) {
                        e = e2;
                    }
                    i3 = i2;
                    i3++;
                }
            } catch (Exception e3) {
                i2 = i3;
                e = e3;
                e.printStackTrace();
                i3 = i2;
                i3++;
            }
        }
        return objArr;
    }

    public ReflectionHelper getConstructorReflection(String str) {
        if (!this.constructorReflections.containsKey(str)) {
            return null;
        }
        return this.constructorReflections.get(str);
    }

    public MemberInfo getEntryPoint() {
        return this.entryPoint;
    }

    public String[] getEventList() {
        return this.eventList;
    }

    public void getMemberInfo(AccessibleObject[] accessibleObjectArr, MemberType memberType) {
        for (AccessibleObject accessibleObject : accessibleObjectArr) {
            if (accessibleObject.isAnnotationPresent(JsApi.class) || accessibleObject.isAnnotationPresent(JsConstructor.class)) {
                MemberInfo memberInfo = new MemberInfo();
                Member member = (Member) accessibleObject;
                String name = member.getName();
                memberInfo.javaName = name;
                memberInfo.accesser = accessibleObject;
                memberInfo.isStatic = Modifier.isStatic(member.getModifiers());
                if (accessibleObject.isAnnotationPresent(JsApi.class)) {
                    JsApi jsApi = (JsApi) accessibleObject.getAnnotation(JsApi.class);
                    if (memberType != MemberType.JS_PROPERTY || !jsApi.isEventList()) {
                        memberInfo.type = memberType;
                        memberInfo.isWritable = jsApi.isWritable();
                        memberInfo.isEntryPoint = jsApi.isEntryPoint();
                        memberInfo.withPromise = jsApi.withPromise();
                        memberInfo.jsName = name;
                        memberInfo.wrapArgs = jsApi.wrapArgs();
                        memberInfo.wrapReturns = jsApi.wrapReturns();
                    } else if (!((Field) accessibleObject).getType().equals(String[].class)) {
                        Log.w(TAG, "Invalid type for Supported JS event list" + name);
                    } else {
                        try {
                            this.eventList = (String[]) ((Field) accessibleObject).get(null);
                        } catch (IllegalAccessException | IllegalArgumentException e) {
                            e.printStackTrace();
                        }
                    }
                } else if (accessibleObject.isAnnotationPresent(JsConstructor.class)) {
                    if (memberType != MemberType.JS_METHOD) {
                        Log.w(TAG, "Invalid @JsConstructor on non-function member:" + name);
                    } else {
                        JsConstructor jsConstructor = (JsConstructor) accessibleObject.getAnnotation(JsConstructor.class);
                        memberInfo.type = MemberType.JS_CONSTRUCTOR;
                        memberInfo.isEntryPoint = jsConstructor.isEntryPoint();
                        Class<?> mainClass = jsConstructor.mainClass();
                        memberInfo.mainClass = mainClass;
                        memberInfo.withPromise = false;
                        if (mainClass != null) {
                            memberInfo.jsName = mainClass.getSimpleName();
                            this.bindingClasses.put(memberInfo.mainClass.getName(), memberInfo.jsName);
                            this.constructorReflections.put(memberInfo.jsName, new ReflectionHelper(memberInfo.mainClass));
                        }
                    }
                }
                if (memberInfo.isEntryPoint) {
                    if (this.entryPoint != null) {
                        StringBuilder j = b2.j("Entry point already exist, try to set another:");
                        j.append(memberInfo.jsName);
                        Log.w(TAG, j.toString());
                    } else if (memberType != MemberType.JS_PROPERTY || isBindingClass(((Field) memberInfo.accesser).getType())) {
                        this.entryPoint = memberInfo;
                    } else {
                        Log.w(TAG, "Invalid entry point setting on property:" + name);
                    }
                }
                if (this.members.containsKey(memberInfo.jsName)) {
                    StringBuilder j2 = b2.j("Conflict namespace - ");
                    j2.append(memberInfo.jsName);
                    Log.w(TAG, j2.toString());
                } else {
                    this.members.put(memberInfo.jsName, memberInfo);
                }
            }
        }
    }

    public Map<String, MemberInfo> getMembers() {
        return this.members;
    }

    public Object getProperty(Object obj, String str) {
        if (!hasProperty(str).booleanValue()) {
            throw new NoSuchFieldException(b2.c("No such property:", str));
        } else if (getMemberInfo(str).isStatic || this.myClass.isInstance(obj)) {
            Field field = (Field) this.members.get(str).accesser;
            if (!field.isAccessible()) {
                field.setAccessible(true);
            }
            return field.get(obj);
        } else {
            throw new InvocationTargetException(new Exception(b2.c("Invalid target to set property:", str)));
        }
    }

    public ReflectionHelper getReflectionByBindingClass(String str) {
        if (!this.bindingClasses.containsKey(str)) {
            return null;
        }
        return getConstructorReflection(this.bindingClasses.get(str));
    }

    public Object handleMessage(MessageInfo messageInfo, Object obj) {
        JSONArray jSONArray;
        Object obj2;
        try {
            String cmd = messageInfo.getCmd();
            if (messageInfo.getBinaryArgs() != null) {
                jSONArray = new JSONArray();
                jSONArray.put(messageInfo.getBinaryArgs());
                jSONArray.put(messageInfo.getCallbackId());
            } else {
                jSONArray = messageInfo.getArgs();
            }
            String jsName = messageInfo.getJsName();
            XWalkExternalExtension extension = messageInfo.getExtension();
            int instanceId = messageInfo.getInstanceId();
            char c = 65535;
            switch (cmd.hashCode()) {
                case -633190737:
                    if (cmd.equals("invokeNative")) {
                        c = 0;
                        break;
                    }
                    break;
                case 996179031:
                    if (cmd.equals("setProperty")) {
                        c = 3;
                        break;
                    }
                    break;
                case 1084758859:
                    if (cmd.equals("getProperty")) {
                        c = 2;
                        break;
                    }
                    break;
                case 1811874389:
                    if (cmd.equals("newInstance")) {
                        c = 1;
                        break;
                    }
                    break;
            }
            if (c == 0) {
                obj2 = invokeMethod(extension, instanceId, obj, jsName, jSONArray);
            } else if (c == 1) {
                obj2 = Boolean.valueOf(messageInfo.getInstanceHelper().addBindingObject(messageInfo.getObjectId(), (BindingObject) invokeMethod(extension, instanceId, obj, jsName, jSONArray)));
            } else if (c == 2) {
                obj2 = getProperty(obj, jsName);
            } else if (c != 3) {
                Log.w(TAG, "Unsupported cmd: " + cmd);
                return null;
            } else {
                setProperty(obj, jsName, jSONArray.get(0));
                return null;
            }
            return obj2;
        } catch (Exception e) {
            StringBuilder j = b2.j("Invalid message, error msg:\n");
            j.append(e.toString());
            Log.w(TAG, j.toString());
            e.printStackTrace();
            return null;
        }
    }

    public Boolean hasMethod(String str) {
        if (!this.members.containsKey(str)) {
            return Boolean.FALSE;
        }
        MemberType memberType = this.members.get(str).type;
        return Boolean.valueOf(memberType == MemberType.JS_METHOD || memberType == MemberType.JS_CONSTRUCTOR);
    }

    public Boolean hasProperty(String str) {
        if (!this.members.containsKey(str)) {
            return Boolean.FALSE;
        }
        return Boolean.valueOf(this.members.get(str).type == MemberType.JS_PROPERTY);
    }

    public void init() {
        primitives.add(Byte.class);
        primitives.add(Integer.class);
        primitives.add(Long.class);
        primitives.add(Double.class);
        primitives.add(Character.class);
        primitives.add(Float.class);
        primitives.add(Boolean.class);
        primitives.add(Short.class);
        getMemberInfo(this.myClass.getDeclaredMethods(), MemberType.JS_METHOD);
        getMemberInfo(this.myClass.getDeclaredFields(), MemberType.JS_PROPERTY);
    }

    public Object invokeMethod(XWalkExternalExtension xWalkExternalExtension, int i, Object obj, String str, JSONArray jSONArray) {
        if (!hasMethod(str).booleanValue()) {
            throw new NoSuchMethodException(b2.c("No such method:", str));
        } else if (getMemberInfo(str).isStatic || this.myClass.isInstance(obj)) {
            Method method = (Method) this.members.get(str).accesser;
            if (!method.isAccessible()) {
                method.setAccessible(true);
            }
            return method.invoke(obj, getArgsFromJson(xWalkExternalExtension, i, method, jSONArray));
        } else {
            throw new InvocationTargetException(new Exception(b2.c("Invalid target to set property:", str)));
        }
    }

    public boolean isBindingClass(Class<?> cls) {
        return BindingObject.class.isAssignableFrom(cls);
    }

    public boolean isEventSupported(String str) {
        if (this.eventList == null) {
            return false;
        }
        int i = 0;
        while (true) {
            String[] strArr = this.eventList;
            if (i >= strArr.length) {
                return false;
            }
            if (strArr[i].equals(str)) {
                return true;
            }
            i++;
        }
    }

    public boolean isInstance(Object obj) {
        return this.myClass.isInstance(obj);
    }

    public void setProperty(Object obj, String str, Object obj2) {
        if (!hasProperty(str).booleanValue()) {
            throw new NoSuchFieldException(b2.c("No such property:", str));
        } else if (getMemberInfo(str).isStatic || this.myClass.isInstance(obj)) {
            Field field = (Field) this.members.get(str).accesser;
            if (!field.isAccessible()) {
                field.setAccessible(true);
            }
            field.set(obj, obj2);
        } else {
            throw new InvocationTargetException(new Exception(b2.c("Invalid target to set property:", str)));
        }
    }

    public MemberInfo getMemberInfo(String str) {
        return this.members.get(str);
    }
}
