package com.google.android.exoplayer2.source.rtsp;

import android.net.Uri;
import android.os.Handler;
import android.util.SparseArray;
import androidx.annotation.Nullable;
import androidx.base.b;
import androidx.base.bs;
import androidx.base.cs;
import androidx.base.ds;
import androidx.base.ko;
import androidx.base.qo;
import androidx.base.tq;
import androidx.base.zr;
import com.google.android.exoplayer2.C;
import com.google.android.exoplayer2.ParserException;
import com.google.android.exoplayer2.source.rtsp.RtspHeaders;
import com.google.android.exoplayer2.source.rtsp.RtspMediaPeriod;
import com.google.android.exoplayer2.source.rtsp.RtspMediaSource;
import com.google.android.exoplayer2.source.rtsp.RtspMessageChannel;
import com.google.android.exoplayer2.source.rtsp.RtspMessageUtil;
import com.google.android.exoplayer2.util.Assertions;
import com.google.android.exoplayer2.util.Util;
import java.io.Closeable;
import java.io.IOException;
import java.net.Socket;
import java.util.ArrayDeque;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.net.SocketFactory;

public final class RtspClient implements Closeable {
    private static final long DEFAULT_RTSP_KEEP_ALIVE_INTERVAL_MS = 30000;
    private boolean hasUpdatedTimelineAndTracks;
    @Nullable
    private KeepAliveMonitor keepAliveMonitor;
    private RtspMessageChannel messageChannel = new RtspMessageChannel(new MessageListener());
    private final MessageSender messageSender = new MessageSender();
    private final SparseArray<RtspRequest> pendingRequests = new SparseArray<>();
    private long pendingSeekPositionUs = C.TIME_UNSET;
    private final ArrayDeque<RtspMediaPeriod.RtpLoadInfo> pendingSetupRtpLoadInfos = new ArrayDeque<>();
    private final PlaybackEventListener playbackEventListener;
    private boolean receivedAuthorizationRequest;
    @Nullable
    private final RtspMessageUtil.RtspAuthUserInfo rtspAuthUserInfo;
    @Nullable
    private RtspAuthenticationInfo rtspAuthenticationInfo;
    @Nullable
    private String sessionId;
    private final SessionInfoListener sessionInfoListener;
    private final Uri uri;
    private final String userAgent;

    public final class KeepAliveMonitor implements Runnable, Closeable {
        private final long intervalMs;
        private boolean isStarted;
        private final Handler keepAliveHandler = Util.createHandlerForCurrentLooper();

        public KeepAliveMonitor(long j) {
            this.intervalMs = j;
        }

        @Override // java.io.Closeable, java.lang.AutoCloseable
        public void close() {
            this.isStarted = false;
            this.keepAliveHandler.removeCallbacks(this);
        }

        public void run() {
            RtspClient.this.messageSender.sendOptionsRequest(RtspClient.this.uri, RtspClient.this.sessionId);
            this.keepAliveHandler.postDelayed(this, this.intervalMs);
        }

        public void start() {
            if (!this.isStarted) {
                this.isStarted = true;
                this.keepAliveHandler.postDelayed(this, this.intervalMs);
            }
        }
    }

    public final class MessageListener implements RtspMessageChannel.MessageListener {
        private final Handler messageHandler = Util.createHandlerForCurrentLooper();

        public MessageListener() {
        }

        /* access modifiers changed from: private */
        /* renamed from: handleRtspMessage */
        public void a(List<String> list) {
            RtspSessionTiming rtspSessionTiming;
            bs<RtspTrackTiming> bsVar;
            RtspResponse parseResponse = RtspMessageUtil.parseResponse(list);
            int parseInt = Integer.parseInt((String) Assertions.checkNotNull(parseResponse.headers.get(RtspHeaders.CSEQ)));
            RtspRequest rtspRequest = (RtspRequest) RtspClient.this.pendingRequests.get(parseInt);
            if (rtspRequest != null) {
                RtspClient.this.pendingRequests.remove(parseInt);
                int i = rtspRequest.method;
                try {
                    int i2 = parseResponse.status;
                    if (i2 != 200) {
                        if (i2 == 401) {
                            if (RtspClient.this.rtspAuthUserInfo != null && !RtspClient.this.receivedAuthorizationRequest) {
                                String str = parseResponse.headers.get(RtspHeaders.WWW_AUTHENTICATE);
                                if (str != null) {
                                    RtspClient.this.rtspAuthenticationInfo = RtspMessageUtil.parseWwwAuthenticateHeader(str);
                                    RtspClient.this.messageSender.retryLastRequest();
                                    RtspClient.this.receivedAuthorizationRequest = true;
                                    return;
                                }
                                throw new ParserException("Missing WWW-Authenticate header in a 401 response.");
                            }
                        }
                        RtspClient rtspClient = RtspClient.this;
                        String methodString = RtspMessageUtil.toMethodString(i);
                        int i3 = parseResponse.status;
                        StringBuilder sb = new StringBuilder(String.valueOf(methodString).length() + 12);
                        sb.append(methodString);
                        sb.append(" ");
                        sb.append(i3);
                        rtspClient.dispatchRtspError(new RtspMediaSource.RtspPlaybackException(sb.toString()));
                        return;
                    }
                    switch (i) {
                        case 1:
                        case 3:
                        case 7:
                        case 8:
                        case 9:
                        case 11:
                        case 12:
                            return;
                        case 2:
                            onDescribeResponseReceived(new RtspDescribeResponse(i2, SessionDescriptionParser.parse(parseResponse.messageBody)));
                            return;
                        case 4:
                            onOptionsResponseReceived(new RtspOptionsResponse(i2, RtspMessageUtil.parsePublicHeader(parseResponse.headers.get(RtspHeaders.PUBLIC))));
                            return;
                        case 5:
                            onPauseResponseReceived();
                            return;
                        case 6:
                            String str2 = parseResponse.headers.get("range");
                            if (str2 == null) {
                                rtspSessionTiming = RtspSessionTiming.DEFAULT;
                            } else {
                                rtspSessionTiming = RtspSessionTiming.parseTiming(str2);
                            }
                            String str3 = parseResponse.headers.get(RtspHeaders.RTP_INFO);
                            if (str3 == null) {
                                bsVar = bs.of();
                            } else {
                                bsVar = RtspTrackTiming.parseTrackTiming(str3);
                            }
                            onPlayResponseReceived(new RtspPlayResponse(parseResponse.status, rtspSessionTiming, bsVar));
                            return;
                        case 10:
                            String str4 = parseResponse.headers.get(RtspHeaders.SESSION);
                            String str5 = parseResponse.headers.get("transport");
                            if (str4 == null || str5 == null) {
                                throw new ParserException();
                            }
                            onSetupResponseReceived(new RtspSetupResponse(parseResponse.status, RtspMessageUtil.parseSessionHeader(str4), str5));
                            return;
                        default:
                            throw new IllegalStateException();
                    }
                } catch (ParserException e) {
                    RtspClient.this.dispatchRtspError(new RtspMediaSource.RtspPlaybackException(e));
                }
            }
        }

        private void onDescribeResponseReceived(RtspDescribeResponse rtspDescribeResponse) {
            RtspSessionTiming rtspSessionTiming;
            String str = rtspDescribeResponse.sessionDescription.attributes.get("range");
            try {
                SessionInfoListener sessionInfoListener = RtspClient.this.sessionInfoListener;
                if (str != null) {
                    rtspSessionTiming = RtspSessionTiming.parseTiming(str);
                } else {
                    rtspSessionTiming = RtspSessionTiming.DEFAULT;
                }
                sessionInfoListener.onSessionTimelineUpdated(rtspSessionTiming, RtspClient.buildTrackList(rtspDescribeResponse.sessionDescription, RtspClient.this.uri));
                RtspClient.this.hasUpdatedTimelineAndTracks = true;
            } catch (ParserException e) {
                RtspClient.this.sessionInfoListener.onSessionTimelineRequestFailed("SDP format error.", e);
            }
        }

        private void onOptionsResponseReceived(RtspOptionsResponse rtspOptionsResponse) {
            if (RtspClient.this.keepAliveMonitor == null) {
                if (RtspClient.serverSupportsDescribe(rtspOptionsResponse.supportedMethods)) {
                    RtspClient.this.messageSender.sendDescribeRequest(RtspClient.this.uri, RtspClient.this.sessionId);
                } else {
                    RtspClient.this.sessionInfoListener.onSessionTimelineRequestFailed("DESCRIBE not supported.", null);
                }
            }
        }

        private void onPauseResponseReceived() {
            if (RtspClient.this.pendingSeekPositionUs != C.TIME_UNSET) {
                RtspClient rtspClient = RtspClient.this;
                rtspClient.startPlayback(C.usToMs(rtspClient.pendingSeekPositionUs));
            }
        }

        private void onPlayResponseReceived(RtspPlayResponse rtspPlayResponse) {
            if (RtspClient.this.keepAliveMonitor == null) {
                RtspClient rtspClient = RtspClient.this;
                rtspClient.keepAliveMonitor = new KeepAliveMonitor(30000);
                RtspClient.this.keepAliveMonitor.start();
            }
            RtspClient.this.playbackEventListener.onPlaybackStarted(C.msToUs(rtspPlayResponse.sessionTiming.startTimeMs), rtspPlayResponse.trackTimingList);
            RtspClient.this.pendingSeekPositionUs = C.TIME_UNSET;
        }

        private void onSetupResponseReceived(RtspSetupResponse rtspSetupResponse) {
            RtspClient.this.sessionId = rtspSetupResponse.sessionHeader.sessionId;
            RtspClient.this.continueSetupRtspTrack();
        }

        @Override // com.google.android.exoplayer2.source.rtsp.RtspMessageChannel.MessageListener
        public /* synthetic */ void onReceivingFailed(Exception exc) {
            qo.a(this, exc);
        }

        @Override // com.google.android.exoplayer2.source.rtsp.RtspMessageChannel.MessageListener
        public void onRtspMessageReceived(List<String> list) {
            this.messageHandler.post(new ko(this, list));
        }

        @Override // com.google.android.exoplayer2.source.rtsp.RtspMessageChannel.MessageListener
        public /* synthetic */ void onSendingFailed(List list, Exception exc) {
            qo.b(this, list, exc);
        }
    }

    public final class MessageSender {
        private int cSeq;
        private RtspRequest lastRequest;

        private MessageSender() {
        }

        private RtspRequest getRequestWithCommonHeaders(int i, @Nullable String str, Map<String, String> map, Uri uri) {
            RtspHeaders.Builder builder = new RtspHeaders.Builder();
            int i2 = this.cSeq;
            this.cSeq = i2 + 1;
            builder.add(RtspHeaders.CSEQ, String.valueOf(i2));
            builder.add(RtspHeaders.USER_AGENT, RtspClient.this.userAgent);
            if (str != null) {
                builder.add(RtspHeaders.SESSION, str);
            }
            if (RtspClient.this.rtspAuthenticationInfo != null) {
                Assertions.checkStateNotNull(RtspClient.this.rtspAuthUserInfo);
                try {
                    builder.add(RtspHeaders.AUTHORIZATION, RtspClient.this.rtspAuthenticationInfo.getAuthorizationHeaderValue(RtspClient.this.rtspAuthUserInfo, uri, i));
                } catch (ParserException e) {
                    RtspClient.this.dispatchRtspError(new RtspMediaSource.RtspPlaybackException(e));
                }
            }
            builder.addAll(map);
            return new RtspRequest(uri, i, builder.build(), "");
        }

        private void sendRequest(RtspRequest rtspRequest) {
            int parseInt = Integer.parseInt((String) Assertions.checkNotNull(rtspRequest.headers.get(RtspHeaders.CSEQ)));
            Assertions.checkState(RtspClient.this.pendingRequests.get(parseInt) == null);
            RtspClient.this.pendingRequests.append(parseInt, rtspRequest);
            RtspClient.this.messageChannel.send(RtspMessageUtil.serializeRequest(rtspRequest));
            this.lastRequest = rtspRequest;
        }

        public void retryLastRequest() {
            Assertions.checkStateNotNull(this.lastRequest);
            cs<String, String> asMultiMap = this.lastRequest.headers.asMultiMap();
            HashMap hashMap = new HashMap();
            for (String str : asMultiMap.keySet()) {
                if (!str.equals(RtspHeaders.CSEQ) && !str.equals(RtspHeaders.USER_AGENT) && !str.equals(RtspHeaders.SESSION) && !str.equals(RtspHeaders.AUTHORIZATION)) {
                    hashMap.put(str, (String) tq.t(asMultiMap.get((Object) str)));
                }
            }
            sendRequest(getRequestWithCommonHeaders(this.lastRequest.method, RtspClient.this.sessionId, hashMap, this.lastRequest.uri));
        }

        public void sendDescribeRequest(Uri uri, @Nullable String str) {
            sendRequest(getRequestWithCommonHeaders(2, str, ds.of(), uri));
        }

        public void sendOptionsRequest(Uri uri, @Nullable String str) {
            sendRequest(getRequestWithCommonHeaders(4, str, ds.of(), uri));
        }

        public void sendPauseRequest(Uri uri, String str) {
            sendRequest(getRequestWithCommonHeaders(5, str, ds.of(), uri));
        }

        public void sendPlayRequest(Uri uri, long j, String str) {
            sendRequest(getRequestWithCommonHeaders(6, str, ds.of("range", RtspSessionTiming.getOffsetStartTimeTiming(j)), uri));
        }

        public void sendSetupRequest(Uri uri, String str, @Nullable String str2) {
            sendRequest(getRequestWithCommonHeaders(10, str2, ds.of("transport", str), uri));
        }

        public void sendTeardownRequest(Uri uri, String str) {
            sendRequest(getRequestWithCommonHeaders(12, str, ds.of(), uri));
        }
    }

    public interface PlaybackEventListener {
        void onPlaybackError(RtspMediaSource.RtspPlaybackException rtspPlaybackException);

        void onPlaybackStarted(long j, bs<RtspTrackTiming> bsVar);

        void onRtspSetupCompleted();
    }

    public interface SessionInfoListener {
        void onSessionTimelineRequestFailed(String str, @Nullable Throwable th);

        void onSessionTimelineUpdated(RtspSessionTiming rtspSessionTiming, bs<RtspMediaTrack> bsVar);
    }

    public RtspClient(SessionInfoListener sessionInfoListener2, PlaybackEventListener playbackEventListener2, String str, Uri uri2) {
        this.sessionInfoListener = sessionInfoListener2;
        this.playbackEventListener = playbackEventListener2;
        this.uri = RtspMessageUtil.removeUserInfo(uri2);
        this.rtspAuthUserInfo = RtspMessageUtil.parseUserInfo(uri2);
        this.userAgent = str;
    }

    /* access modifiers changed from: private */
    public static bs<RtspMediaTrack> buildTrackList(SessionDescription sessionDescription, Uri uri2) {
        b.i(4, "initialCapacity");
        Object[] objArr = new Object[4];
        int i = 0;
        boolean z = false;
        for (int i2 = 0; i2 < sessionDescription.mediaDescriptionList.size(); i2++) {
            MediaDescription mediaDescription = sessionDescription.mediaDescriptionList.get(i2);
            if (RtpPayloadFormat.isFormatSupported(mediaDescription)) {
                RtspMediaTrack rtspMediaTrack = new RtspMediaTrack(mediaDescription, uri2);
                int i3 = i + 1;
                if (objArr.length < i3) {
                    objArr = Arrays.copyOf(objArr, zr.b.a(objArr.length, i3));
                } else {
                    if (z) {
                        objArr = (Object[]) objArr.clone();
                    }
                    objArr[i] = rtspMediaTrack;
                    i++;
                }
                z = false;
                objArr[i] = rtspMediaTrack;
                i++;
            }
        }
        return bs.asImmutableList(objArr, i);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void continueSetupRtspTrack() {
        RtspMediaPeriod.RtpLoadInfo pollFirst = this.pendingSetupRtpLoadInfos.pollFirst();
        if (pollFirst == null) {
            this.playbackEventListener.onRtspSetupCompleted();
        } else {
            this.messageSender.sendSetupRequest(pollFirst.getTrackUri(), pollFirst.getTransport(), this.sessionId);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void dispatchRtspError(Throwable th) {
        RtspMediaSource.RtspPlaybackException rtspPlaybackException;
        if (th instanceof RtspMediaSource.RtspPlaybackException) {
            rtspPlaybackException = (RtspMediaSource.RtspPlaybackException) th;
        } else {
            rtspPlaybackException = new RtspMediaSource.RtspPlaybackException(th);
        }
        if (this.hasUpdatedTimelineAndTracks) {
            this.playbackEventListener.onPlaybackError(rtspPlaybackException);
        } else {
            this.sessionInfoListener.onSessionTimelineRequestFailed(tq.D(th.getMessage()), th);
        }
    }

    private static Socket getSocket(Uri uri2) {
        Assertions.checkArgument(uri2.getHost() != null);
        return SocketFactory.getDefault().createSocket((String) Assertions.checkNotNull(uri2.getHost()), uri2.getPort() > 0 ? uri2.getPort() : RtspMessageChannel.DEFAULT_RTSP_PORT);
    }

    /* access modifiers changed from: private */
    public static boolean serverSupportsDescribe(List<Integer> list) {
        return list.isEmpty() || list.contains(2);
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        KeepAliveMonitor keepAliveMonitor2 = this.keepAliveMonitor;
        if (keepAliveMonitor2 != null) {
            keepAliveMonitor2.close();
            this.keepAliveMonitor = null;
            this.messageSender.sendTeardownRequest(this.uri, (String) Assertions.checkNotNull(this.sessionId));
        }
        this.messageChannel.close();
    }

    public void registerInterleavedDataChannel(int i, RtspMessageChannel.InterleavedBinaryDataListener interleavedBinaryDataListener) {
        this.messageChannel.registerInterleavedBinaryDataListener(i, interleavedBinaryDataListener);
    }

    public void retryWithRtpTcp() {
        try {
            close();
            RtspMessageChannel rtspMessageChannel = new RtspMessageChannel(new MessageListener());
            this.messageChannel = rtspMessageChannel;
            rtspMessageChannel.open(getSocket(this.uri));
            this.sessionId = null;
            this.receivedAuthorizationRequest = false;
            this.rtspAuthenticationInfo = null;
        } catch (IOException e) {
            this.playbackEventListener.onPlaybackError(new RtspMediaSource.RtspPlaybackException(e));
        }
    }

    public void seekToUs(long j) {
        this.messageSender.sendPauseRequest(this.uri, (String) Assertions.checkNotNull(this.sessionId));
        this.pendingSeekPositionUs = j;
    }

    public void setupSelectedTracks(List<RtspMediaPeriod.RtpLoadInfo> list) {
        this.pendingSetupRtpLoadInfos.addAll(list);
        continueSetupRtspTrack();
    }

    public void start() {
        try {
            this.messageChannel.open(getSocket(this.uri));
            this.messageSender.sendOptionsRequest(this.uri, this.sessionId);
        } catch (IOException e) {
            Util.closeQuietly(this.messageChannel);
            throw e;
        }
    }

    public void startPlayback(long j) {
        this.messageSender.sendPlayRequest(this.uri, j, (String) Assertions.checkNotNull(this.sessionId));
    }
}
