package com.google.android.exoplayer2.source.rtsp;

import android.net.Uri;
import androidx.base.tq;
import com.google.android.exoplayer2.ParserException;
import com.google.android.exoplayer2.source.rtsp.MediaDescription;
import com.google.android.exoplayer2.source.rtsp.SessionDescription;
import com.google.android.exoplayer2.util.Assertions;
import com.google.android.exoplayer2.util.Util;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public final class SessionDescriptionParser {
    private static final Pattern ATTRIBUTE_PATTERN = Pattern.compile("([0-9A-Za-z-]+)(?::(.*))?");
    private static final String ATTRIBUTE_TYPE = "a";
    private static final String BANDWIDTH_TYPE = "b";
    private static final String CONNECTION_TYPE = "c";
    private static final String EMAIL_TYPE = "e";
    private static final String INFORMATION_TYPE = "i";
    private static final String KEY_TYPE = "k";
    private static final Pattern MEDIA_DESCRIPTION_PATTERN = Pattern.compile("(\\S+)\\s(\\S+)\\s(\\S+)\\s(\\S+)");
    private static final String MEDIA_TYPE = "m";
    private static final String ORIGIN_TYPE = "o";
    private static final String PHONE_NUMBER_TYPE = "p";
    private static final String REPEAT_TYPE = "r";
    private static final Pattern SDP_LINE_PATTERN = Pattern.compile("([a-z])=\\s?(.+)");
    private static final String SESSION_TYPE = "s";
    private static final String TIMING_TYPE = "t";
    private static final String URI_TYPE = "u";
    private static final String VERSION_TYPE = "v";
    private static final String ZONE_TYPE = "z";

    private SessionDescriptionParser() {
    }

    private static void addMediaDescriptionToSession(SessionDescription.Builder builder, MediaDescription.Builder builder2) {
        try {
            builder.addMediaDescription(builder2.build());
        } catch (IllegalArgumentException | IllegalStateException e) {
            throw new ParserException(e);
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:133:0x01d8, code lost:
        continue;
     */
    public static SessionDescription parse(String str) {
        SessionDescription.Builder builder = new SessionDescription.Builder();
        String[] splitRtspMessageBody = RtspMessageUtil.splitRtspMessageBody(str);
        MediaDescription.Builder builder2 = null;
        for (String str2 : splitRtspMessageBody) {
            if (!"".equals(str2)) {
                Matcher matcher = SDP_LINE_PATTERN.matcher(str2);
                if (!matcher.matches()) {
                    String valueOf = String.valueOf(str2);
                    throw new ParserException(valueOf.length() != 0 ? "Malformed SDP line: ".concat(valueOf) : new String("Malformed SDP line: "));
                }
                String str3 = (String) Assertions.checkNotNull(matcher.group(1));
                String str4 = (String) Assertions.checkNotNull(matcher.group(2));
                char c = 65535;
                switch (str3.hashCode()) {
                    case 97:
                        if (str3.equals(ATTRIBUTE_TYPE)) {
                            c = 11;
                            break;
                        }
                        break;
                    case 98:
                        if (str3.equals(BANDWIDTH_TYPE)) {
                            c = '\b';
                            break;
                        }
                        break;
                    case 99:
                        if (str3.equals(CONNECTION_TYPE)) {
                            c = 7;
                            break;
                        }
                        break;
                    case 101:
                        if (str3.equals(EMAIL_TYPE)) {
                            c = 5;
                            break;
                        }
                        break;
                    case 105:
                        if (str3.equals(INFORMATION_TYPE)) {
                            c = 3;
                            break;
                        }
                        break;
                    case 107:
                        if (str3.equals(KEY_TYPE)) {
                            c = '\n';
                            break;
                        }
                        break;
                    case 109:
                        if (str3.equals(MEDIA_TYPE)) {
                            c = '\f';
                            break;
                        }
                        break;
                    case 111:
                        if (str3.equals(ORIGIN_TYPE)) {
                            c = 1;
                            break;
                        }
                        break;
                    case 112:
                        if (str3.equals("p")) {
                            c = 6;
                            break;
                        }
                        break;
                    case 114:
                        if (str3.equals(REPEAT_TYPE)) {
                            c = '\r';
                            break;
                        }
                        break;
                    case 115:
                        if (str3.equals(SESSION_TYPE)) {
                            c = 2;
                            break;
                        }
                        break;
                    case 116:
                        if (str3.equals(TIMING_TYPE)) {
                            c = '\t';
                            break;
                        }
                        break;
                    case 117:
                        if (str3.equals(URI_TYPE)) {
                            c = 4;
                            break;
                        }
                        break;
                    case 118:
                        if (str3.equals(VERSION_TYPE)) {
                            c = 0;
                            break;
                        }
                        break;
                    case 122:
                        if (str3.equals(ZONE_TYPE)) {
                            c = 14;
                            break;
                        }
                        break;
                }
                switch (c) {
                    case 0:
                        if (SessionDescription.SUPPORTED_SDP_VERSION.equals(str4)) {
                            continue;
                        } else {
                            throw new ParserException(String.format("SDP version %s is not supported.", str4));
                        }
                    case 1:
                        builder.setOrigin(str4);
                        continue;
                    case 2:
                        builder.setSessionName(str4);
                        continue;
                    case 3:
                        if (builder2 != null) {
                            builder2.setMediaTitle(str4);
                            break;
                        } else {
                            builder.setSessionInfo(str4);
                            continue;
                        }
                    case 4:
                        builder.setUri(Uri.parse(str4));
                        continue;
                    case 5:
                        builder.setEmailAddress(str4);
                        continue;
                    case 6:
                        builder.setPhoneNumber(str4);
                        continue;
                    case 7:
                        if (builder2 != null) {
                            builder2.setConnection(str4);
                            break;
                        } else {
                            builder.setConnection(str4);
                            continue;
                        }
                    case '\b':
                        String[] split = Util.split(str4, ":\\s?");
                        Assertions.checkArgument(split.length == 2);
                        int parseInt = Integer.parseInt(split[1]);
                        if (builder2 != null) {
                            builder2.setBitrate(parseInt * 1000);
                            break;
                        } else {
                            builder.setBitrate(parseInt * 1000);
                            continue;
                        }
                    case '\t':
                        builder.setTiming(str4);
                        continue;
                    case '\n':
                        if (builder2 != null) {
                            builder2.setKey(str4);
                            break;
                        } else {
                            builder.setKey(str4);
                            continue;
                        }
                    case 11:
                        Matcher matcher2 = ATTRIBUTE_PATTERN.matcher(str4);
                        if (matcher2.matches()) {
                            String str5 = (String) Assertions.checkNotNull(matcher2.group(1));
                            String D = tq.D(matcher2.group(2));
                            if (builder2 != null) {
                                builder2.addAttribute(str5, D);
                                break;
                            } else {
                                builder.addAttribute(str5, D);
                                continue;
                            }
                        } else {
                            String valueOf2 = String.valueOf(str2);
                            throw new ParserException(valueOf2.length() != 0 ? "Malformed Attribute line: ".concat(valueOf2) : new String("Malformed Attribute line: "));
                        }
                    case '\f':
                        if (builder2 != null) {
                            addMediaDescriptionToSession(builder, builder2);
                        }
                        builder2 = parseMediaDescriptionLine(str4);
                        continue;
                }
            }
        }
        if (builder2 != null) {
            addMediaDescriptionToSession(builder, builder2);
        }
        try {
            return builder.build();
        } catch (IllegalArgumentException | IllegalStateException e) {
            throw new ParserException(e);
        }
    }

    private static MediaDescription.Builder parseMediaDescriptionLine(String str) {
        Matcher matcher = MEDIA_DESCRIPTION_PATTERN.matcher(str);
        if (!matcher.matches()) {
            String valueOf = String.valueOf(str);
            throw new ParserException(valueOf.length() != 0 ? "Malformed SDP media description line: ".concat(valueOf) : new String("Malformed SDP media description line: "));
        }
        try {
            return new MediaDescription.Builder((String) Assertions.checkNotNull(matcher.group(1)), Integer.parseInt((String) Assertions.checkNotNull(matcher.group(2))), (String) Assertions.checkNotNull(matcher.group(3)), Integer.parseInt((String) Assertions.checkNotNull(matcher.group(4))));
        } catch (NumberFormatException e) {
            String valueOf2 = String.valueOf(str);
            throw new ParserException(valueOf2.length() != 0 ? "Malformed SDP media description line: ".concat(valueOf2) : new String("Malformed SDP media description line: "), e);
        }
    }
}
