package org.chromium.content.browser.accessibility.captioning;

import android.graphics.Color;
import android.graphics.Typeface;
import com.google.android.exoplayer2.C;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.util.EnumSet;
import java.util.Locale;
import java.util.Map;
import java.util.WeakHashMap;
import org.chromium.base.VisibleForTesting;
import org.chromium.content.browser.accessibility.captioning.SystemCaptioningBridge;

public class CaptioningChangeDelegate {
    @VisibleForTesting
    public static final String DEFAULT_CAPTIONING_PREF_VALUE = "";
    private static final String FONT_STYLE_ITALIC = "italic";
    private final Map<SystemCaptioningBridge.SystemCaptioningBridgeListener, Boolean> mListeners = new WeakHashMap();
    private String mTextTrackBackgroundColor;
    private String mTextTrackFontFamily;
    private String mTextTrackFontStyle;
    private String mTextTrackFontVariant;
    private String mTextTrackTextColor;
    private String mTextTrackTextShadow;
    private String mTextTrackTextSize;
    private boolean mTextTracksEnabled;

    public enum ClosedCaptionEdgeAttribute {
        NONE(""),
        OUTLINE("%2$s %2$s 0 %1$s, -%2$s -%2$s 0 %1$s, %2$s -%2$s 0 %1$s, -%2$s %2$s 0 %1$s"),
        DROP_SHADOW("%1$s %2$s %2$s 0.1em"),
        RAISED("-%2$s -%2$s 0 %1$s"),
        DEPRESSED("%2$s %2$s 0 %1$s");
        
        private static String sDefaultEdgeColor = "silver";
        private static String sEdgeColor;
        private static String sShadowOffset = "0.05em";
        private final String mTextShadow;

        private ClosedCaptionEdgeAttribute(String str) {
            this.mTextShadow = str;
        }

        public static ClosedCaptionEdgeAttribute fromSystemEdgeAttribute(Integer num, String str) {
            if (num == null) {
                return NONE;
            }
            if (str == null || str.isEmpty()) {
                sEdgeColor = sDefaultEdgeColor;
            } else {
                sEdgeColor = str;
            }
            int intValue = num.intValue();
            if (intValue == 1) {
                return OUTLINE;
            }
            if (intValue == 2) {
                return DROP_SHADOW;
            }
            if (intValue == 3) {
                return RAISED;
            }
            if (intValue != 4) {
                return NONE;
            }
            return DEPRESSED;
        }

        public static void setDefaultEdgeColor(String str) {
            sDefaultEdgeColor = str;
        }

        public static void setShadowOffset(String str) {
            sShadowOffset = str;
        }

        public String getTextShadow() {
            return String.format(this.mTextShadow, sEdgeColor, sShadowOffset);
        }
    }

    /* JADX WARN: Init of enum SANS_SERIF can be incorrect */
    /* JADX WARN: Init of enum SANS_SERIF_CONDENSED can be incorrect */
    /* JADX WARN: Init of enum SANS_SERIF_MONOSPACE can be incorrect */
    /* JADX WARN: Init of enum SERIF can be incorrect */
    /* JADX WARN: Init of enum SERIF_MONOSPACE can be incorrect */
    /* JADX WARN: Init of enum SANS_SERIF_SMALLCAPS can be incorrect */
    /* JADX WARN: Init of enum MONOSPACE can be incorrect */
    public enum ClosedCaptionFont {
        DEFAULT("", EnumSet.noneOf(Flags.class)),
        SANS_SERIF(C.SANS_SERIF_NAME, EnumSet.of(r3)),
        SANS_SERIF_CONDENSED("sans-serif-condensed", EnumSet.of(r3)),
        SANS_SERIF_MONOSPACE("sans-serif-monospace", EnumSet.of(r3, r8)),
        SERIF(C.SERIF_NAME, EnumSet.of(r11)),
        SERIF_MONOSPACE("serif-monospace", EnumSet.of(r11, r8)),
        CASUAL("casual", EnumSet.noneOf(Flags.class)),
        CURSIVE("cursive", EnumSet.noneOf(Flags.class)),
        SANS_SERIF_SMALLCAPS("sans-serif-smallcaps", EnumSet.of(r3)),
        MONOSPACE("monospace", EnumSet.of(r8));
        
        @VisibleForTesting
        public final EnumSet<Flags> mFlags;
        private final String mFontFamily;

        @VisibleForTesting
        public enum Flags {
            SANS_SERIF,
            SERIF,
            MONOSPACE
        }

        /* access modifiers changed from: public */
        static {
            Flags flags = Flags.SANS_SERIF;
            Flags flags2 = Flags.MONOSPACE;
            Flags flags3 = Flags.SERIF;
        }

        private ClosedCaptionFont(String str, EnumSet enumSet) {
            this.mFontFamily = str;
            this.mFlags = enumSet;
        }

        private static boolean belongsToFontFamily(Typeface typeface, ClosedCaptionFont closedCaptionFont) {
            return Typeface.create(closedCaptionFont.getFontFamily(), typeface.getStyle()).equals(typeface);
        }

        public static ClosedCaptionFont fromSystemFont(Typeface typeface) {
            if (typeface == null) {
                return DEFAULT;
            }
            ClosedCaptionFont[] values = values();
            for (int i = 0; i < 10; i++) {
                ClosedCaptionFont closedCaptionFont = values[i];
                if (belongsToFontFamily(typeface, closedCaptionFont)) {
                    return closedCaptionFont;
                }
            }
            return DEFAULT;
        }

        public String getFontFamily() {
            return this.mFontFamily;
        }
    }

    public static String androidColorToCssColor(Integer num) {
        if (num == null) {
            return "";
        }
        DecimalFormat decimalFormat = new DecimalFormat("#.##", new DecimalFormatSymbols(Locale.US));
        double alpha = (double) Color.alpha(num.intValue());
        Double.isNaN(alpha);
        return String.format("rgba(%s, %s, %s, %s)", Integer.valueOf(Color.red(num.intValue())), Integer.valueOf(Color.green(num.intValue())), Integer.valueOf(Color.blue(num.intValue())), decimalFormat.format(alpha / 255.0d));
    }

    public static String androidFontScaleToPercentage(float f) {
        return new DecimalFormat("#%", new DecimalFormatSymbols(Locale.US)).format((double) f);
    }

    private void notifySettingsChanged() {
        for (SystemCaptioningBridge.SystemCaptioningBridgeListener systemCaptioningBridgeListener : this.mListeners.keySet()) {
            notifyListener(systemCaptioningBridgeListener);
        }
    }

    public void addListener(SystemCaptioningBridge.SystemCaptioningBridgeListener systemCaptioningBridgeListener) {
        this.mListeners.put(systemCaptioningBridgeListener, null);
    }

    public boolean hasActiveListener() {
        return !this.mListeners.isEmpty();
    }

    public void notifyListener(SystemCaptioningBridge.SystemCaptioningBridgeListener systemCaptioningBridgeListener) {
        boolean z = this.mTextTracksEnabled;
        if (z) {
            systemCaptioningBridgeListener.onSystemCaptioningChanged(new TextTrackSettings(z, this.mTextTrackBackgroundColor, this.mTextTrackFontFamily, this.mTextTrackFontStyle, this.mTextTrackFontVariant, this.mTextTrackTextColor, this.mTextTrackTextShadow, this.mTextTrackTextSize));
        } else {
            systemCaptioningBridgeListener.onSystemCaptioningChanged(new TextTrackSettings());
        }
    }

    public void onEnabledChanged(boolean z) {
        this.mTextTracksEnabled = z;
        notifySettingsChanged();
    }

    public void onFontScaleChanged(float f) {
        this.mTextTrackTextSize = androidFontScaleToPercentage(f);
        notifySettingsChanged();
    }

    public void onLocaleChanged(Locale locale) {
    }

    public void onUserStyleChanged(CaptioningStyle captioningStyle) {
        this.mTextTrackTextColor = androidColorToCssColor(captioningStyle.getForegroundColor());
        this.mTextTrackBackgroundColor = androidColorToCssColor(captioningStyle.getBackgroundColor());
        this.mTextTrackTextShadow = ClosedCaptionEdgeAttribute.fromSystemEdgeAttribute(captioningStyle.getEdgeType(), androidColorToCssColor(captioningStyle.getEdgeColor())).getTextShadow();
        Typeface typeface = captioningStyle.getTypeface();
        this.mTextTrackFontFamily = ClosedCaptionFont.fromSystemFont(typeface).getFontFamily();
        if (typeface == null || !typeface.isItalic()) {
            this.mTextTrackFontStyle = "";
        } else {
            this.mTextTrackFontStyle = "italic";
        }
        this.mTextTrackFontVariant = "";
        notifySettingsChanged();
    }

    public void removeListener(SystemCaptioningBridge.SystemCaptioningBridgeListener systemCaptioningBridgeListener) {
        this.mListeners.remove(systemCaptioningBridgeListener);
    }
}
