package org.chromium.net;

import androidx.base.b2;
import java.lang.reflect.Method;
import java.security.NoSuchAlgorithmException;
import java.security.PrivateKey;
import java.security.Signature;
import java.security.interfaces.ECKey;
import java.security.interfaces.RSAKey;
import java.security.interfaces.RSAPrivateKey;
import org.chromium.base.Log;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;

@JNINamespace("net::android")
public class AndroidKeyStore {
    private static final String TAG = "AndroidKeyStore";

    @CalledByNative
    private static byte[] getECKeyOrder(PrivateKey privateKey) {
        if (privateKey instanceof ECKey) {
            return ((ECKey) privateKey).getParams().getOrder().toByteArray();
        }
        Log.w(TAG, "Not an ECKey instance!", new Object[0]);
        return null;
    }

    @CalledByNative
    private static Object getOpenSSLEngineForPrivateKey(PrivateKey privateKey) {
        try {
            Class<?> cls = Class.forName("org.apache.harmony.xnet.provider.jsse.OpenSSLEngine");
            Object openSSLKeyForPrivateKey = getOpenSSLKeyForPrivateKey(privateKey);
            if (openSSLKeyForPrivateKey == null) {
                return null;
            }
            try {
                Method declaredMethod = openSSLKeyForPrivateKey.getClass().getDeclaredMethod("getEngine", new Class[0]);
                try {
                    declaredMethod.setAccessible(true);
                    try {
                        Object invoke = declaredMethod.invoke(openSSLKeyForPrivateKey, new Object[0]);
                        if (invoke == null) {
                            Log.e(TAG, "getEngine() returned null", new Object[0]);
                        }
                        if (cls.isInstance(invoke)) {
                            return invoke;
                        }
                        Log.e(TAG, "Engine is not an OpenSSLEngine instance, its class name is:" + invoke.getClass().getCanonicalName(), new Object[0]);
                        return null;
                    } finally {
                        declaredMethod.setAccessible(false);
                    }
                } catch (Exception e) {
                    Log.e(TAG, "Exception while trying to retrieve OpenSSLEngine object: " + e, new Object[0]);
                    return null;
                }
            } catch (Exception e2) {
                Log.e(TAG, "No getEngine() method on OpenSSLKey member:" + e2, new Object[0]);
                return null;
            }
        } catch (Exception e3) {
            Log.e(TAG, "Cannot find system OpenSSLEngine class: " + e3, new Object[0]);
            return null;
        }
    }

    /* JADX INFO: finally extract failed */
    @CalledByNative
    private static long getOpenSSLHandleForPrivateKey(PrivateKey privateKey) {
        Object openSSLKeyForPrivateKey = getOpenSSLKeyForPrivateKey(privateKey);
        if (openSSLKeyForPrivateKey == null) {
            return 0;
        }
        try {
            Method declaredMethod = openSSLKeyForPrivateKey.getClass().getDeclaredMethod("getPkeyContext", new Class[0]);
            try {
                declaredMethod.setAccessible(true);
                try {
                    long longValue = ((Number) declaredMethod.invoke(openSSLKeyForPrivateKey, new Object[0])).longValue();
                    declaredMethod.setAccessible(false);
                    if (longValue == 0) {
                        Log.e(TAG, "getPkeyContext() returned null", new Object[0]);
                    }
                    return longValue;
                } catch (Throwable th) {
                    declaredMethod.setAccessible(false);
                    throw th;
                }
            } catch (Exception e) {
                Log.e(TAG, "Exception while trying to retrieve system EVP_PKEY handle: " + e, new Object[0]);
                return 0;
            }
        } catch (Exception e2) {
            Log.e(TAG, "No getPkeyContext() method on OpenSSLKey member:" + e2, new Object[0]);
            return 0;
        }
    }

    private static Object getOpenSSLKeyForPrivateKey(PrivateKey privateKey) {
        if (privateKey == null) {
            Log.e(TAG, "privateKey == null", new Object[0]);
            return null;
        } else if (!(privateKey instanceof RSAPrivateKey)) {
            Log.e(TAG, "does not implement RSAPrivateKey", new Object[0]);
            return null;
        } else {
            try {
                Class<?> cls = Class.forName("org.apache.harmony.xnet.provider.jsse.OpenSSLRSAPrivateKey");
                if (!cls.isInstance(privateKey)) {
                    StringBuilder j = b2.j("Private key is not an OpenSSLRSAPrivateKey instance, its class name is:");
                    j.append(privateKey.getClass().getCanonicalName());
                    Log.e(TAG, j.toString(), new Object[0]);
                    return null;
                }
                try {
                    Method declaredMethod = cls.getDeclaredMethod("getOpenSSLKey", new Class[0]);
                    declaredMethod.setAccessible(true);
                    try {
                        Object invoke = declaredMethod.invoke(privateKey, new Object[0]);
                        if (invoke != null) {
                            return invoke;
                        }
                        Log.e(TAG, "getOpenSSLKey() returned null", new Object[0]);
                        return null;
                    } finally {
                        declaredMethod.setAccessible(false);
                    }
                } catch (Exception e) {
                    Log.e(TAG, "Exception while trying to retrieve system EVP_PKEY handle: " + e, new Object[0]);
                    return null;
                }
            } catch (Exception e2) {
                Log.e(TAG, "Cannot find system OpenSSLRSAPrivateKey class: " + e2, new Object[0]);
                return null;
            }
        }
    }

    @CalledByNative
    private static int getPrivateKeyType(PrivateKey privateKey) {
        String algorithm = privateKey.getAlgorithm();
        if ("RSA".equalsIgnoreCase(algorithm)) {
            return 0;
        }
        return "EC".equalsIgnoreCase(algorithm) ? 2 : 255;
    }

    @CalledByNative
    private static byte[] getRSAKeyModulus(PrivateKey privateKey) {
        if (privateKey instanceof RSAKey) {
            return ((RSAKey) privateKey).getModulus().toByteArray();
        }
        Log.w(TAG, "Not a RSAKey instance!", new Object[0]);
        return null;
    }

    @CalledByNative
    private static byte[] rawSignDigestWithPrivateKey(PrivateKey privateKey, byte[] bArr) {
        Signature signature;
        try {
            String algorithm = privateKey.getAlgorithm();
            if ("RSA".equalsIgnoreCase(algorithm)) {
                signature = Signature.getInstance("NONEwithRSA");
            } else {
                if ("EC".equalsIgnoreCase(algorithm)) {
                    signature = Signature.getInstance("NONEwithECDSA");
                }
                signature = null;
            }
        } catch (NoSuchAlgorithmException unused) {
        }
        if (signature == null) {
            StringBuilder j = b2.j("Unsupported private key algorithm: ");
            j.append(privateKey.getAlgorithm());
            Log.e(TAG, j.toString(), new Object[0]);
            return null;
        }
        try {
            signature.initSign(privateKey);
            signature.update(bArr);
            return signature.sign();
        } catch (Exception e) {
            StringBuilder j2 = b2.j("Exception while signing message with ");
            j2.append(privateKey.getAlgorithm());
            j2.append(" private key: ");
            j2.append(e);
            Log.e(TAG, j2.toString(), new Object[0]);
            return null;
        }
    }
}
